//
//  Copyright (c) 2003 Launchbird Design Systems, Inc.
//  All rights reserved.
//  
//  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
//    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
//    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
//  
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
//  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
//  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
//  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
//  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//  
//  
//  Overview:
//  
//    Performs a radix 2 Fast Fourier Transform.
//    The FFT architecture is pipelined on a rank basis; each rank has its own butterfly and ranks are
//    isolated from each other using memory interleavers.  This FFT can perform calcualations on continuous
//    streaming data (one data set right after another).  More over, inputs and outputs are passed in pairs,
//    doubling the bandwidth.  For instance, a 2048 point FFT can perform a transform every 1024 cycles.
//  
//  Interface:
//  
//    Synchronization:
//      clock_c  : Clock input.
//      enable_i : Synchronous enable.
//      reset_i  : Synchronous reset.
//  
//    Inputs:
//      sync_i     : Input sync pulse must occur one frame prior to data input.
//      data_0_i   : Input data 0.  Width is 2 * precision.  Real on the left, imag on the right.
//      data_1_i   : Input data 1.  Width is 2 * precision.  Real on the left, imag on the right.
//  
//    Outputs:
//      sync_o     : Output sync pulse occurs one frame before data output.
//      data_0_o   : Output data 0.  Width is 2 * precision.  Real on the left, imag on the right.
//      data_1_o   : Output data 1.  Width is 2 * precision.  Real on the left, imag on the right.
//  
//  Built In Parameters:
//  
//    FFT Points   = 256
//    Precision    = 16
//  
//  
//  
//  
//  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
//  
//  Build Date : Fri Aug 22 08:43:45 CDT 2003
//  
//  Interface
//  
//    Build Name    : cf_fft_256_16
//    Clock Domains : clock_c  
//    Vector Input  : enable_i(1)
//    Vector Input  : reset_i(1)
//    Vector Input  : sync_i(1)
//    Vector Input  : data_0_i(32)
//    Vector Input  : data_1_i(32)
//    Vector Output : sync_o(1)
//    Vector Output : data_0_o(32)
//    Vector Output : data_1_o(32)
//  
//  
//  

`timescale 1 ns / 1 ns

module cf_fft_256_16 (clock_c, enable_i, reset_i, sync_i, data_0_i, data_1_i, sync_o, data_0_o, data_1_o);
input  clock_c;
input  enable_i;
input  reset_i;
input  sync_i;
input  [31:0] data_0_i;
input  [31:0] data_1_i;
output sync_o;
output [31:0] data_0_o;
output [31:0] data_1_o;
wire   n1;
wire   [31:0] n2;
wire   [31:0] n3;
cf_fft_256_16_1 s1 (clock_c, sync_i, data_0_i, data_1_i, enable_i, reset_i, n1, n2, n3);
assign sync_o = n1;
assign data_0_o = n2;
assign data_1_o = n3;
endmodule

module cf_fft_256_16_1 (clock_c, i1, i2, i3, i4, i5, o1, o2, o3);
input  clock_c;
input  i1;
input  [31:0] i2;
input  [31:0] i3;
input  i4;
input  i5;
output o1;
output [31:0] o2;
output [31:0] o3;
wire   s1_1;
wire   [31:0] s1_2;
wire   [31:0] s1_3;
wire   s2_1;
wire   [31:0] s2_2;
wire   [31:0] s2_3;
cf_fft_256_16_20 s1 (clock_c, i1, i2, i3, i4, i5, s1_1, s1_2, s1_3);
cf_fft_256_16_2 s2 (clock_c, s1_1, s1_2, s1_3, i4, i5, s2_1, s2_2, s2_3);
assign o3 = s2_3;
assign o2 = s2_2;
assign o1 = s2_1;
endmodule

module cf_fft_256_16_2 (clock_c, i1, i2, i3, i4, i5, o1, o2, o3);
input  clock_c;
input  i1;
input  [31:0] i2;
input  [31:0] i3;
input  i4;
input  i5;
output o1;
output [31:0] o2;
output [31:0] o3;
wire   s1_1;
wire   [31:0] s1_2;
wire   [31:0] s1_3;
wire   s2_1;
wire   [31:0] s2_2;
wire   [31:0] s2_3;
wire   s3_1;
wire   [31:0] s3_2;
wire   [31:0] s3_3;
wire   s4_1;
wire   [31:0] s4_2;
wire   [31:0] s4_3;
wire   s5_1;
wire   [31:0] s5_2;
wire   [31:0] s5_3;
wire   s6_1;
wire   [31:0] s6_2;
wire   [31:0] s6_3;
wire   s7_1;
wire   [31:0] s7_2;
wire   [31:0] s7_3;
wire   s8_1;
wire   [31:0] s8_2;
wire   [31:0] s8_3;
cf_fft_256_16_16 s1 (clock_c, s3_1, s3_2, s3_3, i4, i5, s1_1, s1_2, s1_3);
cf_fft_256_16_14 s2 (clock_c, s1_1, s1_2, s1_3, i4, i5, s2_1, s2_2, s2_3);
cf_fft_256_16_12 s3 (clock_c, s4_1, s4_2, s4_3, i4, i5, s3_1, s3_2, s3_3);
cf_fft_256_16_10 s4 (clock_c, s5_1, s5_2, s5_3, i4, i5, s4_1, s4_2, s4_3);
cf_fft_256_16_8 s5 (clock_c, s6_1, s6_2, s6_3, i4, i5, s5_1, s5_2, s5_3);
cf_fft_256_16_6 s6 (clock_c, s7_1, s7_2, s7_3, i4, i5, s6_1, s6_2, s6_3);
cf_fft_256_16_4 s7 (clock_c, s8_1, s8_2, s8_3, i4, i5, s7_1, s7_2, s7_3);
cf_fft_256_16_3 s8 (clock_c, i1, i2, i3, i4, i5, s8_1, s8_2, s8_3);
assign o3 = s2_3;
assign o2 = s2_2;
assign o1 = s2_1;
endmodule

module cf_fft_256_16_3 (clock_c, i1, i2, i3, i4, i5, o1, o2, o3);
input  clock_c;
input  i1;
input  [31:0] i2;
input  [31:0] i3;
input  i4;
input  i5;
output o1;
output [31:0] o2;
output [31:0] o3;
wire   n1;
wire   [63:0] n2;
reg    n3;
reg    n4;
reg    n5;
reg    n6;
wire   [5:0] n7;
reg    [5:0] n8;
reg    [5:0] n9;
reg    [5:0] n10;
reg    [5:0] n11;
wire   n12;
reg    n13;
reg    n14;
reg    n15;
reg    n16;
wire   n17;
wire   [1:0] n18;
wire   [31:0] n19;
wire   [31:0] n20;
wire   [31:0] n21;
wire   [31:0] n22;
wire   [31:0] n23;
wire   [31:0] n24;
wire   [31:0] s25_1;
wire   [31:0] s25_2;
wire   s26_1;
wire   s27_1;
wire   s27_2;
wire   [63:0] s27_3;
wire   [63:0] s28_1;
wire   [6:0] s29_1;
wire   s29_2;
assign n1 = 1'b0;
assign n2 = {s25_1, s25_2};
initial n3 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n3 <= 1'b0;
  else if (i4 == 1'b1)
    n3 <= s29_2;
initial n4 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n4 <= 1'b0;
  else if (i4 == 1'b1)
    n4 <= n3;
initial n5 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n5 <= 1'b0;
  else if (i4 == 1'b1)
    n5 <= n4;
initial n6 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n6 <= 1'b0;
  else if (i4 == 1'b1)
    n6 <= n5;
assign n7 = {s29_1[6],
  s29_1[5],
  s29_1[4],
  s29_1[3],
  s29_1[2],
  s29_1[1]};
initial n8 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n8 <= 6'b000000;
  else if (i4 == 1'b1)
    n8 <= n7;
initial n9 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n9 <= 6'b000000;
  else if (i4 == 1'b1)
    n9 <= n8;
initial n10 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n10 <= 6'b000000;
  else if (i4 == 1'b1)
    n10 <= n9;
initial n11 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n11 <= 6'b000000;
  else if (i4 == 1'b1)
    n11 <= n10;
assign n12 = s29_1[0];
initial n13 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n13 <= 1'b0;
  else if (i4 == 1'b1)
    n13 <= n12;
initial n14 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n14 <= 1'b0;
  else if (i4 == 1'b1)
    n14 <= n13;
initial n15 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n15 <= 1'b0;
  else if (i4 == 1'b1)
    n15 <= n14;
initial n16 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n16 <= 1'b0;
  else if (i4 == 1'b1)
    n16 <= n15;
assign n17 = ~n16;
assign n18 = {s27_2, s27_1};
assign n19 = {s27_3[63],
  s27_3[62],
  s27_3[61],
  s27_3[60],
  s27_3[59],
  s27_3[58],
  s27_3[57],
  s27_3[56],
  s27_3[55],
  s27_3[54],
  s27_3[53],
  s27_3[52],
  s27_3[51],
  s27_3[50],
  s27_3[49],
  s27_3[48],
  s27_3[47],
  s27_3[46],
  s27_3[45],
  s27_3[44],
  s27_3[43],
  s27_3[42],
  s27_3[41],
  s27_3[40],
  s27_3[39],
  s27_3[38],
  s27_3[37],
  s27_3[36],
  s27_3[35],
  s27_3[34],
  s27_3[33],
  s27_3[32]};
assign n20 = {s27_3[31],
  s27_3[30],
  s27_3[29],
  s27_3[28],
  s27_3[27],
  s27_3[26],
  s27_3[25],
  s27_3[24],
  s27_3[23],
  s27_3[22],
  s27_3[21],
  s27_3[20],
  s27_3[19],
  s27_3[18],
  s27_3[17],
  s27_3[16],
  s27_3[15],
  s27_3[14],
  s27_3[13],
  s27_3[12],
  s27_3[11],
  s27_3[10],
  s27_3[9],
  s27_3[8],
  s27_3[7],
  s27_3[6],
  s27_3[5],
  s27_3[4],
  s27_3[3],
  s27_3[2],
  s27_3[1],
  s27_3[0]};
assign n21 = {s28_1[63],
  s28_1[62],
  s28_1[61],
  s28_1[60],
  s28_1[59],
  s28_1[58],
  s28_1[57],
  s28_1[56],
  s28_1[55],
  s28_1[54],
  s28_1[53],
  s28_1[52],
  s28_1[51],
  s28_1[50],
  s28_1[49],
  s28_1[48],
  s28_1[47],
  s28_1[46],
  s28_1[45],
  s28_1[44],
  s28_1[43],
  s28_1[42],
  s28_1[41],
  s28_1[40],
  s28_1[39],
  s28_1[38],
  s28_1[37],
  s28_1[36],
  s28_1[35],
  s28_1[34],
  s28_1[33],
  s28_1[32]};
assign n22 = {s28_1[31],
  s28_1[30],
  s28_1[29],
  s28_1[28],
  s28_1[27],
  s28_1[26],
  s28_1[25],
  s28_1[24],
  s28_1[23],
  s28_1[22],
  s28_1[21],
  s28_1[20],
  s28_1[19],
  s28_1[18],
  s28_1[17],
  s28_1[16],
  s28_1[15],
  s28_1[14],
  s28_1[13],
  s28_1[12],
  s28_1[11],
  s28_1[10],
  s28_1[9],
  s28_1[8],
  s28_1[7],
  s28_1[6],
  s28_1[5],
  s28_1[4],
  s28_1[3],
  s28_1[2],
  s28_1[1],
  s28_1[0]};
assign n23 = s26_1 ? n20 : n19;
assign n24 = s26_1 ? n22 : n21;
cf_fft_256_16_5 s25 (clock_c, i2, i3, n1, i4, i5, s25_1, s25_2);
cf_fft_256_16_30 s26 (clock_c, n18, i4, i5, s26_1);
cf_fft_256_16_18 s27 (clock_c, n2, n6, n11, n17, i4, i5, s27_1, s27_2, s27_3);
cf_fft_256_16_17 s28 (clock_c, n2, n6, n11, n16, i4, i5, s28_1);
cf_fft_256_16_21 s29 (clock_c, i1, i4, i5, s29_1, s29_2);
assign o3 = n24;
assign o2 = n23;
assign o1 = s27_1;
endmodule

module cf_fft_256_16_4 (clock_c, i1, i2, i3, i4, i5, o1, o2, o3);
input  clock_c;
input  i1;
input  [31:0] i2;
input  [31:0] i3;
input  i4;
input  i5;
output o1;
output [31:0] o2;
output [31:0] o3;
wire   n1;
wire   [63:0] n2;
reg    n3;
reg    n4;
reg    n5;
reg    n6;
wire   [5:0] n7;
reg    [5:0] n8;
reg    [5:0] n9;
reg    [5:0] n10;
reg    [5:0] n11;
wire   n12;
reg    n13;
reg    n14;
reg    n15;
reg    n16;
wire   n17;
wire   [1:0] n18;
wire   [31:0] n19;
wire   [31:0] n20;
wire   [31:0] n21;
wire   [31:0] n22;
wire   [31:0] n23;
wire   [31:0] n24;
wire   s25_1;
wire   [31:0] s26_1;
wire   [31:0] s26_2;
wire   [6:0] s27_1;
wire   s27_2;
wire   s28_1;
wire   s28_2;
wire   [63:0] s28_3;
wire   [63:0] s29_1;
assign n1 = s27_1[6];
assign n2 = {s26_1, s26_2};
initial n3 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n3 <= 1'b0;
  else if (i4 == 1'b1)
    n3 <= s27_2;
initial n4 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n4 <= 1'b0;
  else if (i4 == 1'b1)
    n4 <= n3;
initial n5 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n5 <= 1'b0;
  else if (i4 == 1'b1)
    n5 <= n4;
initial n6 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n6 <= 1'b0;
  else if (i4 == 1'b1)
    n6 <= n5;
assign n7 = {s27_1[6],
  s27_1[5],
  s27_1[4],
  s27_1[3],
  s27_1[2],
  s27_1[1]};
initial n8 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n8 <= 6'b000000;
  else if (i4 == 1'b1)
    n8 <= n7;
initial n9 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n9 <= 6'b000000;
  else if (i4 == 1'b1)
    n9 <= n8;
initial n10 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n10 <= 6'b000000;
  else if (i4 == 1'b1)
    n10 <= n9;
initial n11 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n11 <= 6'b000000;
  else if (i4 == 1'b1)
    n11 <= n10;
assign n12 = s27_1[0];
initial n13 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n13 <= 1'b0;
  else if (i4 == 1'b1)
    n13 <= n12;
initial n14 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n14 <= 1'b0;
  else if (i4 == 1'b1)
    n14 <= n13;
initial n15 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n15 <= 1'b0;
  else if (i4 == 1'b1)
    n15 <= n14;
initial n16 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n16 <= 1'b0;
  else if (i4 == 1'b1)
    n16 <= n15;
assign n17 = ~n16;
assign n18 = {s28_2, s28_1};
assign n19 = {s28_3[63],
  s28_3[62],
  s28_3[61],
  s28_3[60],
  s28_3[59],
  s28_3[58],
  s28_3[57],
  s28_3[56],
  s28_3[55],
  s28_3[54],
  s28_3[53],
  s28_3[52],
  s28_3[51],
  s28_3[50],
  s28_3[49],
  s28_3[48],
  s28_3[47],
  s28_3[46],
  s28_3[45],
  s28_3[44],
  s28_3[43],
  s28_3[42],
  s28_3[41],
  s28_3[40],
  s28_3[39],
  s28_3[38],
  s28_3[37],
  s28_3[36],
  s28_3[35],
  s28_3[34],
  s28_3[33],
  s28_3[32]};
assign n20 = {s28_3[31],
  s28_3[30],
  s28_3[29],
  s28_3[28],
  s28_3[27],
  s28_3[26],
  s28_3[25],
  s28_3[24],
  s28_3[23],
  s28_3[22],
  s28_3[21],
  s28_3[20],
  s28_3[19],
  s28_3[18],
  s28_3[17],
  s28_3[16],
  s28_3[15],
  s28_3[14],
  s28_3[13],
  s28_3[12],
  s28_3[11],
  s28_3[10],
  s28_3[9],
  s28_3[8],
  s28_3[7],
  s28_3[6],
  s28_3[5],
  s28_3[4],
  s28_3[3],
  s28_3[2],
  s28_3[1],
  s28_3[0]};
assign n21 = {s29_1[63],
  s29_1[62],
  s29_1[61],
  s29_1[60],
  s29_1[59],
  s29_1[58],
  s29_1[57],
  s29_1[56],
  s29_1[55],
  s29_1[54],
  s29_1[53],
  s29_1[52],
  s29_1[51],
  s29_1[50],
  s29_1[49],
  s29_1[48],
  s29_1[47],
  s29_1[46],
  s29_1[45],
  s29_1[44],
  s29_1[43],
  s29_1[42],
  s29_1[41],
  s29_1[40],
  s29_1[39],
  s29_1[38],
  s29_1[37],
  s29_1[36],
  s29_1[35],
  s29_1[34],
  s29_1[33],
  s29_1[32]};
assign n22 = {s29_1[31],
  s29_1[30],
  s29_1[29],
  s29_1[28],
  s29_1[27],
  s29_1[26],
  s29_1[25],
  s29_1[24],
  s29_1[23],
  s29_1[22],
  s29_1[21],
  s29_1[20],
  s29_1[19],
  s29_1[18],
  s29_1[17],
  s29_1[16],
  s29_1[15],
  s29_1[14],
  s29_1[13],
  s29_1[12],
  s29_1[11],
  s29_1[10],
  s29_1[9],
  s29_1[8],
  s29_1[7],
  s29_1[6],
  s29_1[5],
  s29_1[4],
  s29_1[3],
  s29_1[2],
  s29_1[1],
  s29_1[0]};
assign n23 = s25_1 ? n20 : n19;
assign n24 = s25_1 ? n22 : n21;
cf_fft_256_16_30 s25 (clock_c, n18, i4, i5, s25_1);
cf_fft_256_16_5 s26 (clock_c, i2, i3, n1, i4, i5, s26_1, s26_2);
cf_fft_256_16_21 s27 (clock_c, i1, i4, i5, s27_1, s27_2);
cf_fft_256_16_18 s28 (clock_c, n2, n6, n11, n17, i4, i5, s28_1, s28_2, s28_3);
cf_fft_256_16_17 s29 (clock_c, n2, n6, n11, n16, i4, i5, s29_1);
assign o3 = n24;
assign o2 = n23;
assign o1 = s28_1;
endmodule

module cf_fft_256_16_5 (clock_c, i1, i2, i3, i4, i5, o1, o2);
input  clock_c;
input  [31:0] i1;
input  [31:0] i2;
input  i3;
input  i4;
input  i5;
output [31:0] o1;
output [31:0] o2;
reg    [31:0] n1;
wire   [15:0] n2;
wire   [15:0] n3;
reg    [31:0] n4;
wire   [15:0] n5;
wire   [15:0] n6;
reg    [15:0] n7;
reg    [15:0] n8;
reg    [15:0] n9;
reg    [15:0] n10;
reg    [31:0] n11;
wire   [15:0] n12;
wire   [15:0] n13;
wire   [31:0] n14;
wire   [15:0] n15;
reg    [15:0] n16;
wire   [31:0] n17;
wire   [15:0] n18;
reg    [15:0] n19;
wire   [15:0] n20;
reg    [15:0] n21;
wire   [31:0] n22;
wire   [15:0] n23;
reg    [15:0] n24;
wire   [31:0] n25;
wire   [15:0] n26;
reg    [15:0] n27;
wire   [15:0] n28;
reg    [15:0] n29;
wire   [15:0] n30;
wire   [15:0] n31;
wire   [31:0] n32;
reg    [31:0] n33;
wire   [15:0] n34;
wire   [15:0] n35;
wire   [31:0] n36;
reg    [31:0] n37;
initial n1 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n1 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n1 <= i1;
assign n2 = {n1[31],
  n1[30],
  n1[29],
  n1[28],
  n1[27],
  n1[26],
  n1[25],
  n1[24],
  n1[23],
  n1[22],
  n1[21],
  n1[20],
  n1[19],
  n1[18],
  n1[17],
  n1[16]};
assign n3 = {n1[15],
  n1[14],
  n1[13],
  n1[12],
  n1[11],
  n1[10],
  n1[9],
  n1[8],
  n1[7],
  n1[6],
  n1[5],
  n1[4],
  n1[3],
  n1[2],
  n1[1],
  n1[0]};
initial n4 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n4 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n4 <= i2;
assign n5 = {n4[31],
  n4[30],
  n4[29],
  n4[28],
  n4[27],
  n4[26],
  n4[25],
  n4[24],
  n4[23],
  n4[22],
  n4[21],
  n4[20],
  n4[19],
  n4[18],
  n4[17],
  n4[16]};
assign n6 = {n4[15],
  n4[14],
  n4[13],
  n4[12],
  n4[11],
  n4[10],
  n4[9],
  n4[8],
  n4[7],
  n4[6],
  n4[5],
  n4[4],
  n4[3],
  n4[2],
  n4[1],
  n4[0]};
initial n7 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n7 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n7 <= n2;
initial n8 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n8 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n8 <= n7;
initial n9 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n9 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n9 <= n3;
initial n10 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n10 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n10 <= n9;
initial n11 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i4 == 1'b1)
    case (i3)
      1'b0 : n11 <= 32'b01111111111111110000000000000000;
      1'b1 : n11 <= 32'b00000000000000001000000000000000;
      default : n11 <= 32'bxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx;
    endcase
assign n12 = {n11[31],
  n11[30],
  n11[29],
  n11[28],
  n11[27],
  n11[26],
  n11[25],
  n11[24],
  n11[23],
  n11[22],
  n11[21],
  n11[20],
  n11[19],
  n11[18],
  n11[17],
  n11[16]};
assign n13 = {n11[15],
  n11[14],
  n11[13],
  n11[12],
  n11[11],
  n11[10],
  n11[9],
  n11[8],
  n11[7],
  n11[6],
  n11[5],
  n11[4],
  n11[3],
  n11[2],
  n11[1],
  n11[0]};
assign n14 = {{16{n5[15]}}, n5} * {{16{n12[15]}}, n12};
assign n15 = {n14[30],
  n14[29],
  n14[28],
  n14[27],
  n14[26],
  n14[25],
  n14[24],
  n14[23],
  n14[22],
  n14[21],
  n14[20],
  n14[19],
  n14[18],
  n14[17],
  n14[16],
  n14[15]};
initial n16 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n16 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n16 <= n15;
assign n17 = {{16{n6[15]}}, n6} * {{16{n13[15]}}, n13};
assign n18 = {n17[30],
  n17[29],
  n17[28],
  n17[27],
  n17[26],
  n17[25],
  n17[24],
  n17[23],
  n17[22],
  n17[21],
  n17[20],
  n17[19],
  n17[18],
  n17[17],
  n17[16],
  n17[15]};
initial n19 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n19 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n19 <= n18;
assign n20 = n16 - n19;
initial n21 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n21 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n21 <= n20;
assign n22 = {{16{n5[15]}}, n5} * {{16{n13[15]}}, n13};
assign n23 = {n22[30],
  n22[29],
  n22[28],
  n22[27],
  n22[26],
  n22[25],
  n22[24],
  n22[23],
  n22[22],
  n22[21],
  n22[20],
  n22[19],
  n22[18],
  n22[17],
  n22[16],
  n22[15]};
initial n24 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n24 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n24 <= n23;
assign n25 = {{16{n6[15]}}, n6} * {{16{n12[15]}}, n12};
assign n26 = {n25[30],
  n25[29],
  n25[28],
  n25[27],
  n25[26],
  n25[25],
  n25[24],
  n25[23],
  n25[22],
  n25[21],
  n25[20],
  n25[19],
  n25[18],
  n25[17],
  n25[16],
  n25[15]};
initial n27 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n27 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n27 <= n26;
assign n28 = n24 + n27;
initial n29 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n29 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n29 <= n28;
assign n30 = n8 + n21;
assign n31 = n10 + n29;
assign n32 = {n30, n31};
initial n33 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n33 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n33 <= n32;
assign n34 = n8 - n21;
assign n35 = n10 - n29;
assign n36 = {n34, n35};
initial n37 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n37 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n37 <= n36;
assign o2 = n37;
assign o1 = n33;
endmodule

module cf_fft_256_16_6 (clock_c, i1, i2, i3, i4, i5, o1, o2, o3);
input  clock_c;
input  i1;
input  [31:0] i2;
input  [31:0] i3;
input  i4;
input  i5;
output o1;
output [31:0] o2;
output [31:0] o3;
wire   [1:0] n1;
wire   [63:0] n2;
reg    n3;
reg    n4;
reg    n5;
reg    n6;
wire   [5:0] n7;
reg    [5:0] n8;
reg    [5:0] n9;
reg    [5:0] n10;
reg    [5:0] n11;
wire   n12;
reg    n13;
reg    n14;
reg    n15;
reg    n16;
wire   n17;
wire   [1:0] n18;
wire   [31:0] n19;
wire   [31:0] n20;
wire   [31:0] n21;
wire   [31:0] n22;
wire   [31:0] n23;
wire   [31:0] n24;
wire   s25_1;
wire   [31:0] s26_1;
wire   [31:0] s26_2;
wire   [6:0] s27_1;
wire   s27_2;
wire   s28_1;
wire   s28_2;
wire   [63:0] s28_3;
wire   [63:0] s29_1;
assign n1 = {s27_1[6],
  s27_1[5]};
assign n2 = {s26_1, s26_2};
initial n3 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n3 <= 1'b0;
  else if (i4 == 1'b1)
    n3 <= s27_2;
initial n4 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n4 <= 1'b0;
  else if (i4 == 1'b1)
    n4 <= n3;
initial n5 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n5 <= 1'b0;
  else if (i4 == 1'b1)
    n5 <= n4;
initial n6 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n6 <= 1'b0;
  else if (i4 == 1'b1)
    n6 <= n5;
assign n7 = {s27_1[6],
  s27_1[5],
  s27_1[4],
  s27_1[3],
  s27_1[2],
  s27_1[1]};
initial n8 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n8 <= 6'b000000;
  else if (i4 == 1'b1)
    n8 <= n7;
initial n9 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n9 <= 6'b000000;
  else if (i4 == 1'b1)
    n9 <= n8;
initial n10 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n10 <= 6'b000000;
  else if (i4 == 1'b1)
    n10 <= n9;
initial n11 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n11 <= 6'b000000;
  else if (i4 == 1'b1)
    n11 <= n10;
assign n12 = s27_1[0];
initial n13 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n13 <= 1'b0;
  else if (i4 == 1'b1)
    n13 <= n12;
initial n14 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n14 <= 1'b0;
  else if (i4 == 1'b1)
    n14 <= n13;
initial n15 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n15 <= 1'b0;
  else if (i4 == 1'b1)
    n15 <= n14;
initial n16 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n16 <= 1'b0;
  else if (i4 == 1'b1)
    n16 <= n15;
assign n17 = ~n16;
assign n18 = {s28_2, s28_1};
assign n19 = {s28_3[63],
  s28_3[62],
  s28_3[61],
  s28_3[60],
  s28_3[59],
  s28_3[58],
  s28_3[57],
  s28_3[56],
  s28_3[55],
  s28_3[54],
  s28_3[53],
  s28_3[52],
  s28_3[51],
  s28_3[50],
  s28_3[49],
  s28_3[48],
  s28_3[47],
  s28_3[46],
  s28_3[45],
  s28_3[44],
  s28_3[43],
  s28_3[42],
  s28_3[41],
  s28_3[40],
  s28_3[39],
  s28_3[38],
  s28_3[37],
  s28_3[36],
  s28_3[35],
  s28_3[34],
  s28_3[33],
  s28_3[32]};
assign n20 = {s28_3[31],
  s28_3[30],
  s28_3[29],
  s28_3[28],
  s28_3[27],
  s28_3[26],
  s28_3[25],
  s28_3[24],
  s28_3[23],
  s28_3[22],
  s28_3[21],
  s28_3[20],
  s28_3[19],
  s28_3[18],
  s28_3[17],
  s28_3[16],
  s28_3[15],
  s28_3[14],
  s28_3[13],
  s28_3[12],
  s28_3[11],
  s28_3[10],
  s28_3[9],
  s28_3[8],
  s28_3[7],
  s28_3[6],
  s28_3[5],
  s28_3[4],
  s28_3[3],
  s28_3[2],
  s28_3[1],
  s28_3[0]};
assign n21 = {s29_1[63],
  s29_1[62],
  s29_1[61],
  s29_1[60],
  s29_1[59],
  s29_1[58],
  s29_1[57],
  s29_1[56],
  s29_1[55],
  s29_1[54],
  s29_1[53],
  s29_1[52],
  s29_1[51],
  s29_1[50],
  s29_1[49],
  s29_1[48],
  s29_1[47],
  s29_1[46],
  s29_1[45],
  s29_1[44],
  s29_1[43],
  s29_1[42],
  s29_1[41],
  s29_1[40],
  s29_1[39],
  s29_1[38],
  s29_1[37],
  s29_1[36],
  s29_1[35],
  s29_1[34],
  s29_1[33],
  s29_1[32]};
assign n22 = {s29_1[31],
  s29_1[30],
  s29_1[29],
  s29_1[28],
  s29_1[27],
  s29_1[26],
  s29_1[25],
  s29_1[24],
  s29_1[23],
  s29_1[22],
  s29_1[21],
  s29_1[20],
  s29_1[19],
  s29_1[18],
  s29_1[17],
  s29_1[16],
  s29_1[15],
  s29_1[14],
  s29_1[13],
  s29_1[12],
  s29_1[11],
  s29_1[10],
  s29_1[9],
  s29_1[8],
  s29_1[7],
  s29_1[6],
  s29_1[5],
  s29_1[4],
  s29_1[3],
  s29_1[2],
  s29_1[1],
  s29_1[0]};
assign n23 = s25_1 ? n20 : n19;
assign n24 = s25_1 ? n22 : n21;
cf_fft_256_16_30 s25 (clock_c, n18, i4, i5, s25_1);
cf_fft_256_16_7 s26 (clock_c, i2, i3, n1, i4, i5, s26_1, s26_2);
cf_fft_256_16_21 s27 (clock_c, i1, i4, i5, s27_1, s27_2);
cf_fft_256_16_18 s28 (clock_c, n2, n6, n11, n17, i4, i5, s28_1, s28_2, s28_3);
cf_fft_256_16_17 s29 (clock_c, n2, n6, n11, n16, i4, i5, s29_1);
assign o3 = n24;
assign o2 = n23;
assign o1 = s28_1;
endmodule

module cf_fft_256_16_7 (clock_c, i1, i2, i3, i4, i5, o1, o2);
input  clock_c;
input  [31:0] i1;
input  [31:0] i2;
input  [1:0] i3;
input  i4;
input  i5;
output [31:0] o1;
output [31:0] o2;
reg    [31:0] n1;
wire   [15:0] n2;
wire   [15:0] n3;
reg    [31:0] n4;
wire   [15:0] n5;
wire   [15:0] n6;
reg    [15:0] n7;
reg    [15:0] n8;
reg    [15:0] n9;
reg    [15:0] n10;
reg    [31:0] n11;
wire   [15:0] n12;
wire   [15:0] n13;
wire   [31:0] n14;
wire   [15:0] n15;
reg    [15:0] n16;
wire   [31:0] n17;
wire   [15:0] n18;
reg    [15:0] n19;
wire   [15:0] n20;
reg    [15:0] n21;
wire   [31:0] n22;
wire   [15:0] n23;
reg    [15:0] n24;
wire   [31:0] n25;
wire   [15:0] n26;
reg    [15:0] n27;
wire   [15:0] n28;
reg    [15:0] n29;
wire   [15:0] n30;
wire   [15:0] n31;
wire   [31:0] n32;
reg    [31:0] n33;
wire   [15:0] n34;
wire   [15:0] n35;
wire   [31:0] n36;
reg    [31:0] n37;
initial n1 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n1 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n1 <= i1;
assign n2 = {n1[31],
  n1[30],
  n1[29],
  n1[28],
  n1[27],
  n1[26],
  n1[25],
  n1[24],
  n1[23],
  n1[22],
  n1[21],
  n1[20],
  n1[19],
  n1[18],
  n1[17],
  n1[16]};
assign n3 = {n1[15],
  n1[14],
  n1[13],
  n1[12],
  n1[11],
  n1[10],
  n1[9],
  n1[8],
  n1[7],
  n1[6],
  n1[5],
  n1[4],
  n1[3],
  n1[2],
  n1[1],
  n1[0]};
initial n4 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n4 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n4 <= i2;
assign n5 = {n4[31],
  n4[30],
  n4[29],
  n4[28],
  n4[27],
  n4[26],
  n4[25],
  n4[24],
  n4[23],
  n4[22],
  n4[21],
  n4[20],
  n4[19],
  n4[18],
  n4[17],
  n4[16]};
assign n6 = {n4[15],
  n4[14],
  n4[13],
  n4[12],
  n4[11],
  n4[10],
  n4[9],
  n4[8],
  n4[7],
  n4[6],
  n4[5],
  n4[4],
  n4[3],
  n4[2],
  n4[1],
  n4[0]};
initial n7 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n7 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n7 <= n2;
initial n8 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n8 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n8 <= n7;
initial n9 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n9 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n9 <= n3;
initial n10 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n10 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n10 <= n9;
initial n11 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i4 == 1'b1)
    case (i3)
      2'b00 : n11 <= 32'b01111111111111110000000000000000;
      2'b01 : n11 <= 32'b01011010100000101010010101111101;
      2'b10 : n11 <= 32'b00000000000000001000000000000000;
      2'b11 : n11 <= 32'b10100101011111011010010101111101;
      default : n11 <= 32'bxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx;
    endcase
assign n12 = {n11[31],
  n11[30],
  n11[29],
  n11[28],
  n11[27],
  n11[26],
  n11[25],
  n11[24],
  n11[23],
  n11[22],
  n11[21],
  n11[20],
  n11[19],
  n11[18],
  n11[17],
  n11[16]};
assign n13 = {n11[15],
  n11[14],
  n11[13],
  n11[12],
  n11[11],
  n11[10],
  n11[9],
  n11[8],
  n11[7],
  n11[6],
  n11[5],
  n11[4],
  n11[3],
  n11[2],
  n11[1],
  n11[0]};
assign n14 = {{16{n5[15]}}, n5} * {{16{n12[15]}}, n12};
assign n15 = {n14[30],
  n14[29],
  n14[28],
  n14[27],
  n14[26],
  n14[25],
  n14[24],
  n14[23],
  n14[22],
  n14[21],
  n14[20],
  n14[19],
  n14[18],
  n14[17],
  n14[16],
  n14[15]};
initial n16 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n16 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n16 <= n15;
assign n17 = {{16{n6[15]}}, n6} * {{16{n13[15]}}, n13};
assign n18 = {n17[30],
  n17[29],
  n17[28],
  n17[27],
  n17[26],
  n17[25],
  n17[24],
  n17[23],
  n17[22],
  n17[21],
  n17[20],
  n17[19],
  n17[18],
  n17[17],
  n17[16],
  n17[15]};
initial n19 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n19 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n19 <= n18;
assign n20 = n16 - n19;
initial n21 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n21 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n21 <= n20;
assign n22 = {{16{n5[15]}}, n5} * {{16{n13[15]}}, n13};
assign n23 = {n22[30],
  n22[29],
  n22[28],
  n22[27],
  n22[26],
  n22[25],
  n22[24],
  n22[23],
  n22[22],
  n22[21],
  n22[20],
  n22[19],
  n22[18],
  n22[17],
  n22[16],
  n22[15]};
initial n24 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n24 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n24 <= n23;
assign n25 = {{16{n6[15]}}, n6} * {{16{n12[15]}}, n12};
assign n26 = {n25[30],
  n25[29],
  n25[28],
  n25[27],
  n25[26],
  n25[25],
  n25[24],
  n25[23],
  n25[22],
  n25[21],
  n25[20],
  n25[19],
  n25[18],
  n25[17],
  n25[16],
  n25[15]};
initial n27 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n27 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n27 <= n26;
assign n28 = n24 + n27;
initial n29 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n29 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n29 <= n28;
assign n30 = n8 + n21;
assign n31 = n10 + n29;
assign n32 = {n30, n31};
initial n33 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n33 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n33 <= n32;
assign n34 = n8 - n21;
assign n35 = n10 - n29;
assign n36 = {n34, n35};
initial n37 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n37 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n37 <= n36;
assign o2 = n37;
assign o1 = n33;
endmodule

module cf_fft_256_16_8 (clock_c, i1, i2, i3, i4, i5, o1, o2, o3);
input  clock_c;
input  i1;
input  [31:0] i2;
input  [31:0] i3;
input  i4;
input  i5;
output o1;
output [31:0] o2;
output [31:0] o3;
wire   [2:0] n1;
wire   [63:0] n2;
reg    n3;
reg    n4;
reg    n5;
reg    n6;
wire   [5:0] n7;
reg    [5:0] n8;
reg    [5:0] n9;
reg    [5:0] n10;
reg    [5:0] n11;
wire   n12;
reg    n13;
reg    n14;
reg    n15;
reg    n16;
wire   n17;
wire   [1:0] n18;
wire   [31:0] n19;
wire   [31:0] n20;
wire   [31:0] n21;
wire   [31:0] n22;
wire   [31:0] n23;
wire   [31:0] n24;
wire   s25_1;
wire   [31:0] s26_1;
wire   [31:0] s26_2;
wire   [6:0] s27_1;
wire   s27_2;
wire   s28_1;
wire   s28_2;
wire   [63:0] s28_3;
wire   [63:0] s29_1;
assign n1 = {s27_1[6],
  s27_1[5],
  s27_1[4]};
assign n2 = {s26_1, s26_2};
initial n3 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n3 <= 1'b0;
  else if (i4 == 1'b1)
    n3 <= s27_2;
initial n4 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n4 <= 1'b0;
  else if (i4 == 1'b1)
    n4 <= n3;
initial n5 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n5 <= 1'b0;
  else if (i4 == 1'b1)
    n5 <= n4;
initial n6 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n6 <= 1'b0;
  else if (i4 == 1'b1)
    n6 <= n5;
assign n7 = {s27_1[6],
  s27_1[5],
  s27_1[4],
  s27_1[3],
  s27_1[2],
  s27_1[1]};
initial n8 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n8 <= 6'b000000;
  else if (i4 == 1'b1)
    n8 <= n7;
initial n9 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n9 <= 6'b000000;
  else if (i4 == 1'b1)
    n9 <= n8;
initial n10 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n10 <= 6'b000000;
  else if (i4 == 1'b1)
    n10 <= n9;
initial n11 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n11 <= 6'b000000;
  else if (i4 == 1'b1)
    n11 <= n10;
assign n12 = s27_1[0];
initial n13 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n13 <= 1'b0;
  else if (i4 == 1'b1)
    n13 <= n12;
initial n14 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n14 <= 1'b0;
  else if (i4 == 1'b1)
    n14 <= n13;
initial n15 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n15 <= 1'b0;
  else if (i4 == 1'b1)
    n15 <= n14;
initial n16 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n16 <= 1'b0;
  else if (i4 == 1'b1)
    n16 <= n15;
assign n17 = ~n16;
assign n18 = {s28_2, s28_1};
assign n19 = {s28_3[63],
  s28_3[62],
  s28_3[61],
  s28_3[60],
  s28_3[59],
  s28_3[58],
  s28_3[57],
  s28_3[56],
  s28_3[55],
  s28_3[54],
  s28_3[53],
  s28_3[52],
  s28_3[51],
  s28_3[50],
  s28_3[49],
  s28_3[48],
  s28_3[47],
  s28_3[46],
  s28_3[45],
  s28_3[44],
  s28_3[43],
  s28_3[42],
  s28_3[41],
  s28_3[40],
  s28_3[39],
  s28_3[38],
  s28_3[37],
  s28_3[36],
  s28_3[35],
  s28_3[34],
  s28_3[33],
  s28_3[32]};
assign n20 = {s28_3[31],
  s28_3[30],
  s28_3[29],
  s28_3[28],
  s28_3[27],
  s28_3[26],
  s28_3[25],
  s28_3[24],
  s28_3[23],
  s28_3[22],
  s28_3[21],
  s28_3[20],
  s28_3[19],
  s28_3[18],
  s28_3[17],
  s28_3[16],
  s28_3[15],
  s28_3[14],
  s28_3[13],
  s28_3[12],
  s28_3[11],
  s28_3[10],
  s28_3[9],
  s28_3[8],
  s28_3[7],
  s28_3[6],
  s28_3[5],
  s28_3[4],
  s28_3[3],
  s28_3[2],
  s28_3[1],
  s28_3[0]};
assign n21 = {s29_1[63],
  s29_1[62],
  s29_1[61],
  s29_1[60],
  s29_1[59],
  s29_1[58],
  s29_1[57],
  s29_1[56],
  s29_1[55],
  s29_1[54],
  s29_1[53],
  s29_1[52],
  s29_1[51],
  s29_1[50],
  s29_1[49],
  s29_1[48],
  s29_1[47],
  s29_1[46],
  s29_1[45],
  s29_1[44],
  s29_1[43],
  s29_1[42],
  s29_1[41],
  s29_1[40],
  s29_1[39],
  s29_1[38],
  s29_1[37],
  s29_1[36],
  s29_1[35],
  s29_1[34],
  s29_1[33],
  s29_1[32]};
assign n22 = {s29_1[31],
  s29_1[30],
  s29_1[29],
  s29_1[28],
  s29_1[27],
  s29_1[26],
  s29_1[25],
  s29_1[24],
  s29_1[23],
  s29_1[22],
  s29_1[21],
  s29_1[20],
  s29_1[19],
  s29_1[18],
  s29_1[17],
  s29_1[16],
  s29_1[15],
  s29_1[14],
  s29_1[13],
  s29_1[12],
  s29_1[11],
  s29_1[10],
  s29_1[9],
  s29_1[8],
  s29_1[7],
  s29_1[6],
  s29_1[5],
  s29_1[4],
  s29_1[3],
  s29_1[2],
  s29_1[1],
  s29_1[0]};
assign n23 = s25_1 ? n20 : n19;
assign n24 = s25_1 ? n22 : n21;
cf_fft_256_16_30 s25 (clock_c, n18, i4, i5, s25_1);
cf_fft_256_16_9 s26 (clock_c, i2, i3, n1, i4, i5, s26_1, s26_2);
cf_fft_256_16_21 s27 (clock_c, i1, i4, i5, s27_1, s27_2);
cf_fft_256_16_18 s28 (clock_c, n2, n6, n11, n17, i4, i5, s28_1, s28_2, s28_3);
cf_fft_256_16_17 s29 (clock_c, n2, n6, n11, n16, i4, i5, s29_1);
assign o3 = n24;
assign o2 = n23;
assign o1 = s28_1;
endmodule

module cf_fft_256_16_9 (clock_c, i1, i2, i3, i4, i5, o1, o2);
input  clock_c;
input  [31:0] i1;
input  [31:0] i2;
input  [2:0] i3;
input  i4;
input  i5;
output [31:0] o1;
output [31:0] o2;
reg    [31:0] n1;
wire   [15:0] n2;
wire   [15:0] n3;
reg    [31:0] n4;
wire   [15:0] n5;
wire   [15:0] n6;
reg    [15:0] n7;
reg    [15:0] n8;
reg    [15:0] n9;
reg    [15:0] n10;
reg    [31:0] n11;
wire   [15:0] n12;
wire   [15:0] n13;
wire   [31:0] n14;
wire   [15:0] n15;
reg    [15:0] n16;
wire   [31:0] n17;
wire   [15:0] n18;
reg    [15:0] n19;
wire   [15:0] n20;
reg    [15:0] n21;
wire   [31:0] n22;
wire   [15:0] n23;
reg    [15:0] n24;
wire   [31:0] n25;
wire   [15:0] n26;
reg    [15:0] n27;
wire   [15:0] n28;
reg    [15:0] n29;
wire   [15:0] n30;
wire   [15:0] n31;
wire   [31:0] n32;
reg    [31:0] n33;
wire   [15:0] n34;
wire   [15:0] n35;
wire   [31:0] n36;
reg    [31:0] n37;
initial n1 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n1 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n1 <= i1;
assign n2 = {n1[31],
  n1[30],
  n1[29],
  n1[28],
  n1[27],
  n1[26],
  n1[25],
  n1[24],
  n1[23],
  n1[22],
  n1[21],
  n1[20],
  n1[19],
  n1[18],
  n1[17],
  n1[16]};
assign n3 = {n1[15],
  n1[14],
  n1[13],
  n1[12],
  n1[11],
  n1[10],
  n1[9],
  n1[8],
  n1[7],
  n1[6],
  n1[5],
  n1[4],
  n1[3],
  n1[2],
  n1[1],
  n1[0]};
initial n4 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n4 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n4 <= i2;
assign n5 = {n4[31],
  n4[30],
  n4[29],
  n4[28],
  n4[27],
  n4[26],
  n4[25],
  n4[24],
  n4[23],
  n4[22],
  n4[21],
  n4[20],
  n4[19],
  n4[18],
  n4[17],
  n4[16]};
assign n6 = {n4[15],
  n4[14],
  n4[13],
  n4[12],
  n4[11],
  n4[10],
  n4[9],
  n4[8],
  n4[7],
  n4[6],
  n4[5],
  n4[4],
  n4[3],
  n4[2],
  n4[1],
  n4[0]};
initial n7 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n7 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n7 <= n2;
initial n8 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n8 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n8 <= n7;
initial n9 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n9 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n9 <= n3;
initial n10 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n10 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n10 <= n9;
initial n11 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i4 == 1'b1)
    case (i3)
      3'b000 : n11 <= 32'b01111111111111110000000000000000;
      3'b001 : n11 <= 32'b01110110010000011100111100000100;
      3'b010 : n11 <= 32'b01011010100000101010010101111101;
      3'b011 : n11 <= 32'b00110000111110111000100110111110;
      3'b100 : n11 <= 32'b00000000000000001000000000000000;
      3'b101 : n11 <= 32'b11001111000001001000100110111110;
      3'b110 : n11 <= 32'b10100101011111011010010101111101;
      3'b111 : n11 <= 32'b10001001101111101100111100000100;
      default : n11 <= 32'bxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx;
    endcase
assign n12 = {n11[31],
  n11[30],
  n11[29],
  n11[28],
  n11[27],
  n11[26],
  n11[25],
  n11[24],
  n11[23],
  n11[22],
  n11[21],
  n11[20],
  n11[19],
  n11[18],
  n11[17],
  n11[16]};
assign n13 = {n11[15],
  n11[14],
  n11[13],
  n11[12],
  n11[11],
  n11[10],
  n11[9],
  n11[8],
  n11[7],
  n11[6],
  n11[5],
  n11[4],
  n11[3],
  n11[2],
  n11[1],
  n11[0]};
assign n14 = {{16{n5[15]}}, n5} * {{16{n12[15]}}, n12};
assign n15 = {n14[30],
  n14[29],
  n14[28],
  n14[27],
  n14[26],
  n14[25],
  n14[24],
  n14[23],
  n14[22],
  n14[21],
  n14[20],
  n14[19],
  n14[18],
  n14[17],
  n14[16],
  n14[15]};
initial n16 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n16 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n16 <= n15;
assign n17 = {{16{n6[15]}}, n6} * {{16{n13[15]}}, n13};
assign n18 = {n17[30],
  n17[29],
  n17[28],
  n17[27],
  n17[26],
  n17[25],
  n17[24],
  n17[23],
  n17[22],
  n17[21],
  n17[20],
  n17[19],
  n17[18],
  n17[17],
  n17[16],
  n17[15]};
initial n19 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n19 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n19 <= n18;
assign n20 = n16 - n19;
initial n21 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n21 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n21 <= n20;
assign n22 = {{16{n5[15]}}, n5} * {{16{n13[15]}}, n13};
assign n23 = {n22[30],
  n22[29],
  n22[28],
  n22[27],
  n22[26],
  n22[25],
  n22[24],
  n22[23],
  n22[22],
  n22[21],
  n22[20],
  n22[19],
  n22[18],
  n22[17],
  n22[16],
  n22[15]};
initial n24 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n24 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n24 <= n23;
assign n25 = {{16{n6[15]}}, n6} * {{16{n12[15]}}, n12};
assign n26 = {n25[30],
  n25[29],
  n25[28],
  n25[27],
  n25[26],
  n25[25],
  n25[24],
  n25[23],
  n25[22],
  n25[21],
  n25[20],
  n25[19],
  n25[18],
  n25[17],
  n25[16],
  n25[15]};
initial n27 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n27 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n27 <= n26;
assign n28 = n24 + n27;
initial n29 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n29 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n29 <= n28;
assign n30 = n8 + n21;
assign n31 = n10 + n29;
assign n32 = {n30, n31};
initial n33 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n33 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n33 <= n32;
assign n34 = n8 - n21;
assign n35 = n10 - n29;
assign n36 = {n34, n35};
initial n37 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n37 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n37 <= n36;
assign o2 = n37;
assign o1 = n33;
endmodule

module cf_fft_256_16_10 (clock_c, i1, i2, i3, i4, i5, o1, o2, o3);
input  clock_c;
input  i1;
input  [31:0] i2;
input  [31:0] i3;
input  i4;
input  i5;
output o1;
output [31:0] o2;
output [31:0] o3;
wire   [3:0] n1;
wire   [63:0] n2;
reg    n3;
reg    n4;
reg    n5;
reg    n6;
wire   [5:0] n7;
reg    [5:0] n8;
reg    [5:0] n9;
reg    [5:0] n10;
reg    [5:0] n11;
wire   n12;
reg    n13;
reg    n14;
reg    n15;
reg    n16;
wire   n17;
wire   [1:0] n18;
wire   [31:0] n19;
wire   [31:0] n20;
wire   [31:0] n21;
wire   [31:0] n22;
wire   [31:0] n23;
wire   [31:0] n24;
wire   s25_1;
wire   [31:0] s26_1;
wire   [31:0] s26_2;
wire   [6:0] s27_1;
wire   s27_2;
wire   s28_1;
wire   s28_2;
wire   [63:0] s28_3;
wire   [63:0] s29_1;
assign n1 = {s27_1[6],
  s27_1[5],
  s27_1[4],
  s27_1[3]};
assign n2 = {s26_1, s26_2};
initial n3 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n3 <= 1'b0;
  else if (i4 == 1'b1)
    n3 <= s27_2;
initial n4 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n4 <= 1'b0;
  else if (i4 == 1'b1)
    n4 <= n3;
initial n5 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n5 <= 1'b0;
  else if (i4 == 1'b1)
    n5 <= n4;
initial n6 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n6 <= 1'b0;
  else if (i4 == 1'b1)
    n6 <= n5;
assign n7 = {s27_1[6],
  s27_1[5],
  s27_1[4],
  s27_1[3],
  s27_1[2],
  s27_1[1]};
initial n8 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n8 <= 6'b000000;
  else if (i4 == 1'b1)
    n8 <= n7;
initial n9 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n9 <= 6'b000000;
  else if (i4 == 1'b1)
    n9 <= n8;
initial n10 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n10 <= 6'b000000;
  else if (i4 == 1'b1)
    n10 <= n9;
initial n11 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n11 <= 6'b000000;
  else if (i4 == 1'b1)
    n11 <= n10;
assign n12 = s27_1[0];
initial n13 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n13 <= 1'b0;
  else if (i4 == 1'b1)
    n13 <= n12;
initial n14 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n14 <= 1'b0;
  else if (i4 == 1'b1)
    n14 <= n13;
initial n15 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n15 <= 1'b0;
  else if (i4 == 1'b1)
    n15 <= n14;
initial n16 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n16 <= 1'b0;
  else if (i4 == 1'b1)
    n16 <= n15;
assign n17 = ~n16;
assign n18 = {s28_2, s28_1};
assign n19 = {s28_3[63],
  s28_3[62],
  s28_3[61],
  s28_3[60],
  s28_3[59],
  s28_3[58],
  s28_3[57],
  s28_3[56],
  s28_3[55],
  s28_3[54],
  s28_3[53],
  s28_3[52],
  s28_3[51],
  s28_3[50],
  s28_3[49],
  s28_3[48],
  s28_3[47],
  s28_3[46],
  s28_3[45],
  s28_3[44],
  s28_3[43],
  s28_3[42],
  s28_3[41],
  s28_3[40],
  s28_3[39],
  s28_3[38],
  s28_3[37],
  s28_3[36],
  s28_3[35],
  s28_3[34],
  s28_3[33],
  s28_3[32]};
assign n20 = {s28_3[31],
  s28_3[30],
  s28_3[29],
  s28_3[28],
  s28_3[27],
  s28_3[26],
  s28_3[25],
  s28_3[24],
  s28_3[23],
  s28_3[22],
  s28_3[21],
  s28_3[20],
  s28_3[19],
  s28_3[18],
  s28_3[17],
  s28_3[16],
  s28_3[15],
  s28_3[14],
  s28_3[13],
  s28_3[12],
  s28_3[11],
  s28_3[10],
  s28_3[9],
  s28_3[8],
  s28_3[7],
  s28_3[6],
  s28_3[5],
  s28_3[4],
  s28_3[3],
  s28_3[2],
  s28_3[1],
  s28_3[0]};
assign n21 = {s29_1[63],
  s29_1[62],
  s29_1[61],
  s29_1[60],
  s29_1[59],
  s29_1[58],
  s29_1[57],
  s29_1[56],
  s29_1[55],
  s29_1[54],
  s29_1[53],
  s29_1[52],
  s29_1[51],
  s29_1[50],
  s29_1[49],
  s29_1[48],
  s29_1[47],
  s29_1[46],
  s29_1[45],
  s29_1[44],
  s29_1[43],
  s29_1[42],
  s29_1[41],
  s29_1[40],
  s29_1[39],
  s29_1[38],
  s29_1[37],
  s29_1[36],
  s29_1[35],
  s29_1[34],
  s29_1[33],
  s29_1[32]};
assign n22 = {s29_1[31],
  s29_1[30],
  s29_1[29],
  s29_1[28],
  s29_1[27],
  s29_1[26],
  s29_1[25],
  s29_1[24],
  s29_1[23],
  s29_1[22],
  s29_1[21],
  s29_1[20],
  s29_1[19],
  s29_1[18],
  s29_1[17],
  s29_1[16],
  s29_1[15],
  s29_1[14],
  s29_1[13],
  s29_1[12],
  s29_1[11],
  s29_1[10],
  s29_1[9],
  s29_1[8],
  s29_1[7],
  s29_1[6],
  s29_1[5],
  s29_1[4],
  s29_1[3],
  s29_1[2],
  s29_1[1],
  s29_1[0]};
assign n23 = s25_1 ? n20 : n19;
assign n24 = s25_1 ? n22 : n21;
cf_fft_256_16_30 s25 (clock_c, n18, i4, i5, s25_1);
cf_fft_256_16_11 s26 (clock_c, i2, i3, n1, i4, i5, s26_1, s26_2);
cf_fft_256_16_21 s27 (clock_c, i1, i4, i5, s27_1, s27_2);
cf_fft_256_16_18 s28 (clock_c, n2, n6, n11, n17, i4, i5, s28_1, s28_2, s28_3);
cf_fft_256_16_17 s29 (clock_c, n2, n6, n11, n16, i4, i5, s29_1);
assign o3 = n24;
assign o2 = n23;
assign o1 = s28_1;
endmodule

module cf_fft_256_16_11 (clock_c, i1, i2, i3, i4, i5, o1, o2);
input  clock_c;
input  [31:0] i1;
input  [31:0] i2;
input  [3:0] i3;
input  i4;
input  i5;
output [31:0] o1;
output [31:0] o2;
reg    [31:0] n1;
wire   [15:0] n2;
wire   [15:0] n3;
reg    [31:0] n4;
wire   [15:0] n5;
wire   [15:0] n6;
reg    [15:0] n7;
reg    [15:0] n8;
reg    [15:0] n9;
reg    [15:0] n10;
reg    [31:0] n11;
wire   [15:0] n12;
wire   [15:0] n13;
wire   [31:0] n14;
wire   [15:0] n15;
reg    [15:0] n16;
wire   [31:0] n17;
wire   [15:0] n18;
reg    [15:0] n19;
wire   [15:0] n20;
reg    [15:0] n21;
wire   [31:0] n22;
wire   [15:0] n23;
reg    [15:0] n24;
wire   [31:0] n25;
wire   [15:0] n26;
reg    [15:0] n27;
wire   [15:0] n28;
reg    [15:0] n29;
wire   [15:0] n30;
wire   [15:0] n31;
wire   [31:0] n32;
reg    [31:0] n33;
wire   [15:0] n34;
wire   [15:0] n35;
wire   [31:0] n36;
reg    [31:0] n37;
initial n1 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n1 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n1 <= i1;
assign n2 = {n1[31],
  n1[30],
  n1[29],
  n1[28],
  n1[27],
  n1[26],
  n1[25],
  n1[24],
  n1[23],
  n1[22],
  n1[21],
  n1[20],
  n1[19],
  n1[18],
  n1[17],
  n1[16]};
assign n3 = {n1[15],
  n1[14],
  n1[13],
  n1[12],
  n1[11],
  n1[10],
  n1[9],
  n1[8],
  n1[7],
  n1[6],
  n1[5],
  n1[4],
  n1[3],
  n1[2],
  n1[1],
  n1[0]};
initial n4 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n4 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n4 <= i2;
assign n5 = {n4[31],
  n4[30],
  n4[29],
  n4[28],
  n4[27],
  n4[26],
  n4[25],
  n4[24],
  n4[23],
  n4[22],
  n4[21],
  n4[20],
  n4[19],
  n4[18],
  n4[17],
  n4[16]};
assign n6 = {n4[15],
  n4[14],
  n4[13],
  n4[12],
  n4[11],
  n4[10],
  n4[9],
  n4[8],
  n4[7],
  n4[6],
  n4[5],
  n4[4],
  n4[3],
  n4[2],
  n4[1],
  n4[0]};
initial n7 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n7 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n7 <= n2;
initial n8 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n8 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n8 <= n7;
initial n9 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n9 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n9 <= n3;
initial n10 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n10 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n10 <= n9;
initial n11 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i4 == 1'b1)
    case (i3)
      4'b0000 : n11 <= 32'b01111111111111110000000000000000;
      4'b0001 : n11 <= 32'b01111101100010101110011100000111;
      4'b0010 : n11 <= 32'b01110110010000011100111100000100;
      4'b0011 : n11 <= 32'b01101010011011011011100011100011;
      4'b0100 : n11 <= 32'b01011010100000101010010101111101;
      4'b0101 : n11 <= 32'b01000111000111001001010110010010;
      4'b0110 : n11 <= 32'b00110000111110111000100110111110;
      4'b0111 : n11 <= 32'b00011000111110001000001001110101;
      4'b1000 : n11 <= 32'b00000000000000001000000000000000;
      4'b1001 : n11 <= 32'b11100111000001111000001001110101;
      4'b1010 : n11 <= 32'b11001111000001001000100110111110;
      4'b1011 : n11 <= 32'b10111000111000111001010110010010;
      4'b1100 : n11 <= 32'b10100101011111011010010101111101;
      4'b1101 : n11 <= 32'b10010101100100101011100011100011;
      4'b1110 : n11 <= 32'b10001001101111101100111100000100;
      4'b1111 : n11 <= 32'b10000010011101011110011100000111;
      default : n11 <= 32'bxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx;
    endcase
assign n12 = {n11[31],
  n11[30],
  n11[29],
  n11[28],
  n11[27],
  n11[26],
  n11[25],
  n11[24],
  n11[23],
  n11[22],
  n11[21],
  n11[20],
  n11[19],
  n11[18],
  n11[17],
  n11[16]};
assign n13 = {n11[15],
  n11[14],
  n11[13],
  n11[12],
  n11[11],
  n11[10],
  n11[9],
  n11[8],
  n11[7],
  n11[6],
  n11[5],
  n11[4],
  n11[3],
  n11[2],
  n11[1],
  n11[0]};
assign n14 = {{16{n5[15]}}, n5} * {{16{n12[15]}}, n12};
assign n15 = {n14[30],
  n14[29],
  n14[28],
  n14[27],
  n14[26],
  n14[25],
  n14[24],
  n14[23],
  n14[22],
  n14[21],
  n14[20],
  n14[19],
  n14[18],
  n14[17],
  n14[16],
  n14[15]};
initial n16 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n16 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n16 <= n15;
assign n17 = {{16{n6[15]}}, n6} * {{16{n13[15]}}, n13};
assign n18 = {n17[30],
  n17[29],
  n17[28],
  n17[27],
  n17[26],
  n17[25],
  n17[24],
  n17[23],
  n17[22],
  n17[21],
  n17[20],
  n17[19],
  n17[18],
  n17[17],
  n17[16],
  n17[15]};
initial n19 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n19 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n19 <= n18;
assign n20 = n16 - n19;
initial n21 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n21 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n21 <= n20;
assign n22 = {{16{n5[15]}}, n5} * {{16{n13[15]}}, n13};
assign n23 = {n22[30],
  n22[29],
  n22[28],
  n22[27],
  n22[26],
  n22[25],
  n22[24],
  n22[23],
  n22[22],
  n22[21],
  n22[20],
  n22[19],
  n22[18],
  n22[17],
  n22[16],
  n22[15]};
initial n24 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n24 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n24 <= n23;
assign n25 = {{16{n6[15]}}, n6} * {{16{n12[15]}}, n12};
assign n26 = {n25[30],
  n25[29],
  n25[28],
  n25[27],
  n25[26],
  n25[25],
  n25[24],
  n25[23],
  n25[22],
  n25[21],
  n25[20],
  n25[19],
  n25[18],
  n25[17],
  n25[16],
  n25[15]};
initial n27 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n27 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n27 <= n26;
assign n28 = n24 + n27;
initial n29 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n29 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n29 <= n28;
assign n30 = n8 + n21;
assign n31 = n10 + n29;
assign n32 = {n30, n31};
initial n33 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n33 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n33 <= n32;
assign n34 = n8 - n21;
assign n35 = n10 - n29;
assign n36 = {n34, n35};
initial n37 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n37 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n37 <= n36;
assign o2 = n37;
assign o1 = n33;
endmodule

module cf_fft_256_16_12 (clock_c, i1, i2, i3, i4, i5, o1, o2, o3);
input  clock_c;
input  i1;
input  [31:0] i2;
input  [31:0] i3;
input  i4;
input  i5;
output o1;
output [31:0] o2;
output [31:0] o3;
wire   [4:0] n1;
wire   [63:0] n2;
reg    n3;
reg    n4;
reg    n5;
reg    n6;
wire   [5:0] n7;
reg    [5:0] n8;
reg    [5:0] n9;
reg    [5:0] n10;
reg    [5:0] n11;
wire   n12;
reg    n13;
reg    n14;
reg    n15;
reg    n16;
wire   n17;
wire   [1:0] n18;
wire   [31:0] n19;
wire   [31:0] n20;
wire   [31:0] n21;
wire   [31:0] n22;
wire   [31:0] n23;
wire   [31:0] n24;
wire   s25_1;
wire   [31:0] s26_1;
wire   [31:0] s26_2;
wire   [6:0] s27_1;
wire   s27_2;
wire   s28_1;
wire   s28_2;
wire   [63:0] s28_3;
wire   [63:0] s29_1;
assign n1 = {s27_1[6],
  s27_1[5],
  s27_1[4],
  s27_1[3],
  s27_1[2]};
assign n2 = {s26_1, s26_2};
initial n3 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n3 <= 1'b0;
  else if (i4 == 1'b1)
    n3 <= s27_2;
initial n4 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n4 <= 1'b0;
  else if (i4 == 1'b1)
    n4 <= n3;
initial n5 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n5 <= 1'b0;
  else if (i4 == 1'b1)
    n5 <= n4;
initial n6 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n6 <= 1'b0;
  else if (i4 == 1'b1)
    n6 <= n5;
assign n7 = {s27_1[6],
  s27_1[5],
  s27_1[4],
  s27_1[3],
  s27_1[2],
  s27_1[1]};
initial n8 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n8 <= 6'b000000;
  else if (i4 == 1'b1)
    n8 <= n7;
initial n9 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n9 <= 6'b000000;
  else if (i4 == 1'b1)
    n9 <= n8;
initial n10 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n10 <= 6'b000000;
  else if (i4 == 1'b1)
    n10 <= n9;
initial n11 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n11 <= 6'b000000;
  else if (i4 == 1'b1)
    n11 <= n10;
assign n12 = s27_1[0];
initial n13 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n13 <= 1'b0;
  else if (i4 == 1'b1)
    n13 <= n12;
initial n14 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n14 <= 1'b0;
  else if (i4 == 1'b1)
    n14 <= n13;
initial n15 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n15 <= 1'b0;
  else if (i4 == 1'b1)
    n15 <= n14;
initial n16 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n16 <= 1'b0;
  else if (i4 == 1'b1)
    n16 <= n15;
assign n17 = ~n16;
assign n18 = {s28_2, s28_1};
assign n19 = {s28_3[63],
  s28_3[62],
  s28_3[61],
  s28_3[60],
  s28_3[59],
  s28_3[58],
  s28_3[57],
  s28_3[56],
  s28_3[55],
  s28_3[54],
  s28_3[53],
  s28_3[52],
  s28_3[51],
  s28_3[50],
  s28_3[49],
  s28_3[48],
  s28_3[47],
  s28_3[46],
  s28_3[45],
  s28_3[44],
  s28_3[43],
  s28_3[42],
  s28_3[41],
  s28_3[40],
  s28_3[39],
  s28_3[38],
  s28_3[37],
  s28_3[36],
  s28_3[35],
  s28_3[34],
  s28_3[33],
  s28_3[32]};
assign n20 = {s28_3[31],
  s28_3[30],
  s28_3[29],
  s28_3[28],
  s28_3[27],
  s28_3[26],
  s28_3[25],
  s28_3[24],
  s28_3[23],
  s28_3[22],
  s28_3[21],
  s28_3[20],
  s28_3[19],
  s28_3[18],
  s28_3[17],
  s28_3[16],
  s28_3[15],
  s28_3[14],
  s28_3[13],
  s28_3[12],
  s28_3[11],
  s28_3[10],
  s28_3[9],
  s28_3[8],
  s28_3[7],
  s28_3[6],
  s28_3[5],
  s28_3[4],
  s28_3[3],
  s28_3[2],
  s28_3[1],
  s28_3[0]};
assign n21 = {s29_1[63],
  s29_1[62],
  s29_1[61],
  s29_1[60],
  s29_1[59],
  s29_1[58],
  s29_1[57],
  s29_1[56],
  s29_1[55],
  s29_1[54],
  s29_1[53],
  s29_1[52],
  s29_1[51],
  s29_1[50],
  s29_1[49],
  s29_1[48],
  s29_1[47],
  s29_1[46],
  s29_1[45],
  s29_1[44],
  s29_1[43],
  s29_1[42],
  s29_1[41],
  s29_1[40],
  s29_1[39],
  s29_1[38],
  s29_1[37],
  s29_1[36],
  s29_1[35],
  s29_1[34],
  s29_1[33],
  s29_1[32]};
assign n22 = {s29_1[31],
  s29_1[30],
  s29_1[29],
  s29_1[28],
  s29_1[27],
  s29_1[26],
  s29_1[25],
  s29_1[24],
  s29_1[23],
  s29_1[22],
  s29_1[21],
  s29_1[20],
  s29_1[19],
  s29_1[18],
  s29_1[17],
  s29_1[16],
  s29_1[15],
  s29_1[14],
  s29_1[13],
  s29_1[12],
  s29_1[11],
  s29_1[10],
  s29_1[9],
  s29_1[8],
  s29_1[7],
  s29_1[6],
  s29_1[5],
  s29_1[4],
  s29_1[3],
  s29_1[2],
  s29_1[1],
  s29_1[0]};
assign n23 = s25_1 ? n20 : n19;
assign n24 = s25_1 ? n22 : n21;
cf_fft_256_16_30 s25 (clock_c, n18, i4, i5, s25_1);
cf_fft_256_16_13 s26 (clock_c, i2, i3, n1, i4, i5, s26_1, s26_2);
cf_fft_256_16_21 s27 (clock_c, i1, i4, i5, s27_1, s27_2);
cf_fft_256_16_18 s28 (clock_c, n2, n6, n11, n17, i4, i5, s28_1, s28_2, s28_3);
cf_fft_256_16_17 s29 (clock_c, n2, n6, n11, n16, i4, i5, s29_1);
assign o3 = n24;
assign o2 = n23;
assign o1 = s28_1;
endmodule

module cf_fft_256_16_13 (clock_c, i1, i2, i3, i4, i5, o1, o2);
input  clock_c;
input  [31:0] i1;
input  [31:0] i2;
input  [4:0] i3;
input  i4;
input  i5;
output [31:0] o1;
output [31:0] o2;
reg    [31:0] n1;
wire   [15:0] n2;
wire   [15:0] n3;
reg    [31:0] n4;
wire   [15:0] n5;
wire   [15:0] n6;
reg    [15:0] n7;
reg    [15:0] n8;
reg    [15:0] n9;
reg    [15:0] n10;
reg    [31:0] n11;
wire   [15:0] n12;
wire   [15:0] n13;
wire   [31:0] n14;
wire   [15:0] n15;
reg    [15:0] n16;
wire   [31:0] n17;
wire   [15:0] n18;
reg    [15:0] n19;
wire   [15:0] n20;
reg    [15:0] n21;
wire   [31:0] n22;
wire   [15:0] n23;
reg    [15:0] n24;
wire   [31:0] n25;
wire   [15:0] n26;
reg    [15:0] n27;
wire   [15:0] n28;
reg    [15:0] n29;
wire   [15:0] n30;
wire   [15:0] n31;
wire   [31:0] n32;
reg    [31:0] n33;
wire   [15:0] n34;
wire   [15:0] n35;
wire   [31:0] n36;
reg    [31:0] n37;
initial n1 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n1 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n1 <= i1;
assign n2 = {n1[31],
  n1[30],
  n1[29],
  n1[28],
  n1[27],
  n1[26],
  n1[25],
  n1[24],
  n1[23],
  n1[22],
  n1[21],
  n1[20],
  n1[19],
  n1[18],
  n1[17],
  n1[16]};
assign n3 = {n1[15],
  n1[14],
  n1[13],
  n1[12],
  n1[11],
  n1[10],
  n1[9],
  n1[8],
  n1[7],
  n1[6],
  n1[5],
  n1[4],
  n1[3],
  n1[2],
  n1[1],
  n1[0]};
initial n4 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n4 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n4 <= i2;
assign n5 = {n4[31],
  n4[30],
  n4[29],
  n4[28],
  n4[27],
  n4[26],
  n4[25],
  n4[24],
  n4[23],
  n4[22],
  n4[21],
  n4[20],
  n4[19],
  n4[18],
  n4[17],
  n4[16]};
assign n6 = {n4[15],
  n4[14],
  n4[13],
  n4[12],
  n4[11],
  n4[10],
  n4[9],
  n4[8],
  n4[7],
  n4[6],
  n4[5],
  n4[4],
  n4[3],
  n4[2],
  n4[1],
  n4[0]};
initial n7 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n7 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n7 <= n2;
initial n8 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n8 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n8 <= n7;
initial n9 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n9 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n9 <= n3;
initial n10 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n10 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n10 <= n9;
initial n11 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i4 == 1'b1)
    case (i3)
      5'b00000 : n11 <= 32'b01111111111111110000000000000000;
      5'b00001 : n11 <= 32'b01111111011000101111001101110100;
      5'b00010 : n11 <= 32'b01111101100010101110011100000111;
      5'b00011 : n11 <= 32'b01111010011111011101101011010111;
      5'b00100 : n11 <= 32'b01110110010000011100111100000100;
      5'b00101 : n11 <= 32'b01110000111000101100001110101001;
      5'b00110 : n11 <= 32'b01101010011011011011100011100011;
      5'b00111 : n11 <= 32'b01100010111100101010111011001100;
      5'b01000 : n11 <= 32'b01011010100000101010010101111101;
      5'b01001 : n11 <= 32'b01010001001100111001110100001101;
      5'b01010 : n11 <= 32'b01000111000111001001010110010010;
      5'b01011 : n11 <= 32'b00111100010101101000111100011101;
      5'b01100 : n11 <= 32'b00110000111110111000100110111110;
      5'b01101 : n11 <= 32'b00100101001010001000010110000010;
      5'b01110 : n11 <= 32'b00011000111110001000001001110101;
      5'b01111 : n11 <= 32'b00001100100010111000000010011101;
      5'b10000 : n11 <= 32'b00000000000000001000000000000000;
      5'b10001 : n11 <= 32'b11110011011101001000000010011101;
      5'b10010 : n11 <= 32'b11100111000001111000001001110101;
      5'b10011 : n11 <= 32'b11011010110101111000010110000010;
      5'b10100 : n11 <= 32'b11001111000001001000100110111110;
      5'b10101 : n11 <= 32'b11000011101010011000111100011101;
      5'b10110 : n11 <= 32'b10111000111000111001010110010010;
      5'b10111 : n11 <= 32'b10101110110011001001110100001101;
      5'b11000 : n11 <= 32'b10100101011111011010010101111101;
      5'b11001 : n11 <= 32'b10011101000011011010111011001100;
      5'b11010 : n11 <= 32'b10010101100100101011100011100011;
      5'b11011 : n11 <= 32'b10001111000111011100001110101001;
      5'b11100 : n11 <= 32'b10001001101111101100111100000100;
      5'b11101 : n11 <= 32'b10000101100000101101101011010111;
      5'b11110 : n11 <= 32'b10000010011101011110011100000111;
      5'b11111 : n11 <= 32'b10000000100111011111001101110100;
      default : n11 <= 32'bxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx;
    endcase
assign n12 = {n11[31],
  n11[30],
  n11[29],
  n11[28],
  n11[27],
  n11[26],
  n11[25],
  n11[24],
  n11[23],
  n11[22],
  n11[21],
  n11[20],
  n11[19],
  n11[18],
  n11[17],
  n11[16]};
assign n13 = {n11[15],
  n11[14],
  n11[13],
  n11[12],
  n11[11],
  n11[10],
  n11[9],
  n11[8],
  n11[7],
  n11[6],
  n11[5],
  n11[4],
  n11[3],
  n11[2],
  n11[1],
  n11[0]};
assign n14 = {{16{n5[15]}}, n5} * {{16{n12[15]}}, n12};
assign n15 = {n14[30],
  n14[29],
  n14[28],
  n14[27],
  n14[26],
  n14[25],
  n14[24],
  n14[23],
  n14[22],
  n14[21],
  n14[20],
  n14[19],
  n14[18],
  n14[17],
  n14[16],
  n14[15]};
initial n16 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n16 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n16 <= n15;
assign n17 = {{16{n6[15]}}, n6} * {{16{n13[15]}}, n13};
assign n18 = {n17[30],
  n17[29],
  n17[28],
  n17[27],
  n17[26],
  n17[25],
  n17[24],
  n17[23],
  n17[22],
  n17[21],
  n17[20],
  n17[19],
  n17[18],
  n17[17],
  n17[16],
  n17[15]};
initial n19 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n19 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n19 <= n18;
assign n20 = n16 - n19;
initial n21 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n21 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n21 <= n20;
assign n22 = {{16{n5[15]}}, n5} * {{16{n13[15]}}, n13};
assign n23 = {n22[30],
  n22[29],
  n22[28],
  n22[27],
  n22[26],
  n22[25],
  n22[24],
  n22[23],
  n22[22],
  n22[21],
  n22[20],
  n22[19],
  n22[18],
  n22[17],
  n22[16],
  n22[15]};
initial n24 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n24 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n24 <= n23;
assign n25 = {{16{n6[15]}}, n6} * {{16{n12[15]}}, n12};
assign n26 = {n25[30],
  n25[29],
  n25[28],
  n25[27],
  n25[26],
  n25[25],
  n25[24],
  n25[23],
  n25[22],
  n25[21],
  n25[20],
  n25[19],
  n25[18],
  n25[17],
  n25[16],
  n25[15]};
initial n27 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n27 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n27 <= n26;
assign n28 = n24 + n27;
initial n29 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n29 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n29 <= n28;
assign n30 = n8 + n21;
assign n31 = n10 + n29;
assign n32 = {n30, n31};
initial n33 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n33 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n33 <= n32;
assign n34 = n8 - n21;
assign n35 = n10 - n29;
assign n36 = {n34, n35};
initial n37 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n37 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n37 <= n36;
assign o2 = n37;
assign o1 = n33;
endmodule

module cf_fft_256_16_14 (clock_c, i1, i2, i3, i4, i5, o1, o2, o3);
input  clock_c;
input  i1;
input  [31:0] i2;
input  [31:0] i3;
input  i4;
input  i5;
output o1;
output [31:0] o2;
output [31:0] o3;
wire   [6:0] n1;
wire   [63:0] n2;
reg    n3;
reg    n4;
reg    n5;
reg    n6;
wire   [5:0] n7;
reg    [5:0] n8;
reg    [5:0] n9;
reg    [5:0] n10;
reg    [5:0] n11;
wire   n12;
reg    n13;
reg    n14;
reg    n15;
reg    n16;
wire   n17;
wire   [1:0] n18;
wire   [31:0] n19;
wire   [31:0] n20;
wire   [31:0] n21;
wire   [31:0] n22;
wire   [31:0] n23;
wire   [31:0] n24;
wire   [31:0] s25_1;
wire   [31:0] s25_2;
wire   s26_1;
wire   [6:0] s27_1;
wire   s27_2;
wire   [63:0] s28_1;
wire   s29_1;
wire   s29_2;
wire   [63:0] s29_3;
assign n1 = {s27_1[6],
  s27_1[5],
  s27_1[4],
  s27_1[3],
  s27_1[2],
  s27_1[1],
  s27_1[0]};
assign n2 = {s25_1, s25_2};
initial n3 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n3 <= 1'b0;
  else if (i4 == 1'b1)
    n3 <= s27_2;
initial n4 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n4 <= 1'b0;
  else if (i4 == 1'b1)
    n4 <= n3;
initial n5 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n5 <= 1'b0;
  else if (i4 == 1'b1)
    n5 <= n4;
initial n6 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n6 <= 1'b0;
  else if (i4 == 1'b1)
    n6 <= n5;
assign n7 = {s27_1[6],
  s27_1[5],
  s27_1[4],
  s27_1[3],
  s27_1[2],
  s27_1[1]};
initial n8 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n8 <= 6'b000000;
  else if (i4 == 1'b1)
    n8 <= n7;
initial n9 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n9 <= 6'b000000;
  else if (i4 == 1'b1)
    n9 <= n8;
initial n10 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n10 <= 6'b000000;
  else if (i4 == 1'b1)
    n10 <= n9;
initial n11 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n11 <= 6'b000000;
  else if (i4 == 1'b1)
    n11 <= n10;
assign n12 = s27_1[0];
initial n13 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n13 <= 1'b0;
  else if (i4 == 1'b1)
    n13 <= n12;
initial n14 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n14 <= 1'b0;
  else if (i4 == 1'b1)
    n14 <= n13;
initial n15 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n15 <= 1'b0;
  else if (i4 == 1'b1)
    n15 <= n14;
initial n16 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n16 <= 1'b0;
  else if (i4 == 1'b1)
    n16 <= n15;
assign n17 = ~n16;
assign n18 = {s29_2, s29_1};
assign n19 = {s29_3[63],
  s29_3[62],
  s29_3[61],
  s29_3[60],
  s29_3[59],
  s29_3[58],
  s29_3[57],
  s29_3[56],
  s29_3[55],
  s29_3[54],
  s29_3[53],
  s29_3[52],
  s29_3[51],
  s29_3[50],
  s29_3[49],
  s29_3[48],
  s29_3[47],
  s29_3[46],
  s29_3[45],
  s29_3[44],
  s29_3[43],
  s29_3[42],
  s29_3[41],
  s29_3[40],
  s29_3[39],
  s29_3[38],
  s29_3[37],
  s29_3[36],
  s29_3[35],
  s29_3[34],
  s29_3[33],
  s29_3[32]};
assign n20 = {s29_3[31],
  s29_3[30],
  s29_3[29],
  s29_3[28],
  s29_3[27],
  s29_3[26],
  s29_3[25],
  s29_3[24],
  s29_3[23],
  s29_3[22],
  s29_3[21],
  s29_3[20],
  s29_3[19],
  s29_3[18],
  s29_3[17],
  s29_3[16],
  s29_3[15],
  s29_3[14],
  s29_3[13],
  s29_3[12],
  s29_3[11],
  s29_3[10],
  s29_3[9],
  s29_3[8],
  s29_3[7],
  s29_3[6],
  s29_3[5],
  s29_3[4],
  s29_3[3],
  s29_3[2],
  s29_3[1],
  s29_3[0]};
assign n21 = {s28_1[63],
  s28_1[62],
  s28_1[61],
  s28_1[60],
  s28_1[59],
  s28_1[58],
  s28_1[57],
  s28_1[56],
  s28_1[55],
  s28_1[54],
  s28_1[53],
  s28_1[52],
  s28_1[51],
  s28_1[50],
  s28_1[49],
  s28_1[48],
  s28_1[47],
  s28_1[46],
  s28_1[45],
  s28_1[44],
  s28_1[43],
  s28_1[42],
  s28_1[41],
  s28_1[40],
  s28_1[39],
  s28_1[38],
  s28_1[37],
  s28_1[36],
  s28_1[35],
  s28_1[34],
  s28_1[33],
  s28_1[32]};
assign n22 = {s28_1[31],
  s28_1[30],
  s28_1[29],
  s28_1[28],
  s28_1[27],
  s28_1[26],
  s28_1[25],
  s28_1[24],
  s28_1[23],
  s28_1[22],
  s28_1[21],
  s28_1[20],
  s28_1[19],
  s28_1[18],
  s28_1[17],
  s28_1[16],
  s28_1[15],
  s28_1[14],
  s28_1[13],
  s28_1[12],
  s28_1[11],
  s28_1[10],
  s28_1[9],
  s28_1[8],
  s28_1[7],
  s28_1[6],
  s28_1[5],
  s28_1[4],
  s28_1[3],
  s28_1[2],
  s28_1[1],
  s28_1[0]};
assign n23 = s26_1 ? n20 : n19;
assign n24 = s26_1 ? n22 : n21;
cf_fft_256_16_15 s25 (clock_c, i2, i3, n1, i4, i5, s25_1, s25_2);
cf_fft_256_16_30 s26 (clock_c, n18, i4, i5, s26_1);
cf_fft_256_16_21 s27 (clock_c, i1, i4, i5, s27_1, s27_2);
cf_fft_256_16_17 s28 (clock_c, n2, n6, n11, n16, i4, i5, s28_1);
cf_fft_256_16_18 s29 (clock_c, n2, n6, n11, n17, i4, i5, s29_1, s29_2, s29_3);
assign o3 = n24;
assign o2 = n23;
assign o1 = s29_1;
endmodule

module cf_fft_256_16_15 (clock_c, i1, i2, i3, i4, i5, o1, o2);
input  clock_c;
input  [31:0] i1;
input  [31:0] i2;
input  [6:0] i3;
input  i4;
input  i5;
output [31:0] o1;
output [31:0] o2;
reg    [31:0] n1;
wire   [15:0] n2;
wire   [15:0] n3;
reg    [31:0] n4;
wire   [15:0] n5;
wire   [15:0] n6;
reg    [15:0] n7;
reg    [15:0] n8;
reg    [15:0] n9;
reg    [15:0] n10;
reg    [31:0] n11;
wire   [15:0] n12;
wire   [15:0] n13;
wire   [31:0] n14;
wire   [15:0] n15;
reg    [15:0] n16;
wire   [31:0] n17;
wire   [15:0] n18;
reg    [15:0] n19;
wire   [15:0] n20;
reg    [15:0] n21;
wire   [31:0] n22;
wire   [15:0] n23;
reg    [15:0] n24;
wire   [31:0] n25;
wire   [15:0] n26;
reg    [15:0] n27;
wire   [15:0] n28;
reg    [15:0] n29;
wire   [15:0] n30;
wire   [15:0] n31;
wire   [31:0] n32;
reg    [31:0] n33;
wire   [15:0] n34;
wire   [15:0] n35;
wire   [31:0] n36;
reg    [31:0] n37;
initial n1 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n1 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n1 <= i1;
assign n2 = {n1[31],
  n1[30],
  n1[29],
  n1[28],
  n1[27],
  n1[26],
  n1[25],
  n1[24],
  n1[23],
  n1[22],
  n1[21],
  n1[20],
  n1[19],
  n1[18],
  n1[17],
  n1[16]};
assign n3 = {n1[15],
  n1[14],
  n1[13],
  n1[12],
  n1[11],
  n1[10],
  n1[9],
  n1[8],
  n1[7],
  n1[6],
  n1[5],
  n1[4],
  n1[3],
  n1[2],
  n1[1],
  n1[0]};
initial n4 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n4 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n4 <= i2;
assign n5 = {n4[31],
  n4[30],
  n4[29],
  n4[28],
  n4[27],
  n4[26],
  n4[25],
  n4[24],
  n4[23],
  n4[22],
  n4[21],
  n4[20],
  n4[19],
  n4[18],
  n4[17],
  n4[16]};
assign n6 = {n4[15],
  n4[14],
  n4[13],
  n4[12],
  n4[11],
  n4[10],
  n4[9],
  n4[8],
  n4[7],
  n4[6],
  n4[5],
  n4[4],
  n4[3],
  n4[2],
  n4[1],
  n4[0]};
initial n7 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n7 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n7 <= n2;
initial n8 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n8 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n8 <= n7;
initial n9 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n9 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n9 <= n3;
initial n10 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n10 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n10 <= n9;
initial n11 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i4 == 1'b1)
    case (i3)
      7'b0000000 : n11 <= 32'b01111111111111110000000000000000;
      7'b0000001 : n11 <= 32'b01111111111101101111110011011011;
      7'b0000010 : n11 <= 32'b01111111110110001111100110111000;
      7'b0000011 : n11 <= 32'b01111111101001111111011010010101;
      7'b0000100 : n11 <= 32'b01111111011000101111001101110100;
      7'b0000101 : n11 <= 32'b01111111000010011111000001010100;
      7'b0000110 : n11 <= 32'b01111110100111011110110100110111;
      7'b0000111 : n11 <= 32'b01111110000111011110101000011101;
      7'b0001000 : n11 <= 32'b01111101100010101110011100000111;
      7'b0001001 : n11 <= 32'b01111100111000111110001111110100;
      7'b0001010 : n11 <= 32'b01111100001010011110000011100110;
      7'b0001011 : n11 <= 32'b01111011010111011101110111011100;
      7'b0001100 : n11 <= 32'b01111010011111011101101011010111;
      7'b0001101 : n11 <= 32'b01111001100010101101011111011001;
      7'b0001110 : n11 <= 32'b01111000100001001101010011100000;
      7'b0001111 : n11 <= 32'b01110111011011001101000111101110;
      7'b0010000 : n11 <= 32'b01110110010000011100111100000100;
      7'b0010001 : n11 <= 32'b01110101000001001100110000100001;
      7'b0010010 : n11 <= 32'b01110011101101011100100101000101;
      7'b0010011 : n11 <= 32'b01110010010101011100011001110011;
      7'b0010100 : n11 <= 32'b01110000111000101100001110101001;
      7'b0010101 : n11 <= 32'b01101111010111111100000011101000;
      7'b0010110 : n11 <= 32'b01101101110010101011111000110001;
      7'b0010111 : n11 <= 32'b01101100001001001011101110000101;
      7'b0011000 : n11 <= 32'b01101010011011011011100011100011;
      7'b0011001 : n11 <= 32'b01101000101001101011011001001011;
      7'b0011010 : n11 <= 32'b01100110110011111011001111000000;
      7'b0011011 : n11 <= 32'b01100100111010001011000101000000;
      7'b0011100 : n11 <= 32'b01100010111100101010111011001100;
      7'b0011101 : n11 <= 32'b01100000111011001010110001100100;
      7'b0011110 : n11 <= 32'b01011110110101111010101000001010;
      7'b0011111 : n11 <= 32'b01011100101101001010011110111101;
      7'b0100000 : n11 <= 32'b01011010100000101010010101111101;
      7'b0100001 : n11 <= 32'b01011000010000101010001101001011;
      7'b0100010 : n11 <= 32'b01010101111101011010000100101000;
      7'b0100011 : n11 <= 32'b01010011100110111001111100010011;
      7'b0100100 : n11 <= 32'b01010001001100111001110100001101;
      7'b0100101 : n11 <= 32'b01001110101111111001101100010111;
      7'b0100110 : n11 <= 32'b01001100001111111001100100110000;
      7'b0100111 : n11 <= 32'b01001001101101001001011101011001;
      7'b0101000 : n11 <= 32'b01000111000111001001010110010010;
      7'b0101001 : n11 <= 32'b01000100011110101001001111011011;
      7'b0101010 : n11 <= 32'b01000001110011101001001000110101;
      7'b0101011 : n11 <= 32'b00111111000101111001000010100000;
      7'b0101100 : n11 <= 32'b00111100010101101000111100011101;
      7'b0101101 : n11 <= 32'b00111001100011001000110110101010;
      7'b0101110 : n11 <= 32'b00110110101110101000110001001010;
      7'b0101111 : n11 <= 32'b00110011110111101000101011111011;
      7'b0110000 : n11 <= 32'b00110000111110111000100110111110;
      7'b0110001 : n11 <= 32'b00101110000100011000100010010011;
      7'b0110010 : n11 <= 32'b00101011000111111000011101111011;
      7'b0110011 : n11 <= 32'b00101000001001101000011001110101;
      7'b0110100 : n11 <= 32'b00100101001010001000010110000010;
      7'b0110101 : n11 <= 32'b00100010001000111000010010100010;
      7'b0110110 : n11 <= 32'b00011111000110011000001111010110;
      7'b0110111 : n11 <= 32'b00011100000010111000001100011100;
      7'b0111000 : n11 <= 32'b00011000111110001000001001110101;
      7'b0111001 : n11 <= 32'b00010101111000101000000111100010;
      7'b0111010 : n11 <= 32'b00010010110010001000000101100010;
      7'b0111011 : n11 <= 32'b00001111101010111000000011110110;
      7'b0111100 : n11 <= 32'b00001100100010111000000010011101;
      7'b0111101 : n11 <= 32'b00001001011010101000000001011000;
      7'b0111110 : n11 <= 32'b00000110010001111000000000100111;
      7'b0111111 : n11 <= 32'b00000011001001001000000000001001;
      7'b1000000 : n11 <= 32'b00000000000000001000000000000000;
      7'b1000001 : n11 <= 32'b11111100110110111000000000001001;
      7'b1000010 : n11 <= 32'b11111001101110001000000000100111;
      7'b1000011 : n11 <= 32'b11110110100101011000000001011000;
      7'b1000100 : n11 <= 32'b11110011011101001000000010011101;
      7'b1000101 : n11 <= 32'b11110000010101001000000011110110;
      7'b1000110 : n11 <= 32'b11101101001101111000000101100010;
      7'b1000111 : n11 <= 32'b11101010000111011000000111100010;
      7'b1001000 : n11 <= 32'b11100111000001111000001001110101;
      7'b1001001 : n11 <= 32'b11100011111101001000001100011100;
      7'b1001010 : n11 <= 32'b11100000111001101000001111010110;
      7'b1001011 : n11 <= 32'b11011101110111001000010010100010;
      7'b1001100 : n11 <= 32'b11011010110101111000010110000010;
      7'b1001101 : n11 <= 32'b11010111110110011000011001110101;
      7'b1001110 : n11 <= 32'b11010100111000001000011101111011;
      7'b1001111 : n11 <= 32'b11010001111011101000100010010011;
      7'b1010000 : n11 <= 32'b11001111000001001000100110111110;
      7'b1010001 : n11 <= 32'b11001100001000011000101011111011;
      7'b1010010 : n11 <= 32'b11001001010001011000110001001010;
      7'b1010011 : n11 <= 32'b11000110011100111000110110101010;
      7'b1010100 : n11 <= 32'b11000011101010011000111100011101;
      7'b1010101 : n11 <= 32'b11000000111010001001000010100000;
      7'b1010110 : n11 <= 32'b10111110001100011001001000110101;
      7'b1010111 : n11 <= 32'b10111011100001011001001111011011;
      7'b1011000 : n11 <= 32'b10111000111000111001010110010010;
      7'b1011001 : n11 <= 32'b10110110010010111001011101011001;
      7'b1011010 : n11 <= 32'b10110011110000001001100100110000;
      7'b1011011 : n11 <= 32'b10110001010000001001101100010111;
      7'b1011100 : n11 <= 32'b10101110110011001001110100001101;
      7'b1011101 : n11 <= 32'b10101100011001001001111100010011;
      7'b1011110 : n11 <= 32'b10101010000010101010000100101000;
      7'b1011111 : n11 <= 32'b10100111101111011010001101001011;
      7'b1100000 : n11 <= 32'b10100101011111011010010101111101;
      7'b1100001 : n11 <= 32'b10100011010010111010011110111101;
      7'b1100010 : n11 <= 32'b10100001001010001010101000001010;
      7'b1100011 : n11 <= 32'b10011111000100111010110001100100;
      7'b1100100 : n11 <= 32'b10011101000011011010111011001100;
      7'b1100101 : n11 <= 32'b10011011000101111011000101000000;
      7'b1100110 : n11 <= 32'b10011001001100001011001111000000;
      7'b1100111 : n11 <= 32'b10010111010110011011011001001011;
      7'b1101000 : n11 <= 32'b10010101100100101011100011100011;
      7'b1101001 : n11 <= 32'b10010011110110111011101110000101;
      7'b1101010 : n11 <= 32'b10010010001101011011111000110001;
      7'b1101011 : n11 <= 32'b10010000101000001100000011101000;
      7'b1101100 : n11 <= 32'b10001111000111011100001110101001;
      7'b1101101 : n11 <= 32'b10001101101010101100011001110011;
      7'b1101110 : n11 <= 32'b10001100010010101100100101000101;
      7'b1101111 : n11 <= 32'b10001010111110111100110000100001;
      7'b1110000 : n11 <= 32'b10001001101111101100111100000100;
      7'b1110001 : n11 <= 32'b10001000100100111101000111101110;
      7'b1110010 : n11 <= 32'b10000111011110111101010011100000;
      7'b1110011 : n11 <= 32'b10000110011101011101011111011001;
      7'b1110100 : n11 <= 32'b10000101100000101101101011010111;
      7'b1110101 : n11 <= 32'b10000100101000101101110111011100;
      7'b1110110 : n11 <= 32'b10000011110101101110000011100110;
      7'b1110111 : n11 <= 32'b10000011000111001110001111110100;
      7'b1111000 : n11 <= 32'b10000010011101011110011100000111;
      7'b1111001 : n11 <= 32'b10000001111000101110101000011101;
      7'b1111010 : n11 <= 32'b10000001011000101110110100110111;
      7'b1111011 : n11 <= 32'b10000000111101101111000001010100;
      7'b1111100 : n11 <= 32'b10000000100111011111001101110100;
      7'b1111101 : n11 <= 32'b10000000010110001111011010010101;
      7'b1111110 : n11 <= 32'b10000000001001111111100110111000;
      7'b1111111 : n11 <= 32'b10000000000010011111110011011011;
      default : n11 <= 32'bxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx;
    endcase
assign n12 = {n11[31],
  n11[30],
  n11[29],
  n11[28],
  n11[27],
  n11[26],
  n11[25],
  n11[24],
  n11[23],
  n11[22],
  n11[21],
  n11[20],
  n11[19],
  n11[18],
  n11[17],
  n11[16]};
assign n13 = {n11[15],
  n11[14],
  n11[13],
  n11[12],
  n11[11],
  n11[10],
  n11[9],
  n11[8],
  n11[7],
  n11[6],
  n11[5],
  n11[4],
  n11[3],
  n11[2],
  n11[1],
  n11[0]};
assign n14 = {{16{n5[15]}}, n5} * {{16{n12[15]}}, n12};
assign n15 = {n14[30],
  n14[29],
  n14[28],
  n14[27],
  n14[26],
  n14[25],
  n14[24],
  n14[23],
  n14[22],
  n14[21],
  n14[20],
  n14[19],
  n14[18],
  n14[17],
  n14[16],
  n14[15]};
initial n16 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n16 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n16 <= n15;
assign n17 = {{16{n6[15]}}, n6} * {{16{n13[15]}}, n13};
assign n18 = {n17[30],
  n17[29],
  n17[28],
  n17[27],
  n17[26],
  n17[25],
  n17[24],
  n17[23],
  n17[22],
  n17[21],
  n17[20],
  n17[19],
  n17[18],
  n17[17],
  n17[16],
  n17[15]};
initial n19 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n19 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n19 <= n18;
assign n20 = n16 - n19;
initial n21 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n21 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n21 <= n20;
assign n22 = {{16{n5[15]}}, n5} * {{16{n13[15]}}, n13};
assign n23 = {n22[30],
  n22[29],
  n22[28],
  n22[27],
  n22[26],
  n22[25],
  n22[24],
  n22[23],
  n22[22],
  n22[21],
  n22[20],
  n22[19],
  n22[18],
  n22[17],
  n22[16],
  n22[15]};
initial n24 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n24 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n24 <= n23;
assign n25 = {{16{n6[15]}}, n6} * {{16{n12[15]}}, n12};
assign n26 = {n25[30],
  n25[29],
  n25[28],
  n25[27],
  n25[26],
  n25[25],
  n25[24],
  n25[23],
  n25[22],
  n25[21],
  n25[20],
  n25[19],
  n25[18],
  n25[17],
  n25[16],
  n25[15]};
initial n27 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n27 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n27 <= n26;
assign n28 = n24 + n27;
initial n29 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n29 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n29 <= n28;
assign n30 = n8 + n21;
assign n31 = n10 + n29;
assign n32 = {n30, n31};
initial n33 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n33 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n33 <= n32;
assign n34 = n8 - n21;
assign n35 = n10 - n29;
assign n36 = {n34, n35};
initial n37 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n37 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n37 <= n36;
assign o2 = n37;
assign o1 = n33;
endmodule

module cf_fft_256_16_16 (clock_c, i1, i2, i3, i4, i5, o1, o2, o3);
input  clock_c;
input  i1;
input  [31:0] i2;
input  [31:0] i3;
input  i4;
input  i5;
output o1;
output [31:0] o2;
output [31:0] o3;
wire   [5:0] n1;
wire   [63:0] n2;
reg    n3;
reg    n4;
reg    n5;
reg    n6;
wire   [5:0] n7;
reg    [5:0] n8;
reg    [5:0] n9;
reg    [5:0] n10;
reg    [5:0] n11;
wire   n12;
reg    n13;
reg    n14;
reg    n15;
reg    n16;
wire   n17;
wire   [1:0] n18;
wire   [31:0] n19;
wire   [31:0] n20;
wire   [31:0] n21;
wire   [31:0] n22;
wire   [31:0] n23;
wire   [31:0] n24;
wire   s25_1;
wire   [31:0] s26_1;
wire   [31:0] s26_2;
wire   [6:0] s27_1;
wire   s27_2;
wire   s28_1;
wire   s28_2;
wire   [63:0] s28_3;
wire   [63:0] s29_1;
assign n1 = {s27_1[6],
  s27_1[5],
  s27_1[4],
  s27_1[3],
  s27_1[2],
  s27_1[1]};
assign n2 = {s26_1, s26_2};
initial n3 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n3 <= 1'b0;
  else if (i4 == 1'b1)
    n3 <= s27_2;
initial n4 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n4 <= 1'b0;
  else if (i4 == 1'b1)
    n4 <= n3;
initial n5 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n5 <= 1'b0;
  else if (i4 == 1'b1)
    n5 <= n4;
initial n6 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n6 <= 1'b0;
  else if (i4 == 1'b1)
    n6 <= n5;
assign n7 = {s27_1[6],
  s27_1[5],
  s27_1[4],
  s27_1[3],
  s27_1[2],
  s27_1[1]};
initial n8 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n8 <= 6'b000000;
  else if (i4 == 1'b1)
    n8 <= n7;
initial n9 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n9 <= 6'b000000;
  else if (i4 == 1'b1)
    n9 <= n8;
initial n10 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n10 <= 6'b000000;
  else if (i4 == 1'b1)
    n10 <= n9;
initial n11 = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n11 <= 6'b000000;
  else if (i4 == 1'b1)
    n11 <= n10;
assign n12 = s27_1[0];
initial n13 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n13 <= 1'b0;
  else if (i4 == 1'b1)
    n13 <= n12;
initial n14 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n14 <= 1'b0;
  else if (i4 == 1'b1)
    n14 <= n13;
initial n15 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n15 <= 1'b0;
  else if (i4 == 1'b1)
    n15 <= n14;
initial n16 = 1'b0;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n16 <= 1'b0;
  else if (i4 == 1'b1)
    n16 <= n15;
assign n17 = ~n16;
assign n18 = {s28_2, s28_1};
assign n19 = {s28_3[63],
  s28_3[62],
  s28_3[61],
  s28_3[60],
  s28_3[59],
  s28_3[58],
  s28_3[57],
  s28_3[56],
  s28_3[55],
  s28_3[54],
  s28_3[53],
  s28_3[52],
  s28_3[51],
  s28_3[50],
  s28_3[49],
  s28_3[48],
  s28_3[47],
  s28_3[46],
  s28_3[45],
  s28_3[44],
  s28_3[43],
  s28_3[42],
  s28_3[41],
  s28_3[40],
  s28_3[39],
  s28_3[38],
  s28_3[37],
  s28_3[36],
  s28_3[35],
  s28_3[34],
  s28_3[33],
  s28_3[32]};
assign n20 = {s28_3[31],
  s28_3[30],
  s28_3[29],
  s28_3[28],
  s28_3[27],
  s28_3[26],
  s28_3[25],
  s28_3[24],
  s28_3[23],
  s28_3[22],
  s28_3[21],
  s28_3[20],
  s28_3[19],
  s28_3[18],
  s28_3[17],
  s28_3[16],
  s28_3[15],
  s28_3[14],
  s28_3[13],
  s28_3[12],
  s28_3[11],
  s28_3[10],
  s28_3[9],
  s28_3[8],
  s28_3[7],
  s28_3[6],
  s28_3[5],
  s28_3[4],
  s28_3[3],
  s28_3[2],
  s28_3[1],
  s28_3[0]};
assign n21 = {s29_1[63],
  s29_1[62],
  s29_1[61],
  s29_1[60],
  s29_1[59],
  s29_1[58],
  s29_1[57],
  s29_1[56],
  s29_1[55],
  s29_1[54],
  s29_1[53],
  s29_1[52],
  s29_1[51],
  s29_1[50],
  s29_1[49],
  s29_1[48],
  s29_1[47],
  s29_1[46],
  s29_1[45],
  s29_1[44],
  s29_1[43],
  s29_1[42],
  s29_1[41],
  s29_1[40],
  s29_1[39],
  s29_1[38],
  s29_1[37],
  s29_1[36],
  s29_1[35],
  s29_1[34],
  s29_1[33],
  s29_1[32]};
assign n22 = {s29_1[31],
  s29_1[30],
  s29_1[29],
  s29_1[28],
  s29_1[27],
  s29_1[26],
  s29_1[25],
  s29_1[24],
  s29_1[23],
  s29_1[22],
  s29_1[21],
  s29_1[20],
  s29_1[19],
  s29_1[18],
  s29_1[17],
  s29_1[16],
  s29_1[15],
  s29_1[14],
  s29_1[13],
  s29_1[12],
  s29_1[11],
  s29_1[10],
  s29_1[9],
  s29_1[8],
  s29_1[7],
  s29_1[6],
  s29_1[5],
  s29_1[4],
  s29_1[3],
  s29_1[2],
  s29_1[1],
  s29_1[0]};
assign n23 = s25_1 ? n20 : n19;
assign n24 = s25_1 ? n22 : n21;
cf_fft_256_16_30 s25 (clock_c, n18, i4, i5, s25_1);
cf_fft_256_16_19 s26 (clock_c, i2, i3, n1, i4, i5, s26_1, s26_2);
cf_fft_256_16_21 s27 (clock_c, i1, i4, i5, s27_1, s27_2);
cf_fft_256_16_18 s28 (clock_c, n2, n6, n11, n17, i4, i5, s28_1, s28_2, s28_3);
cf_fft_256_16_17 s29 (clock_c, n2, n6, n11, n16, i4, i5, s29_1);
assign o3 = n24;
assign o2 = n23;
assign o1 = s28_1;
endmodule

module cf_fft_256_16_17 (clock_c, i1, i2, i3, i4, i5, i6, o1);
input  clock_c;
input  [63:0] i1;
input  i2;
input  [5:0] i3;
input  i4;
input  i5;
input  i6;
output [63:0] o1;
wire   [5:0] n1;
wire   [5:0] n2;
reg    [5:0] n3;
wire   n4;
wire   n5;
wire   [63:0] n6;
reg    [5:0] n6a;
reg    [63:0] n6m [63:0];
wire   n7;
wire   [63:0] n8;
reg    [5:0] n8a;
reg    [63:0] n8m [63:0];
reg    n9;
wire   [63:0] n10;
wire   n11;
wire   s12_1;
assign n1 = 6'b000001;
assign n2 = n3 + n1;
initial n3 = 6'b000000;
always @ (posedge clock_c)
  if (n11 == 1'b1)
    n3 <= 6'b000000;
  else if (i5 == 1'b1)
    n3 <= n2;
assign n4 = ~s12_1;
assign n5 = i4 & n4;
initial n6a = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1) begin
    if (n5 == 1'b1)
      n6m[i3] <= i1;
    n6a <= n3;
  end
assign n6 = n6m[n6a];
assign n7 = i4 & s12_1;
initial n8a = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1) begin
    if (n7 == 1'b1)
      n8m[i3] <= i1;
    n8a <= n3;
  end
assign n8 = n8m[n8a];
initial n9 = 1'b0;
always @ (posedge clock_c)
  if (i6 == 1'b1)
    n9 <= 1'b0;
  else if (i5 == 1'b1)
    n9 <= n4;
assign n10 = n9 ? n8 : n6;
assign n11 = i2 | i6;
cf_fft_256_16_27 s12 (clock_c, i2, i5, i6, s12_1);
assign o1 = n10;
endmodule

module cf_fft_256_16_18 (clock_c, i1, i2, i3, i4, i5, i6, o1, o2, o3);
input  clock_c;
input  [63:0] i1;
input  i2;
input  [5:0] i3;
input  i4;
input  i5;
input  i6;
output o1;
output o2;
output [63:0] o3;
wire   [5:0] n1;
wire   [5:0] n2;
reg    [5:0] n3;
wire   n4;
reg    n5;
wire   [5:0] n6;
wire   n7;
wire   n8;
wire   [63:0] n9;
reg    [5:0] n9a;
reg    [63:0] n9m [63:0];
wire   n10;
wire   [63:0] n11;
reg    [5:0] n11a;
reg    [63:0] n11m [63:0];
reg    n12;
wire   [63:0] n13;
wire   n14;
wire   s15_1;
assign n1 = 6'b000001;
assign n2 = n3 + n1;
initial n3 = 6'b000000;
always @ (posedge clock_c)
  if (n14 == 1'b1)
    n3 <= 6'b000000;
  else if (i5 == 1'b1)
    n3 <= n2;
assign n4 = ~s15_1;
initial n5 = 1'b0;
always @ (posedge clock_c)
  if (i6 == 1'b1)
    n5 <= 1'b0;
  else if (i5 == 1'b1)
    n5 <= i2;
assign n6 = 6'b000000;
assign n7 = n3 == n6;
assign n8 = i4 & n4;
initial n9a = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1) begin
    if (n8 == 1'b1)
      n9m[i3] <= i1;
    n9a <= n3;
  end
assign n9 = n9m[n9a];
assign n10 = i4 & s15_1;
initial n11a = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1) begin
    if (n10 == 1'b1)
      n11m[i3] <= i1;
    n11a <= n3;
  end
assign n11 = n11m[n11a];
initial n12 = 1'b0;
always @ (posedge clock_c)
  if (i6 == 1'b1)
    n12 <= 1'b0;
  else if (i5 == 1'b1)
    n12 <= n4;
assign n13 = n12 ? n11 : n9;
assign n14 = i2 | i6;
cf_fft_256_16_27 s15 (clock_c, i2, i5, i6, s15_1);
assign o3 = n13;
assign o2 = n7;
assign o1 = n5;
endmodule

module cf_fft_256_16_19 (clock_c, i1, i2, i3, i4, i5, o1, o2);
input  clock_c;
input  [31:0] i1;
input  [31:0] i2;
input  [5:0] i3;
input  i4;
input  i5;
output [31:0] o1;
output [31:0] o2;
reg    [31:0] n1;
wire   [15:0] n2;
wire   [15:0] n3;
reg    [31:0] n4;
wire   [15:0] n5;
wire   [15:0] n6;
reg    [15:0] n7;
reg    [15:0] n8;
reg    [15:0] n9;
reg    [15:0] n10;
reg    [31:0] n11;
wire   [15:0] n12;
wire   [15:0] n13;
wire   [31:0] n14;
wire   [15:0] n15;
reg    [15:0] n16;
wire   [31:0] n17;
wire   [15:0] n18;
reg    [15:0] n19;
wire   [15:0] n20;
reg    [15:0] n21;
wire   [31:0] n22;
wire   [15:0] n23;
reg    [15:0] n24;
wire   [31:0] n25;
wire   [15:0] n26;
reg    [15:0] n27;
wire   [15:0] n28;
reg    [15:0] n29;
wire   [15:0] n30;
wire   [15:0] n31;
wire   [31:0] n32;
reg    [31:0] n33;
wire   [15:0] n34;
wire   [15:0] n35;
wire   [31:0] n36;
reg    [31:0] n37;
initial n1 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n1 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n1 <= i1;
assign n2 = {n1[31],
  n1[30],
  n1[29],
  n1[28],
  n1[27],
  n1[26],
  n1[25],
  n1[24],
  n1[23],
  n1[22],
  n1[21],
  n1[20],
  n1[19],
  n1[18],
  n1[17],
  n1[16]};
assign n3 = {n1[15],
  n1[14],
  n1[13],
  n1[12],
  n1[11],
  n1[10],
  n1[9],
  n1[8],
  n1[7],
  n1[6],
  n1[5],
  n1[4],
  n1[3],
  n1[2],
  n1[1],
  n1[0]};
initial n4 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n4 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n4 <= i2;
assign n5 = {n4[31],
  n4[30],
  n4[29],
  n4[28],
  n4[27],
  n4[26],
  n4[25],
  n4[24],
  n4[23],
  n4[22],
  n4[21],
  n4[20],
  n4[19],
  n4[18],
  n4[17],
  n4[16]};
assign n6 = {n4[15],
  n4[14],
  n4[13],
  n4[12],
  n4[11],
  n4[10],
  n4[9],
  n4[8],
  n4[7],
  n4[6],
  n4[5],
  n4[4],
  n4[3],
  n4[2],
  n4[1],
  n4[0]};
initial n7 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n7 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n7 <= n2;
initial n8 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n8 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n8 <= n7;
initial n9 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n9 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n9 <= n3;
initial n10 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n10 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n10 <= n9;
initial n11 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i4 == 1'b1)
    case (i3)
      6'b000000 : n11 <= 32'b01111111111111110000000000000000;
      6'b000001 : n11 <= 32'b01111111110110001111100110111000;
      6'b000010 : n11 <= 32'b01111111011000101111001101110100;
      6'b000011 : n11 <= 32'b01111110100111011110110100110111;
      6'b000100 : n11 <= 32'b01111101100010101110011100000111;
      6'b000101 : n11 <= 32'b01111100001010011110000011100110;
      6'b000110 : n11 <= 32'b01111010011111011101101011010111;
      6'b000111 : n11 <= 32'b01111000100001001101010011100000;
      6'b001000 : n11 <= 32'b01110110010000011100111100000100;
      6'b001001 : n11 <= 32'b01110011101101011100100101000101;
      6'b001010 : n11 <= 32'b01110000111000101100001110101001;
      6'b001011 : n11 <= 32'b01101101110010101011111000110001;
      6'b001100 : n11 <= 32'b01101010011011011011100011100011;
      6'b001101 : n11 <= 32'b01100110110011111011001111000000;
      6'b001110 : n11 <= 32'b01100010111100101010111011001100;
      6'b001111 : n11 <= 32'b01011110110101111010101000001010;
      6'b010000 : n11 <= 32'b01011010100000101010010101111101;
      6'b010001 : n11 <= 32'b01010101111101011010000100101000;
      6'b010010 : n11 <= 32'b01010001001100111001110100001101;
      6'b010011 : n11 <= 32'b01001100001111111001100100110000;
      6'b010100 : n11 <= 32'b01000111000111001001010110010010;
      6'b010101 : n11 <= 32'b01000001110011101001001000110101;
      6'b010110 : n11 <= 32'b00111100010101101000111100011101;
      6'b010111 : n11 <= 32'b00110110101110101000110001001010;
      6'b011000 : n11 <= 32'b00110000111110111000100110111110;
      6'b011001 : n11 <= 32'b00101011000111111000011101111011;
      6'b011010 : n11 <= 32'b00100101001010001000010110000010;
      6'b011011 : n11 <= 32'b00011111000110011000001111010110;
      6'b011100 : n11 <= 32'b00011000111110001000001001110101;
      6'b011101 : n11 <= 32'b00010010110010001000000101100010;
      6'b011110 : n11 <= 32'b00001100100010111000000010011101;
      6'b011111 : n11 <= 32'b00000110010001111000000000100111;
      6'b100000 : n11 <= 32'b00000000000000001000000000000000;
      6'b100001 : n11 <= 32'b11111001101110001000000000100111;
      6'b100010 : n11 <= 32'b11110011011101001000000010011101;
      6'b100011 : n11 <= 32'b11101101001101111000000101100010;
      6'b100100 : n11 <= 32'b11100111000001111000001001110101;
      6'b100101 : n11 <= 32'b11100000111001101000001111010110;
      6'b100110 : n11 <= 32'b11011010110101111000010110000010;
      6'b100111 : n11 <= 32'b11010100111000001000011101111011;
      6'b101000 : n11 <= 32'b11001111000001001000100110111110;
      6'b101001 : n11 <= 32'b11001001010001011000110001001010;
      6'b101010 : n11 <= 32'b11000011101010011000111100011101;
      6'b101011 : n11 <= 32'b10111110001100011001001000110101;
      6'b101100 : n11 <= 32'b10111000111000111001010110010010;
      6'b101101 : n11 <= 32'b10110011110000001001100100110000;
      6'b101110 : n11 <= 32'b10101110110011001001110100001101;
      6'b101111 : n11 <= 32'b10101010000010101010000100101000;
      6'b110000 : n11 <= 32'b10100101011111011010010101111101;
      6'b110001 : n11 <= 32'b10100001001010001010101000001010;
      6'b110010 : n11 <= 32'b10011101000011011010111011001100;
      6'b110011 : n11 <= 32'b10011001001100001011001111000000;
      6'b110100 : n11 <= 32'b10010101100100101011100011100011;
      6'b110101 : n11 <= 32'b10010010001101011011111000110001;
      6'b110110 : n11 <= 32'b10001111000111011100001110101001;
      6'b110111 : n11 <= 32'b10001100010010101100100101000101;
      6'b111000 : n11 <= 32'b10001001101111101100111100000100;
      6'b111001 : n11 <= 32'b10000111011110111101010011100000;
      6'b111010 : n11 <= 32'b10000101100000101101101011010111;
      6'b111011 : n11 <= 32'b10000011110101101110000011100110;
      6'b111100 : n11 <= 32'b10000010011101011110011100000111;
      6'b111101 : n11 <= 32'b10000001011000101110110100110111;
      6'b111110 : n11 <= 32'b10000000100111011111001101110100;
      6'b111111 : n11 <= 32'b10000000001001111111100110111000;
      default : n11 <= 32'bxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx;
    endcase
assign n12 = {n11[31],
  n11[30],
  n11[29],
  n11[28],
  n11[27],
  n11[26],
  n11[25],
  n11[24],
  n11[23],
  n11[22],
  n11[21],
  n11[20],
  n11[19],
  n11[18],
  n11[17],
  n11[16]};
assign n13 = {n11[15],
  n11[14],
  n11[13],
  n11[12],
  n11[11],
  n11[10],
  n11[9],
  n11[8],
  n11[7],
  n11[6],
  n11[5],
  n11[4],
  n11[3],
  n11[2],
  n11[1],
  n11[0]};
assign n14 = {{16{n5[15]}}, n5} * {{16{n12[15]}}, n12};
assign n15 = {n14[30],
  n14[29],
  n14[28],
  n14[27],
  n14[26],
  n14[25],
  n14[24],
  n14[23],
  n14[22],
  n14[21],
  n14[20],
  n14[19],
  n14[18],
  n14[17],
  n14[16],
  n14[15]};
initial n16 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n16 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n16 <= n15;
assign n17 = {{16{n6[15]}}, n6} * {{16{n13[15]}}, n13};
assign n18 = {n17[30],
  n17[29],
  n17[28],
  n17[27],
  n17[26],
  n17[25],
  n17[24],
  n17[23],
  n17[22],
  n17[21],
  n17[20],
  n17[19],
  n17[18],
  n17[17],
  n17[16],
  n17[15]};
initial n19 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n19 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n19 <= n18;
assign n20 = n16 - n19;
initial n21 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n21 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n21 <= n20;
assign n22 = {{16{n5[15]}}, n5} * {{16{n13[15]}}, n13};
assign n23 = {n22[30],
  n22[29],
  n22[28],
  n22[27],
  n22[26],
  n22[25],
  n22[24],
  n22[23],
  n22[22],
  n22[21],
  n22[20],
  n22[19],
  n22[18],
  n22[17],
  n22[16],
  n22[15]};
initial n24 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n24 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n24 <= n23;
assign n25 = {{16{n6[15]}}, n6} * {{16{n12[15]}}, n12};
assign n26 = {n25[30],
  n25[29],
  n25[28],
  n25[27],
  n25[26],
  n25[25],
  n25[24],
  n25[23],
  n25[22],
  n25[21],
  n25[20],
  n25[19],
  n25[18],
  n25[17],
  n25[16],
  n25[15]};
initial n27 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n27 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n27 <= n26;
assign n28 = n24 + n27;
initial n29 = 16'b0000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n29 <= 16'b0000000000000000;
  else if (i4 == 1'b1)
    n29 <= n28;
assign n30 = n8 + n21;
assign n31 = n10 + n29;
assign n32 = {n30, n31};
initial n33 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n33 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n33 <= n32;
assign n34 = n8 - n21;
assign n35 = n10 - n29;
assign n36 = {n34, n35};
initial n37 = 32'b00000000000000000000000000000000;
always @ (posedge clock_c)
  if (i5 == 1'b1)
    n37 <= 32'b00000000000000000000000000000000;
  else if (i4 == 1'b1)
    n37 <= n36;
assign o2 = n37;
assign o1 = n33;
endmodule

module cf_fft_256_16_20 (clock_c, i1, i2, i3, i4, i5, o1, o2, o3);
input  clock_c;
input  i1;
input  [31:0] i2;
input  [31:0] i3;
input  i4;
input  i5;
output o1;
output [31:0] o2;
output [31:0] o3;
wire   [63:0] n1;
wire   n2;
wire   n3;
wire   [5:0] n4;
wire   [5:0] n5;
wire   [1:0] n6;
wire   [31:0] n7;
wire   [31:0] n8;
wire   [31:0] n9;
wire   [31:0] n10;
wire   [31:0] n11;
wire   [31:0] n12;
wire   s13_1;
wire   [63:0] s14_1;
wire   s15_1;
wire   s15_2;
wire   [63:0] s15_3;
wire   [6:0] s16_1;
wire   s16_2;
assign n1 = {i2, i3};
assign n2 = s16_1[6];
assign n3 = ~n2;
assign n4 = {s16_1[5],
  s16_1[4],
  s16_1[3],
  s16_1[2],
  s16_1[1],
  s16_1[0]};
assign n5 = {n4[0],
  n4[1],
  n4[2],
  n4[3],
  n4[4],
  n4[5]};
assign n6 = {s15_2, s15_1};
assign n7 = {s15_3[63],
  s15_3[62],
  s15_3[61],
  s15_3[60],
  s15_3[59],
  s15_3[58],
  s15_3[57],
  s15_3[56],
  s15_3[55],
  s15_3[54],
  s15_3[53],
  s15_3[52],
  s15_3[51],
  s15_3[50],
  s15_3[49],
  s15_3[48],
  s15_3[47],
  s15_3[46],
  s15_3[45],
  s15_3[44],
  s15_3[43],
  s15_3[42],
  s15_3[41],
  s15_3[40],
  s15_3[39],
  s15_3[38],
  s15_3[37],
  s15_3[36],
  s15_3[35],
  s15_3[34],
  s15_3[33],
  s15_3[32]};
assign n8 = {s15_3[31],
  s15_3[30],
  s15_3[29],
  s15_3[28],
  s15_3[27],
  s15_3[26],
  s15_3[25],
  s15_3[24],
  s15_3[23],
  s15_3[22],
  s15_3[21],
  s15_3[20],
  s15_3[19],
  s15_3[18],
  s15_3[17],
  s15_3[16],
  s15_3[15],
  s15_3[14],
  s15_3[13],
  s15_3[12],
  s15_3[11],
  s15_3[10],
  s15_3[9],
  s15_3[8],
  s15_3[7],
  s15_3[6],
  s15_3[5],
  s15_3[4],
  s15_3[3],
  s15_3[2],
  s15_3[1],
  s15_3[0]};
assign n9 = {s14_1[63],
  s14_1[62],
  s14_1[61],
  s14_1[60],
  s14_1[59],
  s14_1[58],
  s14_1[57],
  s14_1[56],
  s14_1[55],
  s14_1[54],
  s14_1[53],
  s14_1[52],
  s14_1[51],
  s14_1[50],
  s14_1[49],
  s14_1[48],
  s14_1[47],
  s14_1[46],
  s14_1[45],
  s14_1[44],
  s14_1[43],
  s14_1[42],
  s14_1[41],
  s14_1[40],
  s14_1[39],
  s14_1[38],
  s14_1[37],
  s14_1[36],
  s14_1[35],
  s14_1[34],
  s14_1[33],
  s14_1[32]};
assign n10 = {s14_1[31],
  s14_1[30],
  s14_1[29],
  s14_1[28],
  s14_1[27],
  s14_1[26],
  s14_1[25],
  s14_1[24],
  s14_1[23],
  s14_1[22],
  s14_1[21],
  s14_1[20],
  s14_1[19],
  s14_1[18],
  s14_1[17],
  s14_1[16],
  s14_1[15],
  s14_1[14],
  s14_1[13],
  s14_1[12],
  s14_1[11],
  s14_1[10],
  s14_1[9],
  s14_1[8],
  s14_1[7],
  s14_1[6],
  s14_1[5],
  s14_1[4],
  s14_1[3],
  s14_1[2],
  s14_1[1],
  s14_1[0]};
assign n11 = s13_1 ? n8 : n7;
assign n12 = s13_1 ? n10 : n9;
cf_fft_256_16_30 s13 (clock_c, n6, i4, i5, s13_1);
cf_fft_256_16_26 s14 (clock_c, s16_2, n1, n2, n5, i4, i5, s14_1);
cf_fft_256_16_25 s15 (clock_c, s16_2, n1, n3, n5, i4, i5, s15_1, s15_2, s15_3);
cf_fft_256_16_21 s16 (clock_c, i1, i4, i5, s16_1, s16_2);
assign o3 = n12;
assign o2 = n11;
assign o1 = s15_1;
endmodule

module cf_fft_256_16_21 (clock_c, i1, i2, i3, o1, o2);
input  clock_c;
input  i1;
input  i2;
input  i3;
output [6:0] o1;
output o2;
wire   [6:0] n1;
wire   [6:0] n2;
reg    [6:0] n3;
wire   [6:0] n4;
wire   n5;
wire   [1:0] n6;
reg    n7;
wire   n8;
wire   n9;
wire   n10;
wire   s11_1;
assign n1 = 7'b0000001;
assign n2 = n3 + n1;
initial n3 = 7'b0000000;
always @ (posedge clock_c)
  if (n9 == 1'b1)
    n3 <= 7'b0000000;
  else if (n10 == 1'b1)
    n3 <= n2;
assign n4 = 7'b1111111;
assign n5 = n3 == n4;
assign n6 = {i1, n5};
initial n7 = 1'b0;
always @ (posedge clock_c)
  if (i3 == 1'b1)
    n7 <= 1'b0;
  else if (i2 == 1'b1)
    n7 <= s11_1;
assign n8 = n7 & n5;
assign n9 = i1 | i3;
assign n10 = s11_1 & i2;
cf_fft_256_16_22 s11 (clock_c, n6, i2, i3, s11_1);
assign o2 = n8;
assign o1 = n3;
endmodule

module cf_fft_256_16_22 (clock_c, i1, i2, i3, o1);
input  clock_c;
input  [1:0] i1;
input  i2;
input  i3;
output o1;
wire   n1;
wire   n2;
wire   n3;
wire   n4;
wire   n5;
wire   n6;
wire   n7;
wire   n8;
wire   n9;
wire   n10;
wire   n11;
wire   n12;
wire   [2:0] n13;
reg    n14;
wire   s15_1;
wire   s16_1;
assign n1 = 1'b0;
assign n2 = 1'b1;
assign n3 = 1'b1;
assign n4 = 1'b1;
assign n5 = 1'b0;
assign n6 = 1'b0;
assign n7 = 1'b0;
assign n8 = 1'b1;
assign n9 = 1'b1;
assign n10 = 1'b1;
assign n11 = 1'b0;
assign n12 = 1'b0;
assign n13 = {i1, n14};
initial n14 = 1'b0;
always @ (posedge clock_c)
  if (i3 == 1'b1)
    n14 <= 1'b0;
  else if (i2 == 1'b1)
    n14 <= s15_1;
cf_fft_256_16_23 s15 (n1, n2, n3, n4, n5, n6, n13, s15_1);
cf_fft_256_16_23 s16 (n7, n8, n9, n10, n11, n12, n13, s16_1);
assign o1 = s16_1;
endmodule

module cf_fft_256_16_23 (i1, i2, i3, i4, i5, i6, i7, o1);
input  i1;
input  i2;
input  i3;
input  i4;
input  i5;
input  i6;
input  [2:0] i7;
output o1;
wire   [2:0] n1;
wire   [2:0] n2;
wire   [2:0] n3;
wire   n4;
wire   n5;
wire   n6;
wire   n7;
wire   n8;
wire   n9;
wire   s10_1;
assign n1 = 3'b000;
assign n2 = 3'b010;
assign n3 = 3'b100;
assign n4 = i7 == n1;
assign n5 = i7 == n2;
assign n6 = i7 == n3;
assign n7 = n6 ? i4 : s10_1;
assign n8 = n5 ? i5 : n7;
assign n9 = n4 ? i6 : n8;
cf_fft_256_16_24 s10 (i1, i2, i3, i7, s10_1);
assign o1 = n9;
endmodule

module cf_fft_256_16_24 (i1, i2, i3, i4, o1);
input  i1;
input  i2;
input  i3;
input  [2:0] i4;
output o1;
wire   [2:0] n1;
wire   [2:0] n2;
wire   [2:0] n3;
wire   n4;
wire   n5;
wire   n6;
wire   n7;
wire   n8;
wire   n9;
wire   n10;
assign n1 = 3'b110;
assign n2 = 3'b001;
assign n3 = 3'b011;
assign n4 = i4 == n1;
assign n5 = i4 == n2;
assign n6 = i4 == n3;
assign n7 = n6 ? i1 : n10;
assign n8 = n5 ? i2 : n7;
assign n9 = n4 ? i3 : n8;
assign n10 = 1'b1;
assign o1 = n9;
endmodule

module cf_fft_256_16_25 (clock_c, i1, i2, i3, i4, i5, i6, o1, o2, o3);
input  clock_c;
input  i1;
input  [63:0] i2;
input  i3;
input  [5:0] i4;
input  i5;
input  i6;
output o1;
output o2;
output [63:0] o3;
wire   [5:0] n1;
wire   [5:0] n2;
reg    [5:0] n3;
wire   n4;
reg    n5;
wire   [5:0] n6;
wire   n7;
wire   n8;
wire   [63:0] n9;
reg    [5:0] n9a;
reg    [63:0] n9m [63:0];
wire   n10;
wire   [63:0] n11;
reg    [5:0] n11a;
reg    [63:0] n11m [63:0];
reg    n12;
wire   [63:0] n13;
wire   n14;
wire   s15_1;
assign n1 = 6'b000001;
assign n2 = n3 + n1;
initial n3 = 6'b000000;
always @ (posedge clock_c)
  if (n14 == 1'b1)
    n3 <= 6'b000000;
  else if (i5 == 1'b1)
    n3 <= n2;
assign n4 = ~s15_1;
initial n5 = 1'b0;
always @ (posedge clock_c)
  if (i6 == 1'b1)
    n5 <= 1'b0;
  else if (i5 == 1'b1)
    n5 <= i1;
assign n6 = 6'b000000;
assign n7 = n3 == n6;
assign n8 = i3 & n4;
initial n9a = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1) begin
    if (n8 == 1'b1)
      n9m[i4] <= i2;
    n9a <= n3;
  end
assign n9 = n9m[n9a];
assign n10 = i3 & s15_1;
initial n11a = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1) begin
    if (n10 == 1'b1)
      n11m[i4] <= i2;
    n11a <= n3;
  end
assign n11 = n11m[n11a];
initial n12 = 1'b0;
always @ (posedge clock_c)
  if (i6 == 1'b1)
    n12 <= 1'b0;
  else if (i5 == 1'b1)
    n12 <= n4;
assign n13 = n12 ? n11 : n9;
assign n14 = i1 | i6;
cf_fft_256_16_27 s15 (clock_c, i1, i5, i6, s15_1);
assign o3 = n13;
assign o2 = n7;
assign o1 = n5;
endmodule

module cf_fft_256_16_26 (clock_c, i1, i2, i3, i4, i5, i6, o1);
input  clock_c;
input  i1;
input  [63:0] i2;
input  i3;
input  [5:0] i4;
input  i5;
input  i6;
output [63:0] o1;
wire   [5:0] n1;
wire   [5:0] n2;
reg    [5:0] n3;
wire   n4;
wire   n5;
wire   [63:0] n6;
reg    [5:0] n6a;
reg    [63:0] n6m [63:0];
wire   n7;
wire   [63:0] n8;
reg    [5:0] n8a;
reg    [63:0] n8m [63:0];
reg    n9;
wire   [63:0] n10;
wire   n11;
wire   s12_1;
assign n1 = 6'b000001;
assign n2 = n3 + n1;
initial n3 = 6'b000000;
always @ (posedge clock_c)
  if (n11 == 1'b1)
    n3 <= 6'b000000;
  else if (i5 == 1'b1)
    n3 <= n2;
assign n4 = ~s12_1;
assign n5 = i3 & n4;
initial n6a = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1) begin
    if (n5 == 1'b1)
      n6m[i4] <= i2;
    n6a <= n3;
  end
assign n6 = n6m[n6a];
assign n7 = i3 & s12_1;
initial n8a = 6'b000000;
always @ (posedge clock_c)
  if (i5 == 1'b1) begin
    if (n7 == 1'b1)
      n8m[i4] <= i2;
    n8a <= n3;
  end
assign n8 = n8m[n8a];
initial n9 = 1'b0;
always @ (posedge clock_c)
  if (i6 == 1'b1)
    n9 <= 1'b0;
  else if (i5 == 1'b1)
    n9 <= n4;
assign n10 = n9 ? n8 : n6;
assign n11 = i1 | i6;
cf_fft_256_16_27 s12 (clock_c, i1, i5, i6, s12_1);
assign o1 = n10;
endmodule

module cf_fft_256_16_27 (clock_c, i1, i2, i3, o1);
input  clock_c;
input  i1;
input  i2;
input  i3;
output o1;
wire   n1;
wire   n2;
wire   n3;
wire   n4;
wire   [1:0] n5;
reg    n6;
wire   s7_1;
wire   s8_1;
assign n1 = 1'b0;
assign n2 = 1'b1;
assign n3 = 1'b1;
assign n4 = 1'b0;
assign n5 = {i1, n6};
initial n6 = 1'b0;
always @ (posedge clock_c)
  if (i3 == 1'b1)
    n6 <= 1'b0;
  else if (i2 == 1'b1)
    n6 <= s7_1;
cf_fft_256_16_29 s7 (n1, n2, n3, n4, n5, s7_1);
cf_fft_256_16_28 s8 (n5, s8_1);
assign o1 = s8_1;
endmodule

module cf_fft_256_16_28 (i1, o1);
input  [1:0] i1;
output o1;
wire   n1;
wire   n2;
wire   [1:0] n3;
wire   [1:0] n4;
wire   n5;
wire   n6;
wire   n7;
wire   n8;
wire   n9;
assign n1 = 1'b0;
assign n2 = 1'b0;
assign n3 = 2'b00;
assign n4 = 2'b10;
assign n5 = i1 == n3;
assign n6 = i1 == n4;
assign n7 = n6 ? n1 : n9;
assign n8 = n5 ? n2 : n7;
assign n9 = 1'b1;
assign o1 = n8;
endmodule

module cf_fft_256_16_29 (i1, i2, i3, i4, i5, o1);
input  i1;
input  i2;
input  i3;
input  i4;
input  [1:0] i5;
output o1;
wire   [1:0] n1;
wire   [1:0] n2;
wire   [1:0] n3;
wire   n4;
wire   n5;
wire   n6;
wire   n7;
wire   n8;
wire   n9;
assign n1 = 2'b00;
assign n2 = 2'b10;
assign n3 = 2'b01;
assign n4 = i5 == n1;
assign n5 = i5 == n2;
assign n6 = i5 == n3;
assign n7 = n6 ? i2 : i1;
assign n8 = n5 ? i3 : n7;
assign n9 = n4 ? i4 : n8;
assign o1 = n9;
endmodule

module cf_fft_256_16_30 (clock_c, i1, i2, i3, o1);
input  clock_c;
input  [1:0] i1;
input  i2;
input  i3;
output o1;
wire   [2:0] n1;
wire   [2:0] n2;
wire   n3;
wire   n4;
reg    n5;
wire   s6_1;
wire   s7_1;
wire   s7_2;
wire   s7_3;
wire   s7_4;
wire   s7_5;
wire   s7_6;
wire   s7_7;
wire   s7_8;
wire   s8_1;
assign n1 = 3'b000;
assign n2 = {i1, n5};
assign n3 = n2 == n1;
assign n4 = n3 ? s7_8 : s6_1;
initial n5 = 1'b0;
always @ (posedge clock_c)
  if (i3 == 1'b1)
    n5 <= 1'b0;
  else if (i2 == 1'b1)
    n5 <= n4;
cf_fft_256_16_34 s6 (s7_1, s7_2, s7_3, s7_4, s7_5, s7_6, s7_7, n2, s6_1);
cf_fft_256_16_33 s7 (s7_1, s7_2, s7_3, s7_4, s7_5, s7_6, s7_7, s7_8);
cf_fft_256_16_31 s8 (n2, s8_1);
assign o1 = s8_1;
endmodule

module cf_fft_256_16_31 (i1, o1);
input  [2:0] i1;
output o1;
wire   n1;
wire   n2;
wire   n3;
wire   n4;
wire   [2:0] n5;
wire   n6;
wire   n7;
wire   s8_1;
assign n1 = 1'b0;
assign n2 = 1'b0;
assign n3 = 1'b0;
assign n4 = 1'b0;
assign n5 = 3'b000;
assign n6 = i1 == n5;
assign n7 = n6 ? n4 : s8_1;
cf_fft_256_16_32 s8 (n1, n2, n3, i1, s8_1);
assign o1 = n7;
endmodule

module cf_fft_256_16_32 (i1, i2, i3, i4, o1);
input  i1;
input  i2;
input  i3;
input  [2:0] i4;
output o1;
wire   [2:0] n1;
wire   [2:0] n2;
wire   [2:0] n3;
wire   n4;
wire   n5;
wire   n6;
wire   n7;
wire   n8;
wire   n9;
wire   n10;
assign n1 = 3'b010;
assign n2 = 3'b100;
assign n3 = 3'b110;
assign n4 = i4 == n1;
assign n5 = i4 == n2;
assign n6 = i4 == n3;
assign n7 = n6 ? i1 : n10;
assign n8 = n5 ? i2 : n7;
assign n9 = n4 ? i3 : n8;
assign n10 = 1'b1;
assign o1 = n9;
endmodule

module cf_fft_256_16_33 (o1, o2, o3, o4, o5, o6, o7, o8);
output o1;
output o2;
output o3;
output o4;
output o5;
output o6;
output o7;
output o8;
wire   n1;
wire   n2;
wire   n3;
wire   n4;
wire   n5;
wire   n6;
wire   n7;
wire   n8;
assign n1 = 1'b0;
assign n2 = 1'b1;
assign n3 = 1'b0;
assign n4 = 1'b1;
assign n5 = 1'b0;
assign n6 = 1'b1;
assign n7 = 1'b0;
assign n8 = 1'b0;
assign o8 = n8;
assign o7 = n7;
assign o6 = n6;
assign o5 = n5;
assign o4 = n4;
assign o3 = n3;
assign o2 = n2;
assign o1 = n1;
endmodule

module cf_fft_256_16_34 (i1, i2, i3, i4, i5, i6, i7, i8, o1);
input  i1;
input  i2;
input  i3;
input  i4;
input  i5;
input  i6;
input  i7;
input  [2:0] i8;
output o1;
wire   [2:0] n1;
wire   [2:0] n2;
wire   [2:0] n3;
wire   n4;
wire   n5;
wire   n6;
wire   n7;
wire   n8;
wire   n9;
wire   s10_1;
assign n1 = 3'b010;
assign n2 = 3'b100;
assign n3 = 3'b110;
assign n4 = i8 == n1;
assign n5 = i8 == n2;
assign n6 = i8 == n3;
assign n7 = n6 ? i5 : s10_1;
assign n8 = n5 ? i6 : n7;
assign n9 = n4 ? i7 : n8;
cf_fft_256_16_35 s10 (i1, i2, i3, i4, i8, s10_1);
assign o1 = n9;
endmodule

module cf_fft_256_16_35 (i1, i2, i3, i4, i5, o1);
input  i1;
input  i2;
input  i3;
input  i4;
input  [2:0] i5;
output o1;
wire   [2:0] n1;
wire   [2:0] n2;
wire   [2:0] n3;
wire   n4;
wire   n5;
wire   n6;
wire   n7;
wire   n8;
wire   n9;
assign n1 = 3'b001;
assign n2 = 3'b011;
assign n3 = 3'b101;
assign n4 = i5 == n1;
assign n5 = i5 == n2;
assign n6 = i5 == n3;
assign n7 = n6 ? i2 : i1;
assign n8 = n5 ? i3 : n7;
assign n9 = n4 ? i4 : n8;
assign o1 = n9;
endmodule

