#
#  Copyright (c) 2003 Launchbird Design Systems, Inc.
#  All rights reserved.
#  
#  Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
#    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
#    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
#  
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
#  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
#  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
#  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#  
#  
#  Overview:
#  
#    Performs a radix 2 Fast Fourier Transform.
#    The FFT architecture is pipelined on a rank basis; each rank has its own butterfly and ranks are
#    isolated from each other using memory interleavers.  This FFT can perform calcualations on continuous
#    streaming data (one data set right after another).  More over, inputs and outputs are passed in pairs,
#    doubling the bandwidth.  For instance, a 2048 point FFT can perform a transform every 1024 cycles.
#  
#  Interface:
#  
#    Synchronization:
#      clock_c  : Clock input.
#      enable_i : Synchronous enable.
#      reset_i  : Synchronous reset.
#  
#    Inputs:
#      sync_i     : Input sync pulse must occur one frame prior to data input.
#      data_0_i   : Input data 0.  Width is 2 * precision.  Real on the left, imag on the right.
#      data_1_i   : Input data 1.  Width is 2 * precision.  Real on the left, imag on the right.
#  
#    Outputs:
#      sync_o     : Output sync pulse occurs one frame before data output.
#      data_0_o   : Output data 0.  Width is 2 * precision.  Real on the left, imag on the right.
#      data_1_o   : Output data 1.  Width is 2 * precision.  Real on the left, imag on the right.
#  
#  Built In Parameters:
#  
#    FFT Points   = 4096
#    Precision    = 8
#  
#  
#  
#  
#  Generated by Confluence 0.6.3  --  Launchbird Design Systems, Inc.  --  www.launchbird.com
#  
#  Build Date : Fri Aug 22 08:43:42 CDT 2003
#  
#  Interface
#  
#    Build Name    : cf_fft_4096_8
#    Clock Domains : clock_c  
#    Vector Input  : enable_i(1)
#    Vector Input  : reset_i(1)
#    Vector Input  : sync_i(1)
#    Vector Input  : data_0_i(16)
#    Vector Input  : data_1_i(16)
#    Vector Output : sync_o(1)
#    Vector Output : data_0_o(16)
#    Vector Output : data_1_o(16)
#  
#  
#  

import sys
import time

class cf_fft_4096_8:

  def init(self):
    self.n6758 = 0L
    self.n6753 = 0L
    self.n6751 = 0L
    self.n6749 = 0L
    self.n6747 = 0L
    self.n6746 = 0L
    self.n6741 = 0L
    self.n6739 = 0L
    self.n6737 = 0L
    self.n6735 = 0L
    self.n6734 = 0L
    self.n6729 = 0L
    self.n6727 = 0L
    self.n6725 = 0L
    self.n6723 = 0L
    self.n6722 = 0L
    self.n6717 = 0L
    self.n6715 = 0L
    self.n6713 = 0L
    self.n6711 = 0L
    self.n6710 = 0L
    self.n6705 = 0L
    self.n6703 = 0L
    self.n6701 = 0L
    self.n6699 = 0L
    self.n6698 = 0L
    self.n6693 = 0L
    self.n6691 = 0L
    self.n6689 = 0L
    self.n6687 = 0L
    self.n6686 = 0L
    self.n6681 = 0L
    self.n6679 = 0L
    self.n6677 = 0L
    self.n6675 = 0L
    self.n6674 = 0L
    self.n6669 = 0L
    self.n6667 = 0L
    self.n6665 = 0L
    self.n6663 = 0L
    self.n6662 = 0L
    self.n6657 = 0L
    self.n6655 = 0L
    self.n6653 = 0L
    self.n6651 = 0L
    self.n6650 = 0L
    self.n6645 = 0L
    self.n6643 = 0L
    self.n6641 = 0L
    self.n6639 = 0L
    self.n6638 = 0L
    self.n6633 = 0L
    self.n6631 = 0L
    self.n6629 = 0L
    self.n6627 = 0L
    self.n6626 = 0L
    self.n6621 = 0L
    self.n6619 = 0L
    self.n6617 = 0L
    self.n6615 = 0L
    self.n6614 = 0L
    self.n6609 = 0L
    self.n6607 = 0L
    self.n6605 = 0L
    self.n6603 = 0L
    self.n6548 = 0L
    self.n6547 = 0L
    self.n6544 = 0L
    self.n6498 = 0L
    self.n6497 = 0L
    self.n6496 = 0L
    self.n6495 = 0L
    self.n6494 = 0L
    self.n6493 = 0L
    self.n6492 = 0L
    self.n6491 = 0L
    self.n6486 = 0L
    self.n6485 = 0L
    self.n6484 = 0L
    self.n6483 = 0L
    self.n6482 = 0L
    self.n6481 = 0L
    self.n6480 = 0L
    self.n6479 = 0L
    self.n6478 = 0L
    self.n6477 = 0L
    self.n6476 = 0L
    self.n6475 = 0L
    self.n6474 = 0L
    self.n6473 = 0L
    self.n6472 = 0L
    self.n6470 = 0L
    self.n6423 = 0L
    self.n6419 = 0L
    self.n6418 = 0L
    self.n6417 = 0L
    self.n6416 = 0L
    self.n6413 = 0L
    self.n6412 = 0L
    self.n6411 = 0L
    self.n6410 = 0L
    self.n6409 = 0L
    self.n6408 = 0L
    self.n6407 = 0L
    self.n6398 = 0L
    self.n6397 = 0L
    self.n6376 = 0L
    self.n6350 = 0L
    self.n6346 = 0L
    self.n6345 = 0L
    self.n6344 = 0L
    self.n6343 = 0L
    self.n6340 = 0L
    self.n6339 = 0L
    self.n6338 = 0L
    self.n6337 = 0L
    self.n6336 = 0L
    self.n6335 = 0L
    self.n6334 = 0L
    self.n6325 = 0L
    self.n6324 = 0L
    self.n6295 = 0L
    self.n6266 = 0L
    self.n6237 = 0L
    self.n6228 = 0L
    self.n6227 = 0L
    self.n6218 = 0L
    self.n6217 = 0L
    self.n6209 = 0L
    self.n6183 = 0L
    self.n6164 = 0L
    self.n6163 = 0L
    self.n6129 = 0L
    self.n6128 = 0L
    self.n6120 = 0L
    self.n6119 = 0L
    self.n6111 = 0L
    self.n6065 = 0L
    self.n6064 = 0L
    self.n6063 = 0L
    self.n6062 = 0L
    self.n6061 = 0L
    self.n6060 = 0L
    self.n6059 = 0L
    self.n6058 = 0L
    self.n6057 = 0L
    self.n6056 = 0L
    self.n6055 = 0L
    self.n6054 = 0L
    self.n6050 = 0L
    self.n6049 = 0L
    self.n6048 = 0L
    self.n6047 = 0L
    self.n6046 = 0L
    self.n6045 = 0L
    self.n6044 = 0L
    self.n6043 = 0L
    self.n6042 = 0L
    self.n6041 = 0L
    self.n6040 = 0L
    self.n6039 = 0L
    self.n6034 = 0L
    self.n6025 = 0L
    self.n5979 = 0L
    self.n5978 = 0L
    self.n5977 = 0L
    self.n5976 = 0L
    self.n5975 = 0L
    self.n5974 = 0L
    self.n5973 = 0L
    self.n5972 = 0L
    self.n5967 = 0L
    self.n5966 = 0L
    self.n5965 = 0L
    self.n5964 = 0L
    self.n5963 = 0L
    self.n5962 = 0L
    self.n5961 = 0L
    self.n5960 = 0L
    self.n5959 = 0L
    self.n5958 = 0L
    self.n5957 = 0L
    self.n5956 = 0L
    self.n5955 = 0L
    self.n5954 = 0L
    self.n5953 = 0L
    self.n5951 = 0L
    self.n5904 = 0L
    self.n5900 = 0L
    self.n5899 = 0L
    self.n5898 = 0L
    self.n5897 = 0L
    self.n5894 = 0L
    self.n5893 = 0L
    self.n5892 = 0L
    self.n5891 = 0L
    self.n5890 = 0L
    self.n5889 = 0L
    self.n5888 = 0L
    self.n5879 = 0L
    self.n5878 = 0L
    self.n5857 = 0L
    self.n5831 = 0L
    self.n5827 = 0L
    self.n5826 = 0L
    self.n5825 = 0L
    self.n5824 = 0L
    self.n5821 = 0L
    self.n5820 = 0L
    self.n5819 = 0L
    self.n5818 = 0L
    self.n5817 = 0L
    self.n5816 = 0L
    self.n5815 = 0L
    self.n5806 = 0L
    self.n5805 = 0L
    self.n5776 = 0L
    self.n5747 = 0L
    self.n5718 = 0L
    self.n5709 = 0L
    self.n5708 = 0L
    self.n5699 = 0L
    self.n5698 = 0L
    self.n5690 = 0L
    self.n5664 = 0L
    self.n5645 = 0L
    self.n5644 = 0L
    self.n5610 = 0L
    self.n5609 = 0L
    self.n5601 = 0L
    self.n5600 = 0L
    self.n5592 = 0L
    self.n5546 = 0L
    self.n5545 = 0L
    self.n5544 = 0L
    self.n5543 = 0L
    self.n5542 = 0L
    self.n5541 = 0L
    self.n5540 = 0L
    self.n5539 = 0L
    self.n5538 = 0L
    self.n5537 = 0L
    self.n5536 = 0L
    self.n5535 = 0L
    self.n5531 = 0L
    self.n5530 = 0L
    self.n5529 = 0L
    self.n5528 = 0L
    self.n5527 = 0L
    self.n5526 = 0L
    self.n5525 = 0L
    self.n5524 = 0L
    self.n5523 = 0L
    self.n5522 = 0L
    self.n5521 = 0L
    self.n5520 = 0L
    self.n5515 = 0L
    self.n5506 = 0L
    self.n5460 = 0L
    self.n5459 = 0L
    self.n5458 = 0L
    self.n5457 = 0L
    self.n5456 = 0L
    self.n5455 = 0L
    self.n5454 = 0L
    self.n5453 = 0L
    self.n5448 = 0L
    self.n5447 = 0L
    self.n5446 = 0L
    self.n5445 = 0L
    self.n5444 = 0L
    self.n5443 = 0L
    self.n5442 = 0L
    self.n5441 = 0L
    self.n5440 = 0L
    self.n5439 = 0L
    self.n5438 = 0L
    self.n5437 = 0L
    self.n5436 = 0L
    self.n5435 = 0L
    self.n5434 = 0L
    self.n5432 = 0L
    self.n5385 = 0L
    self.n5381 = 0L
    self.n5380 = 0L
    self.n5379 = 0L
    self.n5378 = 0L
    self.n5375 = 0L
    self.n5374 = 0L
    self.n5373 = 0L
    self.n5372 = 0L
    self.n5371 = 0L
    self.n5370 = 0L
    self.n5369 = 0L
    self.n5360 = 0L
    self.n5359 = 0L
    self.n5338 = 0L
    self.n5312 = 0L
    self.n5308 = 0L
    self.n5307 = 0L
    self.n5306 = 0L
    self.n5305 = 0L
    self.n5302 = 0L
    self.n5301 = 0L
    self.n5300 = 0L
    self.n5299 = 0L
    self.n5298 = 0L
    self.n5297 = 0L
    self.n5296 = 0L
    self.n5287 = 0L
    self.n5286 = 0L
    self.n5257 = 0L
    self.n5228 = 0L
    self.n5199 = 0L
    self.n5190 = 0L
    self.n5189 = 0L
    self.n5180 = 0L
    self.n5179 = 0L
    self.n5171 = 0L
    self.n5145 = 0L
    self.n5126 = 0L
    self.n5125 = 0L
    self.n5091 = 0L
    self.n5090 = 0L
    self.n5082 = 0L
    self.n5081 = 0L
    self.n5073 = 0L
    self.n5027 = 0L
    self.n5026 = 0L
    self.n5025 = 0L
    self.n5024 = 0L
    self.n5023 = 0L
    self.n5022 = 0L
    self.n5021 = 0L
    self.n5020 = 0L
    self.n5019 = 0L
    self.n5018 = 0L
    self.n5017 = 0L
    self.n5016 = 0L
    self.n5012 = 0L
    self.n5011 = 0L
    self.n5010 = 0L
    self.n5009 = 0L
    self.n5008 = 0L
    self.n5007 = 0L
    self.n5006 = 0L
    self.n5005 = 0L
    self.n5004 = 0L
    self.n5003 = 0L
    self.n5002 = 0L
    self.n5001 = 0L
    self.n4996 = 0L
    self.n4987 = 0L
    self.n4941 = 0L
    self.n4940 = 0L
    self.n4939 = 0L
    self.n4938 = 0L
    self.n4937 = 0L
    self.n4936 = 0L
    self.n4935 = 0L
    self.n4934 = 0L
    self.n4929 = 0L
    self.n4928 = 0L
    self.n4927 = 0L
    self.n4926 = 0L
    self.n4925 = 0L
    self.n4924 = 0L
    self.n4923 = 0L
    self.n4922 = 0L
    self.n4921 = 0L
    self.n4920 = 0L
    self.n4919 = 0L
    self.n4918 = 0L
    self.n4917 = 0L
    self.n4916 = 0L
    self.n4915 = 0L
    self.n4913 = 0L
    self.n4866 = 0L
    self.n4862 = 0L
    self.n4861 = 0L
    self.n4860 = 0L
    self.n4859 = 0L
    self.n4856 = 0L
    self.n4855 = 0L
    self.n4854 = 0L
    self.n4853 = 0L
    self.n4852 = 0L
    self.n4851 = 0L
    self.n4850 = 0L
    self.n4841 = 0L
    self.n4840 = 0L
    self.n4819 = 0L
    self.n4793 = 0L
    self.n4789 = 0L
    self.n4788 = 0L
    self.n4787 = 0L
    self.n4786 = 0L
    self.n4783 = 0L
    self.n4782 = 0L
    self.n4781 = 0L
    self.n4780 = 0L
    self.n4779 = 0L
    self.n4778 = 0L
    self.n4777 = 0L
    self.n4768 = 0L
    self.n4767 = 0L
    self.n4738 = 0L
    self.n4709 = 0L
    self.n4680 = 0L
    self.n4671 = 0L
    self.n4670 = 0L
    self.n4661 = 0L
    self.n4660 = 0L
    self.n4652 = 0L
    self.n4626 = 0L
    self.n4607 = 0L
    self.n4606 = 0L
    self.n4572 = 0L
    self.n4571 = 0L
    self.n4563 = 0L
    self.n4562 = 0L
    self.n4554 = 0L
    self.n4508 = 0L
    self.n4507 = 0L
    self.n4506 = 0L
    self.n4505 = 0L
    self.n4504 = 0L
    self.n4503 = 0L
    self.n4502 = 0L
    self.n4501 = 0L
    self.n4500 = 0L
    self.n4499 = 0L
    self.n4498 = 0L
    self.n4497 = 0L
    self.n4493 = 0L
    self.n4492 = 0L
    self.n4491 = 0L
    self.n4490 = 0L
    self.n4489 = 0L
    self.n4488 = 0L
    self.n4487 = 0L
    self.n4486 = 0L
    self.n4485 = 0L
    self.n4484 = 0L
    self.n4483 = 0L
    self.n4482 = 0L
    self.n4477 = 0L
    self.n4468 = 0L
    self.n4422 = 0L
    self.n4421 = 0L
    self.n4420 = 0L
    self.n4419 = 0L
    self.n4418 = 0L
    self.n4417 = 0L
    self.n4416 = 0L
    self.n4415 = 0L
    self.n4410 = 0L
    self.n4409 = 0L
    self.n4408 = 0L
    self.n4407 = 0L
    self.n4406 = 0L
    self.n4405 = 0L
    self.n4404 = 0L
    self.n4403 = 0L
    self.n4402 = 0L
    self.n4401 = 0L
    self.n4400 = 0L
    self.n4399 = 0L
    self.n4398 = 0L
    self.n4397 = 0L
    self.n4396 = 0L
    self.n4394 = 0L
    self.n4347 = 0L
    self.n4343 = 0L
    self.n4342 = 0L
    self.n4341 = 0L
    self.n4340 = 0L
    self.n4337 = 0L
    self.n4336 = 0L
    self.n4335 = 0L
    self.n4334 = 0L
    self.n4333 = 0L
    self.n4332 = 0L
    self.n4331 = 0L
    self.n4322 = 0L
    self.n4321 = 0L
    self.n4300 = 0L
    self.n4274 = 0L
    self.n4270 = 0L
    self.n4269 = 0L
    self.n4268 = 0L
    self.n4267 = 0L
    self.n4264 = 0L
    self.n4263 = 0L
    self.n4262 = 0L
    self.n4261 = 0L
    self.n4260 = 0L
    self.n4259 = 0L
    self.n4258 = 0L
    self.n4249 = 0L
    self.n4248 = 0L
    self.n4219 = 0L
    self.n4190 = 0L
    self.n4161 = 0L
    self.n4152 = 0L
    self.n4151 = 0L
    self.n4142 = 0L
    self.n4141 = 0L
    self.n4133 = 0L
    self.n4107 = 0L
    self.n4088 = 0L
    self.n4087 = 0L
    self.n4053 = 0L
    self.n4052 = 0L
    self.n4044 = 0L
    self.n4043 = 0L
    self.n4035 = 0L
    self.n3989 = 0L
    self.n3988 = 0L
    self.n3987 = 0L
    self.n3986 = 0L
    self.n3985 = 0L
    self.n3984 = 0L
    self.n3983 = 0L
    self.n3982 = 0L
    self.n3981 = 0L
    self.n3980 = 0L
    self.n3979 = 0L
    self.n3978 = 0L
    self.n3974 = 0L
    self.n3973 = 0L
    self.n3972 = 0L
    self.n3971 = 0L
    self.n3970 = 0L
    self.n3969 = 0L
    self.n3968 = 0L
    self.n3967 = 0L
    self.n3966 = 0L
    self.n3965 = 0L
    self.n3964 = 0L
    self.n3963 = 0L
    self.n3958 = 0L
    self.n3949 = 0L
    self.n3903 = 0L
    self.n3902 = 0L
    self.n3901 = 0L
    self.n3900 = 0L
    self.n3899 = 0L
    self.n3898 = 0L
    self.n3897 = 0L
    self.n3896 = 0L
    self.n3891 = 0L
    self.n3890 = 0L
    self.n3889 = 0L
    self.n3888 = 0L
    self.n3887 = 0L
    self.n3886 = 0L
    self.n3885 = 0L
    self.n3884 = 0L
    self.n3883 = 0L
    self.n3882 = 0L
    self.n3881 = 0L
    self.n3880 = 0L
    self.n3879 = 0L
    self.n3878 = 0L
    self.n3877 = 0L
    self.n3875 = 0L
    self.n3828 = 0L
    self.n3824 = 0L
    self.n3823 = 0L
    self.n3822 = 0L
    self.n3821 = 0L
    self.n3818 = 0L
    self.n3817 = 0L
    self.n3816 = 0L
    self.n3815 = 0L
    self.n3814 = 0L
    self.n3813 = 0L
    self.n3812 = 0L
    self.n3803 = 0L
    self.n3802 = 0L
    self.n3781 = 0L
    self.n3755 = 0L
    self.n3751 = 0L
    self.n3750 = 0L
    self.n3749 = 0L
    self.n3748 = 0L
    self.n3745 = 0L
    self.n3744 = 0L
    self.n3743 = 0L
    self.n3742 = 0L
    self.n3741 = 0L
    self.n3740 = 0L
    self.n3739 = 0L
    self.n3730 = 0L
    self.n3729 = 0L
    self.n3700 = 0L
    self.n3671 = 0L
    self.n3642 = 0L
    self.n3633 = 0L
    self.n3632 = 0L
    self.n3623 = 0L
    self.n3622 = 0L
    self.n3614 = 0L
    self.n3588 = 0L
    self.n3569 = 0L
    self.n3568 = 0L
    self.n3534 = 0L
    self.n3533 = 0L
    self.n3525 = 0L
    self.n3524 = 0L
    self.n3516 = 0L
    self.n3470 = 0L
    self.n3469 = 0L
    self.n3468 = 0L
    self.n3467 = 0L
    self.n3466 = 0L
    self.n3465 = 0L
    self.n3464 = 0L
    self.n3463 = 0L
    self.n3462 = 0L
    self.n3461 = 0L
    self.n3460 = 0L
    self.n3459 = 0L
    self.n3455 = 0L
    self.n3454 = 0L
    self.n3453 = 0L
    self.n3452 = 0L
    self.n3451 = 0L
    self.n3450 = 0L
    self.n3449 = 0L
    self.n3448 = 0L
    self.n3447 = 0L
    self.n3446 = 0L
    self.n3445 = 0L
    self.n3444 = 0L
    self.n3439 = 0L
    self.n3430 = 0L
    self.n3384 = 0L
    self.n3383 = 0L
    self.n3382 = 0L
    self.n3381 = 0L
    self.n3380 = 0L
    self.n3379 = 0L
    self.n3378 = 0L
    self.n3377 = 0L
    self.n3372 = 0L
    self.n3371 = 0L
    self.n3370 = 0L
    self.n3369 = 0L
    self.n3368 = 0L
    self.n3367 = 0L
    self.n3366 = 0L
    self.n3365 = 0L
    self.n3364 = 0L
    self.n3363 = 0L
    self.n3362 = 0L
    self.n3361 = 0L
    self.n3360 = 0L
    self.n3359 = 0L
    self.n3358 = 0L
    self.n3356 = 0L
    self.n3309 = 0L
    self.n3305 = 0L
    self.n3304 = 0L
    self.n3303 = 0L
    self.n3302 = 0L
    self.n3299 = 0L
    self.n3298 = 0L
    self.n3297 = 0L
    self.n3296 = 0L
    self.n3295 = 0L
    self.n3294 = 0L
    self.n3293 = 0L
    self.n3284 = 0L
    self.n3283 = 0L
    self.n3262 = 0L
    self.n3236 = 0L
    self.n3232 = 0L
    self.n3231 = 0L
    self.n3230 = 0L
    self.n3229 = 0L
    self.n3226 = 0L
    self.n3225 = 0L
    self.n3224 = 0L
    self.n3223 = 0L
    self.n3222 = 0L
    self.n3221 = 0L
    self.n3220 = 0L
    self.n3211 = 0L
    self.n3210 = 0L
    self.n3181 = 0L
    self.n3152 = 0L
    self.n3123 = 0L
    self.n3114 = 0L
    self.n3113 = 0L
    self.n3104 = 0L
    self.n3103 = 0L
    self.n3095 = 0L
    self.n3069 = 0L
    self.n3050 = 0L
    self.n3049 = 0L
    self.n3015 = 0L
    self.n3014 = 0L
    self.n3006 = 0L
    self.n3005 = 0L
    self.n2997 = 0L
    self.n2951 = 0L
    self.n2950 = 0L
    self.n2949 = 0L
    self.n2948 = 0L
    self.n2947 = 0L
    self.n2946 = 0L
    self.n2945 = 0L
    self.n2944 = 0L
    self.n2943 = 0L
    self.n2942 = 0L
    self.n2941 = 0L
    self.n2940 = 0L
    self.n2936 = 0L
    self.n2935 = 0L
    self.n2934 = 0L
    self.n2933 = 0L
    self.n2932 = 0L
    self.n2931 = 0L
    self.n2930 = 0L
    self.n2929 = 0L
    self.n2928 = 0L
    self.n2927 = 0L
    self.n2926 = 0L
    self.n2925 = 0L
    self.n2920 = 0L
    self.n2911 = 0L
    self.n2865 = 0L
    self.n2864 = 0L
    self.n2863 = 0L
    self.n2862 = 0L
    self.n2861 = 0L
    self.n2860 = 0L
    self.n2859 = 0L
    self.n2858 = 0L
    self.n2853 = 0L
    self.n2852 = 0L
    self.n2851 = 0L
    self.n2850 = 0L
    self.n2849 = 0L
    self.n2848 = 0L
    self.n2847 = 0L
    self.n2846 = 0L
    self.n2845 = 0L
    self.n2844 = 0L
    self.n2843 = 0L
    self.n2842 = 0L
    self.n2841 = 0L
    self.n2840 = 0L
    self.n2839 = 0L
    self.n2837 = 0L
    self.n2790 = 0L
    self.n2786 = 0L
    self.n2785 = 0L
    self.n2784 = 0L
    self.n2783 = 0L
    self.n2780 = 0L
    self.n2779 = 0L
    self.n2778 = 0L
    self.n2777 = 0L
    self.n2776 = 0L
    self.n2775 = 0L
    self.n2774 = 0L
    self.n2765 = 0L
    self.n2764 = 0L
    self.n2743 = 0L
    self.n2717 = 0L
    self.n2713 = 0L
    self.n2712 = 0L
    self.n2711 = 0L
    self.n2710 = 0L
    self.n2707 = 0L
    self.n2706 = 0L
    self.n2705 = 0L
    self.n2704 = 0L
    self.n2703 = 0L
    self.n2702 = 0L
    self.n2701 = 0L
    self.n2692 = 0L
    self.n2691 = 0L
    self.n2662 = 0L
    self.n2633 = 0L
    self.n2604 = 0L
    self.n2595 = 0L
    self.n2594 = 0L
    self.n2585 = 0L
    self.n2584 = 0L
    self.n2576 = 0L
    self.n2550 = 0L
    self.n2531 = 0L
    self.n2530 = 0L
    self.n2496 = 0L
    self.n2495 = 0L
    self.n2487 = 0L
    self.n2486 = 0L
    self.n2478 = 0L
    self.n2432 = 0L
    self.n2431 = 0L
    self.n2430 = 0L
    self.n2429 = 0L
    self.n2428 = 0L
    self.n2427 = 0L
    self.n2426 = 0L
    self.n2425 = 0L
    self.n2424 = 0L
    self.n2423 = 0L
    self.n2422 = 0L
    self.n2421 = 0L
    self.n2417 = 0L
    self.n2416 = 0L
    self.n2415 = 0L
    self.n2414 = 0L
    self.n2413 = 0L
    self.n2412 = 0L
    self.n2411 = 0L
    self.n2410 = 0L
    self.n2409 = 0L
    self.n2408 = 0L
    self.n2407 = 0L
    self.n2406 = 0L
    self.n2401 = 0L
    self.n2392 = 0L
    self.n2346 = 0L
    self.n2345 = 0L
    self.n2344 = 0L
    self.n2343 = 0L
    self.n2342 = 0L
    self.n2341 = 0L
    self.n2340 = 0L
    self.n2339 = 0L
    self.n2334 = 0L
    self.n2333 = 0L
    self.n2332 = 0L
    self.n2331 = 0L
    self.n2330 = 0L
    self.n2329 = 0L
    self.n2328 = 0L
    self.n2327 = 0L
    self.n2326 = 0L
    self.n2325 = 0L
    self.n2324 = 0L
    self.n2323 = 0L
    self.n2322 = 0L
    self.n2321 = 0L
    self.n2320 = 0L
    self.n2318 = 0L
    self.n2271 = 0L
    self.n2267 = 0L
    self.n2266 = 0L
    self.n2265 = 0L
    self.n2264 = 0L
    self.n2261 = 0L
    self.n2260 = 0L
    self.n2259 = 0L
    self.n2258 = 0L
    self.n2257 = 0L
    self.n2256 = 0L
    self.n2255 = 0L
    self.n2246 = 0L
    self.n2245 = 0L
    self.n2224 = 0L
    self.n2198 = 0L
    self.n2194 = 0L
    self.n2193 = 0L
    self.n2192 = 0L
    self.n2191 = 0L
    self.n2188 = 0L
    self.n2187 = 0L
    self.n2186 = 0L
    self.n2185 = 0L
    self.n2184 = 0L
    self.n2183 = 0L
    self.n2182 = 0L
    self.n2173 = 0L
    self.n2172 = 0L
    self.n2143 = 0L
    self.n2114 = 0L
    self.n2085 = 0L
    self.n2076 = 0L
    self.n2075 = 0L
    self.n2066 = 0L
    self.n2065 = 0L
    self.n2057 = 0L
    self.n2031 = 0L
    self.n2012 = 0L
    self.n2011 = 0L
    self.n1977 = 0L
    self.n1976 = 0L
    self.n1968 = 0L
    self.n1967 = 0L
    self.n1959 = 0L
    self.n1913 = 0L
    self.n1912 = 0L
    self.n1911 = 0L
    self.n1910 = 0L
    self.n1909 = 0L
    self.n1908 = 0L
    self.n1907 = 0L
    self.n1906 = 0L
    self.n1905 = 0L
    self.n1904 = 0L
    self.n1903 = 0L
    self.n1902 = 0L
    self.n1898 = 0L
    self.n1897 = 0L
    self.n1896 = 0L
    self.n1895 = 0L
    self.n1894 = 0L
    self.n1893 = 0L
    self.n1892 = 0L
    self.n1891 = 0L
    self.n1890 = 0L
    self.n1889 = 0L
    self.n1888 = 0L
    self.n1887 = 0L
    self.n1882 = 0L
    self.n1873 = 0L
    self.n1827 = 0L
    self.n1826 = 0L
    self.n1825 = 0L
    self.n1824 = 0L
    self.n1823 = 0L
    self.n1822 = 0L
    self.n1821 = 0L
    self.n1820 = 0L
    self.n1815 = 0L
    self.n1814 = 0L
    self.n1813 = 0L
    self.n1812 = 0L
    self.n1811 = 0L
    self.n1810 = 0L
    self.n1809 = 0L
    self.n1808 = 0L
    self.n1807 = 0L
    self.n1806 = 0L
    self.n1805 = 0L
    self.n1804 = 0L
    self.n1803 = 0L
    self.n1802 = 0L
    self.n1801 = 0L
    self.n1799 = 0L
    self.n1752 = 0L
    self.n1748 = 0L
    self.n1747 = 0L
    self.n1746 = 0L
    self.n1745 = 0L
    self.n1742 = 0L
    self.n1741 = 0L
    self.n1740 = 0L
    self.n1739 = 0L
    self.n1738 = 0L
    self.n1737 = 0L
    self.n1736 = 0L
    self.n1727 = 0L
    self.n1726 = 0L
    self.n1705 = 0L
    self.n1679 = 0L
    self.n1675 = 0L
    self.n1674 = 0L
    self.n1673 = 0L
    self.n1672 = 0L
    self.n1669 = 0L
    self.n1668 = 0L
    self.n1667 = 0L
    self.n1666 = 0L
    self.n1665 = 0L
    self.n1664 = 0L
    self.n1663 = 0L
    self.n1654 = 0L
    self.n1653 = 0L
    self.n1624 = 0L
    self.n1595 = 0L
    self.n1566 = 0L
    self.n1557 = 0L
    self.n1556 = 0L
    self.n1547 = 0L
    self.n1546 = 0L
    self.n1538 = 0L
    self.n1512 = 0L
    self.n1493 = 0L
    self.n1492 = 0L
    self.n1458 = 0L
    self.n1457 = 0L
    self.n1449 = 0L
    self.n1448 = 0L
    self.n1440 = 0L
    self.n1394 = 0L
    self.n1393 = 0L
    self.n1392 = 0L
    self.n1391 = 0L
    self.n1390 = 0L
    self.n1389 = 0L
    self.n1388 = 0L
    self.n1387 = 0L
    self.n1386 = 0L
    self.n1385 = 0L
    self.n1384 = 0L
    self.n1383 = 0L
    self.n1379 = 0L
    self.n1378 = 0L
    self.n1377 = 0L
    self.n1376 = 0L
    self.n1375 = 0L
    self.n1374 = 0L
    self.n1373 = 0L
    self.n1372 = 0L
    self.n1371 = 0L
    self.n1370 = 0L
    self.n1369 = 0L
    self.n1368 = 0L
    self.n1363 = 0L
    self.n1354 = 0L
    self.n1308 = 0L
    self.n1307 = 0L
    self.n1306 = 0L
    self.n1305 = 0L
    self.n1304 = 0L
    self.n1303 = 0L
    self.n1302 = 0L
    self.n1301 = 0L
    self.n1296 = 0L
    self.n1295 = 0L
    self.n1294 = 0L
    self.n1293 = 0L
    self.n1292 = 0L
    self.n1291 = 0L
    self.n1290 = 0L
    self.n1289 = 0L
    self.n1288 = 0L
    self.n1287 = 0L
    self.n1286 = 0L
    self.n1285 = 0L
    self.n1284 = 0L
    self.n1283 = 0L
    self.n1282 = 0L
    self.n1280 = 0L
    self.n1233 = 0L
    self.n1229 = 0L
    self.n1228 = 0L
    self.n1227 = 0L
    self.n1226 = 0L
    self.n1223 = 0L
    self.n1222 = 0L
    self.n1221 = 0L
    self.n1220 = 0L
    self.n1219 = 0L
    self.n1218 = 0L
    self.n1217 = 0L
    self.n1208 = 0L
    self.n1207 = 0L
    self.n1186 = 0L
    self.n1160 = 0L
    self.n1156 = 0L
    self.n1155 = 0L
    self.n1154 = 0L
    self.n1153 = 0L
    self.n1150 = 0L
    self.n1149 = 0L
    self.n1148 = 0L
    self.n1147 = 0L
    self.n1146 = 0L
    self.n1145 = 0L
    self.n1144 = 0L
    self.n1135 = 0L
    self.n1134 = 0L
    self.n1105 = 0L
    self.n1076 = 0L
    self.n1047 = 0L
    self.n1038 = 0L
    self.n1037 = 0L
    self.n1028 = 0L
    self.n1027 = 0L
    self.n1019 = 0L
    self.n993 = 0L
    self.n974 = 0L
    self.n973 = 0L
    self.n939 = 0L
    self.n938 = 0L
    self.n930 = 0L
    self.n929 = 0L
    self.n921 = 0L
    self.n875 = 0L
    self.n874 = 0L
    self.n873 = 0L
    self.n872 = 0L
    self.n871 = 0L
    self.n870 = 0L
    self.n869 = 0L
    self.n868 = 0L
    self.n867 = 0L
    self.n866 = 0L
    self.n865 = 0L
    self.n864 = 0L
    self.n860 = 0L
    self.n859 = 0L
    self.n858 = 0L
    self.n857 = 0L
    self.n856 = 0L
    self.n855 = 0L
    self.n854 = 0L
    self.n853 = 0L
    self.n852 = 0L
    self.n851 = 0L
    self.n850 = 0L
    self.n849 = 0L
    self.n844 = 0L
    self.n835 = 0L
    self.n789 = 0L
    self.n788 = 0L
    self.n787 = 0L
    self.n786 = 0L
    self.n785 = 0L
    self.n784 = 0L
    self.n783 = 0L
    self.n782 = 0L
    self.n777 = 0L
    self.n776 = 0L
    self.n775 = 0L
    self.n774 = 0L
    self.n773 = 0L
    self.n772 = 0L
    self.n771 = 0L
    self.n770 = 0L
    self.n769 = 0L
    self.n768 = 0L
    self.n767 = 0L
    self.n766 = 0L
    self.n765 = 0L
    self.n764 = 0L
    self.n763 = 0L
    self.n761 = 0L
    self.n714 = 0L
    self.n710 = 0L
    self.n709 = 0L
    self.n708 = 0L
    self.n707 = 0L
    self.n704 = 0L
    self.n703 = 0L
    self.n702 = 0L
    self.n701 = 0L
    self.n700 = 0L
    self.n699 = 0L
    self.n698 = 0L
    self.n689 = 0L
    self.n688 = 0L
    self.n667 = 0L
    self.n641 = 0L
    self.n637 = 0L
    self.n636 = 0L
    self.n635 = 0L
    self.n634 = 0L
    self.n631 = 0L
    self.n630 = 0L
    self.n629 = 0L
    self.n628 = 0L
    self.n627 = 0L
    self.n626 = 0L
    self.n625 = 0L
    self.n616 = 0L
    self.n615 = 0L
    self.n586 = 0L
    self.n557 = 0L
    self.n528 = 0L
    self.n519 = 0L
    self.n518 = 0L
    self.n509 = 0L
    self.n508 = 0L
    self.n500 = 0L
    self.n474 = 0L
    self.n455 = 0L
    self.n454 = 0L
    self.n420 = 0L
    self.n419 = 0L
    self.n411 = 0L
    self.n410 = 0L
    self.n402 = 0L
    self.n356 = 0L
    self.n355 = 0L
    self.n354 = 0L
    self.n353 = 0L
    self.n352 = 0L
    self.n351 = 0L
    self.n350 = 0L
    self.n349 = 0L
    self.n348 = 0L
    self.n347 = 0L
    self.n346 = 0L
    self.n345 = 0L
    self.n341 = 0L
    self.n340 = 0L
    self.n339 = 0L
    self.n338 = 0L
    self.n337 = 0L
    self.n336 = 0L
    self.n335 = 0L
    self.n334 = 0L
    self.n333 = 0L
    self.n332 = 0L
    self.n331 = 0L
    self.n330 = 0L
    self.n325 = 0L
    self.n316 = 0L
    self.n270 = 0L
    self.n269 = 0L
    self.n268 = 0L
    self.n267 = 0L
    self.n266 = 0L
    self.n265 = 0L
    self.n264 = 0L
    self.n263 = 0L
    self.n258 = 0L
    self.n257 = 0L
    self.n256 = 0L
    self.n255 = 0L
    self.n254 = 0L
    self.n253 = 0L
    self.n252 = 0L
    self.n251 = 0L
    self.n250 = 0L
    self.n249 = 0L
    self.n248 = 0L
    self.n247 = 0L
    self.n246 = 0L
    self.n245 = 0L
    self.n244 = 0L
    self.n242 = 0L
    self.n191 = 0L
    self.n190 = 0L
    self.n189 = 0L
    self.n188 = 0L
    self.n185 = 0L
    self.n184 = 0L
    self.n183 = 0L
    self.n182 = 0L
    self.n181 = 0L
    self.n180 = 0L
    self.n179 = 0L
    self.n170 = 0L
    self.n169 = 0L
    self.n148 = 0L
    self.n118 = 0L
    self.n117 = 0L
    self.n116 = 0L
    self.n115 = 0L
    self.n112 = 0L
    self.n111 = 0L
    self.n110 = 0L
    self.n109 = 0L
    self.n108 = 0L
    self.n107 = 0L
    self.n106 = 0L
    self.n97 = 0L
    self.n95 = 0L
    self.n93 = 0L
    self.n46 = 0L
    self.n45 = 0L
    self.n44 = 0L
    self.n43 = 0L
    self.n42 = 0L
    self.n41 = 0L
    self.n40 = 0L
    self.n39 = 0L
    self.n38 = 0L
    self.n37 = 0L
    self.n36 = 0L
    self.n35 = 0L
    self.n31 = 0L
    self.n30 = 0L
    self.n29 = 0L
    self.n28 = 0L
    self.n27 = 0L
    self.n26 = 0L
    self.n25 = 0L
    self.n24 = 0L
    self.n23 = 0L
    self.n22 = 0L
    self.n21 = 0L
    self.n20 = 0L
    self.n15 = 0L
    self.n6 = 0L
    self.n5 = 0L
    self.n4 = 0L
    self.n3 = 0L
    self.n6601 = 0L
    self.n6597 = 0L
    self.n6596 = 0L
    self.n6595 = 0L
    self.n6593 = 0L
    self.n6592 = 0L
    self.n6591 = 0L
    self.n6589 = 0L
    self.n6588 = 0L
    self.n6587 = 0L
    self.n6585 = 0L
    self.n6584 = 0L
    self.n6583 = 0L
    self.n6581 = 0L
    self.n6580 = 0L
    self.n6579 = 0L
    self.n6577 = 0L
    self.n6576 = 0L
    self.n6575 = 0L
    self.n6573 = 0L
    self.n6572 = 0L
    self.n6571 = 0L
    self.n6569 = 0L
    self.n6568 = 0L
    self.n6567 = 0L
    self.n6565 = 0L
    self.n6564 = 0L
    self.n6563 = 0L
    self.n6561 = 0L
    self.n6560 = 0L
    self.n6559 = 0L
    self.n6557 = 0L
    self.n6556 = 0L
    self.n6555 = 0L
    self.n6553 = 0L
    self.n6552 = 0L
    self.n6551 = 0L
    self.n6541 = 0L
    self.n6540 = 0L
    self.n6539 = 0L
    self.n6538 = 0L
    self.n6436 = 0L
    self.n6435 = 0L
    self.n6426 = 0L
    self.n6425 = 0L
    self.n6424 = 0L
    self.n6401 = 0L
    self.n6377 = 0L
    self.n6375 = 0L
    self.n6375r = 0L
    self.n6375e = 0L
    self.n6375d = 0L
    self.n6363 = 0L
    self.n6362 = 0L
    self.n6353 = 0L
    self.n6352 = 0L
    self.n6351 = 0L
    self.n6328 = 0L
    self.n6323 = 0L
    self.n6323r = 0L
    self.n6323e = 0L
    self.n6323d = 0L
    self.n6316 = 0L
    self.n6316r = 0L
    self.n6316e = 0L
    self.n6316d = 0L
    self.n6309 = 0L
    self.n6309r = 0L
    self.n6309e = 0L
    self.n6309d = 0L
    self.n6302 = 0L
    self.n6302r = 0L
    self.n6302e = 0L
    self.n6302d = 0L
    self.n6294 = 0L
    self.n6294r = 0L
    self.n6294e = 0L
    self.n6294d = 0L
    self.n6287 = 0L
    self.n6287r = 0L
    self.n6287e = 0L
    self.n6287d = 0L
    self.n6280 = 0L
    self.n6280r = 0L
    self.n6280e = 0L
    self.n6280d = 0L
    self.n6273 = 0L
    self.n6273r = 0L
    self.n6273e = 0L
    self.n6273d = 0L
    self.n6265 = 0L
    self.n6265r = 0L
    self.n6265e = 0L
    self.n6265d = 0L
    self.n6258 = 0L
    self.n6258r = 0L
    self.n6258e = 0L
    self.n6258d = 0L
    self.n6251 = 0L
    self.n6251r = 0L
    self.n6251e = 0L
    self.n6251d = 0L
    self.n6229 = 0L
    self.n6219 = 0L
    self.n6216 = 0L
    self.n6216r = 0L
    self.n6216e = 0L
    self.n6216d = 0L
    self.n6200 = 0L
    self.n6191 = 0L
    self.n6190 = 0L
    self.n6190r = 0L
    self.n6190e = 0L
    self.n6190d = 0L
    self.n6174 = 0L
    self.n6165 = 0L
    self.n6162 = 0L
    self.n6162e = 0L
    self.n6162a = 0L
    self.n6162m = (0x7F00L,0x7FFFL,0x7FFFL,0x7FFFL,0x7FFFL,0x7FFFL,0x7FFEL,0x7FFEL,0x7FFEL,0x7FFEL,0x7FFEL,0x7FFDL,0x7FFDL,0x7FFDL,0x7FFDL,0x7FFDL,0x7FFCL,0x7FFCL,0x7FFCL,0x7FFCL,0x7FFCL,0x7FFBL,0x7FFBL,0x7FFBL,0x7FFBL,0x7FFBL,0x7FFAL,0x7FFAL,0x7FFAL,0x7FFAL,0x7FFAL,0x7FF9L,0x7FF9L,0x7FF9L,0x7FF9L,0x7FF9L,0x7FF8L,0x7FF8L,0x7FF8L,0x7FF8L,0x7FF8L,0x7FF7L,0x7FF7L,0x7FF7L,0x7FF7L,0x7FF7L,0x7FF6L,0x7FF6L,0x7FF6L,0x7FF6L,0x7FF6L,0x7FF5L,0x7FF5L,0x7FF5L,0x7FF5L,0x7FF5L,0x7FF5L,0x7FF4L,0x7FF4L,0x7FF4L,0x7FF4L,0x7FF4L,0x7FF3L,0x7FF3L,0x7FF3L,0x7FF3L,0x7FF3L,0x7FF2L,0x7FF2L,0x7FF2L,0x7FF2L,0x7FF2L,0x7FF1L,0x7FF1L,0x7FF1L,0x7FF1L,0x7FF1L,0x7FF0L,0x7FF0L,0x7FF0L,0x7FF0L,0x7FF0L,0x7EEFL,0x7EEFL,0x7EEFL,0x7EEFL,0x7EEFL,0x7EEEL,0x7EEEL,0x7EEEL,0x7EEEL,0x7EEEL,0x7EEDL,0x7EEDL,0x7EEDL,0x7EEDL,0x7EEDL,0x7EEDL,0x7EECL,0x7EECL,0x7EECL,0x7EECL,0x7EECL,0x7EEBL,0x7EEBL,0x7EEBL,0x7EEBL,0x7EEBL,0x7EEAL,0x7EEAL,0x7EEAL,0x7EEAL,0x7EEAL,0x7EE9L,0x7EE9L,0x7EE9L,0x7DE9L,0x7DE9L,0x7DE8L,0x7DE8L,0x7DE8L,0x7DE8L,0x7DE8L,0x7DE7L,0x7DE7L,0x7DE7L,0x7DE7L,0x7DE7L,0x7DE7L,0x7DE6L,0x7DE6L,0x7DE6L,0x7DE6L,0x7DE6L,0x7DE5L,0x7DE5L,0x7DE5L,0x7DE5L,0x7DE5L,0x7DE4L,0x7DE4L,0x7DE4L,0x7CE4L,0x7CE4L,0x7CE3L,0x7CE3L,0x7CE3L,0x7CE3L,0x7CE3L,0x7CE2L,0x7CE2L,0x7CE2L,0x7CE2L,0x7CE2L,0x7CE2L,0x7CE1L,0x7CE1L,0x7CE1L,0x7CE1L,0x7CE1L,0x7CE0L,0x7CE0L,0x7CE0L,0x7CE0L,0x7BE0L,0x7BDFL,0x7BDFL,0x7BDFL,0x7BDFL,0x7BDFL,0x7BDEL,0x7BDEL,0x7BDEL,0x7BDEL,0x7BDEL,0x7BDEL,0x7BDDL,0x7BDDL,0x7BDDL,0x7BDDL,0x7BDDL,0x7BDCL,0x7BDCL,0x7ADCL,0x7ADCL,0x7ADCL,0x7ADBL,0x7ADBL,0x7ADBL,0x7ADBL,0x7ADBL,0x7ADBL,0x7ADAL,0x7ADAL,0x7ADAL,0x7ADAL,0x7ADAL,0x7AD9L,0x7AD9L,0x7AD9L,0x7AD9L,0x79D9L,0x79D8L,0x79D8L,0x79D8L,0x79D8L,0x79D8L,0x79D8L,0x79D7L,0x79D7L,0x79D7L,0x79D7L,0x79D7L,0x79D6L,0x79D6L,0x79D6L,0x79D6L,0x78D6L,0x78D5L,0x78D5L,0x78D5L,0x78D5L,0x78D5L,0x78D5L,0x78D4L,0x78D4L,0x78D4L,0x78D4L,0x78D4L,0x78D3L,0x78D3L,0x78D3L,0x77D3L,0x77D3L,0x77D3L,0x77D2L,0x77D2L,0x77D2L,0x77D2L,0x77D2L,0x77D1L,0x77D1L,0x77D1L,0x77D1L,0x77D1L,0x77D1L,0x76D0L,0x76D0L,0x76D0L,0x76D0L,0x76D0L,0x76CFL,0x76CFL,0x76CFL,0x76CFL,0x76CFL,0x76CFL,0x76CEL,0x76CEL,0x76CEL,0x75CEL,0x75CEL,0x75CDL,0x75CDL,0x75CDL,0x75CDL,0x75CDL,0x75CDL,0x75CCL,0x75CCL,0x75CCL,0x75CCL,0x75CCL,0x74CBL,0x74CBL,0x74CBL,0x74CBL,0x74CBL,0x74CBL,0x74CAL,0x74CAL,0x74CAL,0x74CAL,0x74CAL,0x74C9L,0x73C9L,0x73C9L,0x73C9L,0x73C9L,0x73C9L,0x73C8L,0x73C8L,0x73C8L,0x73C8L,0x73C8L,0x73C8L,0x73C7L,0x72C7L,0x72C7L,0x72C7L,0x72C7L,0x72C6L,0x72C6L,0x72C6L,0x72C6L,0x72C6L,0x72C6L,0x72C5L,0x71C5L,0x71C5L,0x71C5L,0x71C5L,0x71C5L,0x71C4L,0x71C4L,0x71C4L,0x71C4L,0x71C4L,0x71C4L,0x70C3L,0x70C3L,0x70C3L,0x70C3L,0x70C3L,0x70C2L,0x70C2L,0x70C2L,0x70C2L,0x70C2L,0x70C2L,0x6FC1L,0x6FC1L,0x6FC1L,0x6FC1L,0x6FC1L,0x6FC1L,0x6FC0L,0x6FC0L,0x6FC0L,0x6FC0L,0x6EC0L,0x6EC0L,0x6EBFL,0x6EBFL,0x6EBFL,0x6EBFL,0x6EBFL,0x6EBFL,0x6EBEL,0x6EBEL,0x6DBEL,0x6DBEL,0x6DBEL,0x6DBEL,0x6DBDL,0x6DBDL,0x6DBDL,0x6DBDL,0x6DBDL,0x6DBDL,0x6CBCL,0x6CBCL,0x6CBCL,0x6CBCL,0x6CBCL,0x6CBCL,0x6CBBL,0x6CBBL,0x6CBBL,0x6CBBL,0x6BBBL,0x6BBBL,0x6BBAL,0x6BBAL,0x6BBAL,0x6BBAL,0x6BBAL,0x6BBAL,0x6BB9L,0x6AB9L,0x6AB9L,0x6AB9L,0x6AB9L,0x6AB9L,0x6AB8L,0x6AB8L,0x6AB8L,0x6AB8L,0x69B8L,0x69B8L,0x69B7L,0x69B7L,0x69B7L,0x69B7L,0x69B7L,0x69B7L,0x69B6L,0x68B6L,0x68B6L,0x68B6L,0x68B6L,0x68B6L,0x68B5L,0x68B5L,0x68B5L,0x68B5L,0x67B5L,0x67B5L,0x67B5L,0x67B4L,0x67B4L,0x67B4L,0x67B4L,0x67B4L,0x67B4L,0x66B3L,0x66B3L,0x66B3L,0x66B3L,0x66B3L,0x66B3L,0x66B2L,0x66B2L,0x65B2L,0x65B2L,0x65B2L,0x65B2L,0x65B2L,0x65B1L,0x65B1L,0x65B1L,0x65B1L,0x64B1L,0x64B1L,0x64B0L,0x64B0L,0x64B0L,0x64B0L,0x64B0L,0x64B0L,0x63B0L,0x63AFL,0x63AFL,0x63AFL,0x63AFL,0x63AFL,0x63AFL,0x63AEL,0x62AEL,0x62AEL,0x62AEL,0x62AEL,0x62AEL,0x62AEL,0x62ADL,0x62ADL,0x61ADL,0x61ADL,0x61ADL,0x61ADL,0x61ACL,0x61ACL,0x61ACL,0x61ACL,0x60ACL,0x60ACL,0x60ACL,0x60ABL,0x60ABL,0x60ABL,0x60ABL,0x60ABL,0x5FABL,0x5FABL,0x5FAAL,0x5FAAL,0x5FAAL,0x5FAAL,0x5FAAL,0x5EAAL,0x5EAAL,0x5EA9L,0x5EA9L,0x5EA9L,0x5EA9L,0x5EA9L,0x5EA9L,0x5DA9L,0x5DA8L,0x5DA8L,0x5DA8L,0x5DA8L,0x5DA8L,0x5DA8L,0x5CA8L,0x5CA7L,0x5CA7L,0x5CA7L,0x5CA7L,0x5CA7L,0x5CA7L,0x5CA7L,0x5BA6L,0x5BA6L,0x5BA6L,0x5BA6L,0x5BA6L,0x5BA6L,0x5BA6L,0x5AA5L,0x5AA5L,0x5AA5L,0x5AA5L,0x5AA5L,0x5AA5L,0x5AA5L,0x59A4L,0x59A4L,0x59A4L,0x59A4L,0x59A4L,0x59A4L,0x59A4L,0x58A3L,0x58A3L,0x58A3L,0x58A3L,0x58A3L,0x58A3L,0x58A3L,0x57A3L,0x57A2L,0x57A2L,0x57A2L,0x57A2L,0x57A2L,0x57A2L,0x56A2L,0x56A1L,0x56A1L,0x56A1L,0x56A1L,0x56A1L,0x56A1L,0x55A1L,0x55A1L,0x55A0L,0x55A0L,0x55A0L,0x55A0L,0x55A0L,0x54A0L,0x54A0L,0x549FL,0x549FL,0x549FL,0x549FL,0x549FL,0x539FL,0x539FL,0x539FL,0x539EL,0x539EL,0x539EL,0x539EL,0x529EL,0x529EL,0x529EL,0x529EL,0x529DL,0x529DL,0x519DL,0x519DL,0x519DL,0x519DL,0x519DL,0x519DL,0x519CL,0x509CL,0x509CL,0x509CL,0x509CL,0x509CL,0x509CL,0x4F9CL,0x4F9BL,0x4F9BL,0x4F9BL,0x4F9BL,0x4F9BL,0x4F9BL,0x4E9BL,0x4E9BL,0x4E9AL,0x4E9AL,0x4E9AL,0x4E9AL,0x4D9AL,0x4D9AL,0x4D9AL,0x4D9AL,0x4D9AL,0x4D99L,0x4D99L,0x4C99L,0x4C99L,0x4C99L,0x4C99L,0x4C99L,0x4C99L,0x4B98L,0x4B98L,0x4B98L,0x4B98L,0x4B98L,0x4B98L,0x4A98L,0x4A98L,0x4A98L,0x4A97L,0x4A97L,0x4A97L,0x4A97L,0x4997L,0x4997L,0x4997L,0x4997L,0x4997L,0x4996L,0x4896L,0x4896L,0x4896L,0x4896L,0x4896L,0x4896L,0x4796L,0x4796L,0x4795L,0x4795L,0x4795L,0x4795L,0x4695L,0x4695L,0x4695L,0x4695L,0x4695L,0x4694L,0x4594L,0x4594L,0x4594L,0x4594L,0x4594L,0x4594L,0x4494L,0x4494L,0x4493L,0x4493L,0x4493L,0x4493L,0x4393L,0x4393L,0x4393L,0x4393L,0x4393L,0x4393L,0x4292L,0x4292L,0x4292L,0x4292L,0x4292L,0x4292L,0x4192L,0x4192L,0x4192L,0x4192L,0x4191L,0x4191L,0x4091L,0x4091L,0x4091L,0x4091L,0x4091L,0x4091L,0x3F91L,0x3F91L,0x3F90L,0x3F90L,0x3F90L,0x3F90L,0x3E90L,0x3E90L,0x3E90L,0x3E90L,0x3E90L,0x3E90L,0x3D8FL,0x3D8FL,0x3D8FL,0x3D8FL,0x3D8FL,0x3D8FL,0x3C8FL,0x3C8FL,0x3C8FL,0x3C8FL,0x3C8FL,0x3B8EL,0x3B8EL,0x3B8EL,0x3B8EL,0x3B8EL,0x3B8EL,0x3A8EL,0x3A8EL,0x3A8EL,0x3A8EL,0x3A8EL,0x3A8DL,0x398DL,0x398DL,0x398DL,0x398DL,0x398DL,0x398DL,0x388DL,0x388DL,0x388DL,0x388DL,0x388CL,0x378CL,0x378CL,0x378CL,0x378CL,0x378CL,0x378CL,0x368CL,0x368CL,0x368CL,0x368CL,0x368CL,0x368BL,0x358BL,0x358BL,0x358BL,0x358BL,0x358BL,0x348BL,0x348BL,0x348BL,0x348BL,0x348BL,0x348BL,0x338AL,0x338AL,0x338AL,0x338AL,0x338AL,0x328AL,0x328AL,0x328AL,0x328AL,0x328AL,0x328AL,0x318AL,0x318AL,0x3189L,0x3189L,0x3189L,0x3089L,0x3089L,0x3089L,0x3089L,0x3089L,0x3089L,0x2F89L,0x2F89L,0x2F89L,0x2F89L,0x2F89L,0x2E88L,0x2E88L,0x2E88L,0x2E88L,0x2E88L,0x2E88L,0x2D88L,0x2D88L,0x2D88L,0x2D88L,0x2D88L,0x2C88L,0x2C88L,0x2C88L,0x2C87L,0x2C87L,0x2C87L,0x2B87L,0x2B87L,0x2B87L,0x2B87L,0x2B87L,0x2A87L,0x2A87L,0x2A87L,0x2A87L,0x2A87L,0x2A87L,0x2987L,0x2986L,0x2986L,0x2986L,0x2986L,0x2886L,0x2886L,0x2886L,0x2886L,0x2886L,0x2786L,0x2786L,0x2786L,0x2786L,0x2786L,0x2786L,0x2686L,0x2685L,0x2685L,0x2685L,0x2685L,0x2585L,0x2585L,0x2585L,0x2585L,0x2585L,0x2485L,0x2485L,0x2485L,0x2485L,0x2485L,0x2485L,0x2385L,0x2385L,0x2385L,0x2384L,0x2384L,0x2284L,0x2284L,0x2284L,0x2284L,0x2284L,0x2184L,0x2184L,0x2184L,0x2184L,0x2184L,0x2184L,0x2084L,0x2084L,0x2084L,0x2084L,0x2084L,0x1F84L,0x1F83L,0x1F83L,0x1F83L,0x1F83L,0x1E83L,0x1E83L,0x1E83L,0x1E83L,0x1E83L,0x1D83L,0x1D83L,0x1D83L,0x1D83L,0x1D83L,0x1D83L,0x1C83L,0x1C83L,0x1C83L,0x1C83L,0x1C83L,0x1B83L,0x1B83L,0x1B82L,0x1B82L,0x1B82L,0x1A82L,0x1A82L,0x1A82L,0x1A82L,0x1A82L,0x1982L,0x1982L,0x1982L,0x1982L,0x1982L,0x1882L,0x1882L,0x1882L,0x1882L,0x1882L,0x1882L,0x1782L,0x1782L,0x1782L,0x1782L,0x1782L,0x1682L,0x1682L,0x1681L,0x1681L,0x1681L,0x1581L,0x1581L,0x1581L,0x1581L,0x1581L,0x1481L,0x1481L,0x1481L,0x1481L,0x1481L,0x1381L,0x1381L,0x1381L,0x1381L,0x1381L,0x1281L,0x1281L,0x1281L,0x1281L,0x1281L,0x1281L,0x1181L,0x1181L,0x1181L,0x1181L,0x1181L,0x1081L,0x1081L,0x1081L,0x1081L,0x1081L,0x0F80L,0x0F80L,0x0F80L,0x0F80L,0x0F80L,0x0E80L,0x0E80L,0x0E80L,0x0E80L,0x0E80L,0x0D80L,0x0D80L,0x0D80L,0x0D80L,0x0D80L,0x0C80L,0x0C80L,0x0C80L,0x0C80L,0x0C80L,0x0B80L,0x0B80L,0x0B80L,0x0B80L,0x0B80L,0x0A80L,0x0A80L,0x0A80L,0x0A80L,0x0A80L,0x0A80L,0x0980L,0x0980L,0x0980L,0x0980L,0x0980L,0x0880L,0x0880L,0x0880L,0x0880L,0x0880L,0x0780L,0x0780L,0x0780L,0x0780L,0x0780L,0x0680L,0x0680L,0x0680L,0x0680L,0x0680L,0x0580L,0x0580L,0x0580L,0x0580L,0x0580L,0x0480L,0x0480L,0x0480L,0x0480L,0x0480L,0x0380L,0x0380L,0x0380L,0x0380L,0x0380L,0x0280L,0x0280L,0x0280L,0x0280L,0x0280L,0x0180L,0x0180L,0x0180L,0x0180L,0x0180L,0x0080L,0x0080L,0x0080L,0x0080L,0x0080L,0x0080L,0xFF80L,0xFF80L,0xFF80L,0xFF80L,0xFF80L,0xFE80L,0xFE80L,0xFE80L,0xFE80L,0xFE80L,0xFD80L,0xFD80L,0xFD80L,0xFD80L,0xFD80L,0xFC80L,0xFC80L,0xFC80L,0xFC80L,0xFC80L,0xFB80L,0xFB80L,0xFB80L,0xFB80L,0xFB80L,0xFA80L,0xFA80L,0xFA80L,0xFA80L,0xFA80L,0xF980L,0xF980L,0xF980L,0xF980L,0xF980L,0xF880L,0xF880L,0xF880L,0xF880L,0xF880L,0xF780L,0xF780L,0xF780L,0xF780L,0xF780L,0xF680L,0xF680L,0xF680L,0xF680L,0xF680L,0xF580L,0xF580L,0xF580L,0xF580L,0xF580L,0xF580L,0xF480L,0xF480L,0xF480L,0xF480L,0xF480L,0xF380L,0xF380L,0xF380L,0xF380L,0xF380L,0xF280L,0xF280L,0xF280L,0xF280L,0xF280L,0xF180L,0xF180L,0xF180L,0xF180L,0xF180L,0xF080L,0xF080L,0xF080L,0xF080L,0xF080L,0xEF81L,0xEF81L,0xEF81L,0xEF81L,0xEF81L,0xEE81L,0xEE81L,0xEE81L,0xEE81L,0xEE81L,0xED81L,0xED81L,0xED81L,0xED81L,0xED81L,0xED81L,0xEC81L,0xEC81L,0xEC81L,0xEC81L,0xEC81L,0xEB81L,0xEB81L,0xEB81L,0xEB81L,0xEB81L,0xEA81L,0xEA81L,0xEA81L,0xEA81L,0xEA81L,0xE981L,0xE981L,0xE981L,0xE982L,0xE982L,0xE882L,0xE882L,0xE882L,0xE882L,0xE882L,0xE782L,0xE782L,0xE782L,0xE782L,0xE782L,0xE782L,0xE682L,0xE682L,0xE682L,0xE682L,0xE682L,0xE582L,0xE582L,0xE582L,0xE582L,0xE582L,0xE482L,0xE482L,0xE482L,0xE483L,0xE483L,0xE383L,0xE383L,0xE383L,0xE383L,0xE383L,0xE283L,0xE283L,0xE283L,0xE283L,0xE283L,0xE283L,0xE183L,0xE183L,0xE183L,0xE183L,0xE183L,0xE083L,0xE083L,0xE083L,0xE083L,0xE084L,0xDF84L,0xDF84L,0xDF84L,0xDF84L,0xDF84L,0xDE84L,0xDE84L,0xDE84L,0xDE84L,0xDE84L,0xDE84L,0xDD84L,0xDD84L,0xDD84L,0xDD84L,0xDD84L,0xDC84L,0xDC84L,0xDC85L,0xDC85L,0xDC85L,0xDB85L,0xDB85L,0xDB85L,0xDB85L,0xDB85L,0xDB85L,0xDA85L,0xDA85L,0xDA85L,0xDA85L,0xDA85L,0xD985L,0xD985L,0xD985L,0xD985L,0xD986L,0xD886L,0xD886L,0xD886L,0xD886L,0xD886L,0xD886L,0xD786L,0xD786L,0xD786L,0xD786L,0xD786L,0xD686L,0xD686L,0xD686L,0xD686L,0xD687L,0xD587L,0xD587L,0xD587L,0xD587L,0xD587L,0xD587L,0xD487L,0xD487L,0xD487L,0xD487L,0xD487L,0xD387L,0xD387L,0xD387L,0xD388L,0xD388L,0xD388L,0xD288L,0xD288L,0xD288L,0xD288L,0xD288L,0xD188L,0xD188L,0xD188L,0xD188L,0xD188L,0xD188L,0xD089L,0xD089L,0xD089L,0xD089L,0xD089L,0xCF89L,0xCF89L,0xCF89L,0xCF89L,0xCF89L,0xCF89L,0xCE89L,0xCE89L,0xCE89L,0xCE8AL,0xCE8AL,0xCD8AL,0xCD8AL,0xCD8AL,0xCD8AL,0xCD8AL,0xCD8AL,0xCC8AL,0xCC8AL,0xCC8AL,0xCC8AL,0xCC8AL,0xCB8BL,0xCB8BL,0xCB8BL,0xCB8BL,0xCB8BL,0xCB8BL,0xCA8BL,0xCA8BL,0xCA8BL,0xCA8BL,0xCA8BL,0xC98BL,0xC98CL,0xC98CL,0xC98CL,0xC98CL,0xC98CL,0xC88CL,0xC88CL,0xC88CL,0xC88CL,0xC88CL,0xC88CL,0xC78CL,0xC78DL,0xC78DL,0xC78DL,0xC78DL,0xC68DL,0xC68DL,0xC68DL,0xC68DL,0xC68DL,0xC68DL,0xC58DL,0xC58EL,0xC58EL,0xC58EL,0xC58EL,0xC58EL,0xC48EL,0xC48EL,0xC48EL,0xC48EL,0xC48EL,0xC48EL,0xC38FL,0xC38FL,0xC38FL,0xC38FL,0xC38FL,0xC28FL,0xC28FL,0xC28FL,0xC28FL,0xC28FL,0xC28FL,0xC190L,0xC190L,0xC190L,0xC190L,0xC190L,0xC190L,0xC090L,0xC090L,0xC090L,0xC090L,0xC091L,0xC091L,0xBF91L,0xBF91L,0xBF91L,0xBF91L,0xBF91L,0xBF91L,0xBE91L,0xBE91L,0xBE92L,0xBE92L,0xBE92L,0xBE92L,0xBD92L,0xBD92L,0xBD92L,0xBD92L,0xBD92L,0xBD92L,0xBC93L,0xBC93L,0xBC93L,0xBC93L,0xBC93L,0xBC93L,0xBB93L,0xBB93L,0xBB93L,0xBB93L,0xBB94L,0xBB94L,0xBA94L,0xBA94L,0xBA94L,0xBA94L,0xBA94L,0xBA94L,0xB994L,0xB995L,0xB995L,0xB995L,0xB995L,0xB995L,0xB895L,0xB895L,0xB895L,0xB895L,0xB896L,0xB896L,0xB796L,0xB796L,0xB796L,0xB796L,0xB796L,0xB796L,0xB696L,0xB697L,0xB697L,0xB697L,0xB697L,0xB697L,0xB597L,0xB597L,0xB597L,0xB597L,0xB598L,0xB598L,0xB598L,0xB498L,0xB498L,0xB498L,0xB498L,0xB498L,0xB498L,0xB399L,0xB399L,0xB399L,0xB399L,0xB399L,0xB399L,0xB299L,0xB299L,0xB29AL,0xB29AL,0xB29AL,0xB29AL,0xB29AL,0xB19AL,0xB19AL,0xB19AL,0xB19AL,0xB19BL,0xB19BL,0xB09BL,0xB09BL,0xB09BL,0xB09BL,0xB09BL,0xB09BL,0xB09CL,0xAF9CL,0xAF9CL,0xAF9CL,0xAF9CL,0xAF9CL,0xAF9CL,0xAE9CL,0xAE9DL,0xAE9DL,0xAE9DL,0xAE9DL,0xAE9DL,0xAE9DL,0xAD9DL,0xAD9DL,0xAD9EL,0xAD9EL,0xAD9EL,0xAD9EL,0xAC9EL,0xAC9EL,0xAC9EL,0xAC9EL,0xAC9FL,0xAC9FL,0xAC9FL,0xAB9FL,0xAB9FL,0xAB9FL,0xAB9FL,0xAB9FL,0xABA0L,0xABA0L,0xAAA0L,0xAAA0L,0xAAA0L,0xAAA0L,0xAAA0L,0xAAA1L,0xAAA1L,0xA9A1L,0xA9A1L,0xA9A1L,0xA9A1L,0xA9A1L,0xA9A1L,0xA9A2L,0xA8A2L,0xA8A2L,0xA8A2L,0xA8A2L,0xA8A2L,0xA8A2L,0xA8A3L,0xA7A3L,0xA7A3L,0xA7A3L,0xA7A3L,0xA7A3L,0xA7A3L,0xA7A3L,0xA6A4L,0xA6A4L,0xA6A4L,0xA6A4L,0xA6A4L,0xA6A4L,0xA6A4L,0xA5A5L,0xA5A5L,0xA5A5L,0xA5A5L,0xA5A5L,0xA5A5L,0xA5A5L,0xA4A6L,0xA4A6L,0xA4A6L,0xA4A6L,0xA4A6L,0xA4A6L,0xA4A6L,0xA3A7L,0xA3A7L,0xA3A7L,0xA3A7L,0xA3A7L,0xA3A7L,0xA3A7L,0xA3A8L,0xA2A8L,0xA2A8L,0xA2A8L,0xA2A8L,0xA2A8L,0xA2A8L,0xA2A9L,0xA1A9L,0xA1A9L,0xA1A9L,0xA1A9L,0xA1A9L,0xA1A9L,0xA1AAL,0xA1AAL,0xA0AAL,0xA0AAL,0xA0AAL,0xA0AAL,0xA0AAL,0xA0ABL,0xA0ABL,0x9FABL,0x9FABL,0x9FABL,0x9FABL,0x9FABL,0x9FACL,0x9FACL,0x9FACL,0x9EACL,0x9EACL,0x9EACL,0x9EACL,0x9EADL,0x9EADL,0x9EADL,0x9EADL,0x9DADL,0x9DADL,0x9DAEL,0x9DAEL,0x9DAEL,0x9DAEL,0x9DAEL,0x9DAEL,0x9CAEL,0x9CAFL,0x9CAFL,0x9CAFL,0x9CAFL,0x9CAFL,0x9CAFL,0x9CB0L,0x9BB0L,0x9BB0L,0x9BB0L,0x9BB0L,0x9BB0L,0x9BB0L,0x9BB1L,0x9BB1L,0x9AB1L,0x9AB1L,0x9AB1L,0x9AB1L,0x9AB2L,0x9AB2L,0x9AB2L,0x9AB2L,0x9AB2L,0x99B2L,0x99B2L,0x99B3L,0x99B3L,0x99B3L,0x99B3L,0x99B3L,0x99B3L,0x98B4L,0x98B4L,0x98B4L,0x98B4L,0x98B4L,0x98B4L,0x98B5L,0x98B5L,0x98B5L,0x97B5L,0x97B5L,0x97B5L,0x97B5L,0x97B6L,0x97B6L,0x97B6L,0x97B6L,0x97B6L,0x96B6L,0x96B7L,0x96B7L,0x96B7L,0x96B7L,0x96B7L,0x96B7L,0x96B8L,0x96B8L,0x95B8L,0x95B8L,0x95B8L,0x95B8L,0x95B9L,0x95B9L,0x95B9L,0x95B9L,0x95B9L,0x94B9L,0x94BAL,0x94BAL,0x94BAL,0x94BAL,0x94BAL,0x94BAL,0x94BBL,0x94BBL,0x93BBL,0x93BBL,0x93BBL,0x93BBL,0x93BCL,0x93BCL,0x93BCL,0x93BCL,0x93BCL,0x93BCL,0x92BDL,0x92BDL,0x92BDL,0x92BDL,0x92BDL,0x92BDL,0x92BEL,0x92BEL,0x92BEL,0x92BEL,0x91BEL,0x91BEL,0x91BFL,0x91BFL,0x91BFL,0x91BFL,0x91BFL,0x91BFL,0x91C0L,0x91C0L,0x90C0L,0x90C0L,0x90C0L,0x90C0L,0x90C1L,0x90C1L,0x90C1L,0x90C1L,0x90C1L,0x90C1L,0x8FC2L,0x8FC2L,0x8FC2L,0x8FC2L,0x8FC2L,0x8FC2L,0x8FC3L,0x8FC3L,0x8FC3L,0x8FC3L,0x8FC3L,0x8EC4L,0x8EC4L,0x8EC4L,0x8EC4L,0x8EC4L,0x8EC4L,0x8EC5L,0x8EC5L,0x8EC5L,0x8EC5L,0x8EC5L,0x8DC5L,0x8DC6L,0x8DC6L,0x8DC6L,0x8DC6L,0x8DC6L,0x8DC6L,0x8DC7L,0x8DC7L,0x8DC7L,0x8DC7L,0x8CC7L,0x8CC8L,0x8CC8L,0x8CC8L,0x8CC8L,0x8CC8L,0x8CC8L,0x8CC9L,0x8CC9L,0x8CC9L,0x8CC9L,0x8CC9L,0x8BC9L,0x8BCAL,0x8BCAL,0x8BCAL,0x8BCAL,0x8BCAL,0x8BCBL,0x8BCBL,0x8BCBL,0x8BCBL,0x8BCBL,0x8BCBL,0x8ACCL,0x8ACCL,0x8ACCL,0x8ACCL,0x8ACCL,0x8ACDL,0x8ACDL,0x8ACDL,0x8ACDL,0x8ACDL,0x8ACDL,0x8ACEL,0x8ACEL,0x89CEL,0x89CEL,0x89CEL,0x89CFL,0x89CFL,0x89CFL,0x89CFL,0x89CFL,0x89CFL,0x89D0L,0x89D0L,0x89D0L,0x89D0L,0x89D0L,0x88D1L,0x88D1L,0x88D1L,0x88D1L,0x88D1L,0x88D1L,0x88D2L,0x88D2L,0x88D2L,0x88D2L,0x88D2L,0x88D3L,0x88D3L,0x88D3L,0x87D3L,0x87D3L,0x87D3L,0x87D4L,0x87D4L,0x87D4L,0x87D4L,0x87D4L,0x87D5L,0x87D5L,0x87D5L,0x87D5L,0x87D5L,0x87D5L,0x87D6L,0x86D6L,0x86D6L,0x86D6L,0x86D6L,0x86D7L,0x86D7L,0x86D7L,0x86D7L,0x86D7L,0x86D8L,0x86D8L,0x86D8L,0x86D8L,0x86D8L,0x86D8L,0x86D9L,0x85D9L,0x85D9L,0x85D9L,0x85D9L,0x85DAL,0x85DAL,0x85DAL,0x85DAL,0x85DAL,0x85DBL,0x85DBL,0x85DBL,0x85DBL,0x85DBL,0x85DBL,0x85DCL,0x85DCL,0x85DCL,0x84DCL,0x84DCL,0x84DDL,0x84DDL,0x84DDL,0x84DDL,0x84DDL,0x84DEL,0x84DEL,0x84DEL,0x84DEL,0x84DEL,0x84DEL,0x84DFL,0x84DFL,0x84DFL,0x84DFL,0x84DFL,0x84E0L,0x83E0L,0x83E0L,0x83E0L,0x83E0L,0x83E1L,0x83E1L,0x83E1L,0x83E1L,0x83E1L,0x83E2L,0x83E2L,0x83E2L,0x83E2L,0x83E2L,0x83E2L,0x83E3L,0x83E3L,0x83E3L,0x83E3L,0x83E3L,0x83E4L,0x83E4L,0x82E4L,0x82E4L,0x82E4L,0x82E5L,0x82E5L,0x82E5L,0x82E5L,0x82E5L,0x82E6L,0x82E6L,0x82E6L,0x82E6L,0x82E6L,0x82E7L,0x82E7L,0x82E7L,0x82E7L,0x82E7L,0x82E7L,0x82E8L,0x82E8L,0x82E8L,0x82E8L,0x82E8L,0x82E9L,0x82E9L,0x81E9L,0x81E9L,0x81E9L,0x81EAL,0x81EAL,0x81EAL,0x81EAL,0x81EAL,0x81EBL,0x81EBL,0x81EBL,0x81EBL,0x81EBL,0x81ECL,0x81ECL,0x81ECL,0x81ECL,0x81ECL,0x81EDL,0x81EDL,0x81EDL,0x81EDL,0x81EDL,0x81EDL,0x81EEL,0x81EEL,0x81EEL,0x81EEL,0x81EEL,0x81EFL,0x81EFL,0x81EFL,0x81EFL,0x81EFL,0x80F0L,0x80F0L,0x80F0L,0x80F0L,0x80F0L,0x80F1L,0x80F1L,0x80F1L,0x80F1L,0x80F1L,0x80F2L,0x80F2L,0x80F2L,0x80F2L,0x80F2L,0x80F3L,0x80F3L,0x80F3L,0x80F3L,0x80F3L,0x80F4L,0x80F4L,0x80F4L,0x80F4L,0x80F4L,0x80F5L,0x80F5L,0x80F5L,0x80F5L,0x80F5L,0x80F5L,0x80F6L,0x80F6L,0x80F6L,0x80F6L,0x80F6L,0x80F7L,0x80F7L,0x80F7L,0x80F7L,0x80F7L,0x80F8L,0x80F8L,0x80F8L,0x80F8L,0x80F8L,0x80F9L,0x80F9L,0x80F9L,0x80F9L,0x80F9L,0x80FAL,0x80FAL,0x80FAL,0x80FAL,0x80FAL,0x80FBL,0x80FBL,0x80FBL,0x80FBL,0x80FBL,0x80FCL,0x80FCL,0x80FCL,0x80FCL,0x80FCL,0x80FDL,0x80FDL,0x80FDL,0x80FDL,0x80FDL,0x80FEL,0x80FEL,0x80FEL,0x80FEL,0x80FEL,0x80FFL,0x80FFL,0x80FFL,0x80FFL,0x80FFL,)
    self.n6157 = 0L
    self.n6157r = 0L
    self.n6157e = 0L
    self.n6157d = 0L
    self.n6150 = 0L
    self.n6150r = 0L
    self.n6150e = 0L
    self.n6150d = 0L
    self.n6143 = 0L
    self.n6143r = 0L
    self.n6143e = 0L
    self.n6143d = 0L
    self.n6136 = 0L
    self.n6136r = 0L
    self.n6136e = 0L
    self.n6136d = 0L
    self.n6035 = 0L
    self.n6028 = 0L
    self.n6022 = 0L
    self.n6021 = 0L
    self.n6020 = 0L
    self.n6019 = 0L
    self.n5917 = 0L
    self.n5916 = 0L
    self.n5907 = 0L
    self.n5906 = 0L
    self.n5905 = 0L
    self.n5882 = 0L
    self.n5858 = 0L
    self.n5856 = 0L
    self.n5856r = 0L
    self.n5856e = 0L
    self.n5856d = 0L
    self.n5844 = 0L
    self.n5843 = 0L
    self.n5834 = 0L
    self.n5833 = 0L
    self.n5832 = 0L
    self.n5809 = 0L
    self.n5804 = 0L
    self.n5804r = 0L
    self.n5804e = 0L
    self.n5804d = 0L
    self.n5797 = 0L
    self.n5797r = 0L
    self.n5797e = 0L
    self.n5797d = 0L
    self.n5790 = 0L
    self.n5790r = 0L
    self.n5790e = 0L
    self.n5790d = 0L
    self.n5783 = 0L
    self.n5783r = 0L
    self.n5783e = 0L
    self.n5783d = 0L
    self.n5775 = 0L
    self.n5775r = 0L
    self.n5775e = 0L
    self.n5775d = 0L
    self.n5768 = 0L
    self.n5768r = 0L
    self.n5768e = 0L
    self.n5768d = 0L
    self.n5761 = 0L
    self.n5761r = 0L
    self.n5761e = 0L
    self.n5761d = 0L
    self.n5754 = 0L
    self.n5754r = 0L
    self.n5754e = 0L
    self.n5754d = 0L
    self.n5746 = 0L
    self.n5746r = 0L
    self.n5746e = 0L
    self.n5746d = 0L
    self.n5739 = 0L
    self.n5739r = 0L
    self.n5739e = 0L
    self.n5739d = 0L
    self.n5732 = 0L
    self.n5732r = 0L
    self.n5732e = 0L
    self.n5732d = 0L
    self.n5710 = 0L
    self.n5700 = 0L
    self.n5697 = 0L
    self.n5697r = 0L
    self.n5697e = 0L
    self.n5697d = 0L
    self.n5681 = 0L
    self.n5672 = 0L
    self.n5671 = 0L
    self.n5671r = 0L
    self.n5671e = 0L
    self.n5671d = 0L
    self.n5655 = 0L
    self.n5646 = 0L
    self.n5643 = 0L
    self.n5643e = 0L
    self.n5643a = 0L
    self.n5643m = (0x7F00L,0x7FFFL,0x7FFFL,0x7FFEL,0x7FFEL,0x7FFEL,0x7FFDL,0x7FFDL,0x7FFCL,0x7FFCL,0x7FFCL,0x7FFBL,0x7FFBL,0x7FFAL,0x7FFAL,0x7FFAL,0x7FF9L,0x7FF9L,0x7FF8L,0x7FF8L,0x7FF8L,0x7FF7L,0x7FF7L,0x7FF6L,0x7FF6L,0x7FF6L,0x7FF5L,0x7FF5L,0x7FF5L,0x7FF4L,0x7FF4L,0x7FF3L,0x7FF3L,0x7FF3L,0x7FF2L,0x7FF2L,0x7FF1L,0x7FF1L,0x7FF1L,0x7FF0L,0x7FF0L,0x7EEFL,0x7EEFL,0x7EEFL,0x7EEEL,0x7EEEL,0x7EEDL,0x7EEDL,0x7EEDL,0x7EECL,0x7EECL,0x7EECL,0x7EEBL,0x7EEBL,0x7EEAL,0x7EEAL,0x7EEAL,0x7EE9L,0x7DE9L,0x7DE8L,0x7DE8L,0x7DE8L,0x7DE7L,0x7DE7L,0x7DE7L,0x7DE6L,0x7DE6L,0x7DE5L,0x7DE5L,0x7DE5L,0x7DE4L,0x7CE4L,0x7CE3L,0x7CE3L,0x7CE3L,0x7CE2L,0x7CE2L,0x7CE2L,0x7CE1L,0x7CE1L,0x7CE0L,0x7CE0L,0x7BE0L,0x7BDFL,0x7BDFL,0x7BDEL,0x7BDEL,0x7BDEL,0x7BDDL,0x7BDDL,0x7BDDL,0x7BDCL,0x7ADCL,0x7ADBL,0x7ADBL,0x7ADBL,0x7ADAL,0x7ADAL,0x7ADAL,0x7AD9L,0x7AD9L,0x79D8L,0x79D8L,0x79D8L,0x79D7L,0x79D7L,0x79D7L,0x79D6L,0x79D6L,0x78D5L,0x78D5L,0x78D5L,0x78D4L,0x78D4L,0x78D4L,0x78D3L,0x77D3L,0x77D3L,0x77D2L,0x77D2L,0x77D1L,0x77D1L,0x77D1L,0x76D0L,0x76D0L,0x76D0L,0x76CFL,0x76CFL,0x76CFL,0x76CEL,0x75CEL,0x75CDL,0x75CDL,0x75CDL,0x75CCL,0x75CCL,0x75CCL,0x74CBL,0x74CBL,0x74CBL,0x74CAL,0x74CAL,0x74C9L,0x73C9L,0x73C9L,0x73C8L,0x73C8L,0x73C8L,0x73C7L,0x72C7L,0x72C7L,0x72C6L,0x72C6L,0x72C6L,0x71C5L,0x71C5L,0x71C5L,0x71C4L,0x71C4L,0x71C4L,0x70C3L,0x70C3L,0x70C2L,0x70C2L,0x70C2L,0x6FC1L,0x6FC1L,0x6FC1L,0x6FC0L,0x6FC0L,0x6EC0L,0x6EBFL,0x6EBFL,0x6EBFL,0x6EBEL,0x6DBEL,0x6DBEL,0x6DBDL,0x6DBDL,0x6DBDL,0x6CBCL,0x6CBCL,0x6CBCL,0x6CBBL,0x6CBBL,0x6BBBL,0x6BBAL,0x6BBAL,0x6BBAL,0x6BB9L,0x6AB9L,0x6AB9L,0x6AB8L,0x6AB8L,0x69B8L,0x69B7L,0x69B7L,0x69B7L,0x69B6L,0x68B6L,0x68B6L,0x68B5L,0x68B5L,0x67B5L,0x67B5L,0x67B4L,0x67B4L,0x67B4L,0x66B3L,0x66B3L,0x66B3L,0x66B2L,0x65B2L,0x65B2L,0x65B1L,0x65B1L,0x64B1L,0x64B0L,0x64B0L,0x64B0L,0x63B0L,0x63AFL,0x63AFL,0x63AFL,0x62AEL,0x62AEL,0x62AEL,0x62ADL,0x61ADL,0x61ADL,0x61ACL,0x61ACL,0x60ACL,0x60ACL,0x60ABL,0x60ABL,0x5FABL,0x5FAAL,0x5FAAL,0x5FAAL,0x5EAAL,0x5EA9L,0x5EA9L,0x5EA9L,0x5DA8L,0x5DA8L,0x5DA8L,0x5CA8L,0x5CA7L,0x5CA7L,0x5CA7L,0x5BA6L,0x5BA6L,0x5BA6L,0x5BA6L,0x5AA5L,0x5AA5L,0x5AA5L,0x59A4L,0x59A4L,0x59A4L,0x59A4L,0x58A3L,0x58A3L,0x58A3L,0x57A3L,0x57A2L,0x57A2L,0x57A2L,0x56A1L,0x56A1L,0x56A1L,0x55A1L,0x55A0L,0x55A0L,0x55A0L,0x54A0L,0x549FL,0x549FL,0x539FL,0x539FL,0x539EL,0x539EL,0x529EL,0x529EL,0x529DL,0x519DL,0x519DL,0x519DL,0x509CL,0x509CL,0x509CL,0x4F9CL,0x4F9BL,0x4F9BL,0x4F9BL,0x4E9BL,0x4E9AL,0x4E9AL,0x4D9AL,0x4D9AL,0x4D99L,0x4C99L,0x4C99L,0x4C99L,0x4B98L,0x4B98L,0x4B98L,0x4A98L,0x4A98L,0x4A97L,0x4A97L,0x4997L,0x4997L,0x4996L,0x4896L,0x4896L,0x4896L,0x4796L,0x4795L,0x4795L,0x4695L,0x4695L,0x4694L,0x4594L,0x4594L,0x4594L,0x4494L,0x4493L,0x4493L,0x4393L,0x4393L,0x4393L,0x4292L,0x4292L,0x4292L,0x4192L,0x4192L,0x4191L,0x4091L,0x4091L,0x4091L,0x3F91L,0x3F90L,0x3F90L,0x3E90L,0x3E90L,0x3E90L,0x3D8FL,0x3D8FL,0x3D8FL,0x3C8FL,0x3C8FL,0x3B8EL,0x3B8EL,0x3B8EL,0x3A8EL,0x3A8EL,0x3A8EL,0x398DL,0x398DL,0x398DL,0x388DL,0x388DL,0x388CL,0x378CL,0x378CL,0x378CL,0x368CL,0x368CL,0x368BL,0x358BL,0x358BL,0x348BL,0x348BL,0x348BL,0x338AL,0x338AL,0x338AL,0x328AL,0x328AL,0x328AL,0x318AL,0x3189L,0x3089L,0x3089L,0x3089L,0x2F89L,0x2F89L,0x2F89L,0x2E88L,0x2E88L,0x2E88L,0x2D88L,0x2D88L,0x2C88L,0x2C88L,0x2C87L,0x2B87L,0x2B87L,0x2B87L,0x2A87L,0x2A87L,0x2A87L,0x2986L,0x2986L,0x2886L,0x2886L,0x2886L,0x2786L,0x2786L,0x2786L,0x2685L,0x2685L,0x2585L,0x2585L,0x2585L,0x2485L,0x2485L,0x2485L,0x2385L,0x2384L,0x2284L,0x2284L,0x2284L,0x2184L,0x2184L,0x2184L,0x2084L,0x2084L,0x1F84L,0x1F83L,0x1F83L,0x1E83L,0x1E83L,0x1D83L,0x1D83L,0x1D83L,0x1C83L,0x1C83L,0x1C83L,0x1B83L,0x1B82L,0x1A82L,0x1A82L,0x1A82L,0x1982L,0x1982L,0x1882L,0x1882L,0x1882L,0x1782L,0x1782L,0x1782L,0x1682L,0x1681L,0x1581L,0x1581L,0x1581L,0x1481L,0x1481L,0x1381L,0x1381L,0x1381L,0x1281L,0x1281L,0x1281L,0x1181L,0x1181L,0x1081L,0x1081L,0x1081L,0x0F80L,0x0F80L,0x0E80L,0x0E80L,0x0E80L,0x0D80L,0x0D80L,0x0C80L,0x0C80L,0x0C80L,0x0B80L,0x0B80L,0x0A80L,0x0A80L,0x0A80L,0x0980L,0x0980L,0x0980L,0x0880L,0x0880L,0x0780L,0x0780L,0x0780L,0x0680L,0x0680L,0x0580L,0x0580L,0x0580L,0x0480L,0x0480L,0x0380L,0x0380L,0x0380L,0x0280L,0x0280L,0x0180L,0x0180L,0x0180L,0x0080L,0x0080L,0x0080L,0xFF80L,0xFF80L,0xFE80L,0xFE80L,0xFE80L,0xFD80L,0xFD80L,0xFC80L,0xFC80L,0xFC80L,0xFB80L,0xFB80L,0xFA80L,0xFA80L,0xFA80L,0xF980L,0xF980L,0xF880L,0xF880L,0xF880L,0xF780L,0xF780L,0xF680L,0xF680L,0xF680L,0xF580L,0xF580L,0xF580L,0xF480L,0xF480L,0xF380L,0xF380L,0xF380L,0xF280L,0xF280L,0xF180L,0xF180L,0xF180L,0xF080L,0xF080L,0xEF81L,0xEF81L,0xEF81L,0xEE81L,0xEE81L,0xED81L,0xED81L,0xED81L,0xEC81L,0xEC81L,0xEC81L,0xEB81L,0xEB81L,0xEA81L,0xEA81L,0xEA81L,0xE981L,0xE982L,0xE882L,0xE882L,0xE882L,0xE782L,0xE782L,0xE782L,0xE682L,0xE682L,0xE582L,0xE582L,0xE582L,0xE482L,0xE483L,0xE383L,0xE383L,0xE383L,0xE283L,0xE283L,0xE283L,0xE183L,0xE183L,0xE083L,0xE083L,0xE084L,0xDF84L,0xDF84L,0xDE84L,0xDE84L,0xDE84L,0xDD84L,0xDD84L,0xDD84L,0xDC84L,0xDC85L,0xDB85L,0xDB85L,0xDB85L,0xDA85L,0xDA85L,0xDA85L,0xD985L,0xD985L,0xD886L,0xD886L,0xD886L,0xD786L,0xD786L,0xD786L,0xD686L,0xD686L,0xD587L,0xD587L,0xD587L,0xD487L,0xD487L,0xD487L,0xD387L,0xD388L,0xD388L,0xD288L,0xD288L,0xD188L,0xD188L,0xD188L,0xD089L,0xD089L,0xD089L,0xCF89L,0xCF89L,0xCF89L,0xCE89L,0xCE8AL,0xCD8AL,0xCD8AL,0xCD8AL,0xCC8AL,0xCC8AL,0xCC8AL,0xCB8BL,0xCB8BL,0xCB8BL,0xCA8BL,0xCA8BL,0xC98BL,0xC98CL,0xC98CL,0xC88CL,0xC88CL,0xC88CL,0xC78CL,0xC78DL,0xC78DL,0xC68DL,0xC68DL,0xC68DL,0xC58EL,0xC58EL,0xC58EL,0xC48EL,0xC48EL,0xC48EL,0xC38FL,0xC38FL,0xC28FL,0xC28FL,0xC28FL,0xC190L,0xC190L,0xC190L,0xC090L,0xC090L,0xC091L,0xBF91L,0xBF91L,0xBF91L,0xBE91L,0xBE92L,0xBE92L,0xBD92L,0xBD92L,0xBD92L,0xBC93L,0xBC93L,0xBC93L,0xBB93L,0xBB93L,0xBB94L,0xBA94L,0xBA94L,0xBA94L,0xB994L,0xB995L,0xB995L,0xB895L,0xB895L,0xB896L,0xB796L,0xB796L,0xB796L,0xB696L,0xB697L,0xB697L,0xB597L,0xB597L,0xB598L,0xB598L,0xB498L,0xB498L,0xB498L,0xB399L,0xB399L,0xB399L,0xB299L,0xB29AL,0xB29AL,0xB19AL,0xB19AL,0xB19BL,0xB09BL,0xB09BL,0xB09BL,0xB09CL,0xAF9CL,0xAF9CL,0xAF9CL,0xAE9DL,0xAE9DL,0xAE9DL,0xAD9DL,0xAD9EL,0xAD9EL,0xAC9EL,0xAC9EL,0xAC9FL,0xAC9FL,0xAB9FL,0xAB9FL,0xABA0L,0xAAA0L,0xAAA0L,0xAAA0L,0xAAA1L,0xA9A1L,0xA9A1L,0xA9A1L,0xA8A2L,0xA8A2L,0xA8A2L,0xA8A3L,0xA7A3L,0xA7A3L,0xA7A3L,0xA6A4L,0xA6A4L,0xA6A4L,0xA6A4L,0xA5A5L,0xA5A5L,0xA5A5L,0xA4A6L,0xA4A6L,0xA4A6L,0xA4A6L,0xA3A7L,0xA3A7L,0xA3A7L,0xA3A8L,0xA2A8L,0xA2A8L,0xA2A8L,0xA1A9L,0xA1A9L,0xA1A9L,0xA1AAL,0xA0AAL,0xA0AAL,0xA0AAL,0xA0ABL,0x9FABL,0x9FABL,0x9FACL,0x9FACL,0x9EACL,0x9EACL,0x9EADL,0x9EADL,0x9DADL,0x9DAEL,0x9DAEL,0x9DAEL,0x9CAFL,0x9CAFL,0x9CAFL,0x9CB0L,0x9BB0L,0x9BB0L,0x9BB0L,0x9BB1L,0x9AB1L,0x9AB1L,0x9AB2L,0x9AB2L,0x99B2L,0x99B3L,0x99B3L,0x99B3L,0x98B4L,0x98B4L,0x98B4L,0x98B5L,0x98B5L,0x97B5L,0x97B5L,0x97B6L,0x97B6L,0x96B6L,0x96B7L,0x96B7L,0x96B7L,0x96B8L,0x95B8L,0x95B8L,0x95B9L,0x95B9L,0x94B9L,0x94BAL,0x94BAL,0x94BAL,0x94BBL,0x93BBL,0x93BBL,0x93BCL,0x93BCL,0x93BCL,0x92BDL,0x92BDL,0x92BDL,0x92BEL,0x92BEL,0x91BEL,0x91BFL,0x91BFL,0x91BFL,0x91C0L,0x90C0L,0x90C0L,0x90C1L,0x90C1L,0x90C1L,0x8FC2L,0x8FC2L,0x8FC2L,0x8FC3L,0x8FC3L,0x8EC4L,0x8EC4L,0x8EC4L,0x8EC5L,0x8EC5L,0x8EC5L,0x8DC6L,0x8DC6L,0x8DC6L,0x8DC7L,0x8DC7L,0x8CC7L,0x8CC8L,0x8CC8L,0x8CC8L,0x8CC9L,0x8CC9L,0x8BC9L,0x8BCAL,0x8BCAL,0x8BCBL,0x8BCBL,0x8BCBL,0x8ACCL,0x8ACCL,0x8ACCL,0x8ACDL,0x8ACDL,0x8ACDL,0x8ACEL,0x89CEL,0x89CFL,0x89CFL,0x89CFL,0x89D0L,0x89D0L,0x89D0L,0x88D1L,0x88D1L,0x88D1L,0x88D2L,0x88D2L,0x88D3L,0x88D3L,0x87D3L,0x87D4L,0x87D4L,0x87D4L,0x87D5L,0x87D5L,0x87D5L,0x86D6L,0x86D6L,0x86D7L,0x86D7L,0x86D7L,0x86D8L,0x86D8L,0x86D8L,0x85D9L,0x85D9L,0x85DAL,0x85DAL,0x85DAL,0x85DBL,0x85DBL,0x85DBL,0x85DCL,0x84DCL,0x84DDL,0x84DDL,0x84DDL,0x84DEL,0x84DEL,0x84DEL,0x84DFL,0x84DFL,0x84E0L,0x83E0L,0x83E0L,0x83E1L,0x83E1L,0x83E2L,0x83E2L,0x83E2L,0x83E3L,0x83E3L,0x83E3L,0x83E4L,0x82E4L,0x82E5L,0x82E5L,0x82E5L,0x82E6L,0x82E6L,0x82E7L,0x82E7L,0x82E7L,0x82E8L,0x82E8L,0x82E8L,0x82E9L,0x81E9L,0x81EAL,0x81EAL,0x81EAL,0x81EBL,0x81EBL,0x81ECL,0x81ECL,0x81ECL,0x81EDL,0x81EDL,0x81EDL,0x81EEL,0x81EEL,0x81EFL,0x81EFL,0x81EFL,0x80F0L,0x80F0L,0x80F1L,0x80F1L,0x80F1L,0x80F2L,0x80F2L,0x80F3L,0x80F3L,0x80F3L,0x80F4L,0x80F4L,0x80F5L,0x80F5L,0x80F5L,0x80F6L,0x80F6L,0x80F6L,0x80F7L,0x80F7L,0x80F8L,0x80F8L,0x80F8L,0x80F9L,0x80F9L,0x80FAL,0x80FAL,0x80FAL,0x80FBL,0x80FBL,0x80FCL,0x80FCL,0x80FCL,0x80FDL,0x80FDL,0x80FEL,0x80FEL,0x80FEL,0x80FFL,0x80FFL,)
    self.n5638 = 0L
    self.n5638r = 0L
    self.n5638e = 0L
    self.n5638d = 0L
    self.n5631 = 0L
    self.n5631r = 0L
    self.n5631e = 0L
    self.n5631d = 0L
    self.n5624 = 0L
    self.n5624r = 0L
    self.n5624e = 0L
    self.n5624d = 0L
    self.n5617 = 0L
    self.n5617r = 0L
    self.n5617e = 0L
    self.n5617d = 0L
    self.n5516 = 0L
    self.n5509 = 0L
    self.n5503 = 0L
    self.n5502 = 0L
    self.n5501 = 0L
    self.n5500 = 0L
    self.n5398 = 0L
    self.n5397 = 0L
    self.n5388 = 0L
    self.n5387 = 0L
    self.n5386 = 0L
    self.n5363 = 0L
    self.n5339 = 0L
    self.n5337 = 0L
    self.n5337r = 0L
    self.n5337e = 0L
    self.n5337d = 0L
    self.n5325 = 0L
    self.n5324 = 0L
    self.n5315 = 0L
    self.n5314 = 0L
    self.n5313 = 0L
    self.n5290 = 0L
    self.n5285 = 0L
    self.n5285r = 0L
    self.n5285e = 0L
    self.n5285d = 0L
    self.n5278 = 0L
    self.n5278r = 0L
    self.n5278e = 0L
    self.n5278d = 0L
    self.n5271 = 0L
    self.n5271r = 0L
    self.n5271e = 0L
    self.n5271d = 0L
    self.n5264 = 0L
    self.n5264r = 0L
    self.n5264e = 0L
    self.n5264d = 0L
    self.n5256 = 0L
    self.n5256r = 0L
    self.n5256e = 0L
    self.n5256d = 0L
    self.n5249 = 0L
    self.n5249r = 0L
    self.n5249e = 0L
    self.n5249d = 0L
    self.n5242 = 0L
    self.n5242r = 0L
    self.n5242e = 0L
    self.n5242d = 0L
    self.n5235 = 0L
    self.n5235r = 0L
    self.n5235e = 0L
    self.n5235d = 0L
    self.n5227 = 0L
    self.n5227r = 0L
    self.n5227e = 0L
    self.n5227d = 0L
    self.n5220 = 0L
    self.n5220r = 0L
    self.n5220e = 0L
    self.n5220d = 0L
    self.n5213 = 0L
    self.n5213r = 0L
    self.n5213e = 0L
    self.n5213d = 0L
    self.n5191 = 0L
    self.n5181 = 0L
    self.n5178 = 0L
    self.n5178r = 0L
    self.n5178e = 0L
    self.n5178d = 0L
    self.n5162 = 0L
    self.n5153 = 0L
    self.n5152 = 0L
    self.n5152r = 0L
    self.n5152e = 0L
    self.n5152d = 0L
    self.n5136 = 0L
    self.n5127 = 0L
    self.n5124 = 0L
    self.n5124e = 0L
    self.n5124a = 0L
    self.n5124m = (0x7F00L,0x7FFFL,0x7FFEL,0x7FFDL,0x7FFCL,0x7FFCL,0x7FFBL,0x7FFAL,0x7FF9L,0x7FF8L,0x7FF8L,0x7FF7L,0x7FF6L,0x7FF5L,0x7FF5L,0x7FF4L,0x7FF3L,0x7FF2L,0x7FF1L,0x7FF1L,0x7FF0L,0x7EEFL,0x7EEEL,0x7EEDL,0x7EEDL,0x7EECL,0x7EEBL,0x7EEAL,0x7EEAL,0x7DE9L,0x7DE8L,0x7DE7L,0x7DE7L,0x7DE6L,0x7DE5L,0x7DE4L,0x7CE3L,0x7CE3L,0x7CE2L,0x7CE1L,0x7CE0L,0x7BE0L,0x7BDFL,0x7BDEL,0x7BDDL,0x7BDDL,0x7ADCL,0x7ADBL,0x7ADAL,0x7ADAL,0x7AD9L,0x79D8L,0x79D7L,0x79D7L,0x79D6L,0x78D5L,0x78D4L,0x78D4L,0x77D3L,0x77D2L,0x77D1L,0x77D1L,0x76D0L,0x76CFL,0x76CFL,0x75CEL,0x75CDL,0x75CCL,0x75CCL,0x74CBL,0x74CAL,0x74C9L,0x73C9L,0x73C8L,0x73C7L,0x72C7L,0x72C6L,0x71C5L,0x71C5L,0x71C4L,0x70C3L,0x70C2L,0x70C2L,0x6FC1L,0x6FC0L,0x6EC0L,0x6EBFL,0x6EBEL,0x6DBEL,0x6DBDL,0x6CBCL,0x6CBCL,0x6CBBL,0x6BBAL,0x6BBAL,0x6AB9L,0x6AB8L,0x69B8L,0x69B7L,0x69B6L,0x68B6L,0x68B5L,0x67B5L,0x67B4L,0x66B3L,0x66B3L,0x65B2L,0x65B1L,0x64B1L,0x64B0L,0x63B0L,0x63AFL,0x62AEL,0x62AEL,0x61ADL,0x61ACL,0x60ACL,0x60ABL,0x5FABL,0x5FAAL,0x5EAAL,0x5EA9L,0x5DA8L,0x5DA8L,0x5CA7L,0x5CA7L,0x5BA6L,0x5BA6L,0x5AA5L,0x59A4L,0x59A4L,0x58A3L,0x58A3L,0x57A2L,0x57A2L,0x56A1L,0x55A1L,0x55A0L,0x54A0L,0x549FL,0x539FL,0x539EL,0x529EL,0x519DL,0x519DL,0x509CL,0x4F9CL,0x4F9BL,0x4E9BL,0x4E9AL,0x4D9AL,0x4C99L,0x4C99L,0x4B98L,0x4A98L,0x4A97L,0x4997L,0x4996L,0x4896L,0x4796L,0x4795L,0x4695L,0x4594L,0x4594L,0x4493L,0x4393L,0x4393L,0x4292L,0x4192L,0x4191L,0x4091L,0x3F91L,0x3F90L,0x3E90L,0x3D8FL,0x3D8FL,0x3C8FL,0x3B8EL,0x3A8EL,0x3A8EL,0x398DL,0x388DL,0x388CL,0x378CL,0x368CL,0x368BL,0x358BL,0x348BL,0x338AL,0x338AL,0x328AL,0x318AL,0x3089L,0x3089L,0x2F89L,0x2E88L,0x2E88L,0x2D88L,0x2C88L,0x2B87L,0x2B87L,0x2A87L,0x2986L,0x2886L,0x2886L,0x2786L,0x2685L,0x2585L,0x2585L,0x2485L,0x2385L,0x2284L,0x2284L,0x2184L,0x2084L,0x1F84L,0x1F83L,0x1E83L,0x1D83L,0x1C83L,0x1C83L,0x1B82L,0x1A82L,0x1982L,0x1882L,0x1882L,0x1782L,0x1682L,0x1581L,0x1581L,0x1481L,0x1381L,0x1281L,0x1281L,0x1181L,0x1081L,0x0F80L,0x0E80L,0x0E80L,0x0D80L,0x0C80L,0x0B80L,0x0A80L,0x0A80L,0x0980L,0x0880L,0x0780L,0x0780L,0x0680L,0x0580L,0x0480L,0x0380L,0x0380L,0x0280L,0x0180L,0x0080L,0x0080L,0xFF80L,0xFE80L,0xFD80L,0xFC80L,0xFC80L,0xFB80L,0xFA80L,0xF980L,0xF880L,0xF880L,0xF780L,0xF680L,0xF580L,0xF580L,0xF480L,0xF380L,0xF280L,0xF180L,0xF180L,0xF080L,0xEF81L,0xEE81L,0xED81L,0xED81L,0xEC81L,0xEB81L,0xEA81L,0xEA81L,0xE982L,0xE882L,0xE782L,0xE782L,0xE682L,0xE582L,0xE482L,0xE383L,0xE383L,0xE283L,0xE183L,0xE083L,0xE084L,0xDF84L,0xDE84L,0xDD84L,0xDD84L,0xDC85L,0xDB85L,0xDA85L,0xDA85L,0xD985L,0xD886L,0xD786L,0xD786L,0xD686L,0xD587L,0xD487L,0xD487L,0xD388L,0xD288L,0xD188L,0xD188L,0xD089L,0xCF89L,0xCF89L,0xCE8AL,0xCD8AL,0xCC8AL,0xCC8AL,0xCB8BL,0xCA8BL,0xC98BL,0xC98CL,0xC88CL,0xC78CL,0xC78DL,0xC68DL,0xC58EL,0xC58EL,0xC48EL,0xC38FL,0xC28FL,0xC28FL,0xC190L,0xC090L,0xC091L,0xBF91L,0xBE91L,0xBE92L,0xBD92L,0xBC93L,0xBC93L,0xBB93L,0xBA94L,0xBA94L,0xB995L,0xB895L,0xB896L,0xB796L,0xB696L,0xB697L,0xB597L,0xB598L,0xB498L,0xB399L,0xB399L,0xB29AL,0xB19AL,0xB19BL,0xB09BL,0xB09CL,0xAF9CL,0xAE9DL,0xAE9DL,0xAD9EL,0xAC9EL,0xAC9FL,0xAB9FL,0xABA0L,0xAAA0L,0xAAA1L,0xA9A1L,0xA8A2L,0xA8A2L,0xA7A3L,0xA7A3L,0xA6A4L,0xA6A4L,0xA5A5L,0xA4A6L,0xA4A6L,0xA3A7L,0xA3A7L,0xA2A8L,0xA2A8L,0xA1A9L,0xA1AAL,0xA0AAL,0xA0ABL,0x9FABL,0x9FACL,0x9EACL,0x9EADL,0x9DAEL,0x9DAEL,0x9CAFL,0x9CB0L,0x9BB0L,0x9BB1L,0x9AB1L,0x9AB2L,0x99B3L,0x99B3L,0x98B4L,0x98B5L,0x97B5L,0x97B6L,0x96B6L,0x96B7L,0x96B8L,0x95B8L,0x95B9L,0x94BAL,0x94BAL,0x93BBL,0x93BCL,0x93BCL,0x92BDL,0x92BEL,0x91BEL,0x91BFL,0x91C0L,0x90C0L,0x90C1L,0x8FC2L,0x8FC2L,0x8FC3L,0x8EC4L,0x8EC5L,0x8EC5L,0x8DC6L,0x8DC7L,0x8CC7L,0x8CC8L,0x8CC9L,0x8BC9L,0x8BCAL,0x8BCBL,0x8ACCL,0x8ACCL,0x8ACDL,0x8ACEL,0x89CFL,0x89CFL,0x89D0L,0x88D1L,0x88D1L,0x88D2L,0x88D3L,0x87D4L,0x87D4L,0x87D5L,0x86D6L,0x86D7L,0x86D7L,0x86D8L,0x85D9L,0x85DAL,0x85DAL,0x85DBL,0x85DCL,0x84DDL,0x84DDL,0x84DEL,0x84DFL,0x84E0L,0x83E0L,0x83E1L,0x83E2L,0x83E3L,0x83E3L,0x82E4L,0x82E5L,0x82E6L,0x82E7L,0x82E7L,0x82E8L,0x82E9L,0x81EAL,0x81EAL,0x81EBL,0x81ECL,0x81EDL,0x81EDL,0x81EEL,0x81EFL,0x80F0L,0x80F1L,0x80F1L,0x80F2L,0x80F3L,0x80F4L,0x80F5L,0x80F5L,0x80F6L,0x80F7L,0x80F8L,0x80F8L,0x80F9L,0x80FAL,0x80FBL,0x80FCL,0x80FCL,0x80FDL,0x80FEL,0x80FFL,)
    self.n5119 = 0L
    self.n5119r = 0L
    self.n5119e = 0L
    self.n5119d = 0L
    self.n5112 = 0L
    self.n5112r = 0L
    self.n5112e = 0L
    self.n5112d = 0L
    self.n5105 = 0L
    self.n5105r = 0L
    self.n5105e = 0L
    self.n5105d = 0L
    self.n5098 = 0L
    self.n5098r = 0L
    self.n5098e = 0L
    self.n5098d = 0L
    self.n4997 = 0L
    self.n4990 = 0L
    self.n4984 = 0L
    self.n4983 = 0L
    self.n4982 = 0L
    self.n4981 = 0L
    self.n4879 = 0L
    self.n4878 = 0L
    self.n4869 = 0L
    self.n4868 = 0L
    self.n4867 = 0L
    self.n4844 = 0L
    self.n4820 = 0L
    self.n4818 = 0L
    self.n4818r = 0L
    self.n4818e = 0L
    self.n4818d = 0L
    self.n4806 = 0L
    self.n4805 = 0L
    self.n4796 = 0L
    self.n4795 = 0L
    self.n4794 = 0L
    self.n4771 = 0L
    self.n4766 = 0L
    self.n4766r = 0L
    self.n4766e = 0L
    self.n4766d = 0L
    self.n4759 = 0L
    self.n4759r = 0L
    self.n4759e = 0L
    self.n4759d = 0L
    self.n4752 = 0L
    self.n4752r = 0L
    self.n4752e = 0L
    self.n4752d = 0L
    self.n4745 = 0L
    self.n4745r = 0L
    self.n4745e = 0L
    self.n4745d = 0L
    self.n4737 = 0L
    self.n4737r = 0L
    self.n4737e = 0L
    self.n4737d = 0L
    self.n4730 = 0L
    self.n4730r = 0L
    self.n4730e = 0L
    self.n4730d = 0L
    self.n4723 = 0L
    self.n4723r = 0L
    self.n4723e = 0L
    self.n4723d = 0L
    self.n4716 = 0L
    self.n4716r = 0L
    self.n4716e = 0L
    self.n4716d = 0L
    self.n4708 = 0L
    self.n4708r = 0L
    self.n4708e = 0L
    self.n4708d = 0L
    self.n4701 = 0L
    self.n4701r = 0L
    self.n4701e = 0L
    self.n4701d = 0L
    self.n4694 = 0L
    self.n4694r = 0L
    self.n4694e = 0L
    self.n4694d = 0L
    self.n4672 = 0L
    self.n4662 = 0L
    self.n4659 = 0L
    self.n4659r = 0L
    self.n4659e = 0L
    self.n4659d = 0L
    self.n4643 = 0L
    self.n4634 = 0L
    self.n4633 = 0L
    self.n4633r = 0L
    self.n4633e = 0L
    self.n4633d = 0L
    self.n4617 = 0L
    self.n4608 = 0L
    self.n4605 = 0L
    self.n4605e = 0L
    self.n4605a = 0L
    self.n4605m = (0x7F00L,0x7FFEL,0x7FFCL,0x7FFBL,0x7FF9L,0x7FF8L,0x7FF6L,0x7FF5L,0x7FF3L,0x7FF1L,0x7FF0L,0x7EEEL,0x7EEDL,0x7EEBL,0x7EEAL,0x7DE8L,0x7DE7L,0x7DE5L,0x7CE3L,0x7CE2L,0x7CE0L,0x7BDFL,0x7BDDL,0x7ADCL,0x7ADAL,0x7AD9L,0x79D7L,0x79D6L,0x78D4L,0x77D3L,0x77D1L,0x76D0L,0x76CFL,0x75CDL,0x75CCL,0x74CAL,0x73C9L,0x73C7L,0x72C6L,0x71C5L,0x70C3L,0x70C2L,0x6FC0L,0x6EBFL,0x6DBEL,0x6CBCL,0x6CBBL,0x6BBAL,0x6AB8L,0x69B7L,0x68B6L,0x67B5L,0x66B3L,0x65B2L,0x64B1L,0x63B0L,0x62AEL,0x61ADL,0x60ACL,0x5FABL,0x5EAAL,0x5DA8L,0x5CA7L,0x5BA6L,0x5AA5L,0x59A4L,0x58A3L,0x57A2L,0x55A1L,0x54A0L,0x539FL,0x529EL,0x519DL,0x4F9CL,0x4E9BL,0x4D9AL,0x4C99L,0x4A98L,0x4997L,0x4896L,0x4795L,0x4594L,0x4493L,0x4393L,0x4192L,0x4091L,0x3F90L,0x3D8FL,0x3C8FL,0x3A8EL,0x398DL,0x388CL,0x368CL,0x358BL,0x338AL,0x328AL,0x3089L,0x2F89L,0x2E88L,0x2C88L,0x2B87L,0x2986L,0x2886L,0x2685L,0x2585L,0x2385L,0x2284L,0x2084L,0x1F83L,0x1D83L,0x1C83L,0x1A82L,0x1882L,0x1782L,0x1581L,0x1481L,0x1281L,0x1181L,0x0F80L,0x0E80L,0x0C80L,0x0A80L,0x0980L,0x0780L,0x0680L,0x0480L,0x0380L,0x0180L,0x0080L,0xFE80L,0xFC80L,0xFB80L,0xF980L,0xF880L,0xF680L,0xF580L,0xF380L,0xF180L,0xF080L,0xEE81L,0xED81L,0xEB81L,0xEA81L,0xE882L,0xE782L,0xE582L,0xE383L,0xE283L,0xE083L,0xDF84L,0xDD84L,0xDC85L,0xDA85L,0xD985L,0xD786L,0xD686L,0xD487L,0xD388L,0xD188L,0xD089L,0xCF89L,0xCD8AL,0xCC8AL,0xCA8BL,0xC98CL,0xC78CL,0xC68DL,0xC58EL,0xC38FL,0xC28FL,0xC090L,0xBF91L,0xBE92L,0xBC93L,0xBB93L,0xBA94L,0xB895L,0xB796L,0xB697L,0xB598L,0xB399L,0xB29AL,0xB19BL,0xB09CL,0xAE9DL,0xAD9EL,0xAC9FL,0xABA0L,0xAAA1L,0xA8A2L,0xA7A3L,0xA6A4L,0xA5A5L,0xA4A6L,0xA3A7L,0xA2A8L,0xA1AAL,0xA0ABL,0x9FACL,0x9EADL,0x9DAEL,0x9CB0L,0x9BB1L,0x9AB2L,0x99B3L,0x98B5L,0x97B6L,0x96B7L,0x95B8L,0x94BAL,0x93BBL,0x93BCL,0x92BEL,0x91BFL,0x90C0L,0x8FC2L,0x8FC3L,0x8EC5L,0x8DC6L,0x8CC7L,0x8CC9L,0x8BCAL,0x8ACCL,0x8ACDL,0x89CFL,0x89D0L,0x88D1L,0x88D3L,0x87D4L,0x86D6L,0x86D7L,0x85D9L,0x85DAL,0x85DCL,0x84DDL,0x84DFL,0x83E0L,0x83E2L,0x83E3L,0x82E5L,0x82E7L,0x82E8L,0x81EAL,0x81EBL,0x81EDL,0x81EEL,0x80F0L,0x80F1L,0x80F3L,0x80F5L,0x80F6L,0x80F8L,0x80F9L,0x80FBL,0x80FCL,0x80FEL,)
    self.n4600 = 0L
    self.n4600r = 0L
    self.n4600e = 0L
    self.n4600d = 0L
    self.n4593 = 0L
    self.n4593r = 0L
    self.n4593e = 0L
    self.n4593d = 0L
    self.n4586 = 0L
    self.n4586r = 0L
    self.n4586e = 0L
    self.n4586d = 0L
    self.n4579 = 0L
    self.n4579r = 0L
    self.n4579e = 0L
    self.n4579d = 0L
    self.n4478 = 0L
    self.n4471 = 0L
    self.n4465 = 0L
    self.n4464 = 0L
    self.n4463 = 0L
    self.n4462 = 0L
    self.n4360 = 0L
    self.n4359 = 0L
    self.n4350 = 0L
    self.n4349 = 0L
    self.n4348 = 0L
    self.n4325 = 0L
    self.n4301 = 0L
    self.n4299 = 0L
    self.n4299r = 0L
    self.n4299e = 0L
    self.n4299d = 0L
    self.n4287 = 0L
    self.n4286 = 0L
    self.n4277 = 0L
    self.n4276 = 0L
    self.n4275 = 0L
    self.n4252 = 0L
    self.n4247 = 0L
    self.n4247r = 0L
    self.n4247e = 0L
    self.n4247d = 0L
    self.n4240 = 0L
    self.n4240r = 0L
    self.n4240e = 0L
    self.n4240d = 0L
    self.n4233 = 0L
    self.n4233r = 0L
    self.n4233e = 0L
    self.n4233d = 0L
    self.n4226 = 0L
    self.n4226r = 0L
    self.n4226e = 0L
    self.n4226d = 0L
    self.n4218 = 0L
    self.n4218r = 0L
    self.n4218e = 0L
    self.n4218d = 0L
    self.n4211 = 0L
    self.n4211r = 0L
    self.n4211e = 0L
    self.n4211d = 0L
    self.n4204 = 0L
    self.n4204r = 0L
    self.n4204e = 0L
    self.n4204d = 0L
    self.n4197 = 0L
    self.n4197r = 0L
    self.n4197e = 0L
    self.n4197d = 0L
    self.n4189 = 0L
    self.n4189r = 0L
    self.n4189e = 0L
    self.n4189d = 0L
    self.n4182 = 0L
    self.n4182r = 0L
    self.n4182e = 0L
    self.n4182d = 0L
    self.n4175 = 0L
    self.n4175r = 0L
    self.n4175e = 0L
    self.n4175d = 0L
    self.n4153 = 0L
    self.n4143 = 0L
    self.n4140 = 0L
    self.n4140r = 0L
    self.n4140e = 0L
    self.n4140d = 0L
    self.n4124 = 0L
    self.n4115 = 0L
    self.n4114 = 0L
    self.n4114r = 0L
    self.n4114e = 0L
    self.n4114d = 0L
    self.n4098 = 0L
    self.n4089 = 0L
    self.n4086 = 0L
    self.n4086e = 0L
    self.n4086a = 0L
    self.n4086m = (0x7F00L,0x7FFCL,0x7FF9L,0x7FF6L,0x7FF3L,0x7FF0L,0x7EEDL,0x7EEAL,0x7DE7L,0x7CE3L,0x7CE0L,0x7BDDL,0x7ADAL,0x79D7L,0x78D4L,0x77D1L,0x76CFL,0x75CCL,0x73C9L,0x72C6L,0x70C3L,0x6FC0L,0x6DBEL,0x6CBBL,0x6AB8L,0x68B6L,0x66B3L,0x64B1L,0x62AEL,0x60ACL,0x5EAAL,0x5CA7L,0x5AA5L,0x58A3L,0x55A1L,0x539FL,0x519DL,0x4E9BL,0x4C99L,0x4997L,0x4795L,0x4493L,0x4192L,0x3F90L,0x3C8FL,0x398DL,0x368CL,0x338AL,0x3089L,0x2E88L,0x2B87L,0x2886L,0x2585L,0x2284L,0x1F83L,0x1C83L,0x1882L,0x1581L,0x1281L,0x0F80L,0x0C80L,0x0980L,0x0680L,0x0380L,0x0080L,0xFC80L,0xF980L,0xF680L,0xF380L,0xF080L,0xED81L,0xEA81L,0xE782L,0xE383L,0xE083L,0xDD84L,0xDA85L,0xD786L,0xD487L,0xD188L,0xCF89L,0xCC8AL,0xC98CL,0xC68DL,0xC38FL,0xC090L,0xBE92L,0xBB93L,0xB895L,0xB697L,0xB399L,0xB19BL,0xAE9DL,0xAC9FL,0xAAA1L,0xA7A3L,0xA5A5L,0xA3A7L,0xA1AAL,0x9FACL,0x9DAEL,0x9BB1L,0x99B3L,0x97B6L,0x95B8L,0x93BBL,0x92BEL,0x90C0L,0x8FC3L,0x8DC6L,0x8CC9L,0x8ACCL,0x89CFL,0x88D1L,0x87D4L,0x86D7L,0x85DAL,0x84DDL,0x83E0L,0x83E3L,0x82E7L,0x81EAL,0x81EDL,0x80F0L,0x80F3L,0x80F6L,0x80F9L,0x80FCL,)
    self.n4081 = 0L
    self.n4081r = 0L
    self.n4081e = 0L
    self.n4081d = 0L
    self.n4074 = 0L
    self.n4074r = 0L
    self.n4074e = 0L
    self.n4074d = 0L
    self.n4067 = 0L
    self.n4067r = 0L
    self.n4067e = 0L
    self.n4067d = 0L
    self.n4060 = 0L
    self.n4060r = 0L
    self.n4060e = 0L
    self.n4060d = 0L
    self.n3959 = 0L
    self.n3952 = 0L
    self.n3946 = 0L
    self.n3945 = 0L
    self.n3944 = 0L
    self.n3943 = 0L
    self.n3841 = 0L
    self.n3840 = 0L
    self.n3831 = 0L
    self.n3830 = 0L
    self.n3829 = 0L
    self.n3806 = 0L
    self.n3782 = 0L
    self.n3780 = 0L
    self.n3780r = 0L
    self.n3780e = 0L
    self.n3780d = 0L
    self.n3768 = 0L
    self.n3767 = 0L
    self.n3758 = 0L
    self.n3757 = 0L
    self.n3756 = 0L
    self.n3733 = 0L
    self.n3728 = 0L
    self.n3728r = 0L
    self.n3728e = 0L
    self.n3728d = 0L
    self.n3721 = 0L
    self.n3721r = 0L
    self.n3721e = 0L
    self.n3721d = 0L
    self.n3714 = 0L
    self.n3714r = 0L
    self.n3714e = 0L
    self.n3714d = 0L
    self.n3707 = 0L
    self.n3707r = 0L
    self.n3707e = 0L
    self.n3707d = 0L
    self.n3699 = 0L
    self.n3699r = 0L
    self.n3699e = 0L
    self.n3699d = 0L
    self.n3692 = 0L
    self.n3692r = 0L
    self.n3692e = 0L
    self.n3692d = 0L
    self.n3685 = 0L
    self.n3685r = 0L
    self.n3685e = 0L
    self.n3685d = 0L
    self.n3678 = 0L
    self.n3678r = 0L
    self.n3678e = 0L
    self.n3678d = 0L
    self.n3670 = 0L
    self.n3670r = 0L
    self.n3670e = 0L
    self.n3670d = 0L
    self.n3663 = 0L
    self.n3663r = 0L
    self.n3663e = 0L
    self.n3663d = 0L
    self.n3656 = 0L
    self.n3656r = 0L
    self.n3656e = 0L
    self.n3656d = 0L
    self.n3634 = 0L
    self.n3624 = 0L
    self.n3621 = 0L
    self.n3621r = 0L
    self.n3621e = 0L
    self.n3621d = 0L
    self.n3605 = 0L
    self.n3596 = 0L
    self.n3595 = 0L
    self.n3595r = 0L
    self.n3595e = 0L
    self.n3595d = 0L
    self.n3579 = 0L
    self.n3570 = 0L
    self.n3567 = 0L
    self.n3567e = 0L
    self.n3567a = 0L
    self.n3567m = (0x7F00L,0x7FF9L,0x7FF3L,0x7EEDL,0x7DE7L,0x7CE0L,0x7ADAL,0x78D4L,0x76CFL,0x73C9L,0x70C3L,0x6DBEL,0x6AB8L,0x66B3L,0x62AEL,0x5EAAL,0x5AA5L,0x55A1L,0x519DL,0x4C99L,0x4795L,0x4192L,0x3C8FL,0x368CL,0x3089L,0x2B87L,0x2585L,0x1F83L,0x1882L,0x1281L,0x0C80L,0x0680L,0x0080L,0xF980L,0xF380L,0xED81L,0xE782L,0xE083L,0xDA85L,0xD487L,0xCF89L,0xC98CL,0xC38FL,0xBE92L,0xB895L,0xB399L,0xAE9DL,0xAAA1L,0xA5A5L,0xA1AAL,0x9DAEL,0x99B3L,0x95B8L,0x92BEL,0x8FC3L,0x8CC9L,0x89CFL,0x87D4L,0x85DAL,0x83E0L,0x82E7L,0x81EDL,0x80F3L,0x80F9L,)
    self.n3562 = 0L
    self.n3562r = 0L
    self.n3562e = 0L
    self.n3562d = 0L
    self.n3555 = 0L
    self.n3555r = 0L
    self.n3555e = 0L
    self.n3555d = 0L
    self.n3548 = 0L
    self.n3548r = 0L
    self.n3548e = 0L
    self.n3548d = 0L
    self.n3541 = 0L
    self.n3541r = 0L
    self.n3541e = 0L
    self.n3541d = 0L
    self.n3440 = 0L
    self.n3433 = 0L
    self.n3427 = 0L
    self.n3426 = 0L
    self.n3425 = 0L
    self.n3424 = 0L
    self.n3322 = 0L
    self.n3321 = 0L
    self.n3312 = 0L
    self.n3311 = 0L
    self.n3310 = 0L
    self.n3287 = 0L
    self.n3263 = 0L
    self.n3261 = 0L
    self.n3261r = 0L
    self.n3261e = 0L
    self.n3261d = 0L
    self.n3249 = 0L
    self.n3248 = 0L
    self.n3239 = 0L
    self.n3238 = 0L
    self.n3237 = 0L
    self.n3214 = 0L
    self.n3209 = 0L
    self.n3209r = 0L
    self.n3209e = 0L
    self.n3209d = 0L
    self.n3202 = 0L
    self.n3202r = 0L
    self.n3202e = 0L
    self.n3202d = 0L
    self.n3195 = 0L
    self.n3195r = 0L
    self.n3195e = 0L
    self.n3195d = 0L
    self.n3188 = 0L
    self.n3188r = 0L
    self.n3188e = 0L
    self.n3188d = 0L
    self.n3180 = 0L
    self.n3180r = 0L
    self.n3180e = 0L
    self.n3180d = 0L
    self.n3173 = 0L
    self.n3173r = 0L
    self.n3173e = 0L
    self.n3173d = 0L
    self.n3166 = 0L
    self.n3166r = 0L
    self.n3166e = 0L
    self.n3166d = 0L
    self.n3159 = 0L
    self.n3159r = 0L
    self.n3159e = 0L
    self.n3159d = 0L
    self.n3151 = 0L
    self.n3151r = 0L
    self.n3151e = 0L
    self.n3151d = 0L
    self.n3144 = 0L
    self.n3144r = 0L
    self.n3144e = 0L
    self.n3144d = 0L
    self.n3137 = 0L
    self.n3137r = 0L
    self.n3137e = 0L
    self.n3137d = 0L
    self.n3115 = 0L
    self.n3105 = 0L
    self.n3102 = 0L
    self.n3102r = 0L
    self.n3102e = 0L
    self.n3102d = 0L
    self.n3086 = 0L
    self.n3077 = 0L
    self.n3076 = 0L
    self.n3076r = 0L
    self.n3076e = 0L
    self.n3076d = 0L
    self.n3060 = 0L
    self.n3051 = 0L
    self.n3048 = 0L
    self.n3048e = 0L
    self.n3048a = 0L
    self.n3048m = (0x7F00L,0x7FF3L,0x7DE7L,0x7ADAL,0x76CFL,0x70C3L,0x6AB8L,0x62AEL,0x5AA5L,0x519DL,0x4795L,0x3C8FL,0x3089L,0x2585L,0x1882L,0x0C80L,0x0080L,0xF380L,0xE782L,0xDA85L,0xCF89L,0xC38FL,0xB895L,0xAE9DL,0xA5A5L,0x9DAEL,0x95B8L,0x8FC3L,0x89CFL,0x85DAL,0x82E7L,0x80F3L,)
    self.n3043 = 0L
    self.n3043r = 0L
    self.n3043e = 0L
    self.n3043d = 0L
    self.n3036 = 0L
    self.n3036r = 0L
    self.n3036e = 0L
    self.n3036d = 0L
    self.n3029 = 0L
    self.n3029r = 0L
    self.n3029e = 0L
    self.n3029d = 0L
    self.n3022 = 0L
    self.n3022r = 0L
    self.n3022e = 0L
    self.n3022d = 0L
    self.n2921 = 0L
    self.n2914 = 0L
    self.n2908 = 0L
    self.n2907 = 0L
    self.n2906 = 0L
    self.n2905 = 0L
    self.n2803 = 0L
    self.n2802 = 0L
    self.n2793 = 0L
    self.n2792 = 0L
    self.n2791 = 0L
    self.n2768 = 0L
    self.n2744 = 0L
    self.n2742 = 0L
    self.n2742r = 0L
    self.n2742e = 0L
    self.n2742d = 0L
    self.n2730 = 0L
    self.n2729 = 0L
    self.n2720 = 0L
    self.n2719 = 0L
    self.n2718 = 0L
    self.n2695 = 0L
    self.n2690 = 0L
    self.n2690r = 0L
    self.n2690e = 0L
    self.n2690d = 0L
    self.n2683 = 0L
    self.n2683r = 0L
    self.n2683e = 0L
    self.n2683d = 0L
    self.n2676 = 0L
    self.n2676r = 0L
    self.n2676e = 0L
    self.n2676d = 0L
    self.n2669 = 0L
    self.n2669r = 0L
    self.n2669e = 0L
    self.n2669d = 0L
    self.n2661 = 0L
    self.n2661r = 0L
    self.n2661e = 0L
    self.n2661d = 0L
    self.n2654 = 0L
    self.n2654r = 0L
    self.n2654e = 0L
    self.n2654d = 0L
    self.n2647 = 0L
    self.n2647r = 0L
    self.n2647e = 0L
    self.n2647d = 0L
    self.n2640 = 0L
    self.n2640r = 0L
    self.n2640e = 0L
    self.n2640d = 0L
    self.n2632 = 0L
    self.n2632r = 0L
    self.n2632e = 0L
    self.n2632d = 0L
    self.n2625 = 0L
    self.n2625r = 0L
    self.n2625e = 0L
    self.n2625d = 0L
    self.n2618 = 0L
    self.n2618r = 0L
    self.n2618e = 0L
    self.n2618d = 0L
    self.n2596 = 0L
    self.n2586 = 0L
    self.n2583 = 0L
    self.n2583r = 0L
    self.n2583e = 0L
    self.n2583d = 0L
    self.n2567 = 0L
    self.n2558 = 0L
    self.n2557 = 0L
    self.n2557r = 0L
    self.n2557e = 0L
    self.n2557d = 0L
    self.n2541 = 0L
    self.n2532 = 0L
    self.n2529 = 0L
    self.n2529e = 0L
    self.n2529a = 0L
    self.n2529m = (0x7F00L,0x7DE7L,0x76CFL,0x6AB8L,0x5AA5L,0x4795L,0x3089L,0x1882L,0x0080L,0xE782L,0xCF89L,0xB895L,0xA5A5L,0x95B8L,0x89CFL,0x82E7L,)
    self.n2524 = 0L
    self.n2524r = 0L
    self.n2524e = 0L
    self.n2524d = 0L
    self.n2517 = 0L
    self.n2517r = 0L
    self.n2517e = 0L
    self.n2517d = 0L
    self.n2510 = 0L
    self.n2510r = 0L
    self.n2510e = 0L
    self.n2510d = 0L
    self.n2503 = 0L
    self.n2503r = 0L
    self.n2503e = 0L
    self.n2503d = 0L
    self.n2402 = 0L
    self.n2395 = 0L
    self.n2389 = 0L
    self.n2388 = 0L
    self.n2387 = 0L
    self.n2386 = 0L
    self.n2284 = 0L
    self.n2283 = 0L
    self.n2274 = 0L
    self.n2273 = 0L
    self.n2272 = 0L
    self.n2249 = 0L
    self.n2225 = 0L
    self.n2223 = 0L
    self.n2223r = 0L
    self.n2223e = 0L
    self.n2223d = 0L
    self.n2211 = 0L
    self.n2210 = 0L
    self.n2201 = 0L
    self.n2200 = 0L
    self.n2199 = 0L
    self.n2176 = 0L
    self.n2171 = 0L
    self.n2171r = 0L
    self.n2171e = 0L
    self.n2171d = 0L
    self.n2164 = 0L
    self.n2164r = 0L
    self.n2164e = 0L
    self.n2164d = 0L
    self.n2157 = 0L
    self.n2157r = 0L
    self.n2157e = 0L
    self.n2157d = 0L
    self.n2150 = 0L
    self.n2150r = 0L
    self.n2150e = 0L
    self.n2150d = 0L
    self.n2142 = 0L
    self.n2142r = 0L
    self.n2142e = 0L
    self.n2142d = 0L
    self.n2135 = 0L
    self.n2135r = 0L
    self.n2135e = 0L
    self.n2135d = 0L
    self.n2128 = 0L
    self.n2128r = 0L
    self.n2128e = 0L
    self.n2128d = 0L
    self.n2121 = 0L
    self.n2121r = 0L
    self.n2121e = 0L
    self.n2121d = 0L
    self.n2113 = 0L
    self.n2113r = 0L
    self.n2113e = 0L
    self.n2113d = 0L
    self.n2106 = 0L
    self.n2106r = 0L
    self.n2106e = 0L
    self.n2106d = 0L
    self.n2099 = 0L
    self.n2099r = 0L
    self.n2099e = 0L
    self.n2099d = 0L
    self.n2077 = 0L
    self.n2067 = 0L
    self.n2064 = 0L
    self.n2064r = 0L
    self.n2064e = 0L
    self.n2064d = 0L
    self.n2048 = 0L
    self.n2039 = 0L
    self.n2038 = 0L
    self.n2038r = 0L
    self.n2038e = 0L
    self.n2038d = 0L
    self.n2022 = 0L
    self.n2013 = 0L
    self.n2010 = 0L
    self.n2010e = 0L
    self.n2010a = 0L
    self.n2010m = (0x7F00L,0x76CFL,0x5AA5L,0x3089L,0x0080L,0xCF89L,0xA5A5L,0x89CFL,)
    self.n2005 = 0L
    self.n2005r = 0L
    self.n2005e = 0L
    self.n2005d = 0L
    self.n1998 = 0L
    self.n1998r = 0L
    self.n1998e = 0L
    self.n1998d = 0L
    self.n1991 = 0L
    self.n1991r = 0L
    self.n1991e = 0L
    self.n1991d = 0L
    self.n1984 = 0L
    self.n1984r = 0L
    self.n1984e = 0L
    self.n1984d = 0L
    self.n1883 = 0L
    self.n1876 = 0L
    self.n1870 = 0L
    self.n1869 = 0L
    self.n1868 = 0L
    self.n1867 = 0L
    self.n1765 = 0L
    self.n1764 = 0L
    self.n1755 = 0L
    self.n1754 = 0L
    self.n1753 = 0L
    self.n1730 = 0L
    self.n1706 = 0L
    self.n1704 = 0L
    self.n1704r = 0L
    self.n1704e = 0L
    self.n1704d = 0L
    self.n1692 = 0L
    self.n1691 = 0L
    self.n1682 = 0L
    self.n1681 = 0L
    self.n1680 = 0L
    self.n1657 = 0L
    self.n1652 = 0L
    self.n1652r = 0L
    self.n1652e = 0L
    self.n1652d = 0L
    self.n1645 = 0L
    self.n1645r = 0L
    self.n1645e = 0L
    self.n1645d = 0L
    self.n1638 = 0L
    self.n1638r = 0L
    self.n1638e = 0L
    self.n1638d = 0L
    self.n1631 = 0L
    self.n1631r = 0L
    self.n1631e = 0L
    self.n1631d = 0L
    self.n1623 = 0L
    self.n1623r = 0L
    self.n1623e = 0L
    self.n1623d = 0L
    self.n1616 = 0L
    self.n1616r = 0L
    self.n1616e = 0L
    self.n1616d = 0L
    self.n1609 = 0L
    self.n1609r = 0L
    self.n1609e = 0L
    self.n1609d = 0L
    self.n1602 = 0L
    self.n1602r = 0L
    self.n1602e = 0L
    self.n1602d = 0L
    self.n1594 = 0L
    self.n1594r = 0L
    self.n1594e = 0L
    self.n1594d = 0L
    self.n1587 = 0L
    self.n1587r = 0L
    self.n1587e = 0L
    self.n1587d = 0L
    self.n1580 = 0L
    self.n1580r = 0L
    self.n1580e = 0L
    self.n1580d = 0L
    self.n1558 = 0L
    self.n1548 = 0L
    self.n1545 = 0L
    self.n1545r = 0L
    self.n1545e = 0L
    self.n1545d = 0L
    self.n1529 = 0L
    self.n1520 = 0L
    self.n1519 = 0L
    self.n1519r = 0L
    self.n1519e = 0L
    self.n1519d = 0L
    self.n1503 = 0L
    self.n1494 = 0L
    self.n1491 = 0L
    self.n1491e = 0L
    self.n1491a = 0L
    self.n1491m = (0x7F00L,0x5AA5L,0x0080L,0xA5A5L,)
    self.n1486 = 0L
    self.n1486r = 0L
    self.n1486e = 0L
    self.n1486d = 0L
    self.n1479 = 0L
    self.n1479r = 0L
    self.n1479e = 0L
    self.n1479d = 0L
    self.n1472 = 0L
    self.n1472r = 0L
    self.n1472e = 0L
    self.n1472d = 0L
    self.n1465 = 0L
    self.n1465r = 0L
    self.n1465e = 0L
    self.n1465d = 0L
    self.n1364 = 0L
    self.n1357 = 0L
    self.n1351 = 0L
    self.n1350 = 0L
    self.n1349 = 0L
    self.n1348 = 0L
    self.n1246 = 0L
    self.n1245 = 0L
    self.n1236 = 0L
    self.n1235 = 0L
    self.n1234 = 0L
    self.n1211 = 0L
    self.n1187 = 0L
    self.n1185 = 0L
    self.n1185r = 0L
    self.n1185e = 0L
    self.n1185d = 0L
    self.n1173 = 0L
    self.n1172 = 0L
    self.n1163 = 0L
    self.n1162 = 0L
    self.n1161 = 0L
    self.n1138 = 0L
    self.n1133 = 0L
    self.n1133r = 0L
    self.n1133e = 0L
    self.n1133d = 0L
    self.n1126 = 0L
    self.n1126r = 0L
    self.n1126e = 0L
    self.n1126d = 0L
    self.n1119 = 0L
    self.n1119r = 0L
    self.n1119e = 0L
    self.n1119d = 0L
    self.n1112 = 0L
    self.n1112r = 0L
    self.n1112e = 0L
    self.n1112d = 0L
    self.n1104 = 0L
    self.n1104r = 0L
    self.n1104e = 0L
    self.n1104d = 0L
    self.n1097 = 0L
    self.n1097r = 0L
    self.n1097e = 0L
    self.n1097d = 0L
    self.n1090 = 0L
    self.n1090r = 0L
    self.n1090e = 0L
    self.n1090d = 0L
    self.n1083 = 0L
    self.n1083r = 0L
    self.n1083e = 0L
    self.n1083d = 0L
    self.n1075 = 0L
    self.n1075r = 0L
    self.n1075e = 0L
    self.n1075d = 0L
    self.n1068 = 0L
    self.n1068r = 0L
    self.n1068e = 0L
    self.n1068d = 0L
    self.n1061 = 0L
    self.n1061r = 0L
    self.n1061e = 0L
    self.n1061d = 0L
    self.n1039 = 0L
    self.n1029 = 0L
    self.n1026 = 0L
    self.n1026r = 0L
    self.n1026e = 0L
    self.n1026d = 0L
    self.n1010 = 0L
    self.n1001 = 0L
    self.n1000 = 0L
    self.n1000r = 0L
    self.n1000e = 0L
    self.n1000d = 0L
    self.n984 = 0L
    self.n975 = 0L
    self.n972 = 0L
    self.n972e = 0L
    self.n972a = 0L
    self.n972m = (0x7F00L,0x0080L,)
    self.n967 = 0L
    self.n967r = 0L
    self.n967e = 0L
    self.n967d = 0L
    self.n960 = 0L
    self.n960r = 0L
    self.n960e = 0L
    self.n960d = 0L
    self.n953 = 0L
    self.n953r = 0L
    self.n953e = 0L
    self.n953d = 0L
    self.n946 = 0L
    self.n946r = 0L
    self.n946e = 0L
    self.n946d = 0L
    self.n845 = 0L
    self.n838 = 0L
    self.n832 = 0L
    self.n831 = 0L
    self.n830 = 0L
    self.n829 = 0L
    self.n727 = 0L
    self.n726 = 0L
    self.n717 = 0L
    self.n716 = 0L
    self.n715 = 0L
    self.n692 = 0L
    self.n668 = 0L
    self.n666 = 0L
    self.n666r = 0L
    self.n666e = 0L
    self.n666d = 0L
    self.n654 = 0L
    self.n653 = 0L
    self.n644 = 0L
    self.n643 = 0L
    self.n642 = 0L
    self.n619 = 0L
    self.n614 = 0L
    self.n614r = 0L
    self.n614e = 0L
    self.n614d = 0L
    self.n607 = 0L
    self.n607r = 0L
    self.n607e = 0L
    self.n607d = 0L
    self.n600 = 0L
    self.n600r = 0L
    self.n600e = 0L
    self.n600d = 0L
    self.n593 = 0L
    self.n593r = 0L
    self.n593e = 0L
    self.n593d = 0L
    self.n585 = 0L
    self.n585r = 0L
    self.n585e = 0L
    self.n585d = 0L
    self.n578 = 0L
    self.n578r = 0L
    self.n578e = 0L
    self.n578d = 0L
    self.n571 = 0L
    self.n571r = 0L
    self.n571e = 0L
    self.n571d = 0L
    self.n564 = 0L
    self.n564r = 0L
    self.n564e = 0L
    self.n564d = 0L
    self.n556 = 0L
    self.n556r = 0L
    self.n556e = 0L
    self.n556d = 0L
    self.n549 = 0L
    self.n549r = 0L
    self.n549e = 0L
    self.n549d = 0L
    self.n542 = 0L
    self.n542r = 0L
    self.n542e = 0L
    self.n542d = 0L
    self.n520 = 0L
    self.n510 = 0L
    self.n507 = 0L
    self.n507r = 0L
    self.n507e = 0L
    self.n507d = 0L
    self.n491 = 0L
    self.n482 = 0L
    self.n481 = 0L
    self.n481r = 0L
    self.n481e = 0L
    self.n481d = 0L
    self.n465 = 0L
    self.n456 = 0L
    self.n453 = 0L
    self.n453e = 0L
    self.n453a = 0L
    self.n453m = (0x7F00L,0x0080L,)
    self.n448 = 0L
    self.n448r = 0L
    self.n448e = 0L
    self.n448d = 0L
    self.n441 = 0L
    self.n441r = 0L
    self.n441e = 0L
    self.n441d = 0L
    self.n434 = 0L
    self.n434r = 0L
    self.n434e = 0L
    self.n434d = 0L
    self.n427 = 0L
    self.n427r = 0L
    self.n427e = 0L
    self.n427d = 0L
    self.n326 = 0L
    self.n319 = 0L
    self.n313 = 0L
    self.n312 = 0L
    self.n311 = 0L
    self.n310 = 0L
    self.n173 = 0L
    self.n149 = 0L
    self.n100 = 0L
    self.n96 = 0L
    self.n94 = 0L
    self.n92 = 0L
    self.n16 = 0L
    self.n9 = 0L
    self.n6471 = 0L
    self.n6439 = 0L
    self.n6427 = 0L
    self.n6406 = 0L
    self.n6406r = 0L
    self.n6406e = 0L
    self.n6406d = 0L
    self.n6366 = 0L
    self.n6354 = 0L
    self.n6333 = 0L
    self.n6333r = 0L
    self.n6333e = 0L
    self.n6333d = 0L
    self.n6236 = 0L
    self.n6236r = 0L
    self.n6236e = 0L
    self.n6236d = 0L
    self.n6226 = 0L
    self.n6226r = 0L
    self.n6226e = 0L
    self.n6226d = 0L
    self.n6201 = 0L
    self.n6192 = 0L
    self.n6175 = 0L
    self.n6166 = 0L
    self.n6110 = 0L
    self.n6036 = 0L
    self.n5952 = 0L
    self.n5920 = 0L
    self.n5908 = 0L
    self.n5887 = 0L
    self.n5887r = 0L
    self.n5887e = 0L
    self.n5887d = 0L
    self.n5847 = 0L
    self.n5835 = 0L
    self.n5814 = 0L
    self.n5814r = 0L
    self.n5814e = 0L
    self.n5814d = 0L
    self.n5717 = 0L
    self.n5717r = 0L
    self.n5717e = 0L
    self.n5717d = 0L
    self.n5707 = 0L
    self.n5707r = 0L
    self.n5707e = 0L
    self.n5707d = 0L
    self.n5682 = 0L
    self.n5673 = 0L
    self.n5656 = 0L
    self.n5647 = 0L
    self.n5591 = 0L
    self.n5517 = 0L
    self.n5433 = 0L
    self.n5401 = 0L
    self.n5389 = 0L
    self.n5368 = 0L
    self.n5368r = 0L
    self.n5368e = 0L
    self.n5368d = 0L
    self.n5328 = 0L
    self.n5316 = 0L
    self.n5295 = 0L
    self.n5295r = 0L
    self.n5295e = 0L
    self.n5295d = 0L
    self.n5198 = 0L
    self.n5198r = 0L
    self.n5198e = 0L
    self.n5198d = 0L
    self.n5188 = 0L
    self.n5188r = 0L
    self.n5188e = 0L
    self.n5188d = 0L
    self.n5163 = 0L
    self.n5154 = 0L
    self.n5137 = 0L
    self.n5128 = 0L
    self.n5072 = 0L
    self.n4998 = 0L
    self.n4914 = 0L
    self.n4882 = 0L
    self.n4870 = 0L
    self.n4849 = 0L
    self.n4849r = 0L
    self.n4849e = 0L
    self.n4849d = 0L
    self.n4809 = 0L
    self.n4797 = 0L
    self.n4776 = 0L
    self.n4776r = 0L
    self.n4776e = 0L
    self.n4776d = 0L
    self.n4679 = 0L
    self.n4679r = 0L
    self.n4679e = 0L
    self.n4679d = 0L
    self.n4669 = 0L
    self.n4669r = 0L
    self.n4669e = 0L
    self.n4669d = 0L
    self.n4644 = 0L
    self.n4635 = 0L
    self.n4618 = 0L
    self.n4609 = 0L
    self.n4553 = 0L
    self.n4479 = 0L
    self.n4395 = 0L
    self.n4363 = 0L
    self.n4351 = 0L
    self.n4330 = 0L
    self.n4330r = 0L
    self.n4330e = 0L
    self.n4330d = 0L
    self.n4290 = 0L
    self.n4278 = 0L
    self.n4257 = 0L
    self.n4257r = 0L
    self.n4257e = 0L
    self.n4257d = 0L
    self.n4160 = 0L
    self.n4160r = 0L
    self.n4160e = 0L
    self.n4160d = 0L
    self.n4150 = 0L
    self.n4150r = 0L
    self.n4150e = 0L
    self.n4150d = 0L
    self.n4125 = 0L
    self.n4116 = 0L
    self.n4099 = 0L
    self.n4090 = 0L
    self.n4034 = 0L
    self.n3960 = 0L
    self.n3876 = 0L
    self.n3844 = 0L
    self.n3832 = 0L
    self.n3811 = 0L
    self.n3811r = 0L
    self.n3811e = 0L
    self.n3811d = 0L
    self.n3771 = 0L
    self.n3759 = 0L
    self.n3738 = 0L
    self.n3738r = 0L
    self.n3738e = 0L
    self.n3738d = 0L
    self.n3641 = 0L
    self.n3641r = 0L
    self.n3641e = 0L
    self.n3641d = 0L
    self.n3631 = 0L
    self.n3631r = 0L
    self.n3631e = 0L
    self.n3631d = 0L
    self.n3606 = 0L
    self.n3597 = 0L
    self.n3580 = 0L
    self.n3571 = 0L
    self.n3515 = 0L
    self.n3441 = 0L
    self.n3357 = 0L
    self.n3325 = 0L
    self.n3313 = 0L
    self.n3292 = 0L
    self.n3292r = 0L
    self.n3292e = 0L
    self.n3292d = 0L
    self.n3252 = 0L
    self.n3240 = 0L
    self.n3219 = 0L
    self.n3219r = 0L
    self.n3219e = 0L
    self.n3219d = 0L
    self.n3122 = 0L
    self.n3122r = 0L
    self.n3122e = 0L
    self.n3122d = 0L
    self.n3112 = 0L
    self.n3112r = 0L
    self.n3112e = 0L
    self.n3112d = 0L
    self.n3087 = 0L
    self.n3078 = 0L
    self.n3061 = 0L
    self.n3052 = 0L
    self.n2996 = 0L
    self.n2922 = 0L
    self.n2838 = 0L
    self.n2806 = 0L
    self.n2794 = 0L
    self.n2773 = 0L
    self.n2773r = 0L
    self.n2773e = 0L
    self.n2773d = 0L
    self.n2733 = 0L
    self.n2721 = 0L
    self.n2700 = 0L
    self.n2700r = 0L
    self.n2700e = 0L
    self.n2700d = 0L
    self.n2603 = 0L
    self.n2603r = 0L
    self.n2603e = 0L
    self.n2603d = 0L
    self.n2593 = 0L
    self.n2593r = 0L
    self.n2593e = 0L
    self.n2593d = 0L
    self.n2568 = 0L
    self.n2559 = 0L
    self.n2542 = 0L
    self.n2533 = 0L
    self.n2477 = 0L
    self.n2403 = 0L
    self.n2319 = 0L
    self.n2287 = 0L
    self.n2275 = 0L
    self.n2254 = 0L
    self.n2254r = 0L
    self.n2254e = 0L
    self.n2254d = 0L
    self.n2214 = 0L
    self.n2202 = 0L
    self.n2181 = 0L
    self.n2181r = 0L
    self.n2181e = 0L
    self.n2181d = 0L
    self.n2084 = 0L
    self.n2084r = 0L
    self.n2084e = 0L
    self.n2084d = 0L
    self.n2074 = 0L
    self.n2074r = 0L
    self.n2074e = 0L
    self.n2074d = 0L
    self.n2049 = 0L
    self.n2040 = 0L
    self.n2023 = 0L
    self.n2014 = 0L
    self.n1958 = 0L
    self.n1884 = 0L
    self.n1800 = 0L
    self.n1768 = 0L
    self.n1756 = 0L
    self.n1735 = 0L
    self.n1735r = 0L
    self.n1735e = 0L
    self.n1735d = 0L
    self.n1695 = 0L
    self.n1683 = 0L
    self.n1662 = 0L
    self.n1662r = 0L
    self.n1662e = 0L
    self.n1662d = 0L
    self.n1565 = 0L
    self.n1565r = 0L
    self.n1565e = 0L
    self.n1565d = 0L
    self.n1555 = 0L
    self.n1555r = 0L
    self.n1555e = 0L
    self.n1555d = 0L
    self.n1530 = 0L
    self.n1521 = 0L
    self.n1504 = 0L
    self.n1495 = 0L
    self.n1439 = 0L
    self.n1365 = 0L
    self.n1281 = 0L
    self.n1249 = 0L
    self.n1237 = 0L
    self.n1216 = 0L
    self.n1216r = 0L
    self.n1216e = 0L
    self.n1216d = 0L
    self.n1176 = 0L
    self.n1164 = 0L
    self.n1143 = 0L
    self.n1143r = 0L
    self.n1143e = 0L
    self.n1143d = 0L
    self.n1046 = 0L
    self.n1046r = 0L
    self.n1046e = 0L
    self.n1046d = 0L
    self.n1036 = 0L
    self.n1036r = 0L
    self.n1036e = 0L
    self.n1036d = 0L
    self.n1011 = 0L
    self.n1002 = 0L
    self.n985 = 0L
    self.n976 = 0L
    self.n920 = 0L
    self.n846 = 0L
    self.n762 = 0L
    self.n730 = 0L
    self.n718 = 0L
    self.n697 = 0L
    self.n697r = 0L
    self.n697e = 0L
    self.n697d = 0L
    self.n657 = 0L
    self.n645 = 0L
    self.n624 = 0L
    self.n624r = 0L
    self.n624e = 0L
    self.n624d = 0L
    self.n527 = 0L
    self.n527r = 0L
    self.n527e = 0L
    self.n527d = 0L
    self.n517 = 0L
    self.n517r = 0L
    self.n517e = 0L
    self.n517d = 0L
    self.n492 = 0L
    self.n483 = 0L
    self.n466 = 0L
    self.n457 = 0L
    self.n401 = 0L
    self.n327 = 0L
    self.n243 = 0L
    self.n91 = 0L
    self.n17 = 0L
    self.n6600 = 0L
    self.n6599 = 0L
    self.n6504 = 0L
    self.n6440 = 0L
    self.n6428 = 0L
    self.n6367 = 0L
    self.n6355 = 0L
    self.n6244 = 0L
    self.n6244r = 0L
    self.n6244e = 0L
    self.n6244d = 0L
    self.n6208 = 0L
    self.n6208r = 0L
    self.n6208e = 0L
    self.n6208d = 0L
    self.n6199 = 0L
    self.n6199r = 0L
    self.n6199e = 0L
    self.n6199d = 0L
    self.n6182 = 0L
    self.n6182r = 0L
    self.n6182e = 0L
    self.n6182d = 0L
    self.n6173 = 0L
    self.n6173r = 0L
    self.n6173e = 0L
    self.n6173d = 0L
    self.n6069 = 0L
    self.n5985 = 0L
    self.n5921 = 0L
    self.n5909 = 0L
    self.n5848 = 0L
    self.n5836 = 0L
    self.n5725 = 0L
    self.n5725r = 0L
    self.n5725e = 0L
    self.n5725d = 0L
    self.n5689 = 0L
    self.n5689r = 0L
    self.n5689e = 0L
    self.n5689d = 0L
    self.n5680 = 0L
    self.n5680r = 0L
    self.n5680e = 0L
    self.n5680d = 0L
    self.n5663 = 0L
    self.n5663r = 0L
    self.n5663e = 0L
    self.n5663d = 0L
    self.n5654 = 0L
    self.n5654r = 0L
    self.n5654e = 0L
    self.n5654d = 0L
    self.n5550 = 0L
    self.n5466 = 0L
    self.n5402 = 0L
    self.n5390 = 0L
    self.n5329 = 0L
    self.n5317 = 0L
    self.n5206 = 0L
    self.n5206r = 0L
    self.n5206e = 0L
    self.n5206d = 0L
    self.n5170 = 0L
    self.n5170r = 0L
    self.n5170e = 0L
    self.n5170d = 0L
    self.n5161 = 0L
    self.n5161r = 0L
    self.n5161e = 0L
    self.n5161d = 0L
    self.n5144 = 0L
    self.n5144r = 0L
    self.n5144e = 0L
    self.n5144d = 0L
    self.n5135 = 0L
    self.n5135r = 0L
    self.n5135e = 0L
    self.n5135d = 0L
    self.n5031 = 0L
    self.n4947 = 0L
    self.n4883 = 0L
    self.n4871 = 0L
    self.n4810 = 0L
    self.n4798 = 0L
    self.n4687 = 0L
    self.n4687r = 0L
    self.n4687e = 0L
    self.n4687d = 0L
    self.n4651 = 0L
    self.n4651r = 0L
    self.n4651e = 0L
    self.n4651d = 0L
    self.n4642 = 0L
    self.n4642r = 0L
    self.n4642e = 0L
    self.n4642d = 0L
    self.n4625 = 0L
    self.n4625r = 0L
    self.n4625e = 0L
    self.n4625d = 0L
    self.n4616 = 0L
    self.n4616r = 0L
    self.n4616e = 0L
    self.n4616d = 0L
    self.n4512 = 0L
    self.n4428 = 0L
    self.n4364 = 0L
    self.n4352 = 0L
    self.n4291 = 0L
    self.n4279 = 0L
    self.n4168 = 0L
    self.n4168r = 0L
    self.n4168e = 0L
    self.n4168d = 0L
    self.n4132 = 0L
    self.n4132r = 0L
    self.n4132e = 0L
    self.n4132d = 0L
    self.n4123 = 0L
    self.n4123r = 0L
    self.n4123e = 0L
    self.n4123d = 0L
    self.n4106 = 0L
    self.n4106r = 0L
    self.n4106e = 0L
    self.n4106d = 0L
    self.n4097 = 0L
    self.n4097r = 0L
    self.n4097e = 0L
    self.n4097d = 0L
    self.n3993 = 0L
    self.n3909 = 0L
    self.n3845 = 0L
    self.n3833 = 0L
    self.n3772 = 0L
    self.n3760 = 0L
    self.n3649 = 0L
    self.n3649r = 0L
    self.n3649e = 0L
    self.n3649d = 0L
    self.n3613 = 0L
    self.n3613r = 0L
    self.n3613e = 0L
    self.n3613d = 0L
    self.n3604 = 0L
    self.n3604r = 0L
    self.n3604e = 0L
    self.n3604d = 0L
    self.n3587 = 0L
    self.n3587r = 0L
    self.n3587e = 0L
    self.n3587d = 0L
    self.n3578 = 0L
    self.n3578r = 0L
    self.n3578e = 0L
    self.n3578d = 0L
    self.n3474 = 0L
    self.n3390 = 0L
    self.n3326 = 0L
    self.n3314 = 0L
    self.n3253 = 0L
    self.n3241 = 0L
    self.n3130 = 0L
    self.n3130r = 0L
    self.n3130e = 0L
    self.n3130d = 0L
    self.n3094 = 0L
    self.n3094r = 0L
    self.n3094e = 0L
    self.n3094d = 0L
    self.n3085 = 0L
    self.n3085r = 0L
    self.n3085e = 0L
    self.n3085d = 0L
    self.n3068 = 0L
    self.n3068r = 0L
    self.n3068e = 0L
    self.n3068d = 0L
    self.n3059 = 0L
    self.n3059r = 0L
    self.n3059e = 0L
    self.n3059d = 0L
    self.n2955 = 0L
    self.n2871 = 0L
    self.n2807 = 0L
    self.n2795 = 0L
    self.n2734 = 0L
    self.n2722 = 0L
    self.n2611 = 0L
    self.n2611r = 0L
    self.n2611e = 0L
    self.n2611d = 0L
    self.n2575 = 0L
    self.n2575r = 0L
    self.n2575e = 0L
    self.n2575d = 0L
    self.n2566 = 0L
    self.n2566r = 0L
    self.n2566e = 0L
    self.n2566d = 0L
    self.n2549 = 0L
    self.n2549r = 0L
    self.n2549e = 0L
    self.n2549d = 0L
    self.n2540 = 0L
    self.n2540r = 0L
    self.n2540e = 0L
    self.n2540d = 0L
    self.n2436 = 0L
    self.n2352 = 0L
    self.n2288 = 0L
    self.n2276 = 0L
    self.n2215 = 0L
    self.n2203 = 0L
    self.n2092 = 0L
    self.n2092r = 0L
    self.n2092e = 0L
    self.n2092d = 0L
    self.n2056 = 0L
    self.n2056r = 0L
    self.n2056e = 0L
    self.n2056d = 0L
    self.n2047 = 0L
    self.n2047r = 0L
    self.n2047e = 0L
    self.n2047d = 0L
    self.n2030 = 0L
    self.n2030r = 0L
    self.n2030e = 0L
    self.n2030d = 0L
    self.n2021 = 0L
    self.n2021r = 0L
    self.n2021e = 0L
    self.n2021d = 0L
    self.n1917 = 0L
    self.n1833 = 0L
    self.n1769 = 0L
    self.n1757 = 0L
    self.n1696 = 0L
    self.n1684 = 0L
    self.n1573 = 0L
    self.n1573r = 0L
    self.n1573e = 0L
    self.n1573d = 0L
    self.n1537 = 0L
    self.n1537r = 0L
    self.n1537e = 0L
    self.n1537d = 0L
    self.n1528 = 0L
    self.n1528r = 0L
    self.n1528e = 0L
    self.n1528d = 0L
    self.n1511 = 0L
    self.n1511r = 0L
    self.n1511e = 0L
    self.n1511d = 0L
    self.n1502 = 0L
    self.n1502r = 0L
    self.n1502e = 0L
    self.n1502d = 0L
    self.n1398 = 0L
    self.n1314 = 0L
    self.n1250 = 0L
    self.n1238 = 0L
    self.n1177 = 0L
    self.n1165 = 0L
    self.n1054 = 0L
    self.n1054r = 0L
    self.n1054e = 0L
    self.n1054d = 0L
    self.n1018 = 0L
    self.n1018r = 0L
    self.n1018e = 0L
    self.n1018d = 0L
    self.n1009 = 0L
    self.n1009r = 0L
    self.n1009e = 0L
    self.n1009d = 0L
    self.n992 = 0L
    self.n992r = 0L
    self.n992e = 0L
    self.n992d = 0L
    self.n983 = 0L
    self.n983r = 0L
    self.n983e = 0L
    self.n983d = 0L
    self.n879 = 0L
    self.n795 = 0L
    self.n731 = 0L
    self.n719 = 0L
    self.n658 = 0L
    self.n646 = 0L
    self.n535 = 0L
    self.n535r = 0L
    self.n535e = 0L
    self.n535d = 0L
    self.n499 = 0L
    self.n499r = 0L
    self.n499e = 0L
    self.n499d = 0L
    self.n490 = 0L
    self.n490r = 0L
    self.n490e = 0L
    self.n490d = 0L
    self.n473 = 0L
    self.n473r = 0L
    self.n473e = 0L
    self.n473d = 0L
    self.n464 = 0L
    self.n464r = 0L
    self.n464e = 0L
    self.n464d = 0L
    self.n360 = 0L
    self.n276 = 0L
    self.n195 = 0L
    self.n147 = 0L
    self.n147r = 0L
    self.n147e = 0L
    self.n147d = 0L
    self.n122 = 0L
    self.n50 = 0L
    self.n6527 = 0L
    self.n6526 = 0L
    self.n6525 = 0L
    self.n6524 = 0L
    self.n6511 = 0L
    self.n6510 = 0L
    self.n6509 = 0L
    self.n6508 = 0L
    self.n6507 = 0L
    self.n6506 = 0L
    self.n6505 = 0L
    self.n6457 = 0L
    self.n6441 = 0L
    self.n6429 = 0L
    self.n6384 = 0L
    self.n6368 = 0L
    self.n6356 = 0L
    self.n6094 = 0L
    self.n6093 = 0L
    self.n6092 = 0L
    self.n6091 = 0L
    self.n6090 = 0L
    self.n6089 = 0L
    self.n6075 = 0L
    self.n6074 = 0L
    self.n6073 = 0L
    self.n6072 = 0L
    self.n6071 = 0L
    self.n6070 = 0L
    self.n6008 = 0L
    self.n6007 = 0L
    self.n6006 = 0L
    self.n6005 = 0L
    self.n5992 = 0L
    self.n5991 = 0L
    self.n5990 = 0L
    self.n5989 = 0L
    self.n5988 = 0L
    self.n5987 = 0L
    self.n5986 = 0L
    self.n5938 = 0L
    self.n5922 = 0L
    self.n5910 = 0L
    self.n5865 = 0L
    self.n5849 = 0L
    self.n5837 = 0L
    self.n5575 = 0L
    self.n5574 = 0L
    self.n5573 = 0L
    self.n5572 = 0L
    self.n5571 = 0L
    self.n5570 = 0L
    self.n5556 = 0L
    self.n5555 = 0L
    self.n5554 = 0L
    self.n5553 = 0L
    self.n5552 = 0L
    self.n5551 = 0L
    self.n5489 = 0L
    self.n5488 = 0L
    self.n5487 = 0L
    self.n5486 = 0L
    self.n5473 = 0L
    self.n5472 = 0L
    self.n5471 = 0L
    self.n5470 = 0L
    self.n5469 = 0L
    self.n5468 = 0L
    self.n5467 = 0L
    self.n5419 = 0L
    self.n5403 = 0L
    self.n5391 = 0L
    self.n5346 = 0L
    self.n5330 = 0L
    self.n5318 = 0L
    self.n5056 = 0L
    self.n5055 = 0L
    self.n5054 = 0L
    self.n5053 = 0L
    self.n5052 = 0L
    self.n5051 = 0L
    self.n5037 = 0L
    self.n5036 = 0L
    self.n5035 = 0L
    self.n5034 = 0L
    self.n5033 = 0L
    self.n5032 = 0L
    self.n4970 = 0L
    self.n4969 = 0L
    self.n4968 = 0L
    self.n4967 = 0L
    self.n4954 = 0L
    self.n4953 = 0L
    self.n4952 = 0L
    self.n4951 = 0L
    self.n4950 = 0L
    self.n4949 = 0L
    self.n4948 = 0L
    self.n4900 = 0L
    self.n4884 = 0L
    self.n4872 = 0L
    self.n4827 = 0L
    self.n4811 = 0L
    self.n4799 = 0L
    self.n4537 = 0L
    self.n4536 = 0L
    self.n4535 = 0L
    self.n4534 = 0L
    self.n4533 = 0L
    self.n4532 = 0L
    self.n4518 = 0L
    self.n4517 = 0L
    self.n4516 = 0L
    self.n4515 = 0L
    self.n4514 = 0L
    self.n4513 = 0L
    self.n4451 = 0L
    self.n4450 = 0L
    self.n4449 = 0L
    self.n4448 = 0L
    self.n4435 = 0L
    self.n4434 = 0L
    self.n4433 = 0L
    self.n4432 = 0L
    self.n4431 = 0L
    self.n4430 = 0L
    self.n4429 = 0L
    self.n4381 = 0L
    self.n4365 = 0L
    self.n4353 = 0L
    self.n4308 = 0L
    self.n4292 = 0L
    self.n4280 = 0L
    self.n4018 = 0L
    self.n4017 = 0L
    self.n4016 = 0L
    self.n4015 = 0L
    self.n4014 = 0L
    self.n4013 = 0L
    self.n3999 = 0L
    self.n3998 = 0L
    self.n3997 = 0L
    self.n3996 = 0L
    self.n3995 = 0L
    self.n3994 = 0L
    self.n3932 = 0L
    self.n3931 = 0L
    self.n3930 = 0L
    self.n3929 = 0L
    self.n3916 = 0L
    self.n3915 = 0L
    self.n3914 = 0L
    self.n3913 = 0L
    self.n3912 = 0L
    self.n3911 = 0L
    self.n3910 = 0L
    self.n3862 = 0L
    self.n3846 = 0L
    self.n3834 = 0L
    self.n3789 = 0L
    self.n3773 = 0L
    self.n3761 = 0L
    self.n3499 = 0L
    self.n3498 = 0L
    self.n3497 = 0L
    self.n3496 = 0L
    self.n3495 = 0L
    self.n3494 = 0L
    self.n3480 = 0L
    self.n3479 = 0L
    self.n3478 = 0L
    self.n3477 = 0L
    self.n3476 = 0L
    self.n3475 = 0L
    self.n3413 = 0L
    self.n3412 = 0L
    self.n3411 = 0L
    self.n3410 = 0L
    self.n3397 = 0L
    self.n3396 = 0L
    self.n3395 = 0L
    self.n3394 = 0L
    self.n3393 = 0L
    self.n3392 = 0L
    self.n3391 = 0L
    self.n3343 = 0L
    self.n3327 = 0L
    self.n3315 = 0L
    self.n3270 = 0L
    self.n3254 = 0L
    self.n3242 = 0L
    self.n2980 = 0L
    self.n2979 = 0L
    self.n2978 = 0L
    self.n2977 = 0L
    self.n2976 = 0L
    self.n2975 = 0L
    self.n2961 = 0L
    self.n2960 = 0L
    self.n2959 = 0L
    self.n2958 = 0L
    self.n2957 = 0L
    self.n2956 = 0L
    self.n2894 = 0L
    self.n2893 = 0L
    self.n2892 = 0L
    self.n2891 = 0L
    self.n2878 = 0L
    self.n2877 = 0L
    self.n2876 = 0L
    self.n2875 = 0L
    self.n2874 = 0L
    self.n2873 = 0L
    self.n2872 = 0L
    self.n2824 = 0L
    self.n2808 = 0L
    self.n2796 = 0L
    self.n2751 = 0L
    self.n2735 = 0L
    self.n2723 = 0L
    self.n2461 = 0L
    self.n2460 = 0L
    self.n2459 = 0L
    self.n2458 = 0L
    self.n2457 = 0L
    self.n2456 = 0L
    self.n2442 = 0L
    self.n2441 = 0L
    self.n2440 = 0L
    self.n2439 = 0L
    self.n2438 = 0L
    self.n2437 = 0L
    self.n2375 = 0L
    self.n2374 = 0L
    self.n2373 = 0L
    self.n2372 = 0L
    self.n2359 = 0L
    self.n2358 = 0L
    self.n2357 = 0L
    self.n2356 = 0L
    self.n2355 = 0L
    self.n2354 = 0L
    self.n2353 = 0L
    self.n2305 = 0L
    self.n2289 = 0L
    self.n2277 = 0L
    self.n2232 = 0L
    self.n2216 = 0L
    self.n2204 = 0L
    self.n1942 = 0L
    self.n1941 = 0L
    self.n1940 = 0L
    self.n1939 = 0L
    self.n1938 = 0L
    self.n1937 = 0L
    self.n1923 = 0L
    self.n1922 = 0L
    self.n1921 = 0L
    self.n1920 = 0L
    self.n1919 = 0L
    self.n1918 = 0L
    self.n1856 = 0L
    self.n1855 = 0L
    self.n1854 = 0L
    self.n1853 = 0L
    self.n1840 = 0L
    self.n1839 = 0L
    self.n1838 = 0L
    self.n1837 = 0L
    self.n1836 = 0L
    self.n1835 = 0L
    self.n1834 = 0L
    self.n1786 = 0L
    self.n1770 = 0L
    self.n1758 = 0L
    self.n1713 = 0L
    self.n1697 = 0L
    self.n1685 = 0L
    self.n1423 = 0L
    self.n1422 = 0L
    self.n1421 = 0L
    self.n1420 = 0L
    self.n1419 = 0L
    self.n1418 = 0L
    self.n1404 = 0L
    self.n1403 = 0L
    self.n1402 = 0L
    self.n1401 = 0L
    self.n1400 = 0L
    self.n1399 = 0L
    self.n1337 = 0L
    self.n1336 = 0L
    self.n1335 = 0L
    self.n1334 = 0L
    self.n1321 = 0L
    self.n1320 = 0L
    self.n1319 = 0L
    self.n1318 = 0L
    self.n1317 = 0L
    self.n1316 = 0L
    self.n1315 = 0L
    self.n1267 = 0L
    self.n1251 = 0L
    self.n1239 = 0L
    self.n1194 = 0L
    self.n1178 = 0L
    self.n1166 = 0L
    self.n904 = 0L
    self.n903 = 0L
    self.n902 = 0L
    self.n901 = 0L
    self.n900 = 0L
    self.n899 = 0L
    self.n885 = 0L
    self.n884 = 0L
    self.n883 = 0L
    self.n882 = 0L
    self.n881 = 0L
    self.n880 = 0L
    self.n818 = 0L
    self.n817 = 0L
    self.n816 = 0L
    self.n815 = 0L
    self.n802 = 0L
    self.n801 = 0L
    self.n800 = 0L
    self.n799 = 0L
    self.n798 = 0L
    self.n797 = 0L
    self.n796 = 0L
    self.n748 = 0L
    self.n732 = 0L
    self.n720 = 0L
    self.n675 = 0L
    self.n659 = 0L
    self.n647 = 0L
    self.n385 = 0L
    self.n384 = 0L
    self.n383 = 0L
    self.n382 = 0L
    self.n381 = 0L
    self.n380 = 0L
    self.n366 = 0L
    self.n365 = 0L
    self.n364 = 0L
    self.n363 = 0L
    self.n362 = 0L
    self.n361 = 0L
    self.n299 = 0L
    self.n298 = 0L
    self.n297 = 0L
    self.n296 = 0L
    self.n283 = 0L
    self.n282 = 0L
    self.n281 = 0L
    self.n280 = 0L
    self.n279 = 0L
    self.n278 = 0L
    self.n277 = 0L
    self.n208 = 0L
    self.n207 = 0L
    self.n198 = 0L
    self.n197 = 0L
    self.n196 = 0L
    self.n178 = 0L
    self.n178r = 0L
    self.n178e = 0L
    self.n178d = 0L
    self.n135 = 0L
    self.n134 = 0L
    self.n125 = 0L
    self.n124 = 0L
    self.n123 = 0L
    self.n105 = 0L
    self.n105r = 0L
    self.n105e = 0L
    self.n105d = 0L
    self.n75 = 0L
    self.n74 = 0L
    self.n73 = 0L
    self.n72 = 0L
    self.n71 = 0L
    self.n70 = 0L
    self.n56 = 0L
    self.n55 = 0L
    self.n54 = 0L
    self.n53 = 0L
    self.n52 = 0L
    self.n51 = 0L
    self.n6534 = 0L
    self.n6512 = 0L
    self.n6469 = 0L
    self.n6469r = 0L
    self.n6469e = 0L
    self.n6469d = 0L
    self.n6462 = 0L
    self.n6462e = 0L
    self.n6462w = 0L
    self.n6462aw = 0L
    self.n6462ar = 0L
    self.n6462dw = 0L
    self.n6462m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n6451 = 0L
    self.n6434 = 0L
    self.n6434r = 0L
    self.n6434e = 0L
    self.n6434d = 0L
    self.n6396 = 0L
    self.n6396r = 0L
    self.n6396e = 0L
    self.n6396d = 0L
    self.n6389 = 0L
    self.n6389e = 0L
    self.n6389w = 0L
    self.n6389aw = 0L
    self.n6389ar = 0L
    self.n6389dw = 0L
    self.n6389m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n6378 = 0L
    self.n6361 = 0L
    self.n6361r = 0L
    self.n6361e = 0L
    self.n6361d = 0L
    self.n6097 = 0L
    self.n6078 = 0L
    self.n6015 = 0L
    self.n5993 = 0L
    self.n5950 = 0L
    self.n5950r = 0L
    self.n5950e = 0L
    self.n5950d = 0L
    self.n5943 = 0L
    self.n5943e = 0L
    self.n5943w = 0L
    self.n5943aw = 0L
    self.n5943ar = 0L
    self.n5943dw = 0L
    self.n5943m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n5932 = 0L
    self.n5915 = 0L
    self.n5915r = 0L
    self.n5915e = 0L
    self.n5915d = 0L
    self.n5877 = 0L
    self.n5877r = 0L
    self.n5877e = 0L
    self.n5877d = 0L
    self.n5870 = 0L
    self.n5870e = 0L
    self.n5870w = 0L
    self.n5870aw = 0L
    self.n5870ar = 0L
    self.n5870dw = 0L
    self.n5870m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n5859 = 0L
    self.n5842 = 0L
    self.n5842r = 0L
    self.n5842e = 0L
    self.n5842d = 0L
    self.n5578 = 0L
    self.n5559 = 0L
    self.n5496 = 0L
    self.n5474 = 0L
    self.n5431 = 0L
    self.n5431r = 0L
    self.n5431e = 0L
    self.n5431d = 0L
    self.n5424 = 0L
    self.n5424e = 0L
    self.n5424w = 0L
    self.n5424aw = 0L
    self.n5424ar = 0L
    self.n5424dw = 0L
    self.n5424m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n5413 = 0L
    self.n5396 = 0L
    self.n5396r = 0L
    self.n5396e = 0L
    self.n5396d = 0L
    self.n5358 = 0L
    self.n5358r = 0L
    self.n5358e = 0L
    self.n5358d = 0L
    self.n5351 = 0L
    self.n5351e = 0L
    self.n5351w = 0L
    self.n5351aw = 0L
    self.n5351ar = 0L
    self.n5351dw = 0L
    self.n5351m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n5340 = 0L
    self.n5323 = 0L
    self.n5323r = 0L
    self.n5323e = 0L
    self.n5323d = 0L
    self.n5059 = 0L
    self.n5040 = 0L
    self.n4977 = 0L
    self.n4955 = 0L
    self.n4912 = 0L
    self.n4912r = 0L
    self.n4912e = 0L
    self.n4912d = 0L
    self.n4905 = 0L
    self.n4905e = 0L
    self.n4905w = 0L
    self.n4905aw = 0L
    self.n4905ar = 0L
    self.n4905dw = 0L
    self.n4905m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n4894 = 0L
    self.n4877 = 0L
    self.n4877r = 0L
    self.n4877e = 0L
    self.n4877d = 0L
    self.n4839 = 0L
    self.n4839r = 0L
    self.n4839e = 0L
    self.n4839d = 0L
    self.n4832 = 0L
    self.n4832e = 0L
    self.n4832w = 0L
    self.n4832aw = 0L
    self.n4832ar = 0L
    self.n4832dw = 0L
    self.n4832m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n4821 = 0L
    self.n4804 = 0L
    self.n4804r = 0L
    self.n4804e = 0L
    self.n4804d = 0L
    self.n4540 = 0L
    self.n4521 = 0L
    self.n4458 = 0L
    self.n4436 = 0L
    self.n4393 = 0L
    self.n4393r = 0L
    self.n4393e = 0L
    self.n4393d = 0L
    self.n4386 = 0L
    self.n4386e = 0L
    self.n4386w = 0L
    self.n4386aw = 0L
    self.n4386ar = 0L
    self.n4386dw = 0L
    self.n4386m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n4375 = 0L
    self.n4358 = 0L
    self.n4358r = 0L
    self.n4358e = 0L
    self.n4358d = 0L
    self.n4320 = 0L
    self.n4320r = 0L
    self.n4320e = 0L
    self.n4320d = 0L
    self.n4313 = 0L
    self.n4313e = 0L
    self.n4313w = 0L
    self.n4313aw = 0L
    self.n4313ar = 0L
    self.n4313dw = 0L
    self.n4313m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n4302 = 0L
    self.n4285 = 0L
    self.n4285r = 0L
    self.n4285e = 0L
    self.n4285d = 0L
    self.n4021 = 0L
    self.n4002 = 0L
    self.n3939 = 0L
    self.n3917 = 0L
    self.n3874 = 0L
    self.n3874r = 0L
    self.n3874e = 0L
    self.n3874d = 0L
    self.n3867 = 0L
    self.n3867e = 0L
    self.n3867w = 0L
    self.n3867aw = 0L
    self.n3867ar = 0L
    self.n3867dw = 0L
    self.n3867m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n3856 = 0L
    self.n3839 = 0L
    self.n3839r = 0L
    self.n3839e = 0L
    self.n3839d = 0L
    self.n3801 = 0L
    self.n3801r = 0L
    self.n3801e = 0L
    self.n3801d = 0L
    self.n3794 = 0L
    self.n3794e = 0L
    self.n3794w = 0L
    self.n3794aw = 0L
    self.n3794ar = 0L
    self.n3794dw = 0L
    self.n3794m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n3783 = 0L
    self.n3766 = 0L
    self.n3766r = 0L
    self.n3766e = 0L
    self.n3766d = 0L
    self.n3502 = 0L
    self.n3483 = 0L
    self.n3420 = 0L
    self.n3398 = 0L
    self.n3355 = 0L
    self.n3355r = 0L
    self.n3355e = 0L
    self.n3355d = 0L
    self.n3348 = 0L
    self.n3348e = 0L
    self.n3348w = 0L
    self.n3348aw = 0L
    self.n3348ar = 0L
    self.n3348dw = 0L
    self.n3348m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n3337 = 0L
    self.n3320 = 0L
    self.n3320r = 0L
    self.n3320e = 0L
    self.n3320d = 0L
    self.n3282 = 0L
    self.n3282r = 0L
    self.n3282e = 0L
    self.n3282d = 0L
    self.n3275 = 0L
    self.n3275e = 0L
    self.n3275w = 0L
    self.n3275aw = 0L
    self.n3275ar = 0L
    self.n3275dw = 0L
    self.n3275m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n3264 = 0L
    self.n3247 = 0L
    self.n3247r = 0L
    self.n3247e = 0L
    self.n3247d = 0L
    self.n2983 = 0L
    self.n2964 = 0L
    self.n2901 = 0L
    self.n2879 = 0L
    self.n2836 = 0L
    self.n2836r = 0L
    self.n2836e = 0L
    self.n2836d = 0L
    self.n2829 = 0L
    self.n2829e = 0L
    self.n2829w = 0L
    self.n2829aw = 0L
    self.n2829ar = 0L
    self.n2829dw = 0L
    self.n2829m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n2818 = 0L
    self.n2801 = 0L
    self.n2801r = 0L
    self.n2801e = 0L
    self.n2801d = 0L
    self.n2763 = 0L
    self.n2763r = 0L
    self.n2763e = 0L
    self.n2763d = 0L
    self.n2756 = 0L
    self.n2756e = 0L
    self.n2756w = 0L
    self.n2756aw = 0L
    self.n2756ar = 0L
    self.n2756dw = 0L
    self.n2756m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n2745 = 0L
    self.n2728 = 0L
    self.n2728r = 0L
    self.n2728e = 0L
    self.n2728d = 0L
    self.n2464 = 0L
    self.n2445 = 0L
    self.n2382 = 0L
    self.n2360 = 0L
    self.n2317 = 0L
    self.n2317r = 0L
    self.n2317e = 0L
    self.n2317d = 0L
    self.n2310 = 0L
    self.n2310e = 0L
    self.n2310w = 0L
    self.n2310aw = 0L
    self.n2310ar = 0L
    self.n2310dw = 0L
    self.n2310m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n2299 = 0L
    self.n2282 = 0L
    self.n2282r = 0L
    self.n2282e = 0L
    self.n2282d = 0L
    self.n2244 = 0L
    self.n2244r = 0L
    self.n2244e = 0L
    self.n2244d = 0L
    self.n2237 = 0L
    self.n2237e = 0L
    self.n2237w = 0L
    self.n2237aw = 0L
    self.n2237ar = 0L
    self.n2237dw = 0L
    self.n2237m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n2226 = 0L
    self.n2209 = 0L
    self.n2209r = 0L
    self.n2209e = 0L
    self.n2209d = 0L
    self.n1945 = 0L
    self.n1926 = 0L
    self.n1863 = 0L
    self.n1841 = 0L
    self.n1798 = 0L
    self.n1798r = 0L
    self.n1798e = 0L
    self.n1798d = 0L
    self.n1791 = 0L
    self.n1791e = 0L
    self.n1791w = 0L
    self.n1791aw = 0L
    self.n1791ar = 0L
    self.n1791dw = 0L
    self.n1791m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n1780 = 0L
    self.n1763 = 0L
    self.n1763r = 0L
    self.n1763e = 0L
    self.n1763d = 0L
    self.n1725 = 0L
    self.n1725r = 0L
    self.n1725e = 0L
    self.n1725d = 0L
    self.n1718 = 0L
    self.n1718e = 0L
    self.n1718w = 0L
    self.n1718aw = 0L
    self.n1718ar = 0L
    self.n1718dw = 0L
    self.n1718m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n1707 = 0L
    self.n1690 = 0L
    self.n1690r = 0L
    self.n1690e = 0L
    self.n1690d = 0L
    self.n1426 = 0L
    self.n1407 = 0L
    self.n1344 = 0L
    self.n1322 = 0L
    self.n1279 = 0L
    self.n1279r = 0L
    self.n1279e = 0L
    self.n1279d = 0L
    self.n1272 = 0L
    self.n1272e = 0L
    self.n1272w = 0L
    self.n1272aw = 0L
    self.n1272ar = 0L
    self.n1272dw = 0L
    self.n1272m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n1261 = 0L
    self.n1244 = 0L
    self.n1244r = 0L
    self.n1244e = 0L
    self.n1244d = 0L
    self.n1206 = 0L
    self.n1206r = 0L
    self.n1206e = 0L
    self.n1206d = 0L
    self.n1199 = 0L
    self.n1199e = 0L
    self.n1199w = 0L
    self.n1199aw = 0L
    self.n1199ar = 0L
    self.n1199dw = 0L
    self.n1199m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n1188 = 0L
    self.n1171 = 0L
    self.n1171r = 0L
    self.n1171e = 0L
    self.n1171d = 0L
    self.n907 = 0L
    self.n888 = 0L
    self.n825 = 0L
    self.n803 = 0L
    self.n760 = 0L
    self.n760r = 0L
    self.n760e = 0L
    self.n760d = 0L
    self.n753 = 0L
    self.n753e = 0L
    self.n753w = 0L
    self.n753aw = 0L
    self.n753ar = 0L
    self.n753dw = 0L
    self.n753m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n742 = 0L
    self.n725 = 0L
    self.n725r = 0L
    self.n725e = 0L
    self.n725d = 0L
    self.n687 = 0L
    self.n687r = 0L
    self.n687e = 0L
    self.n687d = 0L
    self.n680 = 0L
    self.n680e = 0L
    self.n680w = 0L
    self.n680aw = 0L
    self.n680ar = 0L
    self.n680dw = 0L
    self.n680m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n669 = 0L
    self.n652 = 0L
    self.n652r = 0L
    self.n652e = 0L
    self.n652d = 0L
    self.n388 = 0L
    self.n369 = 0L
    self.n306 = 0L
    self.n284 = 0L
    self.n211 = 0L
    self.n199 = 0L
    self.n138 = 0L
    self.n126 = 0L
    self.n78 = 0L
    self.n59 = 0L
    self.n6535 = 0L
    self.n6513 = 0L
    self.n6456 = 0L
    self.n6456e = 0L
    self.n6456w = 0L
    self.n6456aw = 0L
    self.n6456ar = 0L
    self.n6456dw = 0L
    self.n6456m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n6383 = 0L
    self.n6383e = 0L
    self.n6383w = 0L
    self.n6383aw = 0L
    self.n6383ar = 0L
    self.n6383dw = 0L
    self.n6383m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n6098 = 0L
    self.n6079 = 0L
    self.n6016 = 0L
    self.n5994 = 0L
    self.n5937 = 0L
    self.n5937e = 0L
    self.n5937w = 0L
    self.n5937aw = 0L
    self.n5937ar = 0L
    self.n5937dw = 0L
    self.n5937m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n5864 = 0L
    self.n5864e = 0L
    self.n5864w = 0L
    self.n5864aw = 0L
    self.n5864ar = 0L
    self.n5864dw = 0L
    self.n5864m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n5579 = 0L
    self.n5560 = 0L
    self.n5497 = 0L
    self.n5475 = 0L
    self.n5418 = 0L
    self.n5418e = 0L
    self.n5418w = 0L
    self.n5418aw = 0L
    self.n5418ar = 0L
    self.n5418dw = 0L
    self.n5418m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n5345 = 0L
    self.n5345e = 0L
    self.n5345w = 0L
    self.n5345aw = 0L
    self.n5345ar = 0L
    self.n5345dw = 0L
    self.n5345m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n5060 = 0L
    self.n5041 = 0L
    self.n4978 = 0L
    self.n4956 = 0L
    self.n4899 = 0L
    self.n4899e = 0L
    self.n4899w = 0L
    self.n4899aw = 0L
    self.n4899ar = 0L
    self.n4899dw = 0L
    self.n4899m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n4826 = 0L
    self.n4826e = 0L
    self.n4826w = 0L
    self.n4826aw = 0L
    self.n4826ar = 0L
    self.n4826dw = 0L
    self.n4826m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n4541 = 0L
    self.n4522 = 0L
    self.n4459 = 0L
    self.n4437 = 0L
    self.n4380 = 0L
    self.n4380e = 0L
    self.n4380w = 0L
    self.n4380aw = 0L
    self.n4380ar = 0L
    self.n4380dw = 0L
    self.n4380m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n4307 = 0L
    self.n4307e = 0L
    self.n4307w = 0L
    self.n4307aw = 0L
    self.n4307ar = 0L
    self.n4307dw = 0L
    self.n4307m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n4022 = 0L
    self.n4003 = 0L
    self.n3940 = 0L
    self.n3918 = 0L
    self.n3861 = 0L
    self.n3861e = 0L
    self.n3861w = 0L
    self.n3861aw = 0L
    self.n3861ar = 0L
    self.n3861dw = 0L
    self.n3861m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n3788 = 0L
    self.n3788e = 0L
    self.n3788w = 0L
    self.n3788aw = 0L
    self.n3788ar = 0L
    self.n3788dw = 0L
    self.n3788m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n3503 = 0L
    self.n3484 = 0L
    self.n3421 = 0L
    self.n3399 = 0L
    self.n3342 = 0L
    self.n3342e = 0L
    self.n3342w = 0L
    self.n3342aw = 0L
    self.n3342ar = 0L
    self.n3342dw = 0L
    self.n3342m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n3269 = 0L
    self.n3269e = 0L
    self.n3269w = 0L
    self.n3269aw = 0L
    self.n3269ar = 0L
    self.n3269dw = 0L
    self.n3269m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n2984 = 0L
    self.n2965 = 0L
    self.n2902 = 0L
    self.n2880 = 0L
    self.n2823 = 0L
    self.n2823e = 0L
    self.n2823w = 0L
    self.n2823aw = 0L
    self.n2823ar = 0L
    self.n2823dw = 0L
    self.n2823m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n2750 = 0L
    self.n2750e = 0L
    self.n2750w = 0L
    self.n2750aw = 0L
    self.n2750ar = 0L
    self.n2750dw = 0L
    self.n2750m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n2465 = 0L
    self.n2446 = 0L
    self.n2383 = 0L
    self.n2361 = 0L
    self.n2304 = 0L
    self.n2304e = 0L
    self.n2304w = 0L
    self.n2304aw = 0L
    self.n2304ar = 0L
    self.n2304dw = 0L
    self.n2304m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n2231 = 0L
    self.n2231e = 0L
    self.n2231w = 0L
    self.n2231aw = 0L
    self.n2231ar = 0L
    self.n2231dw = 0L
    self.n2231m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n1946 = 0L
    self.n1927 = 0L
    self.n1864 = 0L
    self.n1842 = 0L
    self.n1785 = 0L
    self.n1785e = 0L
    self.n1785w = 0L
    self.n1785aw = 0L
    self.n1785ar = 0L
    self.n1785dw = 0L
    self.n1785m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n1712 = 0L
    self.n1712e = 0L
    self.n1712w = 0L
    self.n1712aw = 0L
    self.n1712ar = 0L
    self.n1712dw = 0L
    self.n1712m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n1427 = 0L
    self.n1408 = 0L
    self.n1345 = 0L
    self.n1323 = 0L
    self.n1266 = 0L
    self.n1266e = 0L
    self.n1266w = 0L
    self.n1266aw = 0L
    self.n1266ar = 0L
    self.n1266dw = 0L
    self.n1266m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n1193 = 0L
    self.n1193e = 0L
    self.n1193w = 0L
    self.n1193aw = 0L
    self.n1193ar = 0L
    self.n1193dw = 0L
    self.n1193m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n908 = 0L
    self.n889 = 0L
    self.n826 = 0L
    self.n804 = 0L
    self.n747 = 0L
    self.n747e = 0L
    self.n747w = 0L
    self.n747aw = 0L
    self.n747ar = 0L
    self.n747dw = 0L
    self.n747m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n674 = 0L
    self.n674e = 0L
    self.n674w = 0L
    self.n674aw = 0L
    self.n674ar = 0L
    self.n674dw = 0L
    self.n674m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n389 = 0L
    self.n370 = 0L
    self.n307 = 0L
    self.n285 = 0L
    self.n212 = 0L
    self.n200 = 0L
    self.n139 = 0L
    self.n127 = 0L
    self.n79 = 0L
    self.n60 = 0L
    self.n6536 = 0L
    self.n6514 = 0L
    self.n6099 = 0L
    self.n6080 = 0L
    self.n6017 = 0L
    self.n5995 = 0L
    self.n5580 = 0L
    self.n5561 = 0L
    self.n5498 = 0L
    self.n5476 = 0L
    self.n5061 = 0L
    self.n5042 = 0L
    self.n4979 = 0L
    self.n4957 = 0L
    self.n4542 = 0L
    self.n4523 = 0L
    self.n4460 = 0L
    self.n4438 = 0L
    self.n4023 = 0L
    self.n4004 = 0L
    self.n3941 = 0L
    self.n3919 = 0L
    self.n3504 = 0L
    self.n3485 = 0L
    self.n3422 = 0L
    self.n3400 = 0L
    self.n2985 = 0L
    self.n2966 = 0L
    self.n2903 = 0L
    self.n2881 = 0L
    self.n2466 = 0L
    self.n2447 = 0L
    self.n2384 = 0L
    self.n2362 = 0L
    self.n1947 = 0L
    self.n1928 = 0L
    self.n1865 = 0L
    self.n1843 = 0L
    self.n1428 = 0L
    self.n1409 = 0L
    self.n1346 = 0L
    self.n1324 = 0L
    self.n909 = 0L
    self.n890 = 0L
    self.n827 = 0L
    self.n805 = 0L
    self.n390 = 0L
    self.n371 = 0L
    self.n308 = 0L
    self.n286 = 0L
    self.n229 = 0L
    self.n213 = 0L
    self.n201 = 0L
    self.n156 = 0L
    self.n140 = 0L
    self.n128 = 0L
    self.n80 = 0L
    self.n61 = 0L
    self.n6537 = 0L
    self.n6515 = 0L
    self.n6100 = 0L
    self.n6081 = 0L
    self.n6018 = 0L
    self.n5996 = 0L
    self.n5581 = 0L
    self.n5562 = 0L
    self.n5499 = 0L
    self.n5477 = 0L
    self.n5062 = 0L
    self.n5043 = 0L
    self.n4980 = 0L
    self.n4958 = 0L
    self.n4543 = 0L
    self.n4524 = 0L
    self.n4461 = 0L
    self.n4439 = 0L
    self.n4024 = 0L
    self.n4005 = 0L
    self.n3942 = 0L
    self.n3920 = 0L
    self.n3505 = 0L
    self.n3486 = 0L
    self.n3423 = 0L
    self.n3401 = 0L
    self.n2986 = 0L
    self.n2967 = 0L
    self.n2904 = 0L
    self.n2882 = 0L
    self.n2467 = 0L
    self.n2448 = 0L
    self.n2385 = 0L
    self.n2363 = 0L
    self.n1948 = 0L
    self.n1929 = 0L
    self.n1866 = 0L
    self.n1844 = 0L
    self.n1429 = 0L
    self.n1410 = 0L
    self.n1347 = 0L
    self.n1325 = 0L
    self.n910 = 0L
    self.n891 = 0L
    self.n828 = 0L
    self.n806 = 0L
    self.n391 = 0L
    self.n372 = 0L
    self.n309 = 0L
    self.n287 = 0L
    self.n241 = 0L
    self.n241r = 0L
    self.n241e = 0L
    self.n241d = 0L
    self.n234 = 0L
    self.n234e = 0L
    self.n234w = 0L
    self.n234aw = 0L
    self.n234ar = 0L
    self.n234dw = 0L
    self.n234m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n223 = 0L
    self.n206 = 0L
    self.n206r = 0L
    self.n206e = 0L
    self.n206d = 0L
    self.n168 = 0L
    self.n168r = 0L
    self.n168e = 0L
    self.n168d = 0L
    self.n161 = 0L
    self.n161e = 0L
    self.n161w = 0L
    self.n161aw = 0L
    self.n161ar = 0L
    self.n161dw = 0L
    self.n161m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n150 = 0L
    self.n133 = 0L
    self.n133r = 0L
    self.n133e = 0L
    self.n133d = 0L
    self.n81 = 0L
    self.n62 = 0L
    self.n6543 = 0L
    self.n6542 = 0L
    self.n6516 = 0L
    self.n6101 = 0L
    self.n6082 = 0L
    self.n6024 = 0L
    self.n6023 = 0L
    self.n5997 = 0L
    self.n5582 = 0L
    self.n5563 = 0L
    self.n5505 = 0L
    self.n5504 = 0L
    self.n5478 = 0L
    self.n5063 = 0L
    self.n5044 = 0L
    self.n4986 = 0L
    self.n4985 = 0L
    self.n4959 = 0L
    self.n4544 = 0L
    self.n4525 = 0L
    self.n4467 = 0L
    self.n4466 = 0L
    self.n4440 = 0L
    self.n4025 = 0L
    self.n4006 = 0L
    self.n3948 = 0L
    self.n3947 = 0L
    self.n3921 = 0L
    self.n3506 = 0L
    self.n3487 = 0L
    self.n3429 = 0L
    self.n3428 = 0L
    self.n3402 = 0L
    self.n2987 = 0L
    self.n2968 = 0L
    self.n2910 = 0L
    self.n2909 = 0L
    self.n2883 = 0L
    self.n2468 = 0L
    self.n2449 = 0L
    self.n2391 = 0L
    self.n2390 = 0L
    self.n2364 = 0L
    self.n1949 = 0L
    self.n1930 = 0L
    self.n1872 = 0L
    self.n1871 = 0L
    self.n1845 = 0L
    self.n1430 = 0L
    self.n1411 = 0L
    self.n1353 = 0L
    self.n1352 = 0L
    self.n1326 = 0L
    self.n911 = 0L
    self.n892 = 0L
    self.n834 = 0L
    self.n833 = 0L
    self.n807 = 0L
    self.n392 = 0L
    self.n373 = 0L
    self.n315 = 0L
    self.n314 = 0L
    self.n288 = 0L
    self.n228 = 0L
    self.n228e = 0L
    self.n228w = 0L
    self.n228aw = 0L
    self.n228ar = 0L
    self.n228dw = 0L
    self.n228m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n155 = 0L
    self.n155e = 0L
    self.n155w = 0L
    self.n155aw = 0L
    self.n155ar = 0L
    self.n155dw = 0L
    self.n155m = [0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,0L,]
    self.n82 = 0L
    self.n63 = 0L
    self.n6546 = 0L
    self.n6545 = 0L
    self.n6517 = 0L
    self.n6127 = 0L
    self.n6127r = 0L
    self.n6127e = 0L
    self.n6127d = 0L
    self.n6118 = 0L
    self.n6118r = 0L
    self.n6118e = 0L
    self.n6118d = 0L
    self.n6102 = 0L
    self.n6083 = 0L
    self.n5998 = 0L
    self.n5608 = 0L
    self.n5608r = 0L
    self.n5608e = 0L
    self.n5608d = 0L
    self.n5599 = 0L
    self.n5599r = 0L
    self.n5599e = 0L
    self.n5599d = 0L
    self.n5583 = 0L
    self.n5564 = 0L
    self.n5479 = 0L
    self.n5089 = 0L
    self.n5089r = 0L
    self.n5089e = 0L
    self.n5089d = 0L
    self.n5080 = 0L
    self.n5080r = 0L
    self.n5080e = 0L
    self.n5080d = 0L
    self.n5064 = 0L
    self.n5045 = 0L
    self.n4960 = 0L
    self.n4570 = 0L
    self.n4570r = 0L
    self.n4570e = 0L
    self.n4570d = 0L
    self.n4561 = 0L
    self.n4561r = 0L
    self.n4561e = 0L
    self.n4561d = 0L
    self.n4545 = 0L
    self.n4526 = 0L
    self.n4441 = 0L
    self.n4051 = 0L
    self.n4051r = 0L
    self.n4051e = 0L
    self.n4051d = 0L
    self.n4042 = 0L
    self.n4042r = 0L
    self.n4042e = 0L
    self.n4042d = 0L
    self.n4026 = 0L
    self.n4007 = 0L
    self.n3922 = 0L
    self.n3532 = 0L
    self.n3532r = 0L
    self.n3532e = 0L
    self.n3532d = 0L
    self.n3523 = 0L
    self.n3523r = 0L
    self.n3523e = 0L
    self.n3523d = 0L
    self.n3507 = 0L
    self.n3488 = 0L
    self.n3403 = 0L
    self.n3013 = 0L
    self.n3013r = 0L
    self.n3013e = 0L
    self.n3013d = 0L
    self.n3004 = 0L
    self.n3004r = 0L
    self.n3004e = 0L
    self.n3004d = 0L
    self.n2988 = 0L
    self.n2969 = 0L
    self.n2884 = 0L
    self.n2494 = 0L
    self.n2494r = 0L
    self.n2494e = 0L
    self.n2494d = 0L
    self.n2485 = 0L
    self.n2485r = 0L
    self.n2485e = 0L
    self.n2485d = 0L
    self.n2469 = 0L
    self.n2450 = 0L
    self.n2365 = 0L
    self.n1975 = 0L
    self.n1975r = 0L
    self.n1975e = 0L
    self.n1975d = 0L
    self.n1966 = 0L
    self.n1966r = 0L
    self.n1966e = 0L
    self.n1966d = 0L
    self.n1950 = 0L
    self.n1931 = 0L
    self.n1846 = 0L
    self.n1456 = 0L
    self.n1456r = 0L
    self.n1456e = 0L
    self.n1456d = 0L
    self.n1447 = 0L
    self.n1447r = 0L
    self.n1447e = 0L
    self.n1447d = 0L
    self.n1431 = 0L
    self.n1412 = 0L
    self.n1327 = 0L
    self.n937 = 0L
    self.n937r = 0L
    self.n937e = 0L
    self.n937d = 0L
    self.n928 = 0L
    self.n928r = 0L
    self.n928e = 0L
    self.n928d = 0L
    self.n912 = 0L
    self.n893 = 0L
    self.n808 = 0L
    self.n418 = 0L
    self.n418r = 0L
    self.n418e = 0L
    self.n418d = 0L
    self.n409 = 0L
    self.n409r = 0L
    self.n409e = 0L
    self.n409d = 0L
    self.n393 = 0L
    self.n374 = 0L
    self.n289 = 0L
    self.n83 = 0L
    self.n64 = 0L
    self.n6602 = 0L
    self.n6598 = 0L
    self.n6594 = 0L
    self.n6590 = 0L
    self.n6586 = 0L
    self.n6582 = 0L
    self.n6578 = 0L
    self.n6574 = 0L
    self.n6570 = 0L
    self.n6566 = 0L
    self.n6562 = 0L
    self.n6558 = 0L
    self.n6554 = 0L
    self.n6518 = 0L
    self.n6109 = 0L
    self.n6109r = 0L
    self.n6109e = 0L
    self.n6109d = 0L
    self.n6088 = 0L
    self.n6088r = 0L
    self.n6088e = 0L
    self.n6088d = 0L
    self.n5999 = 0L
    self.n5590 = 0L
    self.n5590r = 0L
    self.n5590e = 0L
    self.n5590d = 0L
    self.n5569 = 0L
    self.n5569r = 0L
    self.n5569e = 0L
    self.n5569d = 0L
    self.n5480 = 0L
    self.n5071 = 0L
    self.n5071r = 0L
    self.n5071e = 0L
    self.n5071d = 0L
    self.n5050 = 0L
    self.n5050r = 0L
    self.n5050e = 0L
    self.n5050d = 0L
    self.n4961 = 0L
    self.n4552 = 0L
    self.n4552r = 0L
    self.n4552e = 0L
    self.n4552d = 0L
    self.n4531 = 0L
    self.n4531r = 0L
    self.n4531e = 0L
    self.n4531d = 0L
    self.n4442 = 0L
    self.n4033 = 0L
    self.n4033r = 0L
    self.n4033e = 0L
    self.n4033d = 0L
    self.n4012 = 0L
    self.n4012r = 0L
    self.n4012e = 0L
    self.n4012d = 0L
    self.n3923 = 0L
    self.n3514 = 0L
    self.n3514r = 0L
    self.n3514e = 0L
    self.n3514d = 0L
    self.n3493 = 0L
    self.n3493r = 0L
    self.n3493e = 0L
    self.n3493d = 0L
    self.n3404 = 0L
    self.n2995 = 0L
    self.n2995r = 0L
    self.n2995e = 0L
    self.n2995d = 0L
    self.n2974 = 0L
    self.n2974r = 0L
    self.n2974e = 0L
    self.n2974d = 0L
    self.n2885 = 0L
    self.n2476 = 0L
    self.n2476r = 0L
    self.n2476e = 0L
    self.n2476d = 0L
    self.n2455 = 0L
    self.n2455r = 0L
    self.n2455e = 0L
    self.n2455d = 0L
    self.n2366 = 0L
    self.n1957 = 0L
    self.n1957r = 0L
    self.n1957e = 0L
    self.n1957d = 0L
    self.n1936 = 0L
    self.n1936r = 0L
    self.n1936e = 0L
    self.n1936d = 0L
    self.n1847 = 0L
    self.n1438 = 0L
    self.n1438r = 0L
    self.n1438e = 0L
    self.n1438d = 0L
    self.n1417 = 0L
    self.n1417r = 0L
    self.n1417e = 0L
    self.n1417d = 0L
    self.n1328 = 0L
    self.n919 = 0L
    self.n919r = 0L
    self.n919e = 0L
    self.n919d = 0L
    self.n898 = 0L
    self.n898r = 0L
    self.n898e = 0L
    self.n898d = 0L
    self.n809 = 0L
    self.n400 = 0L
    self.n400r = 0L
    self.n400e = 0L
    self.n400d = 0L
    self.n379 = 0L
    self.n379r = 0L
    self.n379e = 0L
    self.n379d = 0L
    self.n290 = 0L
    self.n90 = 0L
    self.n90r = 0L
    self.n90e = 0L
    self.n90d = 0L
    self.n69 = 0L
    self.n69r = 0L
    self.n69e = 0L
    self.n69d = 0L
    self.n6523 = 0L
    self.n6523r = 0L
    self.n6523e = 0L
    self.n6523d = 0L
    self.n6033 = 0L
    self.n6033r = 0L
    self.n6033e = 0L
    self.n6033d = 0L
    self.n6004 = 0L
    self.n6004r = 0L
    self.n6004e = 0L
    self.n6004d = 0L
    self.n5514 = 0L
    self.n5514r = 0L
    self.n5514e = 0L
    self.n5514d = 0L
    self.n5485 = 0L
    self.n5485r = 0L
    self.n5485e = 0L
    self.n5485d = 0L
    self.n4995 = 0L
    self.n4995r = 0L
    self.n4995e = 0L
    self.n4995d = 0L
    self.n4966 = 0L
    self.n4966r = 0L
    self.n4966e = 0L
    self.n4966d = 0L
    self.n4476 = 0L
    self.n4476r = 0L
    self.n4476e = 0L
    self.n4476d = 0L
    self.n4447 = 0L
    self.n4447r = 0L
    self.n4447e = 0L
    self.n4447d = 0L
    self.n3957 = 0L
    self.n3957r = 0L
    self.n3957e = 0L
    self.n3957d = 0L
    self.n3928 = 0L
    self.n3928r = 0L
    self.n3928e = 0L
    self.n3928d = 0L
    self.n3438 = 0L
    self.n3438r = 0L
    self.n3438e = 0L
    self.n3438d = 0L
    self.n3409 = 0L
    self.n3409r = 0L
    self.n3409e = 0L
    self.n3409d = 0L
    self.n2919 = 0L
    self.n2919r = 0L
    self.n2919e = 0L
    self.n2919d = 0L
    self.n2890 = 0L
    self.n2890r = 0L
    self.n2890e = 0L
    self.n2890d = 0L
    self.n2400 = 0L
    self.n2400r = 0L
    self.n2400e = 0L
    self.n2400d = 0L
    self.n2371 = 0L
    self.n2371r = 0L
    self.n2371e = 0L
    self.n2371d = 0L
    self.n1881 = 0L
    self.n1881r = 0L
    self.n1881e = 0L
    self.n1881d = 0L
    self.n1852 = 0L
    self.n1852r = 0L
    self.n1852e = 0L
    self.n1852d = 0L
    self.n1362 = 0L
    self.n1362r = 0L
    self.n1362e = 0L
    self.n1362d = 0L
    self.n1333 = 0L
    self.n1333r = 0L
    self.n1333e = 0L
    self.n1333d = 0L
    self.n843 = 0L
    self.n843r = 0L
    self.n843e = 0L
    self.n843d = 0L
    self.n814 = 0L
    self.n814r = 0L
    self.n814e = 0L
    self.n814d = 0L
    self.n324 = 0L
    self.n324r = 0L
    self.n324e = 0L
    self.n324d = 0L
    self.n295 = 0L
    self.n295r = 0L
    self.n295e = 0L
    self.n295d = 0L
    self.n14 = 0L
    self.n14r = 0L
    self.n14e = 0L
    self.n14d = 0L
    self.calc(0L, 0L, 0L, 0L, 0L, )

  def calc(self, enable_i, reset_i, sync_i, data_0_i, data_1_i, ):
    self.n6758 = 0x1L
    self.n6753 = 0x1L
    self.n6751 = 0x1L
    self.n6749 = 0x1L
    self.n6747 = 0x1L
    self.n6746 = 0x1L
    self.n6741 = 0x1L
    self.n6739 = 0x1L
    self.n6737 = 0x1L
    self.n6735 = 0x1L
    self.n6734 = 0x1L
    self.n6729 = 0x1L
    self.n6727 = 0x1L
    self.n6725 = 0x1L
    self.n6723 = 0x1L
    self.n6722 = 0x1L
    self.n6717 = 0x1L
    self.n6715 = 0x1L
    self.n6713 = 0x1L
    self.n6711 = 0x1L
    self.n6710 = 0x1L
    self.n6705 = 0x1L
    self.n6703 = 0x1L
    self.n6701 = 0x1L
    self.n6699 = 0x1L
    self.n6698 = 0x1L
    self.n6693 = 0x1L
    self.n6691 = 0x1L
    self.n6689 = 0x1L
    self.n6687 = 0x1L
    self.n6686 = 0x1L
    self.n6681 = 0x1L
    self.n6679 = 0x1L
    self.n6677 = 0x1L
    self.n6675 = 0x1L
    self.n6674 = 0x1L
    self.n6669 = 0x1L
    self.n6667 = 0x1L
    self.n6665 = 0x1L
    self.n6663 = 0x1L
    self.n6662 = 0x1L
    self.n6657 = 0x1L
    self.n6655 = 0x1L
    self.n6653 = 0x1L
    self.n6651 = 0x1L
    self.n6650 = 0x1L
    self.n6645 = 0x1L
    self.n6643 = 0x1L
    self.n6641 = 0x1L
    self.n6639 = 0x1L
    self.n6638 = 0x1L
    self.n6633 = 0x1L
    self.n6631 = 0x1L
    self.n6629 = 0x1L
    self.n6627 = 0x1L
    self.n6626 = 0x1L
    self.n6621 = 0x1L
    self.n6619 = 0x1L
    self.n6617 = 0x1L
    self.n6615 = 0x1L
    self.n6614 = 0x1L
    self.n6609 = 0x1L
    self.n6607 = 0x1L
    self.n6605 = 0x1L
    self.n6603 = 0x1L
    self.n6548 = reset_i
    self.n6547 = enable_i
    sync_o = self.n6375
    self.n6544 = self.n6375
    self.n6498 = 0x6L
    self.n6497 = 0x4L
    self.n6496 = 0x2L
    self.n6495 = 0x0L
    self.n6494 = 0x0L
    self.n6493 = 0x0L
    self.n6492 = 0x0L
    self.n6491 = 0x0L
    self.n6486 = 0x5L
    self.n6485 = 0x3L
    self.n6484 = 0x1L
    self.n6483 = 0x6L
    self.n6482 = 0x4L
    self.n6481 = 0x2L
    self.n6480 = 0x0L
    self.n6479 = 0x0L
    self.n6478 = 0x0L
    self.n6477 = 0x1L
    self.n6476 = 0x0L
    self.n6475 = 0x1L
    self.n6474 = 0x0L
    self.n6473 = 0x1L
    self.n6472 = 0x0L
    if self.n6469:
      self.n6470 = self.n6462
    else:
      self.n6470 = self.n6456
    self.n6423 = self.n6265 << 1 | self.n6434
    self.n6419 = 0x2L
    self.n6418 = 0x0L
    self.n6417 = 0x0L
    self.n6416 = 0x0L
    self.n6413 = 0x1L
    self.n6412 = 0x2L
    self.n6411 = 0x0L
    self.n6410 = 0x0L
    self.n6409 = 0x1L
    self.n6408 = 0x1L
    self.n6407 = 0x0L
    self.n6398 = 0x001L
    if self.n6396:
      self.n6397 = self.n6389
    else:
      self.n6397 = self.n6383
    self.n6376 = 0x000L
    self.n6350 = self.n6265 << 1 | self.n6361
    self.n6346 = 0x2L
    self.n6345 = 0x0L
    self.n6344 = 0x0L
    self.n6343 = 0x0L
    self.n6340 = 0x1L
    self.n6339 = 0x2L
    self.n6338 = 0x0L
    self.n6337 = 0x0L
    self.n6336 = 0x1L
    self.n6335 = 0x1L
    self.n6334 = 0x0L
    self.n6325 = 0x001L
    self.n6324 = ~self.n6323 & 0x1L
    self.n6295 = (self.n6033 & 0x1L)
    self.n6266 = ((self.n6033 & 0x400L) >> 1) | ((self.n6033 & 0x200L) >> 1) | ((self.n6033 & 0x100L) >> 1) | ((self.n6033 & 0x80L) >> 1) | ((self.n6033 & 0x40L) >> 1) | ((self.n6033 & 0x20L) >> 1) | ((self.n6033 & 0x10L) >> 1) | ((self.n6033 & 0x8L) >> 1) | ((self.n6033 & 0x4L) >> 1) | ((self.n6033 & 0x2L) >> 1)
    self.n6237 = self.n6226 << 16 | self.n6236
    self.n6228 = (self.n6157 - self.n6216) & 0xFFL
    self.n6227 = (self.n6143 - self.n6190) & 0xFFL
    self.n6218 = (self.n6157 + self.n6216) & 0xFFL
    self.n6217 = (self.n6143 + self.n6190) & 0xFFL
    self.n6209 = (self.n6199 + self.n6208) & 0xFFL
    self.n6183 = (self.n6173 - self.n6182) & 0xFFL
    self.n6164 = (self.n6162 & 0x80L) | (self.n6162 & 0x40L) | (self.n6162 & 0x20L) | (self.n6162 & 0x10L) | (self.n6162 & 0x8L) | (self.n6162 & 0x4L) | (self.n6162 & 0x2L) | (self.n6162 & 0x1L)
    self.n6163 = ((self.n6162 & 0x8000L) >> 8) | ((self.n6162 & 0x4000L) >> 8) | ((self.n6162 & 0x2000L) >> 8) | ((self.n6162 & 0x1000L) >> 8) | ((self.n6162 & 0x800L) >> 8) | ((self.n6162 & 0x400L) >> 8) | ((self.n6162 & 0x200L) >> 8) | ((self.n6162 & 0x100L) >> 8)
    self.n6129 = (self.n6127 & 0x80L) | (self.n6127 & 0x40L) | (self.n6127 & 0x20L) | (self.n6127 & 0x10L) | (self.n6127 & 0x8L) | (self.n6127 & 0x4L) | (self.n6127 & 0x2L) | (self.n6127 & 0x1L)
    self.n6128 = ((self.n6127 & 0x8000L) >> 8) | ((self.n6127 & 0x4000L) >> 8) | ((self.n6127 & 0x2000L) >> 8) | ((self.n6127 & 0x1000L) >> 8) | ((self.n6127 & 0x800L) >> 8) | ((self.n6127 & 0x400L) >> 8) | ((self.n6127 & 0x200L) >> 8) | ((self.n6127 & 0x100L) >> 8)
    self.n6120 = (self.n6118 & 0x80L) | (self.n6118 & 0x40L) | (self.n6118 & 0x20L) | (self.n6118 & 0x10L) | (self.n6118 & 0x8L) | (self.n6118 & 0x4L) | (self.n6118 & 0x2L) | (self.n6118 & 0x1L)
    self.n6119 = ((self.n6118 & 0x8000L) >> 8) | ((self.n6118 & 0x4000L) >> 8) | ((self.n6118 & 0x2000L) >> 8) | ((self.n6118 & 0x1000L) >> 8) | ((self.n6118 & 0x800L) >> 8) | ((self.n6118 & 0x400L) >> 8) | ((self.n6118 & 0x200L) >> 8) | ((self.n6118 & 0x100L) >> 8)
    self.n6111 = (self.n6033 & 0x400L) | (self.n6033 & 0x200L) | (self.n6033 & 0x100L) | (self.n6033 & 0x80L) | (self.n6033 & 0x40L) | (self.n6033 & 0x20L) | (self.n6033 & 0x10L) | (self.n6033 & 0x8L) | (self.n6033 & 0x4L) | (self.n6033 & 0x2L) | (self.n6033 & 0x1L)
    self.n6065 = 0x3L
    self.n6064 = 0x1L
    self.n6063 = 0x6L
    self.n6062 = 0x4L
    self.n6061 = 0x2L
    self.n6060 = 0x0L
    self.n6059 = 0x0L
    self.n6058 = 0x0L
    self.n6057 = 0x1L
    self.n6056 = 0x1L
    self.n6055 = 0x1L
    self.n6054 = 0x0L
    self.n6050 = 0x3L
    self.n6049 = 0x1L
    self.n6048 = 0x6L
    self.n6047 = 0x4L
    self.n6046 = 0x2L
    self.n6045 = 0x0L
    self.n6044 = 0x0L
    self.n6043 = 0x0L
    self.n6042 = 0x1L
    self.n6041 = 0x1L
    self.n6040 = 0x1L
    self.n6039 = 0x0L
    self.n6034 = 0x7FFL
    self.n6025 = 0x001L
    self.n5979 = 0x6L
    self.n5978 = 0x4L
    self.n5977 = 0x2L
    self.n5976 = 0x0L
    self.n5975 = 0x0L
    self.n5974 = 0x0L
    self.n5973 = 0x0L
    self.n5972 = 0x0L
    self.n5967 = 0x5L
    self.n5966 = 0x3L
    self.n5965 = 0x1L
    self.n5964 = 0x6L
    self.n5963 = 0x4L
    self.n5962 = 0x2L
    self.n5961 = 0x0L
    self.n5960 = 0x0L
    self.n5959 = 0x0L
    self.n5958 = 0x1L
    self.n5957 = 0x0L
    self.n5956 = 0x1L
    self.n5955 = 0x0L
    self.n5954 = 0x1L
    self.n5953 = 0x0L
    if self.n5950:
      self.n5951 = self.n5943
    else:
      self.n5951 = self.n5937
    self.n5904 = self.n5746 << 1 | self.n5915
    self.n5900 = 0x2L
    self.n5899 = 0x0L
    self.n5898 = 0x0L
    self.n5897 = 0x0L
    self.n5894 = 0x1L
    self.n5893 = 0x2L
    self.n5892 = 0x0L
    self.n5891 = 0x0L
    self.n5890 = 0x1L
    self.n5889 = 0x1L
    self.n5888 = 0x0L
    self.n5879 = 0x001L
    if self.n5877:
      self.n5878 = self.n5870
    else:
      self.n5878 = self.n5864
    self.n5857 = 0x000L
    self.n5831 = self.n5746 << 1 | self.n5842
    self.n5827 = 0x2L
    self.n5826 = 0x0L
    self.n5825 = 0x0L
    self.n5824 = 0x0L
    self.n5821 = 0x1L
    self.n5820 = 0x2L
    self.n5819 = 0x0L
    self.n5818 = 0x0L
    self.n5817 = 0x1L
    self.n5816 = 0x1L
    self.n5815 = 0x0L
    self.n5806 = 0x001L
    self.n5805 = ~self.n5804 & 0x1L
    self.n5776 = (self.n5514 & 0x1L)
    self.n5747 = ((self.n5514 & 0x400L) >> 1) | ((self.n5514 & 0x200L) >> 1) | ((self.n5514 & 0x100L) >> 1) | ((self.n5514 & 0x80L) >> 1) | ((self.n5514 & 0x40L) >> 1) | ((self.n5514 & 0x20L) >> 1) | ((self.n5514 & 0x10L) >> 1) | ((self.n5514 & 0x8L) >> 1) | ((self.n5514 & 0x4L) >> 1) | ((self.n5514 & 0x2L) >> 1)
    self.n5718 = self.n5707 << 16 | self.n5717
    self.n5709 = (self.n5638 - self.n5697) & 0xFFL
    self.n5708 = (self.n5624 - self.n5671) & 0xFFL
    self.n5699 = (self.n5638 + self.n5697) & 0xFFL
    self.n5698 = (self.n5624 + self.n5671) & 0xFFL
    self.n5690 = (self.n5680 + self.n5689) & 0xFFL
    self.n5664 = (self.n5654 - self.n5663) & 0xFFL
    self.n5645 = (self.n5643 & 0x80L) | (self.n5643 & 0x40L) | (self.n5643 & 0x20L) | (self.n5643 & 0x10L) | (self.n5643 & 0x8L) | (self.n5643 & 0x4L) | (self.n5643 & 0x2L) | (self.n5643 & 0x1L)
    self.n5644 = ((self.n5643 & 0x8000L) >> 8) | ((self.n5643 & 0x4000L) >> 8) | ((self.n5643 & 0x2000L) >> 8) | ((self.n5643 & 0x1000L) >> 8) | ((self.n5643 & 0x800L) >> 8) | ((self.n5643 & 0x400L) >> 8) | ((self.n5643 & 0x200L) >> 8) | ((self.n5643 & 0x100L) >> 8)
    self.n5610 = (self.n5608 & 0x80L) | (self.n5608 & 0x40L) | (self.n5608 & 0x20L) | (self.n5608 & 0x10L) | (self.n5608 & 0x8L) | (self.n5608 & 0x4L) | (self.n5608 & 0x2L) | (self.n5608 & 0x1L)
    self.n5609 = ((self.n5608 & 0x8000L) >> 8) | ((self.n5608 & 0x4000L) >> 8) | ((self.n5608 & 0x2000L) >> 8) | ((self.n5608 & 0x1000L) >> 8) | ((self.n5608 & 0x800L) >> 8) | ((self.n5608 & 0x400L) >> 8) | ((self.n5608 & 0x200L) >> 8) | ((self.n5608 & 0x100L) >> 8)
    self.n5601 = (self.n5599 & 0x80L) | (self.n5599 & 0x40L) | (self.n5599 & 0x20L) | (self.n5599 & 0x10L) | (self.n5599 & 0x8L) | (self.n5599 & 0x4L) | (self.n5599 & 0x2L) | (self.n5599 & 0x1L)
    self.n5600 = ((self.n5599 & 0x8000L) >> 8) | ((self.n5599 & 0x4000L) >> 8) | ((self.n5599 & 0x2000L) >> 8) | ((self.n5599 & 0x1000L) >> 8) | ((self.n5599 & 0x800L) >> 8) | ((self.n5599 & 0x400L) >> 8) | ((self.n5599 & 0x200L) >> 8) | ((self.n5599 & 0x100L) >> 8)
    self.n5592 = ((self.n5514 & 0x400L) >> 1) | ((self.n5514 & 0x200L) >> 1) | ((self.n5514 & 0x100L) >> 1) | ((self.n5514 & 0x80L) >> 1) | ((self.n5514 & 0x40L) >> 1) | ((self.n5514 & 0x20L) >> 1) | ((self.n5514 & 0x10L) >> 1) | ((self.n5514 & 0x8L) >> 1) | ((self.n5514 & 0x4L) >> 1) | ((self.n5514 & 0x2L) >> 1)
    self.n5546 = 0x3L
    self.n5545 = 0x1L
    self.n5544 = 0x6L
    self.n5543 = 0x4L
    self.n5542 = 0x2L
    self.n5541 = 0x0L
    self.n5540 = 0x0L
    self.n5539 = 0x0L
    self.n5538 = 0x1L
    self.n5537 = 0x1L
    self.n5536 = 0x1L
    self.n5535 = 0x0L
    self.n5531 = 0x3L
    self.n5530 = 0x1L
    self.n5529 = 0x6L
    self.n5528 = 0x4L
    self.n5527 = 0x2L
    self.n5526 = 0x0L
    self.n5525 = 0x0L
    self.n5524 = 0x0L
    self.n5523 = 0x1L
    self.n5522 = 0x1L
    self.n5521 = 0x1L
    self.n5520 = 0x0L
    self.n5515 = 0x7FFL
    self.n5506 = 0x001L
    self.n5460 = 0x6L
    self.n5459 = 0x4L
    self.n5458 = 0x2L
    self.n5457 = 0x0L
    self.n5456 = 0x0L
    self.n5455 = 0x0L
    self.n5454 = 0x0L
    self.n5453 = 0x0L
    self.n5448 = 0x5L
    self.n5447 = 0x3L
    self.n5446 = 0x1L
    self.n5445 = 0x6L
    self.n5444 = 0x4L
    self.n5443 = 0x2L
    self.n5442 = 0x0L
    self.n5441 = 0x0L
    self.n5440 = 0x0L
    self.n5439 = 0x1L
    self.n5438 = 0x0L
    self.n5437 = 0x1L
    self.n5436 = 0x0L
    self.n5435 = 0x1L
    self.n5434 = 0x0L
    if self.n5431:
      self.n5432 = self.n5424
    else:
      self.n5432 = self.n5418
    self.n5385 = self.n5227 << 1 | self.n5396
    self.n5381 = 0x2L
    self.n5380 = 0x0L
    self.n5379 = 0x0L
    self.n5378 = 0x0L
    self.n5375 = 0x1L
    self.n5374 = 0x2L
    self.n5373 = 0x0L
    self.n5372 = 0x0L
    self.n5371 = 0x1L
    self.n5370 = 0x1L
    self.n5369 = 0x0L
    self.n5360 = 0x001L
    if self.n5358:
      self.n5359 = self.n5351
    else:
      self.n5359 = self.n5345
    self.n5338 = 0x000L
    self.n5312 = self.n5227 << 1 | self.n5323
    self.n5308 = 0x2L
    self.n5307 = 0x0L
    self.n5306 = 0x0L
    self.n5305 = 0x0L
    self.n5302 = 0x1L
    self.n5301 = 0x2L
    self.n5300 = 0x0L
    self.n5299 = 0x0L
    self.n5298 = 0x1L
    self.n5297 = 0x1L
    self.n5296 = 0x0L
    self.n5287 = 0x001L
    self.n5286 = ~self.n5285 & 0x1L
    self.n5257 = (self.n4995 & 0x1L)
    self.n5228 = ((self.n4995 & 0x400L) >> 1) | ((self.n4995 & 0x200L) >> 1) | ((self.n4995 & 0x100L) >> 1) | ((self.n4995 & 0x80L) >> 1) | ((self.n4995 & 0x40L) >> 1) | ((self.n4995 & 0x20L) >> 1) | ((self.n4995 & 0x10L) >> 1) | ((self.n4995 & 0x8L) >> 1) | ((self.n4995 & 0x4L) >> 1) | ((self.n4995 & 0x2L) >> 1)
    self.n5199 = self.n5188 << 16 | self.n5198
    self.n5190 = (self.n5119 - self.n5178) & 0xFFL
    self.n5189 = (self.n5105 - self.n5152) & 0xFFL
    self.n5180 = (self.n5119 + self.n5178) & 0xFFL
    self.n5179 = (self.n5105 + self.n5152) & 0xFFL
    self.n5171 = (self.n5161 + self.n5170) & 0xFFL
    self.n5145 = (self.n5135 - self.n5144) & 0xFFL
    self.n5126 = (self.n5124 & 0x80L) | (self.n5124 & 0x40L) | (self.n5124 & 0x20L) | (self.n5124 & 0x10L) | (self.n5124 & 0x8L) | (self.n5124 & 0x4L) | (self.n5124 & 0x2L) | (self.n5124 & 0x1L)
    self.n5125 = ((self.n5124 & 0x8000L) >> 8) | ((self.n5124 & 0x4000L) >> 8) | ((self.n5124 & 0x2000L) >> 8) | ((self.n5124 & 0x1000L) >> 8) | ((self.n5124 & 0x800L) >> 8) | ((self.n5124 & 0x400L) >> 8) | ((self.n5124 & 0x200L) >> 8) | ((self.n5124 & 0x100L) >> 8)
    self.n5091 = (self.n5089 & 0x80L) | (self.n5089 & 0x40L) | (self.n5089 & 0x20L) | (self.n5089 & 0x10L) | (self.n5089 & 0x8L) | (self.n5089 & 0x4L) | (self.n5089 & 0x2L) | (self.n5089 & 0x1L)
    self.n5090 = ((self.n5089 & 0x8000L) >> 8) | ((self.n5089 & 0x4000L) >> 8) | ((self.n5089 & 0x2000L) >> 8) | ((self.n5089 & 0x1000L) >> 8) | ((self.n5089 & 0x800L) >> 8) | ((self.n5089 & 0x400L) >> 8) | ((self.n5089 & 0x200L) >> 8) | ((self.n5089 & 0x100L) >> 8)
    self.n5082 = (self.n5080 & 0x80L) | (self.n5080 & 0x40L) | (self.n5080 & 0x20L) | (self.n5080 & 0x10L) | (self.n5080 & 0x8L) | (self.n5080 & 0x4L) | (self.n5080 & 0x2L) | (self.n5080 & 0x1L)
    self.n5081 = ((self.n5080 & 0x8000L) >> 8) | ((self.n5080 & 0x4000L) >> 8) | ((self.n5080 & 0x2000L) >> 8) | ((self.n5080 & 0x1000L) >> 8) | ((self.n5080 & 0x800L) >> 8) | ((self.n5080 & 0x400L) >> 8) | ((self.n5080 & 0x200L) >> 8) | ((self.n5080 & 0x100L) >> 8)
    self.n5073 = ((self.n4995 & 0x400L) >> 2) | ((self.n4995 & 0x200L) >> 2) | ((self.n4995 & 0x100L) >> 2) | ((self.n4995 & 0x80L) >> 2) | ((self.n4995 & 0x40L) >> 2) | ((self.n4995 & 0x20L) >> 2) | ((self.n4995 & 0x10L) >> 2) | ((self.n4995 & 0x8L) >> 2) | ((self.n4995 & 0x4L) >> 2)
    self.n5027 = 0x3L
    self.n5026 = 0x1L
    self.n5025 = 0x6L
    self.n5024 = 0x4L
    self.n5023 = 0x2L
    self.n5022 = 0x0L
    self.n5021 = 0x0L
    self.n5020 = 0x0L
    self.n5019 = 0x1L
    self.n5018 = 0x1L
    self.n5017 = 0x1L
    self.n5016 = 0x0L
    self.n5012 = 0x3L
    self.n5011 = 0x1L
    self.n5010 = 0x6L
    self.n5009 = 0x4L
    self.n5008 = 0x2L
    self.n5007 = 0x0L
    self.n5006 = 0x0L
    self.n5005 = 0x0L
    self.n5004 = 0x1L
    self.n5003 = 0x1L
    self.n5002 = 0x1L
    self.n5001 = 0x0L
    self.n4996 = 0x7FFL
    self.n4987 = 0x001L
    self.n4941 = 0x6L
    self.n4940 = 0x4L
    self.n4939 = 0x2L
    self.n4938 = 0x0L
    self.n4937 = 0x0L
    self.n4936 = 0x0L
    self.n4935 = 0x0L
    self.n4934 = 0x0L
    self.n4929 = 0x5L
    self.n4928 = 0x3L
    self.n4927 = 0x1L
    self.n4926 = 0x6L
    self.n4925 = 0x4L
    self.n4924 = 0x2L
    self.n4923 = 0x0L
    self.n4922 = 0x0L
    self.n4921 = 0x0L
    self.n4920 = 0x1L
    self.n4919 = 0x0L
    self.n4918 = 0x1L
    self.n4917 = 0x0L
    self.n4916 = 0x1L
    self.n4915 = 0x0L
    if self.n4912:
      self.n4913 = self.n4905
    else:
      self.n4913 = self.n4899
    self.n4866 = self.n4708 << 1 | self.n4877
    self.n4862 = 0x2L
    self.n4861 = 0x0L
    self.n4860 = 0x0L
    self.n4859 = 0x0L
    self.n4856 = 0x1L
    self.n4855 = 0x2L
    self.n4854 = 0x0L
    self.n4853 = 0x0L
    self.n4852 = 0x1L
    self.n4851 = 0x1L
    self.n4850 = 0x0L
    self.n4841 = 0x001L
    if self.n4839:
      self.n4840 = self.n4832
    else:
      self.n4840 = self.n4826
    self.n4819 = 0x000L
    self.n4793 = self.n4708 << 1 | self.n4804
    self.n4789 = 0x2L
    self.n4788 = 0x0L
    self.n4787 = 0x0L
    self.n4786 = 0x0L
    self.n4783 = 0x1L
    self.n4782 = 0x2L
    self.n4781 = 0x0L
    self.n4780 = 0x0L
    self.n4779 = 0x1L
    self.n4778 = 0x1L
    self.n4777 = 0x0L
    self.n4768 = 0x001L
    self.n4767 = ~self.n4766 & 0x1L
    self.n4738 = (self.n4476 & 0x1L)
    self.n4709 = ((self.n4476 & 0x400L) >> 1) | ((self.n4476 & 0x200L) >> 1) | ((self.n4476 & 0x100L) >> 1) | ((self.n4476 & 0x80L) >> 1) | ((self.n4476 & 0x40L) >> 1) | ((self.n4476 & 0x20L) >> 1) | ((self.n4476 & 0x10L) >> 1) | ((self.n4476 & 0x8L) >> 1) | ((self.n4476 & 0x4L) >> 1) | ((self.n4476 & 0x2L) >> 1)
    self.n4680 = self.n4669 << 16 | self.n4679
    self.n4671 = (self.n4600 - self.n4659) & 0xFFL
    self.n4670 = (self.n4586 - self.n4633) & 0xFFL
    self.n4661 = (self.n4600 + self.n4659) & 0xFFL
    self.n4660 = (self.n4586 + self.n4633) & 0xFFL
    self.n4652 = (self.n4642 + self.n4651) & 0xFFL
    self.n4626 = (self.n4616 - self.n4625) & 0xFFL
    self.n4607 = (self.n4605 & 0x80L) | (self.n4605 & 0x40L) | (self.n4605 & 0x20L) | (self.n4605 & 0x10L) | (self.n4605 & 0x8L) | (self.n4605 & 0x4L) | (self.n4605 & 0x2L) | (self.n4605 & 0x1L)
    self.n4606 = ((self.n4605 & 0x8000L) >> 8) | ((self.n4605 & 0x4000L) >> 8) | ((self.n4605 & 0x2000L) >> 8) | ((self.n4605 & 0x1000L) >> 8) | ((self.n4605 & 0x800L) >> 8) | ((self.n4605 & 0x400L) >> 8) | ((self.n4605 & 0x200L) >> 8) | ((self.n4605 & 0x100L) >> 8)
    self.n4572 = (self.n4570 & 0x80L) | (self.n4570 & 0x40L) | (self.n4570 & 0x20L) | (self.n4570 & 0x10L) | (self.n4570 & 0x8L) | (self.n4570 & 0x4L) | (self.n4570 & 0x2L) | (self.n4570 & 0x1L)
    self.n4571 = ((self.n4570 & 0x8000L) >> 8) | ((self.n4570 & 0x4000L) >> 8) | ((self.n4570 & 0x2000L) >> 8) | ((self.n4570 & 0x1000L) >> 8) | ((self.n4570 & 0x800L) >> 8) | ((self.n4570 & 0x400L) >> 8) | ((self.n4570 & 0x200L) >> 8) | ((self.n4570 & 0x100L) >> 8)
    self.n4563 = (self.n4561 & 0x80L) | (self.n4561 & 0x40L) | (self.n4561 & 0x20L) | (self.n4561 & 0x10L) | (self.n4561 & 0x8L) | (self.n4561 & 0x4L) | (self.n4561 & 0x2L) | (self.n4561 & 0x1L)
    self.n4562 = ((self.n4561 & 0x8000L) >> 8) | ((self.n4561 & 0x4000L) >> 8) | ((self.n4561 & 0x2000L) >> 8) | ((self.n4561 & 0x1000L) >> 8) | ((self.n4561 & 0x800L) >> 8) | ((self.n4561 & 0x400L) >> 8) | ((self.n4561 & 0x200L) >> 8) | ((self.n4561 & 0x100L) >> 8)
    self.n4554 = ((self.n4476 & 0x400L) >> 3) | ((self.n4476 & 0x200L) >> 3) | ((self.n4476 & 0x100L) >> 3) | ((self.n4476 & 0x80L) >> 3) | ((self.n4476 & 0x40L) >> 3) | ((self.n4476 & 0x20L) >> 3) | ((self.n4476 & 0x10L) >> 3) | ((self.n4476 & 0x8L) >> 3)
    self.n4508 = 0x3L
    self.n4507 = 0x1L
    self.n4506 = 0x6L
    self.n4505 = 0x4L
    self.n4504 = 0x2L
    self.n4503 = 0x0L
    self.n4502 = 0x0L
    self.n4501 = 0x0L
    self.n4500 = 0x1L
    self.n4499 = 0x1L
    self.n4498 = 0x1L
    self.n4497 = 0x0L
    self.n4493 = 0x3L
    self.n4492 = 0x1L
    self.n4491 = 0x6L
    self.n4490 = 0x4L
    self.n4489 = 0x2L
    self.n4488 = 0x0L
    self.n4487 = 0x0L
    self.n4486 = 0x0L
    self.n4485 = 0x1L
    self.n4484 = 0x1L
    self.n4483 = 0x1L
    self.n4482 = 0x0L
    self.n4477 = 0x7FFL
    self.n4468 = 0x001L
    self.n4422 = 0x6L
    self.n4421 = 0x4L
    self.n4420 = 0x2L
    self.n4419 = 0x0L
    self.n4418 = 0x0L
    self.n4417 = 0x0L
    self.n4416 = 0x0L
    self.n4415 = 0x0L
    self.n4410 = 0x5L
    self.n4409 = 0x3L
    self.n4408 = 0x1L
    self.n4407 = 0x6L
    self.n4406 = 0x4L
    self.n4405 = 0x2L
    self.n4404 = 0x0L
    self.n4403 = 0x0L
    self.n4402 = 0x0L
    self.n4401 = 0x1L
    self.n4400 = 0x0L
    self.n4399 = 0x1L
    self.n4398 = 0x0L
    self.n4397 = 0x1L
    self.n4396 = 0x0L
    if self.n4393:
      self.n4394 = self.n4386
    else:
      self.n4394 = self.n4380
    self.n4347 = self.n4189 << 1 | self.n4358
    self.n4343 = 0x2L
    self.n4342 = 0x0L
    self.n4341 = 0x0L
    self.n4340 = 0x0L
    self.n4337 = 0x1L
    self.n4336 = 0x2L
    self.n4335 = 0x0L
    self.n4334 = 0x0L
    self.n4333 = 0x1L
    self.n4332 = 0x1L
    self.n4331 = 0x0L
    self.n4322 = 0x001L
    if self.n4320:
      self.n4321 = self.n4313
    else:
      self.n4321 = self.n4307
    self.n4300 = 0x000L
    self.n4274 = self.n4189 << 1 | self.n4285
    self.n4270 = 0x2L
    self.n4269 = 0x0L
    self.n4268 = 0x0L
    self.n4267 = 0x0L
    self.n4264 = 0x1L
    self.n4263 = 0x2L
    self.n4262 = 0x0L
    self.n4261 = 0x0L
    self.n4260 = 0x1L
    self.n4259 = 0x1L
    self.n4258 = 0x0L
    self.n4249 = 0x001L
    self.n4248 = ~self.n4247 & 0x1L
    self.n4219 = (self.n3957 & 0x1L)
    self.n4190 = ((self.n3957 & 0x400L) >> 1) | ((self.n3957 & 0x200L) >> 1) | ((self.n3957 & 0x100L) >> 1) | ((self.n3957 & 0x80L) >> 1) | ((self.n3957 & 0x40L) >> 1) | ((self.n3957 & 0x20L) >> 1) | ((self.n3957 & 0x10L) >> 1) | ((self.n3957 & 0x8L) >> 1) | ((self.n3957 & 0x4L) >> 1) | ((self.n3957 & 0x2L) >> 1)
    self.n4161 = self.n4150 << 16 | self.n4160
    self.n4152 = (self.n4081 - self.n4140) & 0xFFL
    self.n4151 = (self.n4067 - self.n4114) & 0xFFL
    self.n4142 = (self.n4081 + self.n4140) & 0xFFL
    self.n4141 = (self.n4067 + self.n4114) & 0xFFL
    self.n4133 = (self.n4123 + self.n4132) & 0xFFL
    self.n4107 = (self.n4097 - self.n4106) & 0xFFL
    self.n4088 = (self.n4086 & 0x80L) | (self.n4086 & 0x40L) | (self.n4086 & 0x20L) | (self.n4086 & 0x10L) | (self.n4086 & 0x8L) | (self.n4086 & 0x4L) | (self.n4086 & 0x2L) | (self.n4086 & 0x1L)
    self.n4087 = ((self.n4086 & 0x8000L) >> 8) | ((self.n4086 & 0x4000L) >> 8) | ((self.n4086 & 0x2000L) >> 8) | ((self.n4086 & 0x1000L) >> 8) | ((self.n4086 & 0x800L) >> 8) | ((self.n4086 & 0x400L) >> 8) | ((self.n4086 & 0x200L) >> 8) | ((self.n4086 & 0x100L) >> 8)
    self.n4053 = (self.n4051 & 0x80L) | (self.n4051 & 0x40L) | (self.n4051 & 0x20L) | (self.n4051 & 0x10L) | (self.n4051 & 0x8L) | (self.n4051 & 0x4L) | (self.n4051 & 0x2L) | (self.n4051 & 0x1L)
    self.n4052 = ((self.n4051 & 0x8000L) >> 8) | ((self.n4051 & 0x4000L) >> 8) | ((self.n4051 & 0x2000L) >> 8) | ((self.n4051 & 0x1000L) >> 8) | ((self.n4051 & 0x800L) >> 8) | ((self.n4051 & 0x400L) >> 8) | ((self.n4051 & 0x200L) >> 8) | ((self.n4051 & 0x100L) >> 8)
    self.n4044 = (self.n4042 & 0x80L) | (self.n4042 & 0x40L) | (self.n4042 & 0x20L) | (self.n4042 & 0x10L) | (self.n4042 & 0x8L) | (self.n4042 & 0x4L) | (self.n4042 & 0x2L) | (self.n4042 & 0x1L)
    self.n4043 = ((self.n4042 & 0x8000L) >> 8) | ((self.n4042 & 0x4000L) >> 8) | ((self.n4042 & 0x2000L) >> 8) | ((self.n4042 & 0x1000L) >> 8) | ((self.n4042 & 0x800L) >> 8) | ((self.n4042 & 0x400L) >> 8) | ((self.n4042 & 0x200L) >> 8) | ((self.n4042 & 0x100L) >> 8)
    self.n4035 = ((self.n3957 & 0x400L) >> 4) | ((self.n3957 & 0x200L) >> 4) | ((self.n3957 & 0x100L) >> 4) | ((self.n3957 & 0x80L) >> 4) | ((self.n3957 & 0x40L) >> 4) | ((self.n3957 & 0x20L) >> 4) | ((self.n3957 & 0x10L) >> 4)
    self.n3989 = 0x3L
    self.n3988 = 0x1L
    self.n3987 = 0x6L
    self.n3986 = 0x4L
    self.n3985 = 0x2L
    self.n3984 = 0x0L
    self.n3983 = 0x0L
    self.n3982 = 0x0L
    self.n3981 = 0x1L
    self.n3980 = 0x1L
    self.n3979 = 0x1L
    self.n3978 = 0x0L
    self.n3974 = 0x3L
    self.n3973 = 0x1L
    self.n3972 = 0x6L
    self.n3971 = 0x4L
    self.n3970 = 0x2L
    self.n3969 = 0x0L
    self.n3968 = 0x0L
    self.n3967 = 0x0L
    self.n3966 = 0x1L
    self.n3965 = 0x1L
    self.n3964 = 0x1L
    self.n3963 = 0x0L
    self.n3958 = 0x7FFL
    self.n3949 = 0x001L
    self.n3903 = 0x6L
    self.n3902 = 0x4L
    self.n3901 = 0x2L
    self.n3900 = 0x0L
    self.n3899 = 0x0L
    self.n3898 = 0x0L
    self.n3897 = 0x0L
    self.n3896 = 0x0L
    self.n3891 = 0x5L
    self.n3890 = 0x3L
    self.n3889 = 0x1L
    self.n3888 = 0x6L
    self.n3887 = 0x4L
    self.n3886 = 0x2L
    self.n3885 = 0x0L
    self.n3884 = 0x0L
    self.n3883 = 0x0L
    self.n3882 = 0x1L
    self.n3881 = 0x0L
    self.n3880 = 0x1L
    self.n3879 = 0x0L
    self.n3878 = 0x1L
    self.n3877 = 0x0L
    if self.n3874:
      self.n3875 = self.n3867
    else:
      self.n3875 = self.n3861
    self.n3828 = self.n3670 << 1 | self.n3839
    self.n3824 = 0x2L
    self.n3823 = 0x0L
    self.n3822 = 0x0L
    self.n3821 = 0x0L
    self.n3818 = 0x1L
    self.n3817 = 0x2L
    self.n3816 = 0x0L
    self.n3815 = 0x0L
    self.n3814 = 0x1L
    self.n3813 = 0x1L
    self.n3812 = 0x0L
    self.n3803 = 0x001L
    if self.n3801:
      self.n3802 = self.n3794
    else:
      self.n3802 = self.n3788
    self.n3781 = 0x000L
    self.n3755 = self.n3670 << 1 | self.n3766
    self.n3751 = 0x2L
    self.n3750 = 0x0L
    self.n3749 = 0x0L
    self.n3748 = 0x0L
    self.n3745 = 0x1L
    self.n3744 = 0x2L
    self.n3743 = 0x0L
    self.n3742 = 0x0L
    self.n3741 = 0x1L
    self.n3740 = 0x1L
    self.n3739 = 0x0L
    self.n3730 = 0x001L
    self.n3729 = ~self.n3728 & 0x1L
    self.n3700 = (self.n3438 & 0x1L)
    self.n3671 = ((self.n3438 & 0x400L) >> 1) | ((self.n3438 & 0x200L) >> 1) | ((self.n3438 & 0x100L) >> 1) | ((self.n3438 & 0x80L) >> 1) | ((self.n3438 & 0x40L) >> 1) | ((self.n3438 & 0x20L) >> 1) | ((self.n3438 & 0x10L) >> 1) | ((self.n3438 & 0x8L) >> 1) | ((self.n3438 & 0x4L) >> 1) | ((self.n3438 & 0x2L) >> 1)
    self.n3642 = self.n3631 << 16 | self.n3641
    self.n3633 = (self.n3562 - self.n3621) & 0xFFL
    self.n3632 = (self.n3548 - self.n3595) & 0xFFL
    self.n3623 = (self.n3562 + self.n3621) & 0xFFL
    self.n3622 = (self.n3548 + self.n3595) & 0xFFL
    self.n3614 = (self.n3604 + self.n3613) & 0xFFL
    self.n3588 = (self.n3578 - self.n3587) & 0xFFL
    self.n3569 = (self.n3567 & 0x80L) | (self.n3567 & 0x40L) | (self.n3567 & 0x20L) | (self.n3567 & 0x10L) | (self.n3567 & 0x8L) | (self.n3567 & 0x4L) | (self.n3567 & 0x2L) | (self.n3567 & 0x1L)
    self.n3568 = ((self.n3567 & 0x8000L) >> 8) | ((self.n3567 & 0x4000L) >> 8) | ((self.n3567 & 0x2000L) >> 8) | ((self.n3567 & 0x1000L) >> 8) | ((self.n3567 & 0x800L) >> 8) | ((self.n3567 & 0x400L) >> 8) | ((self.n3567 & 0x200L) >> 8) | ((self.n3567 & 0x100L) >> 8)
    self.n3534 = (self.n3532 & 0x80L) | (self.n3532 & 0x40L) | (self.n3532 & 0x20L) | (self.n3532 & 0x10L) | (self.n3532 & 0x8L) | (self.n3532 & 0x4L) | (self.n3532 & 0x2L) | (self.n3532 & 0x1L)
    self.n3533 = ((self.n3532 & 0x8000L) >> 8) | ((self.n3532 & 0x4000L) >> 8) | ((self.n3532 & 0x2000L) >> 8) | ((self.n3532 & 0x1000L) >> 8) | ((self.n3532 & 0x800L) >> 8) | ((self.n3532 & 0x400L) >> 8) | ((self.n3532 & 0x200L) >> 8) | ((self.n3532 & 0x100L) >> 8)
    self.n3525 = (self.n3523 & 0x80L) | (self.n3523 & 0x40L) | (self.n3523 & 0x20L) | (self.n3523 & 0x10L) | (self.n3523 & 0x8L) | (self.n3523 & 0x4L) | (self.n3523 & 0x2L) | (self.n3523 & 0x1L)
    self.n3524 = ((self.n3523 & 0x8000L) >> 8) | ((self.n3523 & 0x4000L) >> 8) | ((self.n3523 & 0x2000L) >> 8) | ((self.n3523 & 0x1000L) >> 8) | ((self.n3523 & 0x800L) >> 8) | ((self.n3523 & 0x400L) >> 8) | ((self.n3523 & 0x200L) >> 8) | ((self.n3523 & 0x100L) >> 8)
    self.n3516 = ((self.n3438 & 0x400L) >> 5) | ((self.n3438 & 0x200L) >> 5) | ((self.n3438 & 0x100L) >> 5) | ((self.n3438 & 0x80L) >> 5) | ((self.n3438 & 0x40L) >> 5) | ((self.n3438 & 0x20L) >> 5)
    self.n3470 = 0x3L
    self.n3469 = 0x1L
    self.n3468 = 0x6L
    self.n3467 = 0x4L
    self.n3466 = 0x2L
    self.n3465 = 0x0L
    self.n3464 = 0x0L
    self.n3463 = 0x0L
    self.n3462 = 0x1L
    self.n3461 = 0x1L
    self.n3460 = 0x1L
    self.n3459 = 0x0L
    self.n3455 = 0x3L
    self.n3454 = 0x1L
    self.n3453 = 0x6L
    self.n3452 = 0x4L
    self.n3451 = 0x2L
    self.n3450 = 0x0L
    self.n3449 = 0x0L
    self.n3448 = 0x0L
    self.n3447 = 0x1L
    self.n3446 = 0x1L
    self.n3445 = 0x1L
    self.n3444 = 0x0L
    self.n3439 = 0x7FFL
    self.n3430 = 0x001L
    self.n3384 = 0x6L
    self.n3383 = 0x4L
    self.n3382 = 0x2L
    self.n3381 = 0x0L
    self.n3380 = 0x0L
    self.n3379 = 0x0L
    self.n3378 = 0x0L
    self.n3377 = 0x0L
    self.n3372 = 0x5L
    self.n3371 = 0x3L
    self.n3370 = 0x1L
    self.n3369 = 0x6L
    self.n3368 = 0x4L
    self.n3367 = 0x2L
    self.n3366 = 0x0L
    self.n3365 = 0x0L
    self.n3364 = 0x0L
    self.n3363 = 0x1L
    self.n3362 = 0x0L
    self.n3361 = 0x1L
    self.n3360 = 0x0L
    self.n3359 = 0x1L
    self.n3358 = 0x0L
    if self.n3355:
      self.n3356 = self.n3348
    else:
      self.n3356 = self.n3342
    self.n3309 = self.n3151 << 1 | self.n3320
    self.n3305 = 0x2L
    self.n3304 = 0x0L
    self.n3303 = 0x0L
    self.n3302 = 0x0L
    self.n3299 = 0x1L
    self.n3298 = 0x2L
    self.n3297 = 0x0L
    self.n3296 = 0x0L
    self.n3295 = 0x1L
    self.n3294 = 0x1L
    self.n3293 = 0x0L
    self.n3284 = 0x001L
    if self.n3282:
      self.n3283 = self.n3275
    else:
      self.n3283 = self.n3269
    self.n3262 = 0x000L
    self.n3236 = self.n3151 << 1 | self.n3247
    self.n3232 = 0x2L
    self.n3231 = 0x0L
    self.n3230 = 0x0L
    self.n3229 = 0x0L
    self.n3226 = 0x1L
    self.n3225 = 0x2L
    self.n3224 = 0x0L
    self.n3223 = 0x0L
    self.n3222 = 0x1L
    self.n3221 = 0x1L
    self.n3220 = 0x0L
    self.n3211 = 0x001L
    self.n3210 = ~self.n3209 & 0x1L
    self.n3181 = (self.n2919 & 0x1L)
    self.n3152 = ((self.n2919 & 0x400L) >> 1) | ((self.n2919 & 0x200L) >> 1) | ((self.n2919 & 0x100L) >> 1) | ((self.n2919 & 0x80L) >> 1) | ((self.n2919 & 0x40L) >> 1) | ((self.n2919 & 0x20L) >> 1) | ((self.n2919 & 0x10L) >> 1) | ((self.n2919 & 0x8L) >> 1) | ((self.n2919 & 0x4L) >> 1) | ((self.n2919 & 0x2L) >> 1)
    self.n3123 = self.n3112 << 16 | self.n3122
    self.n3114 = (self.n3043 - self.n3102) & 0xFFL
    self.n3113 = (self.n3029 - self.n3076) & 0xFFL
    self.n3104 = (self.n3043 + self.n3102) & 0xFFL
    self.n3103 = (self.n3029 + self.n3076) & 0xFFL
    self.n3095 = (self.n3085 + self.n3094) & 0xFFL
    self.n3069 = (self.n3059 - self.n3068) & 0xFFL
    self.n3050 = (self.n3048 & 0x80L) | (self.n3048 & 0x40L) | (self.n3048 & 0x20L) | (self.n3048 & 0x10L) | (self.n3048 & 0x8L) | (self.n3048 & 0x4L) | (self.n3048 & 0x2L) | (self.n3048 & 0x1L)
    self.n3049 = ((self.n3048 & 0x8000L) >> 8) | ((self.n3048 & 0x4000L) >> 8) | ((self.n3048 & 0x2000L) >> 8) | ((self.n3048 & 0x1000L) >> 8) | ((self.n3048 & 0x800L) >> 8) | ((self.n3048 & 0x400L) >> 8) | ((self.n3048 & 0x200L) >> 8) | ((self.n3048 & 0x100L) >> 8)
    self.n3015 = (self.n3013 & 0x80L) | (self.n3013 & 0x40L) | (self.n3013 & 0x20L) | (self.n3013 & 0x10L) | (self.n3013 & 0x8L) | (self.n3013 & 0x4L) | (self.n3013 & 0x2L) | (self.n3013 & 0x1L)
    self.n3014 = ((self.n3013 & 0x8000L) >> 8) | ((self.n3013 & 0x4000L) >> 8) | ((self.n3013 & 0x2000L) >> 8) | ((self.n3013 & 0x1000L) >> 8) | ((self.n3013 & 0x800L) >> 8) | ((self.n3013 & 0x400L) >> 8) | ((self.n3013 & 0x200L) >> 8) | ((self.n3013 & 0x100L) >> 8)
    self.n3006 = (self.n3004 & 0x80L) | (self.n3004 & 0x40L) | (self.n3004 & 0x20L) | (self.n3004 & 0x10L) | (self.n3004 & 0x8L) | (self.n3004 & 0x4L) | (self.n3004 & 0x2L) | (self.n3004 & 0x1L)
    self.n3005 = ((self.n3004 & 0x8000L) >> 8) | ((self.n3004 & 0x4000L) >> 8) | ((self.n3004 & 0x2000L) >> 8) | ((self.n3004 & 0x1000L) >> 8) | ((self.n3004 & 0x800L) >> 8) | ((self.n3004 & 0x400L) >> 8) | ((self.n3004 & 0x200L) >> 8) | ((self.n3004 & 0x100L) >> 8)
    self.n2997 = ((self.n2919 & 0x400L) >> 6) | ((self.n2919 & 0x200L) >> 6) | ((self.n2919 & 0x100L) >> 6) | ((self.n2919 & 0x80L) >> 6) | ((self.n2919 & 0x40L) >> 6)
    self.n2951 = 0x3L
    self.n2950 = 0x1L
    self.n2949 = 0x6L
    self.n2948 = 0x4L
    self.n2947 = 0x2L
    self.n2946 = 0x0L
    self.n2945 = 0x0L
    self.n2944 = 0x0L
    self.n2943 = 0x1L
    self.n2942 = 0x1L
    self.n2941 = 0x1L
    self.n2940 = 0x0L
    self.n2936 = 0x3L
    self.n2935 = 0x1L
    self.n2934 = 0x6L
    self.n2933 = 0x4L
    self.n2932 = 0x2L
    self.n2931 = 0x0L
    self.n2930 = 0x0L
    self.n2929 = 0x0L
    self.n2928 = 0x1L
    self.n2927 = 0x1L
    self.n2926 = 0x1L
    self.n2925 = 0x0L
    self.n2920 = 0x7FFL
    self.n2911 = 0x001L
    self.n2865 = 0x6L
    self.n2864 = 0x4L
    self.n2863 = 0x2L
    self.n2862 = 0x0L
    self.n2861 = 0x0L
    self.n2860 = 0x0L
    self.n2859 = 0x0L
    self.n2858 = 0x0L
    self.n2853 = 0x5L
    self.n2852 = 0x3L
    self.n2851 = 0x1L
    self.n2850 = 0x6L
    self.n2849 = 0x4L
    self.n2848 = 0x2L
    self.n2847 = 0x0L
    self.n2846 = 0x0L
    self.n2845 = 0x0L
    self.n2844 = 0x1L
    self.n2843 = 0x0L
    self.n2842 = 0x1L
    self.n2841 = 0x0L
    self.n2840 = 0x1L
    self.n2839 = 0x0L
    if self.n2836:
      self.n2837 = self.n2829
    else:
      self.n2837 = self.n2823
    self.n2790 = self.n2632 << 1 | self.n2801
    self.n2786 = 0x2L
    self.n2785 = 0x0L
    self.n2784 = 0x0L
    self.n2783 = 0x0L
    self.n2780 = 0x1L
    self.n2779 = 0x2L
    self.n2778 = 0x0L
    self.n2777 = 0x0L
    self.n2776 = 0x1L
    self.n2775 = 0x1L
    self.n2774 = 0x0L
    self.n2765 = 0x001L
    if self.n2763:
      self.n2764 = self.n2756
    else:
      self.n2764 = self.n2750
    self.n2743 = 0x000L
    self.n2717 = self.n2632 << 1 | self.n2728
    self.n2713 = 0x2L
    self.n2712 = 0x0L
    self.n2711 = 0x0L
    self.n2710 = 0x0L
    self.n2707 = 0x1L
    self.n2706 = 0x2L
    self.n2705 = 0x0L
    self.n2704 = 0x0L
    self.n2703 = 0x1L
    self.n2702 = 0x1L
    self.n2701 = 0x0L
    self.n2692 = 0x001L
    self.n2691 = ~self.n2690 & 0x1L
    self.n2662 = (self.n2400 & 0x1L)
    self.n2633 = ((self.n2400 & 0x400L) >> 1) | ((self.n2400 & 0x200L) >> 1) | ((self.n2400 & 0x100L) >> 1) | ((self.n2400 & 0x80L) >> 1) | ((self.n2400 & 0x40L) >> 1) | ((self.n2400 & 0x20L) >> 1) | ((self.n2400 & 0x10L) >> 1) | ((self.n2400 & 0x8L) >> 1) | ((self.n2400 & 0x4L) >> 1) | ((self.n2400 & 0x2L) >> 1)
    self.n2604 = self.n2593 << 16 | self.n2603
    self.n2595 = (self.n2524 - self.n2583) & 0xFFL
    self.n2594 = (self.n2510 - self.n2557) & 0xFFL
    self.n2585 = (self.n2524 + self.n2583) & 0xFFL
    self.n2584 = (self.n2510 + self.n2557) & 0xFFL
    self.n2576 = (self.n2566 + self.n2575) & 0xFFL
    self.n2550 = (self.n2540 - self.n2549) & 0xFFL
    self.n2531 = (self.n2529 & 0x80L) | (self.n2529 & 0x40L) | (self.n2529 & 0x20L) | (self.n2529 & 0x10L) | (self.n2529 & 0x8L) | (self.n2529 & 0x4L) | (self.n2529 & 0x2L) | (self.n2529 & 0x1L)
    self.n2530 = ((self.n2529 & 0x8000L) >> 8) | ((self.n2529 & 0x4000L) >> 8) | ((self.n2529 & 0x2000L) >> 8) | ((self.n2529 & 0x1000L) >> 8) | ((self.n2529 & 0x800L) >> 8) | ((self.n2529 & 0x400L) >> 8) | ((self.n2529 & 0x200L) >> 8) | ((self.n2529 & 0x100L) >> 8)
    self.n2496 = (self.n2494 & 0x80L) | (self.n2494 & 0x40L) | (self.n2494 & 0x20L) | (self.n2494 & 0x10L) | (self.n2494 & 0x8L) | (self.n2494 & 0x4L) | (self.n2494 & 0x2L) | (self.n2494 & 0x1L)
    self.n2495 = ((self.n2494 & 0x8000L) >> 8) | ((self.n2494 & 0x4000L) >> 8) | ((self.n2494 & 0x2000L) >> 8) | ((self.n2494 & 0x1000L) >> 8) | ((self.n2494 & 0x800L) >> 8) | ((self.n2494 & 0x400L) >> 8) | ((self.n2494 & 0x200L) >> 8) | ((self.n2494 & 0x100L) >> 8)
    self.n2487 = (self.n2485 & 0x80L) | (self.n2485 & 0x40L) | (self.n2485 & 0x20L) | (self.n2485 & 0x10L) | (self.n2485 & 0x8L) | (self.n2485 & 0x4L) | (self.n2485 & 0x2L) | (self.n2485 & 0x1L)
    self.n2486 = ((self.n2485 & 0x8000L) >> 8) | ((self.n2485 & 0x4000L) >> 8) | ((self.n2485 & 0x2000L) >> 8) | ((self.n2485 & 0x1000L) >> 8) | ((self.n2485 & 0x800L) >> 8) | ((self.n2485 & 0x400L) >> 8) | ((self.n2485 & 0x200L) >> 8) | ((self.n2485 & 0x100L) >> 8)
    self.n2478 = ((self.n2400 & 0x400L) >> 7) | ((self.n2400 & 0x200L) >> 7) | ((self.n2400 & 0x100L) >> 7) | ((self.n2400 & 0x80L) >> 7)
    self.n2432 = 0x3L
    self.n2431 = 0x1L
    self.n2430 = 0x6L
    self.n2429 = 0x4L
    self.n2428 = 0x2L
    self.n2427 = 0x0L
    self.n2426 = 0x0L
    self.n2425 = 0x0L
    self.n2424 = 0x1L
    self.n2423 = 0x1L
    self.n2422 = 0x1L
    self.n2421 = 0x0L
    self.n2417 = 0x3L
    self.n2416 = 0x1L
    self.n2415 = 0x6L
    self.n2414 = 0x4L
    self.n2413 = 0x2L
    self.n2412 = 0x0L
    self.n2411 = 0x0L
    self.n2410 = 0x0L
    self.n2409 = 0x1L
    self.n2408 = 0x1L
    self.n2407 = 0x1L
    self.n2406 = 0x0L
    self.n2401 = 0x7FFL
    self.n2392 = 0x001L
    self.n2346 = 0x6L
    self.n2345 = 0x4L
    self.n2344 = 0x2L
    self.n2343 = 0x0L
    self.n2342 = 0x0L
    self.n2341 = 0x0L
    self.n2340 = 0x0L
    self.n2339 = 0x0L
    self.n2334 = 0x5L
    self.n2333 = 0x3L
    self.n2332 = 0x1L
    self.n2331 = 0x6L
    self.n2330 = 0x4L
    self.n2329 = 0x2L
    self.n2328 = 0x0L
    self.n2327 = 0x0L
    self.n2326 = 0x0L
    self.n2325 = 0x1L
    self.n2324 = 0x0L
    self.n2323 = 0x1L
    self.n2322 = 0x0L
    self.n2321 = 0x1L
    self.n2320 = 0x0L
    if self.n2317:
      self.n2318 = self.n2310
    else:
      self.n2318 = self.n2304
    self.n2271 = self.n2113 << 1 | self.n2282
    self.n2267 = 0x2L
    self.n2266 = 0x0L
    self.n2265 = 0x0L
    self.n2264 = 0x0L
    self.n2261 = 0x1L
    self.n2260 = 0x2L
    self.n2259 = 0x0L
    self.n2258 = 0x0L
    self.n2257 = 0x1L
    self.n2256 = 0x1L
    self.n2255 = 0x0L
    self.n2246 = 0x001L
    if self.n2244:
      self.n2245 = self.n2237
    else:
      self.n2245 = self.n2231
    self.n2224 = 0x000L
    self.n2198 = self.n2113 << 1 | self.n2209
    self.n2194 = 0x2L
    self.n2193 = 0x0L
    self.n2192 = 0x0L
    self.n2191 = 0x0L
    self.n2188 = 0x1L
    self.n2187 = 0x2L
    self.n2186 = 0x0L
    self.n2185 = 0x0L
    self.n2184 = 0x1L
    self.n2183 = 0x1L
    self.n2182 = 0x0L
    self.n2173 = 0x001L
    self.n2172 = ~self.n2171 & 0x1L
    self.n2143 = (self.n1881 & 0x1L)
    self.n2114 = ((self.n1881 & 0x400L) >> 1) | ((self.n1881 & 0x200L) >> 1) | ((self.n1881 & 0x100L) >> 1) | ((self.n1881 & 0x80L) >> 1) | ((self.n1881 & 0x40L) >> 1) | ((self.n1881 & 0x20L) >> 1) | ((self.n1881 & 0x10L) >> 1) | ((self.n1881 & 0x8L) >> 1) | ((self.n1881 & 0x4L) >> 1) | ((self.n1881 & 0x2L) >> 1)
    self.n2085 = self.n2074 << 16 | self.n2084
    self.n2076 = (self.n2005 - self.n2064) & 0xFFL
    self.n2075 = (self.n1991 - self.n2038) & 0xFFL
    self.n2066 = (self.n2005 + self.n2064) & 0xFFL
    self.n2065 = (self.n1991 + self.n2038) & 0xFFL
    self.n2057 = (self.n2047 + self.n2056) & 0xFFL
    self.n2031 = (self.n2021 - self.n2030) & 0xFFL
    self.n2012 = (self.n2010 & 0x80L) | (self.n2010 & 0x40L) | (self.n2010 & 0x20L) | (self.n2010 & 0x10L) | (self.n2010 & 0x8L) | (self.n2010 & 0x4L) | (self.n2010 & 0x2L) | (self.n2010 & 0x1L)
    self.n2011 = ((self.n2010 & 0x8000L) >> 8) | ((self.n2010 & 0x4000L) >> 8) | ((self.n2010 & 0x2000L) >> 8) | ((self.n2010 & 0x1000L) >> 8) | ((self.n2010 & 0x800L) >> 8) | ((self.n2010 & 0x400L) >> 8) | ((self.n2010 & 0x200L) >> 8) | ((self.n2010 & 0x100L) >> 8)
    self.n1977 = (self.n1975 & 0x80L) | (self.n1975 & 0x40L) | (self.n1975 & 0x20L) | (self.n1975 & 0x10L) | (self.n1975 & 0x8L) | (self.n1975 & 0x4L) | (self.n1975 & 0x2L) | (self.n1975 & 0x1L)
    self.n1976 = ((self.n1975 & 0x8000L) >> 8) | ((self.n1975 & 0x4000L) >> 8) | ((self.n1975 & 0x2000L) >> 8) | ((self.n1975 & 0x1000L) >> 8) | ((self.n1975 & 0x800L) >> 8) | ((self.n1975 & 0x400L) >> 8) | ((self.n1975 & 0x200L) >> 8) | ((self.n1975 & 0x100L) >> 8)
    self.n1968 = (self.n1966 & 0x80L) | (self.n1966 & 0x40L) | (self.n1966 & 0x20L) | (self.n1966 & 0x10L) | (self.n1966 & 0x8L) | (self.n1966 & 0x4L) | (self.n1966 & 0x2L) | (self.n1966 & 0x1L)
    self.n1967 = ((self.n1966 & 0x8000L) >> 8) | ((self.n1966 & 0x4000L) >> 8) | ((self.n1966 & 0x2000L) >> 8) | ((self.n1966 & 0x1000L) >> 8) | ((self.n1966 & 0x800L) >> 8) | ((self.n1966 & 0x400L) >> 8) | ((self.n1966 & 0x200L) >> 8) | ((self.n1966 & 0x100L) >> 8)
    self.n1959 = ((self.n1881 & 0x400L) >> 8) | ((self.n1881 & 0x200L) >> 8) | ((self.n1881 & 0x100L) >> 8)
    self.n1913 = 0x3L
    self.n1912 = 0x1L
    self.n1911 = 0x6L
    self.n1910 = 0x4L
    self.n1909 = 0x2L
    self.n1908 = 0x0L
    self.n1907 = 0x0L
    self.n1906 = 0x0L
    self.n1905 = 0x1L
    self.n1904 = 0x1L
    self.n1903 = 0x1L
    self.n1902 = 0x0L
    self.n1898 = 0x3L
    self.n1897 = 0x1L
    self.n1896 = 0x6L
    self.n1895 = 0x4L
    self.n1894 = 0x2L
    self.n1893 = 0x0L
    self.n1892 = 0x0L
    self.n1891 = 0x0L
    self.n1890 = 0x1L
    self.n1889 = 0x1L
    self.n1888 = 0x1L
    self.n1887 = 0x0L
    self.n1882 = 0x7FFL
    self.n1873 = 0x001L
    self.n1827 = 0x6L
    self.n1826 = 0x4L
    self.n1825 = 0x2L
    self.n1824 = 0x0L
    self.n1823 = 0x0L
    self.n1822 = 0x0L
    self.n1821 = 0x0L
    self.n1820 = 0x0L
    self.n1815 = 0x5L
    self.n1814 = 0x3L
    self.n1813 = 0x1L
    self.n1812 = 0x6L
    self.n1811 = 0x4L
    self.n1810 = 0x2L
    self.n1809 = 0x0L
    self.n1808 = 0x0L
    self.n1807 = 0x0L
    self.n1806 = 0x1L
    self.n1805 = 0x0L
    self.n1804 = 0x1L
    self.n1803 = 0x0L
    self.n1802 = 0x1L
    self.n1801 = 0x0L
    if self.n1798:
      self.n1799 = self.n1791
    else:
      self.n1799 = self.n1785
    self.n1752 = self.n1594 << 1 | self.n1763
    self.n1748 = 0x2L
    self.n1747 = 0x0L
    self.n1746 = 0x0L
    self.n1745 = 0x0L
    self.n1742 = 0x1L
    self.n1741 = 0x2L
    self.n1740 = 0x0L
    self.n1739 = 0x0L
    self.n1738 = 0x1L
    self.n1737 = 0x1L
    self.n1736 = 0x0L
    self.n1727 = 0x001L
    if self.n1725:
      self.n1726 = self.n1718
    else:
      self.n1726 = self.n1712
    self.n1705 = 0x000L
    self.n1679 = self.n1594 << 1 | self.n1690
    self.n1675 = 0x2L
    self.n1674 = 0x0L
    self.n1673 = 0x0L
    self.n1672 = 0x0L
    self.n1669 = 0x1L
    self.n1668 = 0x2L
    self.n1667 = 0x0L
    self.n1666 = 0x0L
    self.n1665 = 0x1L
    self.n1664 = 0x1L
    self.n1663 = 0x0L
    self.n1654 = 0x001L
    self.n1653 = ~self.n1652 & 0x1L
    self.n1624 = (self.n1362 & 0x1L)
    self.n1595 = ((self.n1362 & 0x400L) >> 1) | ((self.n1362 & 0x200L) >> 1) | ((self.n1362 & 0x100L) >> 1) | ((self.n1362 & 0x80L) >> 1) | ((self.n1362 & 0x40L) >> 1) | ((self.n1362 & 0x20L) >> 1) | ((self.n1362 & 0x10L) >> 1) | ((self.n1362 & 0x8L) >> 1) | ((self.n1362 & 0x4L) >> 1) | ((self.n1362 & 0x2L) >> 1)
    self.n1566 = self.n1555 << 16 | self.n1565
    self.n1557 = (self.n1486 - self.n1545) & 0xFFL
    self.n1556 = (self.n1472 - self.n1519) & 0xFFL
    self.n1547 = (self.n1486 + self.n1545) & 0xFFL
    self.n1546 = (self.n1472 + self.n1519) & 0xFFL
    self.n1538 = (self.n1528 + self.n1537) & 0xFFL
    self.n1512 = (self.n1502 - self.n1511) & 0xFFL
    self.n1493 = (self.n1491 & 0x80L) | (self.n1491 & 0x40L) | (self.n1491 & 0x20L) | (self.n1491 & 0x10L) | (self.n1491 & 0x8L) | (self.n1491 & 0x4L) | (self.n1491 & 0x2L) | (self.n1491 & 0x1L)
    self.n1492 = ((self.n1491 & 0x8000L) >> 8) | ((self.n1491 & 0x4000L) >> 8) | ((self.n1491 & 0x2000L) >> 8) | ((self.n1491 & 0x1000L) >> 8) | ((self.n1491 & 0x800L) >> 8) | ((self.n1491 & 0x400L) >> 8) | ((self.n1491 & 0x200L) >> 8) | ((self.n1491 & 0x100L) >> 8)
    self.n1458 = (self.n1456 & 0x80L) | (self.n1456 & 0x40L) | (self.n1456 & 0x20L) | (self.n1456 & 0x10L) | (self.n1456 & 0x8L) | (self.n1456 & 0x4L) | (self.n1456 & 0x2L) | (self.n1456 & 0x1L)
    self.n1457 = ((self.n1456 & 0x8000L) >> 8) | ((self.n1456 & 0x4000L) >> 8) | ((self.n1456 & 0x2000L) >> 8) | ((self.n1456 & 0x1000L) >> 8) | ((self.n1456 & 0x800L) >> 8) | ((self.n1456 & 0x400L) >> 8) | ((self.n1456 & 0x200L) >> 8) | ((self.n1456 & 0x100L) >> 8)
    self.n1449 = (self.n1447 & 0x80L) | (self.n1447 & 0x40L) | (self.n1447 & 0x20L) | (self.n1447 & 0x10L) | (self.n1447 & 0x8L) | (self.n1447 & 0x4L) | (self.n1447 & 0x2L) | (self.n1447 & 0x1L)
    self.n1448 = ((self.n1447 & 0x8000L) >> 8) | ((self.n1447 & 0x4000L) >> 8) | ((self.n1447 & 0x2000L) >> 8) | ((self.n1447 & 0x1000L) >> 8) | ((self.n1447 & 0x800L) >> 8) | ((self.n1447 & 0x400L) >> 8) | ((self.n1447 & 0x200L) >> 8) | ((self.n1447 & 0x100L) >> 8)
    self.n1440 = ((self.n1362 & 0x400L) >> 9) | ((self.n1362 & 0x200L) >> 9)
    self.n1394 = 0x3L
    self.n1393 = 0x1L
    self.n1392 = 0x6L
    self.n1391 = 0x4L
    self.n1390 = 0x2L
    self.n1389 = 0x0L
    self.n1388 = 0x0L
    self.n1387 = 0x0L
    self.n1386 = 0x1L
    self.n1385 = 0x1L
    self.n1384 = 0x1L
    self.n1383 = 0x0L
    self.n1379 = 0x3L
    self.n1378 = 0x1L
    self.n1377 = 0x6L
    self.n1376 = 0x4L
    self.n1375 = 0x2L
    self.n1374 = 0x0L
    self.n1373 = 0x0L
    self.n1372 = 0x0L
    self.n1371 = 0x1L
    self.n1370 = 0x1L
    self.n1369 = 0x1L
    self.n1368 = 0x0L
    self.n1363 = 0x7FFL
    self.n1354 = 0x001L
    self.n1308 = 0x6L
    self.n1307 = 0x4L
    self.n1306 = 0x2L
    self.n1305 = 0x0L
    self.n1304 = 0x0L
    self.n1303 = 0x0L
    self.n1302 = 0x0L
    self.n1301 = 0x0L
    self.n1296 = 0x5L
    self.n1295 = 0x3L
    self.n1294 = 0x1L
    self.n1293 = 0x6L
    self.n1292 = 0x4L
    self.n1291 = 0x2L
    self.n1290 = 0x0L
    self.n1289 = 0x0L
    self.n1288 = 0x0L
    self.n1287 = 0x1L
    self.n1286 = 0x0L
    self.n1285 = 0x1L
    self.n1284 = 0x0L
    self.n1283 = 0x1L
    self.n1282 = 0x0L
    if self.n1279:
      self.n1280 = self.n1272
    else:
      self.n1280 = self.n1266
    self.n1233 = self.n1075 << 1 | self.n1244
    self.n1229 = 0x2L
    self.n1228 = 0x0L
    self.n1227 = 0x0L
    self.n1226 = 0x0L
    self.n1223 = 0x1L
    self.n1222 = 0x2L
    self.n1221 = 0x0L
    self.n1220 = 0x0L
    self.n1219 = 0x1L
    self.n1218 = 0x1L
    self.n1217 = 0x0L
    self.n1208 = 0x001L
    if self.n1206:
      self.n1207 = self.n1199
    else:
      self.n1207 = self.n1193
    self.n1186 = 0x000L
    self.n1160 = self.n1075 << 1 | self.n1171
    self.n1156 = 0x2L
    self.n1155 = 0x0L
    self.n1154 = 0x0L
    self.n1153 = 0x0L
    self.n1150 = 0x1L
    self.n1149 = 0x2L
    self.n1148 = 0x0L
    self.n1147 = 0x0L
    self.n1146 = 0x1L
    self.n1145 = 0x1L
    self.n1144 = 0x0L
    self.n1135 = 0x001L
    self.n1134 = ~self.n1133 & 0x1L
    self.n1105 = (self.n843 & 0x1L)
    self.n1076 = ((self.n843 & 0x400L) >> 1) | ((self.n843 & 0x200L) >> 1) | ((self.n843 & 0x100L) >> 1) | ((self.n843 & 0x80L) >> 1) | ((self.n843 & 0x40L) >> 1) | ((self.n843 & 0x20L) >> 1) | ((self.n843 & 0x10L) >> 1) | ((self.n843 & 0x8L) >> 1) | ((self.n843 & 0x4L) >> 1) | ((self.n843 & 0x2L) >> 1)
    self.n1047 = self.n1036 << 16 | self.n1046
    self.n1038 = (self.n967 - self.n1026) & 0xFFL
    self.n1037 = (self.n953 - self.n1000) & 0xFFL
    self.n1028 = (self.n967 + self.n1026) & 0xFFL
    self.n1027 = (self.n953 + self.n1000) & 0xFFL
    self.n1019 = (self.n1009 + self.n1018) & 0xFFL
    self.n993 = (self.n983 - self.n992) & 0xFFL
    self.n974 = (self.n972 & 0x80L) | (self.n972 & 0x40L) | (self.n972 & 0x20L) | (self.n972 & 0x10L) | (self.n972 & 0x8L) | (self.n972 & 0x4L) | (self.n972 & 0x2L) | (self.n972 & 0x1L)
    self.n973 = ((self.n972 & 0x8000L) >> 8) | ((self.n972 & 0x4000L) >> 8) | ((self.n972 & 0x2000L) >> 8) | ((self.n972 & 0x1000L) >> 8) | ((self.n972 & 0x800L) >> 8) | ((self.n972 & 0x400L) >> 8) | ((self.n972 & 0x200L) >> 8) | ((self.n972 & 0x100L) >> 8)
    self.n939 = (self.n937 & 0x80L) | (self.n937 & 0x40L) | (self.n937 & 0x20L) | (self.n937 & 0x10L) | (self.n937 & 0x8L) | (self.n937 & 0x4L) | (self.n937 & 0x2L) | (self.n937 & 0x1L)
    self.n938 = ((self.n937 & 0x8000L) >> 8) | ((self.n937 & 0x4000L) >> 8) | ((self.n937 & 0x2000L) >> 8) | ((self.n937 & 0x1000L) >> 8) | ((self.n937 & 0x800L) >> 8) | ((self.n937 & 0x400L) >> 8) | ((self.n937 & 0x200L) >> 8) | ((self.n937 & 0x100L) >> 8)
    self.n930 = (self.n928 & 0x80L) | (self.n928 & 0x40L) | (self.n928 & 0x20L) | (self.n928 & 0x10L) | (self.n928 & 0x8L) | (self.n928 & 0x4L) | (self.n928 & 0x2L) | (self.n928 & 0x1L)
    self.n929 = ((self.n928 & 0x8000L) >> 8) | ((self.n928 & 0x4000L) >> 8) | ((self.n928 & 0x2000L) >> 8) | ((self.n928 & 0x1000L) >> 8) | ((self.n928 & 0x800L) >> 8) | ((self.n928 & 0x400L) >> 8) | ((self.n928 & 0x200L) >> 8) | ((self.n928 & 0x100L) >> 8)
    self.n921 = ((self.n843 & 0x400L) >> 10)
    self.n875 = 0x3L
    self.n874 = 0x1L
    self.n873 = 0x6L
    self.n872 = 0x4L
    self.n871 = 0x2L
    self.n870 = 0x0L
    self.n869 = 0x0L
    self.n868 = 0x0L
    self.n867 = 0x1L
    self.n866 = 0x1L
    self.n865 = 0x1L
    self.n864 = 0x0L
    self.n860 = 0x3L
    self.n859 = 0x1L
    self.n858 = 0x6L
    self.n857 = 0x4L
    self.n856 = 0x2L
    self.n855 = 0x0L
    self.n854 = 0x0L
    self.n853 = 0x0L
    self.n852 = 0x1L
    self.n851 = 0x1L
    self.n850 = 0x1L
    self.n849 = 0x0L
    self.n844 = 0x7FFL
    self.n835 = 0x001L
    self.n789 = 0x6L
    self.n788 = 0x4L
    self.n787 = 0x2L
    self.n786 = 0x0L
    self.n785 = 0x0L
    self.n784 = 0x0L
    self.n783 = 0x0L
    self.n782 = 0x0L
    self.n777 = 0x5L
    self.n776 = 0x3L
    self.n775 = 0x1L
    self.n774 = 0x6L
    self.n773 = 0x4L
    self.n772 = 0x2L
    self.n771 = 0x0L
    self.n770 = 0x0L
    self.n769 = 0x0L
    self.n768 = 0x1L
    self.n767 = 0x0L
    self.n766 = 0x1L
    self.n765 = 0x0L
    self.n764 = 0x1L
    self.n763 = 0x0L
    if self.n760:
      self.n761 = self.n753
    else:
      self.n761 = self.n747
    self.n714 = self.n556 << 1 | self.n725
    self.n710 = 0x2L
    self.n709 = 0x0L
    self.n708 = 0x0L
    self.n707 = 0x0L
    self.n704 = 0x1L
    self.n703 = 0x2L
    self.n702 = 0x0L
    self.n701 = 0x0L
    self.n700 = 0x1L
    self.n699 = 0x1L
    self.n698 = 0x0L
    self.n689 = 0x001L
    if self.n687:
      self.n688 = self.n680
    else:
      self.n688 = self.n674
    self.n667 = 0x000L
    self.n641 = self.n556 << 1 | self.n652
    self.n637 = 0x2L
    self.n636 = 0x0L
    self.n635 = 0x0L
    self.n634 = 0x0L
    self.n631 = 0x1L
    self.n630 = 0x2L
    self.n629 = 0x0L
    self.n628 = 0x0L
    self.n627 = 0x1L
    self.n626 = 0x1L
    self.n625 = 0x0L
    self.n616 = 0x001L
    self.n615 = ~self.n614 & 0x1L
    self.n586 = (self.n324 & 0x1L)
    self.n557 = ((self.n324 & 0x400L) >> 1) | ((self.n324 & 0x200L) >> 1) | ((self.n324 & 0x100L) >> 1) | ((self.n324 & 0x80L) >> 1) | ((self.n324 & 0x40L) >> 1) | ((self.n324 & 0x20L) >> 1) | ((self.n324 & 0x10L) >> 1) | ((self.n324 & 0x8L) >> 1) | ((self.n324 & 0x4L) >> 1) | ((self.n324 & 0x2L) >> 1)
    self.n528 = self.n517 << 16 | self.n527
    self.n519 = (self.n448 - self.n507) & 0xFFL
    self.n518 = (self.n434 - self.n481) & 0xFFL
    self.n509 = (self.n448 + self.n507) & 0xFFL
    self.n508 = (self.n434 + self.n481) & 0xFFL
    self.n500 = (self.n490 + self.n499) & 0xFFL
    self.n474 = (self.n464 - self.n473) & 0xFFL
    self.n455 = (self.n453 & 0x80L) | (self.n453 & 0x40L) | (self.n453 & 0x20L) | (self.n453 & 0x10L) | (self.n453 & 0x8L) | (self.n453 & 0x4L) | (self.n453 & 0x2L) | (self.n453 & 0x1L)
    self.n454 = ((self.n453 & 0x8000L) >> 8) | ((self.n453 & 0x4000L) >> 8) | ((self.n453 & 0x2000L) >> 8) | ((self.n453 & 0x1000L) >> 8) | ((self.n453 & 0x800L) >> 8) | ((self.n453 & 0x400L) >> 8) | ((self.n453 & 0x200L) >> 8) | ((self.n453 & 0x100L) >> 8)
    self.n420 = (self.n418 & 0x80L) | (self.n418 & 0x40L) | (self.n418 & 0x20L) | (self.n418 & 0x10L) | (self.n418 & 0x8L) | (self.n418 & 0x4L) | (self.n418 & 0x2L) | (self.n418 & 0x1L)
    self.n419 = ((self.n418 & 0x8000L) >> 8) | ((self.n418 & 0x4000L) >> 8) | ((self.n418 & 0x2000L) >> 8) | ((self.n418 & 0x1000L) >> 8) | ((self.n418 & 0x800L) >> 8) | ((self.n418 & 0x400L) >> 8) | ((self.n418 & 0x200L) >> 8) | ((self.n418 & 0x100L) >> 8)
    self.n411 = (self.n409 & 0x80L) | (self.n409 & 0x40L) | (self.n409 & 0x20L) | (self.n409 & 0x10L) | (self.n409 & 0x8L) | (self.n409 & 0x4L) | (self.n409 & 0x2L) | (self.n409 & 0x1L)
    self.n410 = ((self.n409 & 0x8000L) >> 8) | ((self.n409 & 0x4000L) >> 8) | ((self.n409 & 0x2000L) >> 8) | ((self.n409 & 0x1000L) >> 8) | ((self.n409 & 0x800L) >> 8) | ((self.n409 & 0x400L) >> 8) | ((self.n409 & 0x200L) >> 8) | ((self.n409 & 0x100L) >> 8)
    self.n402 = 0x0L
    self.n356 = 0x3L
    self.n355 = 0x1L
    self.n354 = 0x6L
    self.n353 = 0x4L
    self.n352 = 0x2L
    self.n351 = 0x0L
    self.n350 = 0x0L
    self.n349 = 0x0L
    self.n348 = 0x1L
    self.n347 = 0x1L
    self.n346 = 0x1L
    self.n345 = 0x0L
    self.n341 = 0x3L
    self.n340 = 0x1L
    self.n339 = 0x6L
    self.n338 = 0x4L
    self.n337 = 0x2L
    self.n336 = 0x0L
    self.n335 = 0x0L
    self.n334 = 0x0L
    self.n333 = 0x1L
    self.n332 = 0x1L
    self.n331 = 0x1L
    self.n330 = 0x0L
    self.n325 = 0x7FFL
    self.n316 = 0x001L
    self.n270 = 0x6L
    self.n269 = 0x4L
    self.n268 = 0x2L
    self.n267 = 0x0L
    self.n266 = 0x0L
    self.n265 = 0x0L
    self.n264 = 0x0L
    self.n263 = 0x0L
    self.n258 = 0x5L
    self.n257 = 0x3L
    self.n256 = 0x1L
    self.n255 = 0x6L
    self.n254 = 0x4L
    self.n253 = 0x2L
    self.n252 = 0x0L
    self.n251 = 0x0L
    self.n250 = 0x0L
    self.n249 = 0x1L
    self.n248 = 0x0L
    self.n247 = 0x1L
    self.n246 = 0x0L
    self.n245 = 0x1L
    self.n244 = 0x0L
    if self.n241:
      self.n242 = self.n234
    else:
      self.n242 = self.n228
    self.n191 = 0x2L
    self.n190 = 0x0L
    self.n189 = 0x0L
    self.n188 = 0x0L
    self.n185 = 0x1L
    self.n184 = 0x2L
    self.n183 = 0x0L
    self.n182 = 0x0L
    self.n181 = 0x1L
    self.n180 = 0x1L
    self.n179 = 0x0L
    self.n170 = 0x001L
    if self.n168:
      self.n169 = self.n161
    else:
      self.n169 = self.n155
    self.n148 = 0x000L
    self.n118 = 0x2L
    self.n117 = 0x0L
    self.n116 = 0x0L
    self.n115 = 0x0L
    self.n112 = 0x1L
    self.n111 = 0x2L
    self.n110 = 0x0L
    self.n109 = 0x0L
    self.n108 = 0x1L
    self.n107 = 0x1L
    self.n106 = 0x0L
    self.n97 = 0x001L
    self.n95 = (self.n14 & 0x200L) | (self.n14 & 0x100L) | (self.n14 & 0x80L) | (self.n14 & 0x40L) | (self.n14 & 0x20L) | (self.n14 & 0x10L) | (self.n14 & 0x8L) | (self.n14 & 0x4L) | (self.n14 & 0x2L) | (self.n14 & 0x1L)
    self.n93 = ((self.n14 & 0x400L) >> 10)
    self.n46 = 0x3L
    self.n45 = 0x1L
    self.n44 = 0x6L
    self.n43 = 0x4L
    self.n42 = 0x2L
    self.n41 = 0x0L
    self.n40 = 0x0L
    self.n39 = 0x0L
    self.n38 = 0x1L
    self.n37 = 0x1L
    self.n36 = 0x1L
    self.n35 = 0x0L
    self.n31 = 0x3L
    self.n30 = 0x1L
    self.n29 = 0x6L
    self.n28 = 0x4L
    self.n27 = 0x2L
    self.n26 = 0x0L
    self.n25 = 0x0L
    self.n24 = 0x0L
    self.n23 = 0x1L
    self.n22 = 0x1L
    self.n21 = 0x1L
    self.n20 = 0x0L
    self.n15 = 0x7FFL
    self.n6 = 0x001L
    self.n5 = data_1_i
    self.n4 = data_0_i
    self.n3 = sync_i
    self.n6601 = self.n3 | self.n6548
    self.n6597 = self.n147 | self.n6548
    self.n6596 = self.n556 | self.n6548
    self.n6595 = self.n556 | self.n6548
    self.n6593 = self.n666 | self.n6548
    self.n6592 = self.n1075 | self.n6548
    self.n6591 = self.n1075 | self.n6548
    self.n6589 = self.n1185 | self.n6548
    self.n6588 = self.n1594 | self.n6548
    self.n6587 = self.n1594 | self.n6548
    self.n6585 = self.n1704 | self.n6548
    self.n6584 = self.n2113 | self.n6548
    self.n6583 = self.n2113 | self.n6548
    self.n6581 = self.n2223 | self.n6548
    self.n6580 = self.n2632 | self.n6548
    self.n6579 = self.n2632 | self.n6548
    self.n6577 = self.n2742 | self.n6548
    self.n6576 = self.n3151 | self.n6548
    self.n6575 = self.n3151 | self.n6548
    self.n6573 = self.n3261 | self.n6548
    self.n6572 = self.n3670 | self.n6548
    self.n6571 = self.n3670 | self.n6548
    self.n6569 = self.n3780 | self.n6548
    self.n6568 = self.n4189 | self.n6548
    self.n6567 = self.n4189 | self.n6548
    self.n6565 = self.n4299 | self.n6548
    self.n6564 = self.n4708 | self.n6548
    self.n6563 = self.n4708 | self.n6548
    self.n6561 = self.n4818 | self.n6548
    self.n6560 = self.n5227 | self.n6548
    self.n6559 = self.n5227 | self.n6548
    self.n6557 = self.n5337 | self.n6548
    self.n6556 = self.n5746 | self.n6548
    self.n6555 = self.n5746 | self.n6548
    self.n6553 = self.n5856 | self.n6548
    self.n6552 = self.n6265 | self.n6548
    self.n6551 = self.n6265 | self.n6548
    self.n6541 = (self.n6470 & 0x8000L) | (self.n6470 & 0x4000L) | (self.n6470 & 0x2000L) | (self.n6470 & 0x1000L) | (self.n6470 & 0x800L) | (self.n6470 & 0x400L) | (self.n6470 & 0x200L) | (self.n6470 & 0x100L) | (self.n6470 & 0x80L) | (self.n6470 & 0x40L) | (self.n6470 & 0x20L) | (self.n6470 & 0x10L) | (self.n6470 & 0x8L) | (self.n6470 & 0x4L) | (self.n6470 & 0x2L) | (self.n6470 & 0x1L)
    self.n6540 = ((self.n6470 & 0x80000000L) >> 16) | ((self.n6470 & 0x40000000L) >> 16) | ((self.n6470 & 0x20000000L) >> 16) | ((self.n6470 & 0x10000000L) >> 16) | ((self.n6470 & 0x8000000L) >> 16) | ((self.n6470 & 0x4000000L) >> 16) | ((self.n6470 & 0x2000000L) >> 16) | ((self.n6470 & 0x1000000L) >> 16) | ((self.n6470 & 0x800000L) >> 16) | ((self.n6470 & 0x400000L) >> 16) | ((self.n6470 & 0x200000L) >> 16) | ((self.n6470 & 0x100000L) >> 16) | ((self.n6470 & 0x80000L) >> 16) | ((self.n6470 & 0x40000L) >> 16) | ((self.n6470 & 0x20000L) >> 16) | ((self.n6470 & 0x10000L) >> 16)
    self.n6539 = (self.n6397 & 0x8000L) | (self.n6397 & 0x4000L) | (self.n6397 & 0x2000L) | (self.n6397 & 0x1000L) | (self.n6397 & 0x800L) | (self.n6397 & 0x400L) | (self.n6397 & 0x200L) | (self.n6397 & 0x100L) | (self.n6397 & 0x80L) | (self.n6397 & 0x40L) | (self.n6397 & 0x20L) | (self.n6397 & 0x10L) | (self.n6397 & 0x8L) | (self.n6397 & 0x4L) | (self.n6397 & 0x2L) | (self.n6397 & 0x1L)
    self.n6538 = ((self.n6397 & 0x80000000L) >> 16) | ((self.n6397 & 0x40000000L) >> 16) | ((self.n6397 & 0x20000000L) >> 16) | ((self.n6397 & 0x10000000L) >> 16) | ((self.n6397 & 0x8000000L) >> 16) | ((self.n6397 & 0x4000000L) >> 16) | ((self.n6397 & 0x2000000L) >> 16) | ((self.n6397 & 0x1000000L) >> 16) | ((self.n6397 & 0x800000L) >> 16) | ((self.n6397 & 0x400000L) >> 16) | ((self.n6397 & 0x200000L) >> 16) | ((self.n6397 & 0x100000L) >> 16) | ((self.n6397 & 0x80000L) >> 16) | ((self.n6397 & 0x40000L) >> 16) | ((self.n6397 & 0x20000L) >> 16) | ((self.n6397 & 0x10000L) >> 16)
    if self.n6423 == self.n6419:
      self.n6436 = 1L
    else:
      self.n6436 = 0L
    if self.n6423 == self.n6418:
      self.n6435 = 1L
    else:
      self.n6435 = 0L
    if self.n6423 == self.n6413:
      self.n6426 = 1L
    else:
      self.n6426 = 0L
    if self.n6423 == self.n6412:
      self.n6425 = 1L
    else:
      self.n6425 = 0L
    if self.n6423 == self.n6411:
      self.n6424 = 1L
    else:
      self.n6424 = 0L
    self.n6401 = (self.n6406 + self.n6398) & 0x3FFL
    if self.n6333 == self.n6376:
      self.n6377 = 1L
    else:
      self.n6377 = 0L
    self.n6375r = self.n6548
    self.n6375e = self.n6547
    self.n6375d = self.n6265
    if self.n6350 == self.n6346:
      self.n6363 = 1L
    else:
      self.n6363 = 0L
    if self.n6350 == self.n6345:
      self.n6362 = 1L
    else:
      self.n6362 = 0L
    if self.n6350 == self.n6340:
      self.n6353 = 1L
    else:
      self.n6353 = 0L
    if self.n6350 == self.n6339:
      self.n6352 = 1L
    else:
      self.n6352 = 0L
    if self.n6350 == self.n6338:
      self.n6351 = 1L
    else:
      self.n6351 = 0L
    self.n6328 = (self.n6333 + self.n6325) & 0x3FFL
    self.n6323r = self.n6548
    self.n6323e = self.n6547
    self.n6323d = self.n6316
    self.n6316r = self.n6548
    self.n6316e = self.n6547
    self.n6316d = self.n6309
    self.n6309r = self.n6548
    self.n6309e = self.n6547
    self.n6309d = self.n6302
    self.n6302r = self.n6548
    self.n6302e = self.n6547
    self.n6302d = self.n6295
    self.n6294r = self.n6548
    self.n6294e = self.n6547
    self.n6294d = self.n6287
    self.n6287r = self.n6548
    self.n6287e = self.n6547
    self.n6287d = self.n6280
    self.n6280r = self.n6548
    self.n6280e = self.n6547
    self.n6280d = self.n6273
    self.n6273r = self.n6548
    self.n6273e = self.n6547
    self.n6273d = self.n6266
    self.n6265r = self.n6548
    self.n6265e = self.n6547
    self.n6265d = self.n6258
    self.n6258r = self.n6548
    self.n6258e = self.n6547
    self.n6258d = self.n6251
    self.n6251r = self.n6548
    self.n6251e = self.n6547
    self.n6251d = self.n6244
    self.n6229 = self.n6227 << 8 | self.n6228
    self.n6219 = self.n6217 << 8 | self.n6218
    self.n6216r = self.n6548
    self.n6216e = self.n6547
    self.n6216d = self.n6209
    isNeg0 = self.n6129 & 0x80L
    isNeg1 = self.n6163 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n6200 = (self.n6129 * self.n6163) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n6200 = (self.n6129 * (0xFF00L | self.n6163)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n6200 = ((0xFF00L | self.n6129) * self.n6163) & 0xFFFFL
    else:
      self.n6200 = ((0xFF00L | self.n6129) * (0xFF00L | self.n6163)) & 0xFFFFL
    isNeg0 = self.n6128 & 0x80L
    isNeg1 = self.n6164 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n6191 = (self.n6128 * self.n6164) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n6191 = (self.n6128 * (0xFF00L | self.n6164)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n6191 = ((0xFF00L | self.n6128) * self.n6164) & 0xFFFFL
    else:
      self.n6191 = ((0xFF00L | self.n6128) * (0xFF00L | self.n6164)) & 0xFFFFL
    self.n6190r = self.n6548
    self.n6190e = self.n6547
    self.n6190d = self.n6183
    isNeg0 = self.n6129 & 0x80L
    isNeg1 = self.n6164 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n6174 = (self.n6129 * self.n6164) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n6174 = (self.n6129 * (0xFF00L | self.n6164)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n6174 = ((0xFF00L | self.n6129) * self.n6164) & 0xFFFFL
    else:
      self.n6174 = ((0xFF00L | self.n6129) * (0xFF00L | self.n6164)) & 0xFFFFL
    isNeg0 = self.n6128 & 0x80L
    isNeg1 = self.n6163 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n6165 = (self.n6128 * self.n6163) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n6165 = (self.n6128 * (0xFF00L | self.n6163)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n6165 = ((0xFF00L | self.n6128) * self.n6163) & 0xFFFFL
    else:
      self.n6165 = ((0xFF00L | self.n6128) * (0xFF00L | self.n6163)) & 0xFFFFL
    self.n6162e = self.n6547
    self.n6162a = self.n6111
    self.n6157r = self.n6548
    self.n6157e = self.n6547
    self.n6157d = self.n6150
    self.n6150r = self.n6548
    self.n6150e = self.n6547
    self.n6150d = self.n6120
    self.n6143r = self.n6548
    self.n6143e = self.n6547
    self.n6143d = self.n6136
    self.n6136r = self.n6548
    self.n6136e = self.n6547
    self.n6136d = self.n6119
    if self.n6033 == self.n6034:
      self.n6035 = 1L
    else:
      self.n6035 = 0L
    self.n6028 = (self.n6033 + self.n6025) & 0x7FFL
    self.n6022 = (self.n5951 & 0x8000L) | (self.n5951 & 0x4000L) | (self.n5951 & 0x2000L) | (self.n5951 & 0x1000L) | (self.n5951 & 0x800L) | (self.n5951 & 0x400L) | (self.n5951 & 0x200L) | (self.n5951 & 0x100L) | (self.n5951 & 0x80L) | (self.n5951 & 0x40L) | (self.n5951 & 0x20L) | (self.n5951 & 0x10L) | (self.n5951 & 0x8L) | (self.n5951 & 0x4L) | (self.n5951 & 0x2L) | (self.n5951 & 0x1L)
    self.n6021 = ((self.n5951 & 0x80000000L) >> 16) | ((self.n5951 & 0x40000000L) >> 16) | ((self.n5951 & 0x20000000L) >> 16) | ((self.n5951 & 0x10000000L) >> 16) | ((self.n5951 & 0x8000000L) >> 16) | ((self.n5951 & 0x4000000L) >> 16) | ((self.n5951 & 0x2000000L) >> 16) | ((self.n5951 & 0x1000000L) >> 16) | ((self.n5951 & 0x800000L) >> 16) | ((self.n5951 & 0x400000L) >> 16) | ((self.n5951 & 0x200000L) >> 16) | ((self.n5951 & 0x100000L) >> 16) | ((self.n5951 & 0x80000L) >> 16) | ((self.n5951 & 0x40000L) >> 16) | ((self.n5951 & 0x20000L) >> 16) | ((self.n5951 & 0x10000L) >> 16)
    self.n6020 = (self.n5878 & 0x8000L) | (self.n5878 & 0x4000L) | (self.n5878 & 0x2000L) | (self.n5878 & 0x1000L) | (self.n5878 & 0x800L) | (self.n5878 & 0x400L) | (self.n5878 & 0x200L) | (self.n5878 & 0x100L) | (self.n5878 & 0x80L) | (self.n5878 & 0x40L) | (self.n5878 & 0x20L) | (self.n5878 & 0x10L) | (self.n5878 & 0x8L) | (self.n5878 & 0x4L) | (self.n5878 & 0x2L) | (self.n5878 & 0x1L)
    self.n6019 = ((self.n5878 & 0x80000000L) >> 16) | ((self.n5878 & 0x40000000L) >> 16) | ((self.n5878 & 0x20000000L) >> 16) | ((self.n5878 & 0x10000000L) >> 16) | ((self.n5878 & 0x8000000L) >> 16) | ((self.n5878 & 0x4000000L) >> 16) | ((self.n5878 & 0x2000000L) >> 16) | ((self.n5878 & 0x1000000L) >> 16) | ((self.n5878 & 0x800000L) >> 16) | ((self.n5878 & 0x400000L) >> 16) | ((self.n5878 & 0x200000L) >> 16) | ((self.n5878 & 0x100000L) >> 16) | ((self.n5878 & 0x80000L) >> 16) | ((self.n5878 & 0x40000L) >> 16) | ((self.n5878 & 0x20000L) >> 16) | ((self.n5878 & 0x10000L) >> 16)
    if self.n5904 == self.n5900:
      self.n5917 = 1L
    else:
      self.n5917 = 0L
    if self.n5904 == self.n5899:
      self.n5916 = 1L
    else:
      self.n5916 = 0L
    if self.n5904 == self.n5894:
      self.n5907 = 1L
    else:
      self.n5907 = 0L
    if self.n5904 == self.n5893:
      self.n5906 = 1L
    else:
      self.n5906 = 0L
    if self.n5904 == self.n5892:
      self.n5905 = 1L
    else:
      self.n5905 = 0L
    self.n5882 = (self.n5887 + self.n5879) & 0x3FFL
    if self.n5814 == self.n5857:
      self.n5858 = 1L
    else:
      self.n5858 = 0L
    self.n5856r = self.n6548
    self.n5856e = self.n6547
    self.n5856d = self.n5746
    if self.n5831 == self.n5827:
      self.n5844 = 1L
    else:
      self.n5844 = 0L
    if self.n5831 == self.n5826:
      self.n5843 = 1L
    else:
      self.n5843 = 0L
    if self.n5831 == self.n5821:
      self.n5834 = 1L
    else:
      self.n5834 = 0L
    if self.n5831 == self.n5820:
      self.n5833 = 1L
    else:
      self.n5833 = 0L
    if self.n5831 == self.n5819:
      self.n5832 = 1L
    else:
      self.n5832 = 0L
    self.n5809 = (self.n5814 + self.n5806) & 0x3FFL
    self.n5804r = self.n6548
    self.n5804e = self.n6547
    self.n5804d = self.n5797
    self.n5797r = self.n6548
    self.n5797e = self.n6547
    self.n5797d = self.n5790
    self.n5790r = self.n6548
    self.n5790e = self.n6547
    self.n5790d = self.n5783
    self.n5783r = self.n6548
    self.n5783e = self.n6547
    self.n5783d = self.n5776
    self.n5775r = self.n6548
    self.n5775e = self.n6547
    self.n5775d = self.n5768
    self.n5768r = self.n6548
    self.n5768e = self.n6547
    self.n5768d = self.n5761
    self.n5761r = self.n6548
    self.n5761e = self.n6547
    self.n5761d = self.n5754
    self.n5754r = self.n6548
    self.n5754e = self.n6547
    self.n5754d = self.n5747
    self.n5746r = self.n6548
    self.n5746e = self.n6547
    self.n5746d = self.n5739
    self.n5739r = self.n6548
    self.n5739e = self.n6547
    self.n5739d = self.n5732
    self.n5732r = self.n6548
    self.n5732e = self.n6547
    self.n5732d = self.n5725
    self.n5710 = self.n5708 << 8 | self.n5709
    self.n5700 = self.n5698 << 8 | self.n5699
    self.n5697r = self.n6548
    self.n5697e = self.n6547
    self.n5697d = self.n5690
    isNeg0 = self.n5610 & 0x80L
    isNeg1 = self.n5644 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n5681 = (self.n5610 * self.n5644) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n5681 = (self.n5610 * (0xFF00L | self.n5644)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n5681 = ((0xFF00L | self.n5610) * self.n5644) & 0xFFFFL
    else:
      self.n5681 = ((0xFF00L | self.n5610) * (0xFF00L | self.n5644)) & 0xFFFFL
    isNeg0 = self.n5609 & 0x80L
    isNeg1 = self.n5645 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n5672 = (self.n5609 * self.n5645) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n5672 = (self.n5609 * (0xFF00L | self.n5645)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n5672 = ((0xFF00L | self.n5609) * self.n5645) & 0xFFFFL
    else:
      self.n5672 = ((0xFF00L | self.n5609) * (0xFF00L | self.n5645)) & 0xFFFFL
    self.n5671r = self.n6548
    self.n5671e = self.n6547
    self.n5671d = self.n5664
    isNeg0 = self.n5610 & 0x80L
    isNeg1 = self.n5645 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n5655 = (self.n5610 * self.n5645) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n5655 = (self.n5610 * (0xFF00L | self.n5645)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n5655 = ((0xFF00L | self.n5610) * self.n5645) & 0xFFFFL
    else:
      self.n5655 = ((0xFF00L | self.n5610) * (0xFF00L | self.n5645)) & 0xFFFFL
    isNeg0 = self.n5609 & 0x80L
    isNeg1 = self.n5644 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n5646 = (self.n5609 * self.n5644) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n5646 = (self.n5609 * (0xFF00L | self.n5644)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n5646 = ((0xFF00L | self.n5609) * self.n5644) & 0xFFFFL
    else:
      self.n5646 = ((0xFF00L | self.n5609) * (0xFF00L | self.n5644)) & 0xFFFFL
    self.n5643e = self.n6547
    self.n5643a = self.n5592
    self.n5638r = self.n6548
    self.n5638e = self.n6547
    self.n5638d = self.n5631
    self.n5631r = self.n6548
    self.n5631e = self.n6547
    self.n5631d = self.n5601
    self.n5624r = self.n6548
    self.n5624e = self.n6547
    self.n5624d = self.n5617
    self.n5617r = self.n6548
    self.n5617e = self.n6547
    self.n5617d = self.n5600
    if self.n5514 == self.n5515:
      self.n5516 = 1L
    else:
      self.n5516 = 0L
    self.n5509 = (self.n5514 + self.n5506) & 0x7FFL
    self.n5503 = (self.n5432 & 0x8000L) | (self.n5432 & 0x4000L) | (self.n5432 & 0x2000L) | (self.n5432 & 0x1000L) | (self.n5432 & 0x800L) | (self.n5432 & 0x400L) | (self.n5432 & 0x200L) | (self.n5432 & 0x100L) | (self.n5432 & 0x80L) | (self.n5432 & 0x40L) | (self.n5432 & 0x20L) | (self.n5432 & 0x10L) | (self.n5432 & 0x8L) | (self.n5432 & 0x4L) | (self.n5432 & 0x2L) | (self.n5432 & 0x1L)
    self.n5502 = ((self.n5432 & 0x80000000L) >> 16) | ((self.n5432 & 0x40000000L) >> 16) | ((self.n5432 & 0x20000000L) >> 16) | ((self.n5432 & 0x10000000L) >> 16) | ((self.n5432 & 0x8000000L) >> 16) | ((self.n5432 & 0x4000000L) >> 16) | ((self.n5432 & 0x2000000L) >> 16) | ((self.n5432 & 0x1000000L) >> 16) | ((self.n5432 & 0x800000L) >> 16) | ((self.n5432 & 0x400000L) >> 16) | ((self.n5432 & 0x200000L) >> 16) | ((self.n5432 & 0x100000L) >> 16) | ((self.n5432 & 0x80000L) >> 16) | ((self.n5432 & 0x40000L) >> 16) | ((self.n5432 & 0x20000L) >> 16) | ((self.n5432 & 0x10000L) >> 16)
    self.n5501 = (self.n5359 & 0x8000L) | (self.n5359 & 0x4000L) | (self.n5359 & 0x2000L) | (self.n5359 & 0x1000L) | (self.n5359 & 0x800L) | (self.n5359 & 0x400L) | (self.n5359 & 0x200L) | (self.n5359 & 0x100L) | (self.n5359 & 0x80L) | (self.n5359 & 0x40L) | (self.n5359 & 0x20L) | (self.n5359 & 0x10L) | (self.n5359 & 0x8L) | (self.n5359 & 0x4L) | (self.n5359 & 0x2L) | (self.n5359 & 0x1L)
    self.n5500 = ((self.n5359 & 0x80000000L) >> 16) | ((self.n5359 & 0x40000000L) >> 16) | ((self.n5359 & 0x20000000L) >> 16) | ((self.n5359 & 0x10000000L) >> 16) | ((self.n5359 & 0x8000000L) >> 16) | ((self.n5359 & 0x4000000L) >> 16) | ((self.n5359 & 0x2000000L) >> 16) | ((self.n5359 & 0x1000000L) >> 16) | ((self.n5359 & 0x800000L) >> 16) | ((self.n5359 & 0x400000L) >> 16) | ((self.n5359 & 0x200000L) >> 16) | ((self.n5359 & 0x100000L) >> 16) | ((self.n5359 & 0x80000L) >> 16) | ((self.n5359 & 0x40000L) >> 16) | ((self.n5359 & 0x20000L) >> 16) | ((self.n5359 & 0x10000L) >> 16)
    if self.n5385 == self.n5381:
      self.n5398 = 1L
    else:
      self.n5398 = 0L
    if self.n5385 == self.n5380:
      self.n5397 = 1L
    else:
      self.n5397 = 0L
    if self.n5385 == self.n5375:
      self.n5388 = 1L
    else:
      self.n5388 = 0L
    if self.n5385 == self.n5374:
      self.n5387 = 1L
    else:
      self.n5387 = 0L
    if self.n5385 == self.n5373:
      self.n5386 = 1L
    else:
      self.n5386 = 0L
    self.n5363 = (self.n5368 + self.n5360) & 0x3FFL
    if self.n5295 == self.n5338:
      self.n5339 = 1L
    else:
      self.n5339 = 0L
    self.n5337r = self.n6548
    self.n5337e = self.n6547
    self.n5337d = self.n5227
    if self.n5312 == self.n5308:
      self.n5325 = 1L
    else:
      self.n5325 = 0L
    if self.n5312 == self.n5307:
      self.n5324 = 1L
    else:
      self.n5324 = 0L
    if self.n5312 == self.n5302:
      self.n5315 = 1L
    else:
      self.n5315 = 0L
    if self.n5312 == self.n5301:
      self.n5314 = 1L
    else:
      self.n5314 = 0L
    if self.n5312 == self.n5300:
      self.n5313 = 1L
    else:
      self.n5313 = 0L
    self.n5290 = (self.n5295 + self.n5287) & 0x3FFL
    self.n5285r = self.n6548
    self.n5285e = self.n6547
    self.n5285d = self.n5278
    self.n5278r = self.n6548
    self.n5278e = self.n6547
    self.n5278d = self.n5271
    self.n5271r = self.n6548
    self.n5271e = self.n6547
    self.n5271d = self.n5264
    self.n5264r = self.n6548
    self.n5264e = self.n6547
    self.n5264d = self.n5257
    self.n5256r = self.n6548
    self.n5256e = self.n6547
    self.n5256d = self.n5249
    self.n5249r = self.n6548
    self.n5249e = self.n6547
    self.n5249d = self.n5242
    self.n5242r = self.n6548
    self.n5242e = self.n6547
    self.n5242d = self.n5235
    self.n5235r = self.n6548
    self.n5235e = self.n6547
    self.n5235d = self.n5228
    self.n5227r = self.n6548
    self.n5227e = self.n6547
    self.n5227d = self.n5220
    self.n5220r = self.n6548
    self.n5220e = self.n6547
    self.n5220d = self.n5213
    self.n5213r = self.n6548
    self.n5213e = self.n6547
    self.n5213d = self.n5206
    self.n5191 = self.n5189 << 8 | self.n5190
    self.n5181 = self.n5179 << 8 | self.n5180
    self.n5178r = self.n6548
    self.n5178e = self.n6547
    self.n5178d = self.n5171
    isNeg0 = self.n5091 & 0x80L
    isNeg1 = self.n5125 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n5162 = (self.n5091 * self.n5125) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n5162 = (self.n5091 * (0xFF00L | self.n5125)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n5162 = ((0xFF00L | self.n5091) * self.n5125) & 0xFFFFL
    else:
      self.n5162 = ((0xFF00L | self.n5091) * (0xFF00L | self.n5125)) & 0xFFFFL
    isNeg0 = self.n5090 & 0x80L
    isNeg1 = self.n5126 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n5153 = (self.n5090 * self.n5126) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n5153 = (self.n5090 * (0xFF00L | self.n5126)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n5153 = ((0xFF00L | self.n5090) * self.n5126) & 0xFFFFL
    else:
      self.n5153 = ((0xFF00L | self.n5090) * (0xFF00L | self.n5126)) & 0xFFFFL
    self.n5152r = self.n6548
    self.n5152e = self.n6547
    self.n5152d = self.n5145
    isNeg0 = self.n5091 & 0x80L
    isNeg1 = self.n5126 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n5136 = (self.n5091 * self.n5126) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n5136 = (self.n5091 * (0xFF00L | self.n5126)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n5136 = ((0xFF00L | self.n5091) * self.n5126) & 0xFFFFL
    else:
      self.n5136 = ((0xFF00L | self.n5091) * (0xFF00L | self.n5126)) & 0xFFFFL
    isNeg0 = self.n5090 & 0x80L
    isNeg1 = self.n5125 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n5127 = (self.n5090 * self.n5125) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n5127 = (self.n5090 * (0xFF00L | self.n5125)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n5127 = ((0xFF00L | self.n5090) * self.n5125) & 0xFFFFL
    else:
      self.n5127 = ((0xFF00L | self.n5090) * (0xFF00L | self.n5125)) & 0xFFFFL
    self.n5124e = self.n6547
    self.n5124a = self.n5073
    self.n5119r = self.n6548
    self.n5119e = self.n6547
    self.n5119d = self.n5112
    self.n5112r = self.n6548
    self.n5112e = self.n6547
    self.n5112d = self.n5082
    self.n5105r = self.n6548
    self.n5105e = self.n6547
    self.n5105d = self.n5098
    self.n5098r = self.n6548
    self.n5098e = self.n6547
    self.n5098d = self.n5081
    if self.n4995 == self.n4996:
      self.n4997 = 1L
    else:
      self.n4997 = 0L
    self.n4990 = (self.n4995 + self.n4987) & 0x7FFL
    self.n4984 = (self.n4913 & 0x8000L) | (self.n4913 & 0x4000L) | (self.n4913 & 0x2000L) | (self.n4913 & 0x1000L) | (self.n4913 & 0x800L) | (self.n4913 & 0x400L) | (self.n4913 & 0x200L) | (self.n4913 & 0x100L) | (self.n4913 & 0x80L) | (self.n4913 & 0x40L) | (self.n4913 & 0x20L) | (self.n4913 & 0x10L) | (self.n4913 & 0x8L) | (self.n4913 & 0x4L) | (self.n4913 & 0x2L) | (self.n4913 & 0x1L)
    self.n4983 = ((self.n4913 & 0x80000000L) >> 16) | ((self.n4913 & 0x40000000L) >> 16) | ((self.n4913 & 0x20000000L) >> 16) | ((self.n4913 & 0x10000000L) >> 16) | ((self.n4913 & 0x8000000L) >> 16) | ((self.n4913 & 0x4000000L) >> 16) | ((self.n4913 & 0x2000000L) >> 16) | ((self.n4913 & 0x1000000L) >> 16) | ((self.n4913 & 0x800000L) >> 16) | ((self.n4913 & 0x400000L) >> 16) | ((self.n4913 & 0x200000L) >> 16) | ((self.n4913 & 0x100000L) >> 16) | ((self.n4913 & 0x80000L) >> 16) | ((self.n4913 & 0x40000L) >> 16) | ((self.n4913 & 0x20000L) >> 16) | ((self.n4913 & 0x10000L) >> 16)
    self.n4982 = (self.n4840 & 0x8000L) | (self.n4840 & 0x4000L) | (self.n4840 & 0x2000L) | (self.n4840 & 0x1000L) | (self.n4840 & 0x800L) | (self.n4840 & 0x400L) | (self.n4840 & 0x200L) | (self.n4840 & 0x100L) | (self.n4840 & 0x80L) | (self.n4840 & 0x40L) | (self.n4840 & 0x20L) | (self.n4840 & 0x10L) | (self.n4840 & 0x8L) | (self.n4840 & 0x4L) | (self.n4840 & 0x2L) | (self.n4840 & 0x1L)
    self.n4981 = ((self.n4840 & 0x80000000L) >> 16) | ((self.n4840 & 0x40000000L) >> 16) | ((self.n4840 & 0x20000000L) >> 16) | ((self.n4840 & 0x10000000L) >> 16) | ((self.n4840 & 0x8000000L) >> 16) | ((self.n4840 & 0x4000000L) >> 16) | ((self.n4840 & 0x2000000L) >> 16) | ((self.n4840 & 0x1000000L) >> 16) | ((self.n4840 & 0x800000L) >> 16) | ((self.n4840 & 0x400000L) >> 16) | ((self.n4840 & 0x200000L) >> 16) | ((self.n4840 & 0x100000L) >> 16) | ((self.n4840 & 0x80000L) >> 16) | ((self.n4840 & 0x40000L) >> 16) | ((self.n4840 & 0x20000L) >> 16) | ((self.n4840 & 0x10000L) >> 16)
    if self.n4866 == self.n4862:
      self.n4879 = 1L
    else:
      self.n4879 = 0L
    if self.n4866 == self.n4861:
      self.n4878 = 1L
    else:
      self.n4878 = 0L
    if self.n4866 == self.n4856:
      self.n4869 = 1L
    else:
      self.n4869 = 0L
    if self.n4866 == self.n4855:
      self.n4868 = 1L
    else:
      self.n4868 = 0L
    if self.n4866 == self.n4854:
      self.n4867 = 1L
    else:
      self.n4867 = 0L
    self.n4844 = (self.n4849 + self.n4841) & 0x3FFL
    if self.n4776 == self.n4819:
      self.n4820 = 1L
    else:
      self.n4820 = 0L
    self.n4818r = self.n6548
    self.n4818e = self.n6547
    self.n4818d = self.n4708
    if self.n4793 == self.n4789:
      self.n4806 = 1L
    else:
      self.n4806 = 0L
    if self.n4793 == self.n4788:
      self.n4805 = 1L
    else:
      self.n4805 = 0L
    if self.n4793 == self.n4783:
      self.n4796 = 1L
    else:
      self.n4796 = 0L
    if self.n4793 == self.n4782:
      self.n4795 = 1L
    else:
      self.n4795 = 0L
    if self.n4793 == self.n4781:
      self.n4794 = 1L
    else:
      self.n4794 = 0L
    self.n4771 = (self.n4776 + self.n4768) & 0x3FFL
    self.n4766r = self.n6548
    self.n4766e = self.n6547
    self.n4766d = self.n4759
    self.n4759r = self.n6548
    self.n4759e = self.n6547
    self.n4759d = self.n4752
    self.n4752r = self.n6548
    self.n4752e = self.n6547
    self.n4752d = self.n4745
    self.n4745r = self.n6548
    self.n4745e = self.n6547
    self.n4745d = self.n4738
    self.n4737r = self.n6548
    self.n4737e = self.n6547
    self.n4737d = self.n4730
    self.n4730r = self.n6548
    self.n4730e = self.n6547
    self.n4730d = self.n4723
    self.n4723r = self.n6548
    self.n4723e = self.n6547
    self.n4723d = self.n4716
    self.n4716r = self.n6548
    self.n4716e = self.n6547
    self.n4716d = self.n4709
    self.n4708r = self.n6548
    self.n4708e = self.n6547
    self.n4708d = self.n4701
    self.n4701r = self.n6548
    self.n4701e = self.n6547
    self.n4701d = self.n4694
    self.n4694r = self.n6548
    self.n4694e = self.n6547
    self.n4694d = self.n4687
    self.n4672 = self.n4670 << 8 | self.n4671
    self.n4662 = self.n4660 << 8 | self.n4661
    self.n4659r = self.n6548
    self.n4659e = self.n6547
    self.n4659d = self.n4652
    isNeg0 = self.n4572 & 0x80L
    isNeg1 = self.n4606 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n4643 = (self.n4572 * self.n4606) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n4643 = (self.n4572 * (0xFF00L | self.n4606)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n4643 = ((0xFF00L | self.n4572) * self.n4606) & 0xFFFFL
    else:
      self.n4643 = ((0xFF00L | self.n4572) * (0xFF00L | self.n4606)) & 0xFFFFL
    isNeg0 = self.n4571 & 0x80L
    isNeg1 = self.n4607 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n4634 = (self.n4571 * self.n4607) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n4634 = (self.n4571 * (0xFF00L | self.n4607)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n4634 = ((0xFF00L | self.n4571) * self.n4607) & 0xFFFFL
    else:
      self.n4634 = ((0xFF00L | self.n4571) * (0xFF00L | self.n4607)) & 0xFFFFL
    self.n4633r = self.n6548
    self.n4633e = self.n6547
    self.n4633d = self.n4626
    isNeg0 = self.n4572 & 0x80L
    isNeg1 = self.n4607 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n4617 = (self.n4572 * self.n4607) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n4617 = (self.n4572 * (0xFF00L | self.n4607)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n4617 = ((0xFF00L | self.n4572) * self.n4607) & 0xFFFFL
    else:
      self.n4617 = ((0xFF00L | self.n4572) * (0xFF00L | self.n4607)) & 0xFFFFL
    isNeg0 = self.n4571 & 0x80L
    isNeg1 = self.n4606 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n4608 = (self.n4571 * self.n4606) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n4608 = (self.n4571 * (0xFF00L | self.n4606)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n4608 = ((0xFF00L | self.n4571) * self.n4606) & 0xFFFFL
    else:
      self.n4608 = ((0xFF00L | self.n4571) * (0xFF00L | self.n4606)) & 0xFFFFL
    self.n4605e = self.n6547
    self.n4605a = self.n4554
    self.n4600r = self.n6548
    self.n4600e = self.n6547
    self.n4600d = self.n4593
    self.n4593r = self.n6548
    self.n4593e = self.n6547
    self.n4593d = self.n4563
    self.n4586r = self.n6548
    self.n4586e = self.n6547
    self.n4586d = self.n4579
    self.n4579r = self.n6548
    self.n4579e = self.n6547
    self.n4579d = self.n4562
    if self.n4476 == self.n4477:
      self.n4478 = 1L
    else:
      self.n4478 = 0L
    self.n4471 = (self.n4476 + self.n4468) & 0x7FFL
    self.n4465 = (self.n4394 & 0x8000L) | (self.n4394 & 0x4000L) | (self.n4394 & 0x2000L) | (self.n4394 & 0x1000L) | (self.n4394 & 0x800L) | (self.n4394 & 0x400L) | (self.n4394 & 0x200L) | (self.n4394 & 0x100L) | (self.n4394 & 0x80L) | (self.n4394 & 0x40L) | (self.n4394 & 0x20L) | (self.n4394 & 0x10L) | (self.n4394 & 0x8L) | (self.n4394 & 0x4L) | (self.n4394 & 0x2L) | (self.n4394 & 0x1L)
    self.n4464 = ((self.n4394 & 0x80000000L) >> 16) | ((self.n4394 & 0x40000000L) >> 16) | ((self.n4394 & 0x20000000L) >> 16) | ((self.n4394 & 0x10000000L) >> 16) | ((self.n4394 & 0x8000000L) >> 16) | ((self.n4394 & 0x4000000L) >> 16) | ((self.n4394 & 0x2000000L) >> 16) | ((self.n4394 & 0x1000000L) >> 16) | ((self.n4394 & 0x800000L) >> 16) | ((self.n4394 & 0x400000L) >> 16) | ((self.n4394 & 0x200000L) >> 16) | ((self.n4394 & 0x100000L) >> 16) | ((self.n4394 & 0x80000L) >> 16) | ((self.n4394 & 0x40000L) >> 16) | ((self.n4394 & 0x20000L) >> 16) | ((self.n4394 & 0x10000L) >> 16)
    self.n4463 = (self.n4321 & 0x8000L) | (self.n4321 & 0x4000L) | (self.n4321 & 0x2000L) | (self.n4321 & 0x1000L) | (self.n4321 & 0x800L) | (self.n4321 & 0x400L) | (self.n4321 & 0x200L) | (self.n4321 & 0x100L) | (self.n4321 & 0x80L) | (self.n4321 & 0x40L) | (self.n4321 & 0x20L) | (self.n4321 & 0x10L) | (self.n4321 & 0x8L) | (self.n4321 & 0x4L) | (self.n4321 & 0x2L) | (self.n4321 & 0x1L)
    self.n4462 = ((self.n4321 & 0x80000000L) >> 16) | ((self.n4321 & 0x40000000L) >> 16) | ((self.n4321 & 0x20000000L) >> 16) | ((self.n4321 & 0x10000000L) >> 16) | ((self.n4321 & 0x8000000L) >> 16) | ((self.n4321 & 0x4000000L) >> 16) | ((self.n4321 & 0x2000000L) >> 16) | ((self.n4321 & 0x1000000L) >> 16) | ((self.n4321 & 0x800000L) >> 16) | ((self.n4321 & 0x400000L) >> 16) | ((self.n4321 & 0x200000L) >> 16) | ((self.n4321 & 0x100000L) >> 16) | ((self.n4321 & 0x80000L) >> 16) | ((self.n4321 & 0x40000L) >> 16) | ((self.n4321 & 0x20000L) >> 16) | ((self.n4321 & 0x10000L) >> 16)
    if self.n4347 == self.n4343:
      self.n4360 = 1L
    else:
      self.n4360 = 0L
    if self.n4347 == self.n4342:
      self.n4359 = 1L
    else:
      self.n4359 = 0L
    if self.n4347 == self.n4337:
      self.n4350 = 1L
    else:
      self.n4350 = 0L
    if self.n4347 == self.n4336:
      self.n4349 = 1L
    else:
      self.n4349 = 0L
    if self.n4347 == self.n4335:
      self.n4348 = 1L
    else:
      self.n4348 = 0L
    self.n4325 = (self.n4330 + self.n4322) & 0x3FFL
    if self.n4257 == self.n4300:
      self.n4301 = 1L
    else:
      self.n4301 = 0L
    self.n4299r = self.n6548
    self.n4299e = self.n6547
    self.n4299d = self.n4189
    if self.n4274 == self.n4270:
      self.n4287 = 1L
    else:
      self.n4287 = 0L
    if self.n4274 == self.n4269:
      self.n4286 = 1L
    else:
      self.n4286 = 0L
    if self.n4274 == self.n4264:
      self.n4277 = 1L
    else:
      self.n4277 = 0L
    if self.n4274 == self.n4263:
      self.n4276 = 1L
    else:
      self.n4276 = 0L
    if self.n4274 == self.n4262:
      self.n4275 = 1L
    else:
      self.n4275 = 0L
    self.n4252 = (self.n4257 + self.n4249) & 0x3FFL
    self.n4247r = self.n6548
    self.n4247e = self.n6547
    self.n4247d = self.n4240
    self.n4240r = self.n6548
    self.n4240e = self.n6547
    self.n4240d = self.n4233
    self.n4233r = self.n6548
    self.n4233e = self.n6547
    self.n4233d = self.n4226
    self.n4226r = self.n6548
    self.n4226e = self.n6547
    self.n4226d = self.n4219
    self.n4218r = self.n6548
    self.n4218e = self.n6547
    self.n4218d = self.n4211
    self.n4211r = self.n6548
    self.n4211e = self.n6547
    self.n4211d = self.n4204
    self.n4204r = self.n6548
    self.n4204e = self.n6547
    self.n4204d = self.n4197
    self.n4197r = self.n6548
    self.n4197e = self.n6547
    self.n4197d = self.n4190
    self.n4189r = self.n6548
    self.n4189e = self.n6547
    self.n4189d = self.n4182
    self.n4182r = self.n6548
    self.n4182e = self.n6547
    self.n4182d = self.n4175
    self.n4175r = self.n6548
    self.n4175e = self.n6547
    self.n4175d = self.n4168
    self.n4153 = self.n4151 << 8 | self.n4152
    self.n4143 = self.n4141 << 8 | self.n4142
    self.n4140r = self.n6548
    self.n4140e = self.n6547
    self.n4140d = self.n4133
    isNeg0 = self.n4053 & 0x80L
    isNeg1 = self.n4087 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n4124 = (self.n4053 * self.n4087) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n4124 = (self.n4053 * (0xFF00L | self.n4087)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n4124 = ((0xFF00L | self.n4053) * self.n4087) & 0xFFFFL
    else:
      self.n4124 = ((0xFF00L | self.n4053) * (0xFF00L | self.n4087)) & 0xFFFFL
    isNeg0 = self.n4052 & 0x80L
    isNeg1 = self.n4088 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n4115 = (self.n4052 * self.n4088) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n4115 = (self.n4052 * (0xFF00L | self.n4088)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n4115 = ((0xFF00L | self.n4052) * self.n4088) & 0xFFFFL
    else:
      self.n4115 = ((0xFF00L | self.n4052) * (0xFF00L | self.n4088)) & 0xFFFFL
    self.n4114r = self.n6548
    self.n4114e = self.n6547
    self.n4114d = self.n4107
    isNeg0 = self.n4053 & 0x80L
    isNeg1 = self.n4088 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n4098 = (self.n4053 * self.n4088) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n4098 = (self.n4053 * (0xFF00L | self.n4088)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n4098 = ((0xFF00L | self.n4053) * self.n4088) & 0xFFFFL
    else:
      self.n4098 = ((0xFF00L | self.n4053) * (0xFF00L | self.n4088)) & 0xFFFFL
    isNeg0 = self.n4052 & 0x80L
    isNeg1 = self.n4087 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n4089 = (self.n4052 * self.n4087) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n4089 = (self.n4052 * (0xFF00L | self.n4087)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n4089 = ((0xFF00L | self.n4052) * self.n4087) & 0xFFFFL
    else:
      self.n4089 = ((0xFF00L | self.n4052) * (0xFF00L | self.n4087)) & 0xFFFFL
    self.n4086e = self.n6547
    self.n4086a = self.n4035
    self.n4081r = self.n6548
    self.n4081e = self.n6547
    self.n4081d = self.n4074
    self.n4074r = self.n6548
    self.n4074e = self.n6547
    self.n4074d = self.n4044
    self.n4067r = self.n6548
    self.n4067e = self.n6547
    self.n4067d = self.n4060
    self.n4060r = self.n6548
    self.n4060e = self.n6547
    self.n4060d = self.n4043
    if self.n3957 == self.n3958:
      self.n3959 = 1L
    else:
      self.n3959 = 0L
    self.n3952 = (self.n3957 + self.n3949) & 0x7FFL
    self.n3946 = (self.n3875 & 0x8000L) | (self.n3875 & 0x4000L) | (self.n3875 & 0x2000L) | (self.n3875 & 0x1000L) | (self.n3875 & 0x800L) | (self.n3875 & 0x400L) | (self.n3875 & 0x200L) | (self.n3875 & 0x100L) | (self.n3875 & 0x80L) | (self.n3875 & 0x40L) | (self.n3875 & 0x20L) | (self.n3875 & 0x10L) | (self.n3875 & 0x8L) | (self.n3875 & 0x4L) | (self.n3875 & 0x2L) | (self.n3875 & 0x1L)
    self.n3945 = ((self.n3875 & 0x80000000L) >> 16) | ((self.n3875 & 0x40000000L) >> 16) | ((self.n3875 & 0x20000000L) >> 16) | ((self.n3875 & 0x10000000L) >> 16) | ((self.n3875 & 0x8000000L) >> 16) | ((self.n3875 & 0x4000000L) >> 16) | ((self.n3875 & 0x2000000L) >> 16) | ((self.n3875 & 0x1000000L) >> 16) | ((self.n3875 & 0x800000L) >> 16) | ((self.n3875 & 0x400000L) >> 16) | ((self.n3875 & 0x200000L) >> 16) | ((self.n3875 & 0x100000L) >> 16) | ((self.n3875 & 0x80000L) >> 16) | ((self.n3875 & 0x40000L) >> 16) | ((self.n3875 & 0x20000L) >> 16) | ((self.n3875 & 0x10000L) >> 16)
    self.n3944 = (self.n3802 & 0x8000L) | (self.n3802 & 0x4000L) | (self.n3802 & 0x2000L) | (self.n3802 & 0x1000L) | (self.n3802 & 0x800L) | (self.n3802 & 0x400L) | (self.n3802 & 0x200L) | (self.n3802 & 0x100L) | (self.n3802 & 0x80L) | (self.n3802 & 0x40L) | (self.n3802 & 0x20L) | (self.n3802 & 0x10L) | (self.n3802 & 0x8L) | (self.n3802 & 0x4L) | (self.n3802 & 0x2L) | (self.n3802 & 0x1L)
    self.n3943 = ((self.n3802 & 0x80000000L) >> 16) | ((self.n3802 & 0x40000000L) >> 16) | ((self.n3802 & 0x20000000L) >> 16) | ((self.n3802 & 0x10000000L) >> 16) | ((self.n3802 & 0x8000000L) >> 16) | ((self.n3802 & 0x4000000L) >> 16) | ((self.n3802 & 0x2000000L) >> 16) | ((self.n3802 & 0x1000000L) >> 16) | ((self.n3802 & 0x800000L) >> 16) | ((self.n3802 & 0x400000L) >> 16) | ((self.n3802 & 0x200000L) >> 16) | ((self.n3802 & 0x100000L) >> 16) | ((self.n3802 & 0x80000L) >> 16) | ((self.n3802 & 0x40000L) >> 16) | ((self.n3802 & 0x20000L) >> 16) | ((self.n3802 & 0x10000L) >> 16)
    if self.n3828 == self.n3824:
      self.n3841 = 1L
    else:
      self.n3841 = 0L
    if self.n3828 == self.n3823:
      self.n3840 = 1L
    else:
      self.n3840 = 0L
    if self.n3828 == self.n3818:
      self.n3831 = 1L
    else:
      self.n3831 = 0L
    if self.n3828 == self.n3817:
      self.n3830 = 1L
    else:
      self.n3830 = 0L
    if self.n3828 == self.n3816:
      self.n3829 = 1L
    else:
      self.n3829 = 0L
    self.n3806 = (self.n3811 + self.n3803) & 0x3FFL
    if self.n3738 == self.n3781:
      self.n3782 = 1L
    else:
      self.n3782 = 0L
    self.n3780r = self.n6548
    self.n3780e = self.n6547
    self.n3780d = self.n3670
    if self.n3755 == self.n3751:
      self.n3768 = 1L
    else:
      self.n3768 = 0L
    if self.n3755 == self.n3750:
      self.n3767 = 1L
    else:
      self.n3767 = 0L
    if self.n3755 == self.n3745:
      self.n3758 = 1L
    else:
      self.n3758 = 0L
    if self.n3755 == self.n3744:
      self.n3757 = 1L
    else:
      self.n3757 = 0L
    if self.n3755 == self.n3743:
      self.n3756 = 1L
    else:
      self.n3756 = 0L
    self.n3733 = (self.n3738 + self.n3730) & 0x3FFL
    self.n3728r = self.n6548
    self.n3728e = self.n6547
    self.n3728d = self.n3721
    self.n3721r = self.n6548
    self.n3721e = self.n6547
    self.n3721d = self.n3714
    self.n3714r = self.n6548
    self.n3714e = self.n6547
    self.n3714d = self.n3707
    self.n3707r = self.n6548
    self.n3707e = self.n6547
    self.n3707d = self.n3700
    self.n3699r = self.n6548
    self.n3699e = self.n6547
    self.n3699d = self.n3692
    self.n3692r = self.n6548
    self.n3692e = self.n6547
    self.n3692d = self.n3685
    self.n3685r = self.n6548
    self.n3685e = self.n6547
    self.n3685d = self.n3678
    self.n3678r = self.n6548
    self.n3678e = self.n6547
    self.n3678d = self.n3671
    self.n3670r = self.n6548
    self.n3670e = self.n6547
    self.n3670d = self.n3663
    self.n3663r = self.n6548
    self.n3663e = self.n6547
    self.n3663d = self.n3656
    self.n3656r = self.n6548
    self.n3656e = self.n6547
    self.n3656d = self.n3649
    self.n3634 = self.n3632 << 8 | self.n3633
    self.n3624 = self.n3622 << 8 | self.n3623
    self.n3621r = self.n6548
    self.n3621e = self.n6547
    self.n3621d = self.n3614
    isNeg0 = self.n3534 & 0x80L
    isNeg1 = self.n3568 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n3605 = (self.n3534 * self.n3568) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n3605 = (self.n3534 * (0xFF00L | self.n3568)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n3605 = ((0xFF00L | self.n3534) * self.n3568) & 0xFFFFL
    else:
      self.n3605 = ((0xFF00L | self.n3534) * (0xFF00L | self.n3568)) & 0xFFFFL
    isNeg0 = self.n3533 & 0x80L
    isNeg1 = self.n3569 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n3596 = (self.n3533 * self.n3569) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n3596 = (self.n3533 * (0xFF00L | self.n3569)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n3596 = ((0xFF00L | self.n3533) * self.n3569) & 0xFFFFL
    else:
      self.n3596 = ((0xFF00L | self.n3533) * (0xFF00L | self.n3569)) & 0xFFFFL
    self.n3595r = self.n6548
    self.n3595e = self.n6547
    self.n3595d = self.n3588
    isNeg0 = self.n3534 & 0x80L
    isNeg1 = self.n3569 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n3579 = (self.n3534 * self.n3569) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n3579 = (self.n3534 * (0xFF00L | self.n3569)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n3579 = ((0xFF00L | self.n3534) * self.n3569) & 0xFFFFL
    else:
      self.n3579 = ((0xFF00L | self.n3534) * (0xFF00L | self.n3569)) & 0xFFFFL
    isNeg0 = self.n3533 & 0x80L
    isNeg1 = self.n3568 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n3570 = (self.n3533 * self.n3568) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n3570 = (self.n3533 * (0xFF00L | self.n3568)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n3570 = ((0xFF00L | self.n3533) * self.n3568) & 0xFFFFL
    else:
      self.n3570 = ((0xFF00L | self.n3533) * (0xFF00L | self.n3568)) & 0xFFFFL
    self.n3567e = self.n6547
    self.n3567a = self.n3516
    self.n3562r = self.n6548
    self.n3562e = self.n6547
    self.n3562d = self.n3555
    self.n3555r = self.n6548
    self.n3555e = self.n6547
    self.n3555d = self.n3525
    self.n3548r = self.n6548
    self.n3548e = self.n6547
    self.n3548d = self.n3541
    self.n3541r = self.n6548
    self.n3541e = self.n6547
    self.n3541d = self.n3524
    if self.n3438 == self.n3439:
      self.n3440 = 1L
    else:
      self.n3440 = 0L
    self.n3433 = (self.n3438 + self.n3430) & 0x7FFL
    self.n3427 = (self.n3356 & 0x8000L) | (self.n3356 & 0x4000L) | (self.n3356 & 0x2000L) | (self.n3356 & 0x1000L) | (self.n3356 & 0x800L) | (self.n3356 & 0x400L) | (self.n3356 & 0x200L) | (self.n3356 & 0x100L) | (self.n3356 & 0x80L) | (self.n3356 & 0x40L) | (self.n3356 & 0x20L) | (self.n3356 & 0x10L) | (self.n3356 & 0x8L) | (self.n3356 & 0x4L) | (self.n3356 & 0x2L) | (self.n3356 & 0x1L)
    self.n3426 = ((self.n3356 & 0x80000000L) >> 16) | ((self.n3356 & 0x40000000L) >> 16) | ((self.n3356 & 0x20000000L) >> 16) | ((self.n3356 & 0x10000000L) >> 16) | ((self.n3356 & 0x8000000L) >> 16) | ((self.n3356 & 0x4000000L) >> 16) | ((self.n3356 & 0x2000000L) >> 16) | ((self.n3356 & 0x1000000L) >> 16) | ((self.n3356 & 0x800000L) >> 16) | ((self.n3356 & 0x400000L) >> 16) | ((self.n3356 & 0x200000L) >> 16) | ((self.n3356 & 0x100000L) >> 16) | ((self.n3356 & 0x80000L) >> 16) | ((self.n3356 & 0x40000L) >> 16) | ((self.n3356 & 0x20000L) >> 16) | ((self.n3356 & 0x10000L) >> 16)
    self.n3425 = (self.n3283 & 0x8000L) | (self.n3283 & 0x4000L) | (self.n3283 & 0x2000L) | (self.n3283 & 0x1000L) | (self.n3283 & 0x800L) | (self.n3283 & 0x400L) | (self.n3283 & 0x200L) | (self.n3283 & 0x100L) | (self.n3283 & 0x80L) | (self.n3283 & 0x40L) | (self.n3283 & 0x20L) | (self.n3283 & 0x10L) | (self.n3283 & 0x8L) | (self.n3283 & 0x4L) | (self.n3283 & 0x2L) | (self.n3283 & 0x1L)
    self.n3424 = ((self.n3283 & 0x80000000L) >> 16) | ((self.n3283 & 0x40000000L) >> 16) | ((self.n3283 & 0x20000000L) >> 16) | ((self.n3283 & 0x10000000L) >> 16) | ((self.n3283 & 0x8000000L) >> 16) | ((self.n3283 & 0x4000000L) >> 16) | ((self.n3283 & 0x2000000L) >> 16) | ((self.n3283 & 0x1000000L) >> 16) | ((self.n3283 & 0x800000L) >> 16) | ((self.n3283 & 0x400000L) >> 16) | ((self.n3283 & 0x200000L) >> 16) | ((self.n3283 & 0x100000L) >> 16) | ((self.n3283 & 0x80000L) >> 16) | ((self.n3283 & 0x40000L) >> 16) | ((self.n3283 & 0x20000L) >> 16) | ((self.n3283 & 0x10000L) >> 16)
    if self.n3309 == self.n3305:
      self.n3322 = 1L
    else:
      self.n3322 = 0L
    if self.n3309 == self.n3304:
      self.n3321 = 1L
    else:
      self.n3321 = 0L
    if self.n3309 == self.n3299:
      self.n3312 = 1L
    else:
      self.n3312 = 0L
    if self.n3309 == self.n3298:
      self.n3311 = 1L
    else:
      self.n3311 = 0L
    if self.n3309 == self.n3297:
      self.n3310 = 1L
    else:
      self.n3310 = 0L
    self.n3287 = (self.n3292 + self.n3284) & 0x3FFL
    if self.n3219 == self.n3262:
      self.n3263 = 1L
    else:
      self.n3263 = 0L
    self.n3261r = self.n6548
    self.n3261e = self.n6547
    self.n3261d = self.n3151
    if self.n3236 == self.n3232:
      self.n3249 = 1L
    else:
      self.n3249 = 0L
    if self.n3236 == self.n3231:
      self.n3248 = 1L
    else:
      self.n3248 = 0L
    if self.n3236 == self.n3226:
      self.n3239 = 1L
    else:
      self.n3239 = 0L
    if self.n3236 == self.n3225:
      self.n3238 = 1L
    else:
      self.n3238 = 0L
    if self.n3236 == self.n3224:
      self.n3237 = 1L
    else:
      self.n3237 = 0L
    self.n3214 = (self.n3219 + self.n3211) & 0x3FFL
    self.n3209r = self.n6548
    self.n3209e = self.n6547
    self.n3209d = self.n3202
    self.n3202r = self.n6548
    self.n3202e = self.n6547
    self.n3202d = self.n3195
    self.n3195r = self.n6548
    self.n3195e = self.n6547
    self.n3195d = self.n3188
    self.n3188r = self.n6548
    self.n3188e = self.n6547
    self.n3188d = self.n3181
    self.n3180r = self.n6548
    self.n3180e = self.n6547
    self.n3180d = self.n3173
    self.n3173r = self.n6548
    self.n3173e = self.n6547
    self.n3173d = self.n3166
    self.n3166r = self.n6548
    self.n3166e = self.n6547
    self.n3166d = self.n3159
    self.n3159r = self.n6548
    self.n3159e = self.n6547
    self.n3159d = self.n3152
    self.n3151r = self.n6548
    self.n3151e = self.n6547
    self.n3151d = self.n3144
    self.n3144r = self.n6548
    self.n3144e = self.n6547
    self.n3144d = self.n3137
    self.n3137r = self.n6548
    self.n3137e = self.n6547
    self.n3137d = self.n3130
    self.n3115 = self.n3113 << 8 | self.n3114
    self.n3105 = self.n3103 << 8 | self.n3104
    self.n3102r = self.n6548
    self.n3102e = self.n6547
    self.n3102d = self.n3095
    isNeg0 = self.n3015 & 0x80L
    isNeg1 = self.n3049 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n3086 = (self.n3015 * self.n3049) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n3086 = (self.n3015 * (0xFF00L | self.n3049)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n3086 = ((0xFF00L | self.n3015) * self.n3049) & 0xFFFFL
    else:
      self.n3086 = ((0xFF00L | self.n3015) * (0xFF00L | self.n3049)) & 0xFFFFL
    isNeg0 = self.n3014 & 0x80L
    isNeg1 = self.n3050 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n3077 = (self.n3014 * self.n3050) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n3077 = (self.n3014 * (0xFF00L | self.n3050)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n3077 = ((0xFF00L | self.n3014) * self.n3050) & 0xFFFFL
    else:
      self.n3077 = ((0xFF00L | self.n3014) * (0xFF00L | self.n3050)) & 0xFFFFL
    self.n3076r = self.n6548
    self.n3076e = self.n6547
    self.n3076d = self.n3069
    isNeg0 = self.n3015 & 0x80L
    isNeg1 = self.n3050 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n3060 = (self.n3015 * self.n3050) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n3060 = (self.n3015 * (0xFF00L | self.n3050)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n3060 = ((0xFF00L | self.n3015) * self.n3050) & 0xFFFFL
    else:
      self.n3060 = ((0xFF00L | self.n3015) * (0xFF00L | self.n3050)) & 0xFFFFL
    isNeg0 = self.n3014 & 0x80L
    isNeg1 = self.n3049 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n3051 = (self.n3014 * self.n3049) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n3051 = (self.n3014 * (0xFF00L | self.n3049)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n3051 = ((0xFF00L | self.n3014) * self.n3049) & 0xFFFFL
    else:
      self.n3051 = ((0xFF00L | self.n3014) * (0xFF00L | self.n3049)) & 0xFFFFL
    self.n3048e = self.n6547
    self.n3048a = self.n2997
    self.n3043r = self.n6548
    self.n3043e = self.n6547
    self.n3043d = self.n3036
    self.n3036r = self.n6548
    self.n3036e = self.n6547
    self.n3036d = self.n3006
    self.n3029r = self.n6548
    self.n3029e = self.n6547
    self.n3029d = self.n3022
    self.n3022r = self.n6548
    self.n3022e = self.n6547
    self.n3022d = self.n3005
    if self.n2919 == self.n2920:
      self.n2921 = 1L
    else:
      self.n2921 = 0L
    self.n2914 = (self.n2919 + self.n2911) & 0x7FFL
    self.n2908 = (self.n2837 & 0x8000L) | (self.n2837 & 0x4000L) | (self.n2837 & 0x2000L) | (self.n2837 & 0x1000L) | (self.n2837 & 0x800L) | (self.n2837 & 0x400L) | (self.n2837 & 0x200L) | (self.n2837 & 0x100L) | (self.n2837 & 0x80L) | (self.n2837 & 0x40L) | (self.n2837 & 0x20L) | (self.n2837 & 0x10L) | (self.n2837 & 0x8L) | (self.n2837 & 0x4L) | (self.n2837 & 0x2L) | (self.n2837 & 0x1L)
    self.n2907 = ((self.n2837 & 0x80000000L) >> 16) | ((self.n2837 & 0x40000000L) >> 16) | ((self.n2837 & 0x20000000L) >> 16) | ((self.n2837 & 0x10000000L) >> 16) | ((self.n2837 & 0x8000000L) >> 16) | ((self.n2837 & 0x4000000L) >> 16) | ((self.n2837 & 0x2000000L) >> 16) | ((self.n2837 & 0x1000000L) >> 16) | ((self.n2837 & 0x800000L) >> 16) | ((self.n2837 & 0x400000L) >> 16) | ((self.n2837 & 0x200000L) >> 16) | ((self.n2837 & 0x100000L) >> 16) | ((self.n2837 & 0x80000L) >> 16) | ((self.n2837 & 0x40000L) >> 16) | ((self.n2837 & 0x20000L) >> 16) | ((self.n2837 & 0x10000L) >> 16)
    self.n2906 = (self.n2764 & 0x8000L) | (self.n2764 & 0x4000L) | (self.n2764 & 0x2000L) | (self.n2764 & 0x1000L) | (self.n2764 & 0x800L) | (self.n2764 & 0x400L) | (self.n2764 & 0x200L) | (self.n2764 & 0x100L) | (self.n2764 & 0x80L) | (self.n2764 & 0x40L) | (self.n2764 & 0x20L) | (self.n2764 & 0x10L) | (self.n2764 & 0x8L) | (self.n2764 & 0x4L) | (self.n2764 & 0x2L) | (self.n2764 & 0x1L)
    self.n2905 = ((self.n2764 & 0x80000000L) >> 16) | ((self.n2764 & 0x40000000L) >> 16) | ((self.n2764 & 0x20000000L) >> 16) | ((self.n2764 & 0x10000000L) >> 16) | ((self.n2764 & 0x8000000L) >> 16) | ((self.n2764 & 0x4000000L) >> 16) | ((self.n2764 & 0x2000000L) >> 16) | ((self.n2764 & 0x1000000L) >> 16) | ((self.n2764 & 0x800000L) >> 16) | ((self.n2764 & 0x400000L) >> 16) | ((self.n2764 & 0x200000L) >> 16) | ((self.n2764 & 0x100000L) >> 16) | ((self.n2764 & 0x80000L) >> 16) | ((self.n2764 & 0x40000L) >> 16) | ((self.n2764 & 0x20000L) >> 16) | ((self.n2764 & 0x10000L) >> 16)
    if self.n2790 == self.n2786:
      self.n2803 = 1L
    else:
      self.n2803 = 0L
    if self.n2790 == self.n2785:
      self.n2802 = 1L
    else:
      self.n2802 = 0L
    if self.n2790 == self.n2780:
      self.n2793 = 1L
    else:
      self.n2793 = 0L
    if self.n2790 == self.n2779:
      self.n2792 = 1L
    else:
      self.n2792 = 0L
    if self.n2790 == self.n2778:
      self.n2791 = 1L
    else:
      self.n2791 = 0L
    self.n2768 = (self.n2773 + self.n2765) & 0x3FFL
    if self.n2700 == self.n2743:
      self.n2744 = 1L
    else:
      self.n2744 = 0L
    self.n2742r = self.n6548
    self.n2742e = self.n6547
    self.n2742d = self.n2632
    if self.n2717 == self.n2713:
      self.n2730 = 1L
    else:
      self.n2730 = 0L
    if self.n2717 == self.n2712:
      self.n2729 = 1L
    else:
      self.n2729 = 0L
    if self.n2717 == self.n2707:
      self.n2720 = 1L
    else:
      self.n2720 = 0L
    if self.n2717 == self.n2706:
      self.n2719 = 1L
    else:
      self.n2719 = 0L
    if self.n2717 == self.n2705:
      self.n2718 = 1L
    else:
      self.n2718 = 0L
    self.n2695 = (self.n2700 + self.n2692) & 0x3FFL
    self.n2690r = self.n6548
    self.n2690e = self.n6547
    self.n2690d = self.n2683
    self.n2683r = self.n6548
    self.n2683e = self.n6547
    self.n2683d = self.n2676
    self.n2676r = self.n6548
    self.n2676e = self.n6547
    self.n2676d = self.n2669
    self.n2669r = self.n6548
    self.n2669e = self.n6547
    self.n2669d = self.n2662
    self.n2661r = self.n6548
    self.n2661e = self.n6547
    self.n2661d = self.n2654
    self.n2654r = self.n6548
    self.n2654e = self.n6547
    self.n2654d = self.n2647
    self.n2647r = self.n6548
    self.n2647e = self.n6547
    self.n2647d = self.n2640
    self.n2640r = self.n6548
    self.n2640e = self.n6547
    self.n2640d = self.n2633
    self.n2632r = self.n6548
    self.n2632e = self.n6547
    self.n2632d = self.n2625
    self.n2625r = self.n6548
    self.n2625e = self.n6547
    self.n2625d = self.n2618
    self.n2618r = self.n6548
    self.n2618e = self.n6547
    self.n2618d = self.n2611
    self.n2596 = self.n2594 << 8 | self.n2595
    self.n2586 = self.n2584 << 8 | self.n2585
    self.n2583r = self.n6548
    self.n2583e = self.n6547
    self.n2583d = self.n2576
    isNeg0 = self.n2496 & 0x80L
    isNeg1 = self.n2530 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n2567 = (self.n2496 * self.n2530) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n2567 = (self.n2496 * (0xFF00L | self.n2530)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n2567 = ((0xFF00L | self.n2496) * self.n2530) & 0xFFFFL
    else:
      self.n2567 = ((0xFF00L | self.n2496) * (0xFF00L | self.n2530)) & 0xFFFFL
    isNeg0 = self.n2495 & 0x80L
    isNeg1 = self.n2531 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n2558 = (self.n2495 * self.n2531) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n2558 = (self.n2495 * (0xFF00L | self.n2531)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n2558 = ((0xFF00L | self.n2495) * self.n2531) & 0xFFFFL
    else:
      self.n2558 = ((0xFF00L | self.n2495) * (0xFF00L | self.n2531)) & 0xFFFFL
    self.n2557r = self.n6548
    self.n2557e = self.n6547
    self.n2557d = self.n2550
    isNeg0 = self.n2496 & 0x80L
    isNeg1 = self.n2531 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n2541 = (self.n2496 * self.n2531) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n2541 = (self.n2496 * (0xFF00L | self.n2531)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n2541 = ((0xFF00L | self.n2496) * self.n2531) & 0xFFFFL
    else:
      self.n2541 = ((0xFF00L | self.n2496) * (0xFF00L | self.n2531)) & 0xFFFFL
    isNeg0 = self.n2495 & 0x80L
    isNeg1 = self.n2530 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n2532 = (self.n2495 * self.n2530) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n2532 = (self.n2495 * (0xFF00L | self.n2530)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n2532 = ((0xFF00L | self.n2495) * self.n2530) & 0xFFFFL
    else:
      self.n2532 = ((0xFF00L | self.n2495) * (0xFF00L | self.n2530)) & 0xFFFFL
    self.n2529e = self.n6547
    self.n2529a = self.n2478
    self.n2524r = self.n6548
    self.n2524e = self.n6547
    self.n2524d = self.n2517
    self.n2517r = self.n6548
    self.n2517e = self.n6547
    self.n2517d = self.n2487
    self.n2510r = self.n6548
    self.n2510e = self.n6547
    self.n2510d = self.n2503
    self.n2503r = self.n6548
    self.n2503e = self.n6547
    self.n2503d = self.n2486
    if self.n2400 == self.n2401:
      self.n2402 = 1L
    else:
      self.n2402 = 0L
    self.n2395 = (self.n2400 + self.n2392) & 0x7FFL
    self.n2389 = (self.n2318 & 0x8000L) | (self.n2318 & 0x4000L) | (self.n2318 & 0x2000L) | (self.n2318 & 0x1000L) | (self.n2318 & 0x800L) | (self.n2318 & 0x400L) | (self.n2318 & 0x200L) | (self.n2318 & 0x100L) | (self.n2318 & 0x80L) | (self.n2318 & 0x40L) | (self.n2318 & 0x20L) | (self.n2318 & 0x10L) | (self.n2318 & 0x8L) | (self.n2318 & 0x4L) | (self.n2318 & 0x2L) | (self.n2318 & 0x1L)
    self.n2388 = ((self.n2318 & 0x80000000L) >> 16) | ((self.n2318 & 0x40000000L) >> 16) | ((self.n2318 & 0x20000000L) >> 16) | ((self.n2318 & 0x10000000L) >> 16) | ((self.n2318 & 0x8000000L) >> 16) | ((self.n2318 & 0x4000000L) >> 16) | ((self.n2318 & 0x2000000L) >> 16) | ((self.n2318 & 0x1000000L) >> 16) | ((self.n2318 & 0x800000L) >> 16) | ((self.n2318 & 0x400000L) >> 16) | ((self.n2318 & 0x200000L) >> 16) | ((self.n2318 & 0x100000L) >> 16) | ((self.n2318 & 0x80000L) >> 16) | ((self.n2318 & 0x40000L) >> 16) | ((self.n2318 & 0x20000L) >> 16) | ((self.n2318 & 0x10000L) >> 16)
    self.n2387 = (self.n2245 & 0x8000L) | (self.n2245 & 0x4000L) | (self.n2245 & 0x2000L) | (self.n2245 & 0x1000L) | (self.n2245 & 0x800L) | (self.n2245 & 0x400L) | (self.n2245 & 0x200L) | (self.n2245 & 0x100L) | (self.n2245 & 0x80L) | (self.n2245 & 0x40L) | (self.n2245 & 0x20L) | (self.n2245 & 0x10L) | (self.n2245 & 0x8L) | (self.n2245 & 0x4L) | (self.n2245 & 0x2L) | (self.n2245 & 0x1L)
    self.n2386 = ((self.n2245 & 0x80000000L) >> 16) | ((self.n2245 & 0x40000000L) >> 16) | ((self.n2245 & 0x20000000L) >> 16) | ((self.n2245 & 0x10000000L) >> 16) | ((self.n2245 & 0x8000000L) >> 16) | ((self.n2245 & 0x4000000L) >> 16) | ((self.n2245 & 0x2000000L) >> 16) | ((self.n2245 & 0x1000000L) >> 16) | ((self.n2245 & 0x800000L) >> 16) | ((self.n2245 & 0x400000L) >> 16) | ((self.n2245 & 0x200000L) >> 16) | ((self.n2245 & 0x100000L) >> 16) | ((self.n2245 & 0x80000L) >> 16) | ((self.n2245 & 0x40000L) >> 16) | ((self.n2245 & 0x20000L) >> 16) | ((self.n2245 & 0x10000L) >> 16)
    if self.n2271 == self.n2267:
      self.n2284 = 1L
    else:
      self.n2284 = 0L
    if self.n2271 == self.n2266:
      self.n2283 = 1L
    else:
      self.n2283 = 0L
    if self.n2271 == self.n2261:
      self.n2274 = 1L
    else:
      self.n2274 = 0L
    if self.n2271 == self.n2260:
      self.n2273 = 1L
    else:
      self.n2273 = 0L
    if self.n2271 == self.n2259:
      self.n2272 = 1L
    else:
      self.n2272 = 0L
    self.n2249 = (self.n2254 + self.n2246) & 0x3FFL
    if self.n2181 == self.n2224:
      self.n2225 = 1L
    else:
      self.n2225 = 0L
    self.n2223r = self.n6548
    self.n2223e = self.n6547
    self.n2223d = self.n2113
    if self.n2198 == self.n2194:
      self.n2211 = 1L
    else:
      self.n2211 = 0L
    if self.n2198 == self.n2193:
      self.n2210 = 1L
    else:
      self.n2210 = 0L
    if self.n2198 == self.n2188:
      self.n2201 = 1L
    else:
      self.n2201 = 0L
    if self.n2198 == self.n2187:
      self.n2200 = 1L
    else:
      self.n2200 = 0L
    if self.n2198 == self.n2186:
      self.n2199 = 1L
    else:
      self.n2199 = 0L
    self.n2176 = (self.n2181 + self.n2173) & 0x3FFL
    self.n2171r = self.n6548
    self.n2171e = self.n6547
    self.n2171d = self.n2164
    self.n2164r = self.n6548
    self.n2164e = self.n6547
    self.n2164d = self.n2157
    self.n2157r = self.n6548
    self.n2157e = self.n6547
    self.n2157d = self.n2150
    self.n2150r = self.n6548
    self.n2150e = self.n6547
    self.n2150d = self.n2143
    self.n2142r = self.n6548
    self.n2142e = self.n6547
    self.n2142d = self.n2135
    self.n2135r = self.n6548
    self.n2135e = self.n6547
    self.n2135d = self.n2128
    self.n2128r = self.n6548
    self.n2128e = self.n6547
    self.n2128d = self.n2121
    self.n2121r = self.n6548
    self.n2121e = self.n6547
    self.n2121d = self.n2114
    self.n2113r = self.n6548
    self.n2113e = self.n6547
    self.n2113d = self.n2106
    self.n2106r = self.n6548
    self.n2106e = self.n6547
    self.n2106d = self.n2099
    self.n2099r = self.n6548
    self.n2099e = self.n6547
    self.n2099d = self.n2092
    self.n2077 = self.n2075 << 8 | self.n2076
    self.n2067 = self.n2065 << 8 | self.n2066
    self.n2064r = self.n6548
    self.n2064e = self.n6547
    self.n2064d = self.n2057
    isNeg0 = self.n1977 & 0x80L
    isNeg1 = self.n2011 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n2048 = (self.n1977 * self.n2011) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n2048 = (self.n1977 * (0xFF00L | self.n2011)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n2048 = ((0xFF00L | self.n1977) * self.n2011) & 0xFFFFL
    else:
      self.n2048 = ((0xFF00L | self.n1977) * (0xFF00L | self.n2011)) & 0xFFFFL
    isNeg0 = self.n1976 & 0x80L
    isNeg1 = self.n2012 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n2039 = (self.n1976 * self.n2012) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n2039 = (self.n1976 * (0xFF00L | self.n2012)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n2039 = ((0xFF00L | self.n1976) * self.n2012) & 0xFFFFL
    else:
      self.n2039 = ((0xFF00L | self.n1976) * (0xFF00L | self.n2012)) & 0xFFFFL
    self.n2038r = self.n6548
    self.n2038e = self.n6547
    self.n2038d = self.n2031
    isNeg0 = self.n1977 & 0x80L
    isNeg1 = self.n2012 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n2022 = (self.n1977 * self.n2012) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n2022 = (self.n1977 * (0xFF00L | self.n2012)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n2022 = ((0xFF00L | self.n1977) * self.n2012) & 0xFFFFL
    else:
      self.n2022 = ((0xFF00L | self.n1977) * (0xFF00L | self.n2012)) & 0xFFFFL
    isNeg0 = self.n1976 & 0x80L
    isNeg1 = self.n2011 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n2013 = (self.n1976 * self.n2011) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n2013 = (self.n1976 * (0xFF00L | self.n2011)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n2013 = ((0xFF00L | self.n1976) * self.n2011) & 0xFFFFL
    else:
      self.n2013 = ((0xFF00L | self.n1976) * (0xFF00L | self.n2011)) & 0xFFFFL
    self.n2010e = self.n6547
    self.n2010a = self.n1959
    self.n2005r = self.n6548
    self.n2005e = self.n6547
    self.n2005d = self.n1998
    self.n1998r = self.n6548
    self.n1998e = self.n6547
    self.n1998d = self.n1968
    self.n1991r = self.n6548
    self.n1991e = self.n6547
    self.n1991d = self.n1984
    self.n1984r = self.n6548
    self.n1984e = self.n6547
    self.n1984d = self.n1967
    if self.n1881 == self.n1882:
      self.n1883 = 1L
    else:
      self.n1883 = 0L
    self.n1876 = (self.n1881 + self.n1873) & 0x7FFL
    self.n1870 = (self.n1799 & 0x8000L) | (self.n1799 & 0x4000L) | (self.n1799 & 0x2000L) | (self.n1799 & 0x1000L) | (self.n1799 & 0x800L) | (self.n1799 & 0x400L) | (self.n1799 & 0x200L) | (self.n1799 & 0x100L) | (self.n1799 & 0x80L) | (self.n1799 & 0x40L) | (self.n1799 & 0x20L) | (self.n1799 & 0x10L) | (self.n1799 & 0x8L) | (self.n1799 & 0x4L) | (self.n1799 & 0x2L) | (self.n1799 & 0x1L)
    self.n1869 = ((self.n1799 & 0x80000000L) >> 16) | ((self.n1799 & 0x40000000L) >> 16) | ((self.n1799 & 0x20000000L) >> 16) | ((self.n1799 & 0x10000000L) >> 16) | ((self.n1799 & 0x8000000L) >> 16) | ((self.n1799 & 0x4000000L) >> 16) | ((self.n1799 & 0x2000000L) >> 16) | ((self.n1799 & 0x1000000L) >> 16) | ((self.n1799 & 0x800000L) >> 16) | ((self.n1799 & 0x400000L) >> 16) | ((self.n1799 & 0x200000L) >> 16) | ((self.n1799 & 0x100000L) >> 16) | ((self.n1799 & 0x80000L) >> 16) | ((self.n1799 & 0x40000L) >> 16) | ((self.n1799 & 0x20000L) >> 16) | ((self.n1799 & 0x10000L) >> 16)
    self.n1868 = (self.n1726 & 0x8000L) | (self.n1726 & 0x4000L) | (self.n1726 & 0x2000L) | (self.n1726 & 0x1000L) | (self.n1726 & 0x800L) | (self.n1726 & 0x400L) | (self.n1726 & 0x200L) | (self.n1726 & 0x100L) | (self.n1726 & 0x80L) | (self.n1726 & 0x40L) | (self.n1726 & 0x20L) | (self.n1726 & 0x10L) | (self.n1726 & 0x8L) | (self.n1726 & 0x4L) | (self.n1726 & 0x2L) | (self.n1726 & 0x1L)
    self.n1867 = ((self.n1726 & 0x80000000L) >> 16) | ((self.n1726 & 0x40000000L) >> 16) | ((self.n1726 & 0x20000000L) >> 16) | ((self.n1726 & 0x10000000L) >> 16) | ((self.n1726 & 0x8000000L) >> 16) | ((self.n1726 & 0x4000000L) >> 16) | ((self.n1726 & 0x2000000L) >> 16) | ((self.n1726 & 0x1000000L) >> 16) | ((self.n1726 & 0x800000L) >> 16) | ((self.n1726 & 0x400000L) >> 16) | ((self.n1726 & 0x200000L) >> 16) | ((self.n1726 & 0x100000L) >> 16) | ((self.n1726 & 0x80000L) >> 16) | ((self.n1726 & 0x40000L) >> 16) | ((self.n1726 & 0x20000L) >> 16) | ((self.n1726 & 0x10000L) >> 16)
    if self.n1752 == self.n1748:
      self.n1765 = 1L
    else:
      self.n1765 = 0L
    if self.n1752 == self.n1747:
      self.n1764 = 1L
    else:
      self.n1764 = 0L
    if self.n1752 == self.n1742:
      self.n1755 = 1L
    else:
      self.n1755 = 0L
    if self.n1752 == self.n1741:
      self.n1754 = 1L
    else:
      self.n1754 = 0L
    if self.n1752 == self.n1740:
      self.n1753 = 1L
    else:
      self.n1753 = 0L
    self.n1730 = (self.n1735 + self.n1727) & 0x3FFL
    if self.n1662 == self.n1705:
      self.n1706 = 1L
    else:
      self.n1706 = 0L
    self.n1704r = self.n6548
    self.n1704e = self.n6547
    self.n1704d = self.n1594
    if self.n1679 == self.n1675:
      self.n1692 = 1L
    else:
      self.n1692 = 0L
    if self.n1679 == self.n1674:
      self.n1691 = 1L
    else:
      self.n1691 = 0L
    if self.n1679 == self.n1669:
      self.n1682 = 1L
    else:
      self.n1682 = 0L
    if self.n1679 == self.n1668:
      self.n1681 = 1L
    else:
      self.n1681 = 0L
    if self.n1679 == self.n1667:
      self.n1680 = 1L
    else:
      self.n1680 = 0L
    self.n1657 = (self.n1662 + self.n1654) & 0x3FFL
    self.n1652r = self.n6548
    self.n1652e = self.n6547
    self.n1652d = self.n1645
    self.n1645r = self.n6548
    self.n1645e = self.n6547
    self.n1645d = self.n1638
    self.n1638r = self.n6548
    self.n1638e = self.n6547
    self.n1638d = self.n1631
    self.n1631r = self.n6548
    self.n1631e = self.n6547
    self.n1631d = self.n1624
    self.n1623r = self.n6548
    self.n1623e = self.n6547
    self.n1623d = self.n1616
    self.n1616r = self.n6548
    self.n1616e = self.n6547
    self.n1616d = self.n1609
    self.n1609r = self.n6548
    self.n1609e = self.n6547
    self.n1609d = self.n1602
    self.n1602r = self.n6548
    self.n1602e = self.n6547
    self.n1602d = self.n1595
    self.n1594r = self.n6548
    self.n1594e = self.n6547
    self.n1594d = self.n1587
    self.n1587r = self.n6548
    self.n1587e = self.n6547
    self.n1587d = self.n1580
    self.n1580r = self.n6548
    self.n1580e = self.n6547
    self.n1580d = self.n1573
    self.n1558 = self.n1556 << 8 | self.n1557
    self.n1548 = self.n1546 << 8 | self.n1547
    self.n1545r = self.n6548
    self.n1545e = self.n6547
    self.n1545d = self.n1538
    isNeg0 = self.n1458 & 0x80L
    isNeg1 = self.n1492 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n1529 = (self.n1458 * self.n1492) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n1529 = (self.n1458 * (0xFF00L | self.n1492)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n1529 = ((0xFF00L | self.n1458) * self.n1492) & 0xFFFFL
    else:
      self.n1529 = ((0xFF00L | self.n1458) * (0xFF00L | self.n1492)) & 0xFFFFL
    isNeg0 = self.n1457 & 0x80L
    isNeg1 = self.n1493 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n1520 = (self.n1457 * self.n1493) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n1520 = (self.n1457 * (0xFF00L | self.n1493)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n1520 = ((0xFF00L | self.n1457) * self.n1493) & 0xFFFFL
    else:
      self.n1520 = ((0xFF00L | self.n1457) * (0xFF00L | self.n1493)) & 0xFFFFL
    self.n1519r = self.n6548
    self.n1519e = self.n6547
    self.n1519d = self.n1512
    isNeg0 = self.n1458 & 0x80L
    isNeg1 = self.n1493 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n1503 = (self.n1458 * self.n1493) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n1503 = (self.n1458 * (0xFF00L | self.n1493)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n1503 = ((0xFF00L | self.n1458) * self.n1493) & 0xFFFFL
    else:
      self.n1503 = ((0xFF00L | self.n1458) * (0xFF00L | self.n1493)) & 0xFFFFL
    isNeg0 = self.n1457 & 0x80L
    isNeg1 = self.n1492 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n1494 = (self.n1457 * self.n1492) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n1494 = (self.n1457 * (0xFF00L | self.n1492)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n1494 = ((0xFF00L | self.n1457) * self.n1492) & 0xFFFFL
    else:
      self.n1494 = ((0xFF00L | self.n1457) * (0xFF00L | self.n1492)) & 0xFFFFL
    self.n1491e = self.n6547
    self.n1491a = self.n1440
    self.n1486r = self.n6548
    self.n1486e = self.n6547
    self.n1486d = self.n1479
    self.n1479r = self.n6548
    self.n1479e = self.n6547
    self.n1479d = self.n1449
    self.n1472r = self.n6548
    self.n1472e = self.n6547
    self.n1472d = self.n1465
    self.n1465r = self.n6548
    self.n1465e = self.n6547
    self.n1465d = self.n1448
    if self.n1362 == self.n1363:
      self.n1364 = 1L
    else:
      self.n1364 = 0L
    self.n1357 = (self.n1362 + self.n1354) & 0x7FFL
    self.n1351 = (self.n1280 & 0x8000L) | (self.n1280 & 0x4000L) | (self.n1280 & 0x2000L) | (self.n1280 & 0x1000L) | (self.n1280 & 0x800L) | (self.n1280 & 0x400L) | (self.n1280 & 0x200L) | (self.n1280 & 0x100L) | (self.n1280 & 0x80L) | (self.n1280 & 0x40L) | (self.n1280 & 0x20L) | (self.n1280 & 0x10L) | (self.n1280 & 0x8L) | (self.n1280 & 0x4L) | (self.n1280 & 0x2L) | (self.n1280 & 0x1L)
    self.n1350 = ((self.n1280 & 0x80000000L) >> 16) | ((self.n1280 & 0x40000000L) >> 16) | ((self.n1280 & 0x20000000L) >> 16) | ((self.n1280 & 0x10000000L) >> 16) | ((self.n1280 & 0x8000000L) >> 16) | ((self.n1280 & 0x4000000L) >> 16) | ((self.n1280 & 0x2000000L) >> 16) | ((self.n1280 & 0x1000000L) >> 16) | ((self.n1280 & 0x800000L) >> 16) | ((self.n1280 & 0x400000L) >> 16) | ((self.n1280 & 0x200000L) >> 16) | ((self.n1280 & 0x100000L) >> 16) | ((self.n1280 & 0x80000L) >> 16) | ((self.n1280 & 0x40000L) >> 16) | ((self.n1280 & 0x20000L) >> 16) | ((self.n1280 & 0x10000L) >> 16)
    self.n1349 = (self.n1207 & 0x8000L) | (self.n1207 & 0x4000L) | (self.n1207 & 0x2000L) | (self.n1207 & 0x1000L) | (self.n1207 & 0x800L) | (self.n1207 & 0x400L) | (self.n1207 & 0x200L) | (self.n1207 & 0x100L) | (self.n1207 & 0x80L) | (self.n1207 & 0x40L) | (self.n1207 & 0x20L) | (self.n1207 & 0x10L) | (self.n1207 & 0x8L) | (self.n1207 & 0x4L) | (self.n1207 & 0x2L) | (self.n1207 & 0x1L)
    self.n1348 = ((self.n1207 & 0x80000000L) >> 16) | ((self.n1207 & 0x40000000L) >> 16) | ((self.n1207 & 0x20000000L) >> 16) | ((self.n1207 & 0x10000000L) >> 16) | ((self.n1207 & 0x8000000L) >> 16) | ((self.n1207 & 0x4000000L) >> 16) | ((self.n1207 & 0x2000000L) >> 16) | ((self.n1207 & 0x1000000L) >> 16) | ((self.n1207 & 0x800000L) >> 16) | ((self.n1207 & 0x400000L) >> 16) | ((self.n1207 & 0x200000L) >> 16) | ((self.n1207 & 0x100000L) >> 16) | ((self.n1207 & 0x80000L) >> 16) | ((self.n1207 & 0x40000L) >> 16) | ((self.n1207 & 0x20000L) >> 16) | ((self.n1207 & 0x10000L) >> 16)
    if self.n1233 == self.n1229:
      self.n1246 = 1L
    else:
      self.n1246 = 0L
    if self.n1233 == self.n1228:
      self.n1245 = 1L
    else:
      self.n1245 = 0L
    if self.n1233 == self.n1223:
      self.n1236 = 1L
    else:
      self.n1236 = 0L
    if self.n1233 == self.n1222:
      self.n1235 = 1L
    else:
      self.n1235 = 0L
    if self.n1233 == self.n1221:
      self.n1234 = 1L
    else:
      self.n1234 = 0L
    self.n1211 = (self.n1216 + self.n1208) & 0x3FFL
    if self.n1143 == self.n1186:
      self.n1187 = 1L
    else:
      self.n1187 = 0L
    self.n1185r = self.n6548
    self.n1185e = self.n6547
    self.n1185d = self.n1075
    if self.n1160 == self.n1156:
      self.n1173 = 1L
    else:
      self.n1173 = 0L
    if self.n1160 == self.n1155:
      self.n1172 = 1L
    else:
      self.n1172 = 0L
    if self.n1160 == self.n1150:
      self.n1163 = 1L
    else:
      self.n1163 = 0L
    if self.n1160 == self.n1149:
      self.n1162 = 1L
    else:
      self.n1162 = 0L
    if self.n1160 == self.n1148:
      self.n1161 = 1L
    else:
      self.n1161 = 0L
    self.n1138 = (self.n1143 + self.n1135) & 0x3FFL
    self.n1133r = self.n6548
    self.n1133e = self.n6547
    self.n1133d = self.n1126
    self.n1126r = self.n6548
    self.n1126e = self.n6547
    self.n1126d = self.n1119
    self.n1119r = self.n6548
    self.n1119e = self.n6547
    self.n1119d = self.n1112
    self.n1112r = self.n6548
    self.n1112e = self.n6547
    self.n1112d = self.n1105
    self.n1104r = self.n6548
    self.n1104e = self.n6547
    self.n1104d = self.n1097
    self.n1097r = self.n6548
    self.n1097e = self.n6547
    self.n1097d = self.n1090
    self.n1090r = self.n6548
    self.n1090e = self.n6547
    self.n1090d = self.n1083
    self.n1083r = self.n6548
    self.n1083e = self.n6547
    self.n1083d = self.n1076
    self.n1075r = self.n6548
    self.n1075e = self.n6547
    self.n1075d = self.n1068
    self.n1068r = self.n6548
    self.n1068e = self.n6547
    self.n1068d = self.n1061
    self.n1061r = self.n6548
    self.n1061e = self.n6547
    self.n1061d = self.n1054
    self.n1039 = self.n1037 << 8 | self.n1038
    self.n1029 = self.n1027 << 8 | self.n1028
    self.n1026r = self.n6548
    self.n1026e = self.n6547
    self.n1026d = self.n1019
    isNeg0 = self.n939 & 0x80L
    isNeg1 = self.n973 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n1010 = (self.n939 * self.n973) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n1010 = (self.n939 * (0xFF00L | self.n973)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n1010 = ((0xFF00L | self.n939) * self.n973) & 0xFFFFL
    else:
      self.n1010 = ((0xFF00L | self.n939) * (0xFF00L | self.n973)) & 0xFFFFL
    isNeg0 = self.n938 & 0x80L
    isNeg1 = self.n974 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n1001 = (self.n938 * self.n974) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n1001 = (self.n938 * (0xFF00L | self.n974)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n1001 = ((0xFF00L | self.n938) * self.n974) & 0xFFFFL
    else:
      self.n1001 = ((0xFF00L | self.n938) * (0xFF00L | self.n974)) & 0xFFFFL
    self.n1000r = self.n6548
    self.n1000e = self.n6547
    self.n1000d = self.n993
    isNeg0 = self.n939 & 0x80L
    isNeg1 = self.n974 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n984 = (self.n939 * self.n974) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n984 = (self.n939 * (0xFF00L | self.n974)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n984 = ((0xFF00L | self.n939) * self.n974) & 0xFFFFL
    else:
      self.n984 = ((0xFF00L | self.n939) * (0xFF00L | self.n974)) & 0xFFFFL
    isNeg0 = self.n938 & 0x80L
    isNeg1 = self.n973 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n975 = (self.n938 * self.n973) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n975 = (self.n938 * (0xFF00L | self.n973)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n975 = ((0xFF00L | self.n938) * self.n973) & 0xFFFFL
    else:
      self.n975 = ((0xFF00L | self.n938) * (0xFF00L | self.n973)) & 0xFFFFL
    self.n972e = self.n6547
    self.n972a = self.n921
    self.n967r = self.n6548
    self.n967e = self.n6547
    self.n967d = self.n960
    self.n960r = self.n6548
    self.n960e = self.n6547
    self.n960d = self.n930
    self.n953r = self.n6548
    self.n953e = self.n6547
    self.n953d = self.n946
    self.n946r = self.n6548
    self.n946e = self.n6547
    self.n946d = self.n929
    if self.n843 == self.n844:
      self.n845 = 1L
    else:
      self.n845 = 0L
    self.n838 = (self.n843 + self.n835) & 0x7FFL
    self.n832 = (self.n761 & 0x8000L) | (self.n761 & 0x4000L) | (self.n761 & 0x2000L) | (self.n761 & 0x1000L) | (self.n761 & 0x800L) | (self.n761 & 0x400L) | (self.n761 & 0x200L) | (self.n761 & 0x100L) | (self.n761 & 0x80L) | (self.n761 & 0x40L) | (self.n761 & 0x20L) | (self.n761 & 0x10L) | (self.n761 & 0x8L) | (self.n761 & 0x4L) | (self.n761 & 0x2L) | (self.n761 & 0x1L)
    self.n831 = ((self.n761 & 0x80000000L) >> 16) | ((self.n761 & 0x40000000L) >> 16) | ((self.n761 & 0x20000000L) >> 16) | ((self.n761 & 0x10000000L) >> 16) | ((self.n761 & 0x8000000L) >> 16) | ((self.n761 & 0x4000000L) >> 16) | ((self.n761 & 0x2000000L) >> 16) | ((self.n761 & 0x1000000L) >> 16) | ((self.n761 & 0x800000L) >> 16) | ((self.n761 & 0x400000L) >> 16) | ((self.n761 & 0x200000L) >> 16) | ((self.n761 & 0x100000L) >> 16) | ((self.n761 & 0x80000L) >> 16) | ((self.n761 & 0x40000L) >> 16) | ((self.n761 & 0x20000L) >> 16) | ((self.n761 & 0x10000L) >> 16)
    self.n830 = (self.n688 & 0x8000L) | (self.n688 & 0x4000L) | (self.n688 & 0x2000L) | (self.n688 & 0x1000L) | (self.n688 & 0x800L) | (self.n688 & 0x400L) | (self.n688 & 0x200L) | (self.n688 & 0x100L) | (self.n688 & 0x80L) | (self.n688 & 0x40L) | (self.n688 & 0x20L) | (self.n688 & 0x10L) | (self.n688 & 0x8L) | (self.n688 & 0x4L) | (self.n688 & 0x2L) | (self.n688 & 0x1L)
    self.n829 = ((self.n688 & 0x80000000L) >> 16) | ((self.n688 & 0x40000000L) >> 16) | ((self.n688 & 0x20000000L) >> 16) | ((self.n688 & 0x10000000L) >> 16) | ((self.n688 & 0x8000000L) >> 16) | ((self.n688 & 0x4000000L) >> 16) | ((self.n688 & 0x2000000L) >> 16) | ((self.n688 & 0x1000000L) >> 16) | ((self.n688 & 0x800000L) >> 16) | ((self.n688 & 0x400000L) >> 16) | ((self.n688 & 0x200000L) >> 16) | ((self.n688 & 0x100000L) >> 16) | ((self.n688 & 0x80000L) >> 16) | ((self.n688 & 0x40000L) >> 16) | ((self.n688 & 0x20000L) >> 16) | ((self.n688 & 0x10000L) >> 16)
    if self.n714 == self.n710:
      self.n727 = 1L
    else:
      self.n727 = 0L
    if self.n714 == self.n709:
      self.n726 = 1L
    else:
      self.n726 = 0L
    if self.n714 == self.n704:
      self.n717 = 1L
    else:
      self.n717 = 0L
    if self.n714 == self.n703:
      self.n716 = 1L
    else:
      self.n716 = 0L
    if self.n714 == self.n702:
      self.n715 = 1L
    else:
      self.n715 = 0L
    self.n692 = (self.n697 + self.n689) & 0x3FFL
    if self.n624 == self.n667:
      self.n668 = 1L
    else:
      self.n668 = 0L
    self.n666r = self.n6548
    self.n666e = self.n6547
    self.n666d = self.n556
    if self.n641 == self.n637:
      self.n654 = 1L
    else:
      self.n654 = 0L
    if self.n641 == self.n636:
      self.n653 = 1L
    else:
      self.n653 = 0L
    if self.n641 == self.n631:
      self.n644 = 1L
    else:
      self.n644 = 0L
    if self.n641 == self.n630:
      self.n643 = 1L
    else:
      self.n643 = 0L
    if self.n641 == self.n629:
      self.n642 = 1L
    else:
      self.n642 = 0L
    self.n619 = (self.n624 + self.n616) & 0x3FFL
    self.n614r = self.n6548
    self.n614e = self.n6547
    self.n614d = self.n607
    self.n607r = self.n6548
    self.n607e = self.n6547
    self.n607d = self.n600
    self.n600r = self.n6548
    self.n600e = self.n6547
    self.n600d = self.n593
    self.n593r = self.n6548
    self.n593e = self.n6547
    self.n593d = self.n586
    self.n585r = self.n6548
    self.n585e = self.n6547
    self.n585d = self.n578
    self.n578r = self.n6548
    self.n578e = self.n6547
    self.n578d = self.n571
    self.n571r = self.n6548
    self.n571e = self.n6547
    self.n571d = self.n564
    self.n564r = self.n6548
    self.n564e = self.n6547
    self.n564d = self.n557
    self.n556r = self.n6548
    self.n556e = self.n6547
    self.n556d = self.n549
    self.n549r = self.n6548
    self.n549e = self.n6547
    self.n549d = self.n542
    self.n542r = self.n6548
    self.n542e = self.n6547
    self.n542d = self.n535
    self.n520 = self.n518 << 8 | self.n519
    self.n510 = self.n508 << 8 | self.n509
    self.n507r = self.n6548
    self.n507e = self.n6547
    self.n507d = self.n500
    isNeg0 = self.n420 & 0x80L
    isNeg1 = self.n454 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n491 = (self.n420 * self.n454) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n491 = (self.n420 * (0xFF00L | self.n454)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n491 = ((0xFF00L | self.n420) * self.n454) & 0xFFFFL
    else:
      self.n491 = ((0xFF00L | self.n420) * (0xFF00L | self.n454)) & 0xFFFFL
    isNeg0 = self.n419 & 0x80L
    isNeg1 = self.n455 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n482 = (self.n419 * self.n455) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n482 = (self.n419 * (0xFF00L | self.n455)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n482 = ((0xFF00L | self.n419) * self.n455) & 0xFFFFL
    else:
      self.n482 = ((0xFF00L | self.n419) * (0xFF00L | self.n455)) & 0xFFFFL
    self.n481r = self.n6548
    self.n481e = self.n6547
    self.n481d = self.n474
    isNeg0 = self.n420 & 0x80L
    isNeg1 = self.n455 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n465 = (self.n420 * self.n455) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n465 = (self.n420 * (0xFF00L | self.n455)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n465 = ((0xFF00L | self.n420) * self.n455) & 0xFFFFL
    else:
      self.n465 = ((0xFF00L | self.n420) * (0xFF00L | self.n455)) & 0xFFFFL
    isNeg0 = self.n419 & 0x80L
    isNeg1 = self.n454 & 0x80L
    if not isNeg0 and not isNeg1:
      self.n456 = (self.n419 * self.n454) & 0xFFFFL
    elif not isNeg0 and isNeg1:
      self.n456 = (self.n419 * (0xFF00L | self.n454)) & 0xFFFFL
    elif isNeg0 and not isNeg1:
      self.n456 = ((0xFF00L | self.n419) * self.n454) & 0xFFFFL
    else:
      self.n456 = ((0xFF00L | self.n419) * (0xFF00L | self.n454)) & 0xFFFFL
    self.n453e = self.n6547
    self.n453a = self.n402
    self.n448r = self.n6548
    self.n448e = self.n6547
    self.n448d = self.n441
    self.n441r = self.n6548
    self.n441e = self.n6547
    self.n441d = self.n411
    self.n434r = self.n6548
    self.n434e = self.n6547
    self.n434d = self.n427
    self.n427r = self.n6548
    self.n427e = self.n6547
    self.n427d = self.n410
    if self.n324 == self.n325:
      self.n326 = 1L
    else:
      self.n326 = 0L
    self.n319 = (self.n324 + self.n316) & 0x7FFL
    self.n313 = (self.n242 & 0x8000L) | (self.n242 & 0x4000L) | (self.n242 & 0x2000L) | (self.n242 & 0x1000L) | (self.n242 & 0x800L) | (self.n242 & 0x400L) | (self.n242 & 0x200L) | (self.n242 & 0x100L) | (self.n242 & 0x80L) | (self.n242 & 0x40L) | (self.n242 & 0x20L) | (self.n242 & 0x10L) | (self.n242 & 0x8L) | (self.n242 & 0x4L) | (self.n242 & 0x2L) | (self.n242 & 0x1L)
    self.n312 = ((self.n242 & 0x80000000L) >> 16) | ((self.n242 & 0x40000000L) >> 16) | ((self.n242 & 0x20000000L) >> 16) | ((self.n242 & 0x10000000L) >> 16) | ((self.n242 & 0x8000000L) >> 16) | ((self.n242 & 0x4000000L) >> 16) | ((self.n242 & 0x2000000L) >> 16) | ((self.n242 & 0x1000000L) >> 16) | ((self.n242 & 0x800000L) >> 16) | ((self.n242 & 0x400000L) >> 16) | ((self.n242 & 0x200000L) >> 16) | ((self.n242 & 0x100000L) >> 16) | ((self.n242 & 0x80000L) >> 16) | ((self.n242 & 0x40000L) >> 16) | ((self.n242 & 0x20000L) >> 16) | ((self.n242 & 0x10000L) >> 16)
    self.n311 = (self.n169 & 0x8000L) | (self.n169 & 0x4000L) | (self.n169 & 0x2000L) | (self.n169 & 0x1000L) | (self.n169 & 0x800L) | (self.n169 & 0x400L) | (self.n169 & 0x200L) | (self.n169 & 0x100L) | (self.n169 & 0x80L) | (self.n169 & 0x40L) | (self.n169 & 0x20L) | (self.n169 & 0x10L) | (self.n169 & 0x8L) | (self.n169 & 0x4L) | (self.n169 & 0x2L) | (self.n169 & 0x1L)
    self.n310 = ((self.n169 & 0x80000000L) >> 16) | ((self.n169 & 0x40000000L) >> 16) | ((self.n169 & 0x20000000L) >> 16) | ((self.n169 & 0x10000000L) >> 16) | ((self.n169 & 0x8000000L) >> 16) | ((self.n169 & 0x4000000L) >> 16) | ((self.n169 & 0x2000000L) >> 16) | ((self.n169 & 0x1000000L) >> 16) | ((self.n169 & 0x800000L) >> 16) | ((self.n169 & 0x400000L) >> 16) | ((self.n169 & 0x200000L) >> 16) | ((self.n169 & 0x100000L) >> 16) | ((self.n169 & 0x80000L) >> 16) | ((self.n169 & 0x40000L) >> 16) | ((self.n169 & 0x20000L) >> 16) | ((self.n169 & 0x10000L) >> 16)
    self.n173 = (self.n178 + self.n170) & 0x3FFL
    if self.n105 == self.n148:
      self.n149 = 1L
    else:
      self.n149 = 0L
    self.n100 = (self.n105 + self.n97) & 0x3FFL
    self.n96 = ((self.n95 & 0x1L) << 9) | ((self.n95 & 0x2L) << 7) | ((self.n95 & 0x4L) << 5) | ((self.n95 & 0x8L) << 3) | ((self.n95 & 0x10L) << 1) | ((self.n95 & 0x20L) >> 1) | ((self.n95 & 0x40L) >> 3) | ((self.n95 & 0x80L) >> 5) | ((self.n95 & 0x100L) >> 7) | ((self.n95 & 0x200L) >> 9)
    self.n94 = ~self.n93 & 0x1L
    self.n92 = self.n4 << 16 | self.n5
    if self.n14 == self.n15:
      self.n16 = 1L
    else:
      self.n16 = 0L
    self.n9 = (self.n14 + self.n6) & 0x7FFL
    self.n6471 = self.n6377 << 1 | self.n6375
    if self.n6436:
      self.n6439 = self.n6416
    else:
      self.n6439 = self.n6753
    if self.n6426:
      self.n6427 = self.n6408
    else:
      self.n6427 = self.n6407
    self.n6406r = self.n6551
    self.n6406e = self.n6547
    self.n6406d = self.n6401
    if self.n6363:
      self.n6366 = self.n6343
    else:
      self.n6366 = self.n6751
    if self.n6353:
      self.n6354 = self.n6335
    else:
      self.n6354 = self.n6334
    self.n6333r = self.n6552
    self.n6333e = self.n6547
    self.n6333d = self.n6328
    self.n6236r = self.n6548
    self.n6236e = self.n6547
    self.n6236d = self.n6229
    self.n6226r = self.n6548
    self.n6226e = self.n6547
    self.n6226d = self.n6219
    self.n6201 = ((self.n6200 & 0x4000L) >> 7) | ((self.n6200 & 0x2000L) >> 7) | ((self.n6200 & 0x1000L) >> 7) | ((self.n6200 & 0x800L) >> 7) | ((self.n6200 & 0x400L) >> 7) | ((self.n6200 & 0x200L) >> 7) | ((self.n6200 & 0x100L) >> 7) | ((self.n6200 & 0x80L) >> 7)
    self.n6192 = ((self.n6191 & 0x4000L) >> 7) | ((self.n6191 & 0x2000L) >> 7) | ((self.n6191 & 0x1000L) >> 7) | ((self.n6191 & 0x800L) >> 7) | ((self.n6191 & 0x400L) >> 7) | ((self.n6191 & 0x200L) >> 7) | ((self.n6191 & 0x100L) >> 7) | ((self.n6191 & 0x80L) >> 7)
    self.n6175 = ((self.n6174 & 0x4000L) >> 7) | ((self.n6174 & 0x2000L) >> 7) | ((self.n6174 & 0x1000L) >> 7) | ((self.n6174 & 0x800L) >> 7) | ((self.n6174 & 0x400L) >> 7) | ((self.n6174 & 0x200L) >> 7) | ((self.n6174 & 0x100L) >> 7) | ((self.n6174 & 0x80L) >> 7)
    self.n6166 = ((self.n6165 & 0x4000L) >> 7) | ((self.n6165 & 0x2000L) >> 7) | ((self.n6165 & 0x1000L) >> 7) | ((self.n6165 & 0x800L) >> 7) | ((self.n6165 & 0x400L) >> 7) | ((self.n6165 & 0x200L) >> 7) | ((self.n6165 & 0x100L) >> 7) | ((self.n6165 & 0x80L) >> 7)
    self.n6110 = self.n6109 & self.n6035
    self.n6036 = self.n5856 << 1 | self.n6035
    self.n5952 = self.n5858 << 1 | self.n5856
    if self.n5917:
      self.n5920 = self.n5897
    else:
      self.n5920 = self.n6741
    if self.n5907:
      self.n5908 = self.n5889
    else:
      self.n5908 = self.n5888
    self.n5887r = self.n6555
    self.n5887e = self.n6547
    self.n5887d = self.n5882
    if self.n5844:
      self.n5847 = self.n5824
    else:
      self.n5847 = self.n6739
    if self.n5834:
      self.n5835 = self.n5816
    else:
      self.n5835 = self.n5815
    self.n5814r = self.n6556
    self.n5814e = self.n6547
    self.n5814d = self.n5809
    self.n5717r = self.n6548
    self.n5717e = self.n6547
    self.n5717d = self.n5710
    self.n5707r = self.n6548
    self.n5707e = self.n6547
    self.n5707d = self.n5700
    self.n5682 = ((self.n5681 & 0x4000L) >> 7) | ((self.n5681 & 0x2000L) >> 7) | ((self.n5681 & 0x1000L) >> 7) | ((self.n5681 & 0x800L) >> 7) | ((self.n5681 & 0x400L) >> 7) | ((self.n5681 & 0x200L) >> 7) | ((self.n5681 & 0x100L) >> 7) | ((self.n5681 & 0x80L) >> 7)
    self.n5673 = ((self.n5672 & 0x4000L) >> 7) | ((self.n5672 & 0x2000L) >> 7) | ((self.n5672 & 0x1000L) >> 7) | ((self.n5672 & 0x800L) >> 7) | ((self.n5672 & 0x400L) >> 7) | ((self.n5672 & 0x200L) >> 7) | ((self.n5672 & 0x100L) >> 7) | ((self.n5672 & 0x80L) >> 7)
    self.n5656 = ((self.n5655 & 0x4000L) >> 7) | ((self.n5655 & 0x2000L) >> 7) | ((self.n5655 & 0x1000L) >> 7) | ((self.n5655 & 0x800L) >> 7) | ((self.n5655 & 0x400L) >> 7) | ((self.n5655 & 0x200L) >> 7) | ((self.n5655 & 0x100L) >> 7) | ((self.n5655 & 0x80L) >> 7)
    self.n5647 = ((self.n5646 & 0x4000L) >> 7) | ((self.n5646 & 0x2000L) >> 7) | ((self.n5646 & 0x1000L) >> 7) | ((self.n5646 & 0x800L) >> 7) | ((self.n5646 & 0x400L) >> 7) | ((self.n5646 & 0x200L) >> 7) | ((self.n5646 & 0x100L) >> 7) | ((self.n5646 & 0x80L) >> 7)
    self.n5591 = self.n5590 & self.n5516
    self.n5517 = self.n5337 << 1 | self.n5516
    self.n5433 = self.n5339 << 1 | self.n5337
    if self.n5398:
      self.n5401 = self.n5378
    else:
      self.n5401 = self.n6729
    if self.n5388:
      self.n5389 = self.n5370
    else:
      self.n5389 = self.n5369
    self.n5368r = self.n6559
    self.n5368e = self.n6547
    self.n5368d = self.n5363
    if self.n5325:
      self.n5328 = self.n5305
    else:
      self.n5328 = self.n6727
    if self.n5315:
      self.n5316 = self.n5297
    else:
      self.n5316 = self.n5296
    self.n5295r = self.n6560
    self.n5295e = self.n6547
    self.n5295d = self.n5290
    self.n5198r = self.n6548
    self.n5198e = self.n6547
    self.n5198d = self.n5191
    self.n5188r = self.n6548
    self.n5188e = self.n6547
    self.n5188d = self.n5181
    self.n5163 = ((self.n5162 & 0x4000L) >> 7) | ((self.n5162 & 0x2000L) >> 7) | ((self.n5162 & 0x1000L) >> 7) | ((self.n5162 & 0x800L) >> 7) | ((self.n5162 & 0x400L) >> 7) | ((self.n5162 & 0x200L) >> 7) | ((self.n5162 & 0x100L) >> 7) | ((self.n5162 & 0x80L) >> 7)
    self.n5154 = ((self.n5153 & 0x4000L) >> 7) | ((self.n5153 & 0x2000L) >> 7) | ((self.n5153 & 0x1000L) >> 7) | ((self.n5153 & 0x800L) >> 7) | ((self.n5153 & 0x400L) >> 7) | ((self.n5153 & 0x200L) >> 7) | ((self.n5153 & 0x100L) >> 7) | ((self.n5153 & 0x80L) >> 7)
    self.n5137 = ((self.n5136 & 0x4000L) >> 7) | ((self.n5136 & 0x2000L) >> 7) | ((self.n5136 & 0x1000L) >> 7) | ((self.n5136 & 0x800L) >> 7) | ((self.n5136 & 0x400L) >> 7) | ((self.n5136 & 0x200L) >> 7) | ((self.n5136 & 0x100L) >> 7) | ((self.n5136 & 0x80L) >> 7)
    self.n5128 = ((self.n5127 & 0x4000L) >> 7) | ((self.n5127 & 0x2000L) >> 7) | ((self.n5127 & 0x1000L) >> 7) | ((self.n5127 & 0x800L) >> 7) | ((self.n5127 & 0x400L) >> 7) | ((self.n5127 & 0x200L) >> 7) | ((self.n5127 & 0x100L) >> 7) | ((self.n5127 & 0x80L) >> 7)
    self.n5072 = self.n5071 & self.n4997
    self.n4998 = self.n4818 << 1 | self.n4997
    self.n4914 = self.n4820 << 1 | self.n4818
    if self.n4879:
      self.n4882 = self.n4859
    else:
      self.n4882 = self.n6717
    if self.n4869:
      self.n4870 = self.n4851
    else:
      self.n4870 = self.n4850
    self.n4849r = self.n6563
    self.n4849e = self.n6547
    self.n4849d = self.n4844
    if self.n4806:
      self.n4809 = self.n4786
    else:
      self.n4809 = self.n6715
    if self.n4796:
      self.n4797 = self.n4778
    else:
      self.n4797 = self.n4777
    self.n4776r = self.n6564
    self.n4776e = self.n6547
    self.n4776d = self.n4771
    self.n4679r = self.n6548
    self.n4679e = self.n6547
    self.n4679d = self.n4672
    self.n4669r = self.n6548
    self.n4669e = self.n6547
    self.n4669d = self.n4662
    self.n4644 = ((self.n4643 & 0x4000L) >> 7) | ((self.n4643 & 0x2000L) >> 7) | ((self.n4643 & 0x1000L) >> 7) | ((self.n4643 & 0x800L) >> 7) | ((self.n4643 & 0x400L) >> 7) | ((self.n4643 & 0x200L) >> 7) | ((self.n4643 & 0x100L) >> 7) | ((self.n4643 & 0x80L) >> 7)
    self.n4635 = ((self.n4634 & 0x4000L) >> 7) | ((self.n4634 & 0x2000L) >> 7) | ((self.n4634 & 0x1000L) >> 7) | ((self.n4634 & 0x800L) >> 7) | ((self.n4634 & 0x400L) >> 7) | ((self.n4634 & 0x200L) >> 7) | ((self.n4634 & 0x100L) >> 7) | ((self.n4634 & 0x80L) >> 7)
    self.n4618 = ((self.n4617 & 0x4000L) >> 7) | ((self.n4617 & 0x2000L) >> 7) | ((self.n4617 & 0x1000L) >> 7) | ((self.n4617 & 0x800L) >> 7) | ((self.n4617 & 0x400L) >> 7) | ((self.n4617 & 0x200L) >> 7) | ((self.n4617 & 0x100L) >> 7) | ((self.n4617 & 0x80L) >> 7)
    self.n4609 = ((self.n4608 & 0x4000L) >> 7) | ((self.n4608 & 0x2000L) >> 7) | ((self.n4608 & 0x1000L) >> 7) | ((self.n4608 & 0x800L) >> 7) | ((self.n4608 & 0x400L) >> 7) | ((self.n4608 & 0x200L) >> 7) | ((self.n4608 & 0x100L) >> 7) | ((self.n4608 & 0x80L) >> 7)
    self.n4553 = self.n4552 & self.n4478
    self.n4479 = self.n4299 << 1 | self.n4478
    self.n4395 = self.n4301 << 1 | self.n4299
    if self.n4360:
      self.n4363 = self.n4340
    else:
      self.n4363 = self.n6705
    if self.n4350:
      self.n4351 = self.n4332
    else:
      self.n4351 = self.n4331
    self.n4330r = self.n6567
    self.n4330e = self.n6547
    self.n4330d = self.n4325
    if self.n4287:
      self.n4290 = self.n4267
    else:
      self.n4290 = self.n6703
    if self.n4277:
      self.n4278 = self.n4259
    else:
      self.n4278 = self.n4258
    self.n4257r = self.n6568
    self.n4257e = self.n6547
    self.n4257d = self.n4252
    self.n4160r = self.n6548
    self.n4160e = self.n6547
    self.n4160d = self.n4153
    self.n4150r = self.n6548
    self.n4150e = self.n6547
    self.n4150d = self.n4143
    self.n4125 = ((self.n4124 & 0x4000L) >> 7) | ((self.n4124 & 0x2000L) >> 7) | ((self.n4124 & 0x1000L) >> 7) | ((self.n4124 & 0x800L) >> 7) | ((self.n4124 & 0x400L) >> 7) | ((self.n4124 & 0x200L) >> 7) | ((self.n4124 & 0x100L) >> 7) | ((self.n4124 & 0x80L) >> 7)
    self.n4116 = ((self.n4115 & 0x4000L) >> 7) | ((self.n4115 & 0x2000L) >> 7) | ((self.n4115 & 0x1000L) >> 7) | ((self.n4115 & 0x800L) >> 7) | ((self.n4115 & 0x400L) >> 7) | ((self.n4115 & 0x200L) >> 7) | ((self.n4115 & 0x100L) >> 7) | ((self.n4115 & 0x80L) >> 7)
    self.n4099 = ((self.n4098 & 0x4000L) >> 7) | ((self.n4098 & 0x2000L) >> 7) | ((self.n4098 & 0x1000L) >> 7) | ((self.n4098 & 0x800L) >> 7) | ((self.n4098 & 0x400L) >> 7) | ((self.n4098 & 0x200L) >> 7) | ((self.n4098 & 0x100L) >> 7) | ((self.n4098 & 0x80L) >> 7)
    self.n4090 = ((self.n4089 & 0x4000L) >> 7) | ((self.n4089 & 0x2000L) >> 7) | ((self.n4089 & 0x1000L) >> 7) | ((self.n4089 & 0x800L) >> 7) | ((self.n4089 & 0x400L) >> 7) | ((self.n4089 & 0x200L) >> 7) | ((self.n4089 & 0x100L) >> 7) | ((self.n4089 & 0x80L) >> 7)
    self.n4034 = self.n4033 & self.n3959
    self.n3960 = self.n3780 << 1 | self.n3959
    self.n3876 = self.n3782 << 1 | self.n3780
    if self.n3841:
      self.n3844 = self.n3821
    else:
      self.n3844 = self.n6693
    if self.n3831:
      self.n3832 = self.n3813
    else:
      self.n3832 = self.n3812
    self.n3811r = self.n6571
    self.n3811e = self.n6547
    self.n3811d = self.n3806
    if self.n3768:
      self.n3771 = self.n3748
    else:
      self.n3771 = self.n6691
    if self.n3758:
      self.n3759 = self.n3740
    else:
      self.n3759 = self.n3739
    self.n3738r = self.n6572
    self.n3738e = self.n6547
    self.n3738d = self.n3733
    self.n3641r = self.n6548
    self.n3641e = self.n6547
    self.n3641d = self.n3634
    self.n3631r = self.n6548
    self.n3631e = self.n6547
    self.n3631d = self.n3624
    self.n3606 = ((self.n3605 & 0x4000L) >> 7) | ((self.n3605 & 0x2000L) >> 7) | ((self.n3605 & 0x1000L) >> 7) | ((self.n3605 & 0x800L) >> 7) | ((self.n3605 & 0x400L) >> 7) | ((self.n3605 & 0x200L) >> 7) | ((self.n3605 & 0x100L) >> 7) | ((self.n3605 & 0x80L) >> 7)
    self.n3597 = ((self.n3596 & 0x4000L) >> 7) | ((self.n3596 & 0x2000L) >> 7) | ((self.n3596 & 0x1000L) >> 7) | ((self.n3596 & 0x800L) >> 7) | ((self.n3596 & 0x400L) >> 7) | ((self.n3596 & 0x200L) >> 7) | ((self.n3596 & 0x100L) >> 7) | ((self.n3596 & 0x80L) >> 7)
    self.n3580 = ((self.n3579 & 0x4000L) >> 7) | ((self.n3579 & 0x2000L) >> 7) | ((self.n3579 & 0x1000L) >> 7) | ((self.n3579 & 0x800L) >> 7) | ((self.n3579 & 0x400L) >> 7) | ((self.n3579 & 0x200L) >> 7) | ((self.n3579 & 0x100L) >> 7) | ((self.n3579 & 0x80L) >> 7)
    self.n3571 = ((self.n3570 & 0x4000L) >> 7) | ((self.n3570 & 0x2000L) >> 7) | ((self.n3570 & 0x1000L) >> 7) | ((self.n3570 & 0x800L) >> 7) | ((self.n3570 & 0x400L) >> 7) | ((self.n3570 & 0x200L) >> 7) | ((self.n3570 & 0x100L) >> 7) | ((self.n3570 & 0x80L) >> 7)
    self.n3515 = self.n3514 & self.n3440
    self.n3441 = self.n3261 << 1 | self.n3440
    self.n3357 = self.n3263 << 1 | self.n3261
    if self.n3322:
      self.n3325 = self.n3302
    else:
      self.n3325 = self.n6681
    if self.n3312:
      self.n3313 = self.n3294
    else:
      self.n3313 = self.n3293
    self.n3292r = self.n6575
    self.n3292e = self.n6547
    self.n3292d = self.n3287
    if self.n3249:
      self.n3252 = self.n3229
    else:
      self.n3252 = self.n6679
    if self.n3239:
      self.n3240 = self.n3221
    else:
      self.n3240 = self.n3220
    self.n3219r = self.n6576
    self.n3219e = self.n6547
    self.n3219d = self.n3214
    self.n3122r = self.n6548
    self.n3122e = self.n6547
    self.n3122d = self.n3115
    self.n3112r = self.n6548
    self.n3112e = self.n6547
    self.n3112d = self.n3105
    self.n3087 = ((self.n3086 & 0x4000L) >> 7) | ((self.n3086 & 0x2000L) >> 7) | ((self.n3086 & 0x1000L) >> 7) | ((self.n3086 & 0x800L) >> 7) | ((self.n3086 & 0x400L) >> 7) | ((self.n3086 & 0x200L) >> 7) | ((self.n3086 & 0x100L) >> 7) | ((self.n3086 & 0x80L) >> 7)
    self.n3078 = ((self.n3077 & 0x4000L) >> 7) | ((self.n3077 & 0x2000L) >> 7) | ((self.n3077 & 0x1000L) >> 7) | ((self.n3077 & 0x800L) >> 7) | ((self.n3077 & 0x400L) >> 7) | ((self.n3077 & 0x200L) >> 7) | ((self.n3077 & 0x100L) >> 7) | ((self.n3077 & 0x80L) >> 7)
    self.n3061 = ((self.n3060 & 0x4000L) >> 7) | ((self.n3060 & 0x2000L) >> 7) | ((self.n3060 & 0x1000L) >> 7) | ((self.n3060 & 0x800L) >> 7) | ((self.n3060 & 0x400L) >> 7) | ((self.n3060 & 0x200L) >> 7) | ((self.n3060 & 0x100L) >> 7) | ((self.n3060 & 0x80L) >> 7)
    self.n3052 = ((self.n3051 & 0x4000L) >> 7) | ((self.n3051 & 0x2000L) >> 7) | ((self.n3051 & 0x1000L) >> 7) | ((self.n3051 & 0x800L) >> 7) | ((self.n3051 & 0x400L) >> 7) | ((self.n3051 & 0x200L) >> 7) | ((self.n3051 & 0x100L) >> 7) | ((self.n3051 & 0x80L) >> 7)
    self.n2996 = self.n2995 & self.n2921
    self.n2922 = self.n2742 << 1 | self.n2921
    self.n2838 = self.n2744 << 1 | self.n2742
    if self.n2803:
      self.n2806 = self.n2783
    else:
      self.n2806 = self.n6669
    if self.n2793:
      self.n2794 = self.n2775
    else:
      self.n2794 = self.n2774
    self.n2773r = self.n6579
    self.n2773e = self.n6547
    self.n2773d = self.n2768
    if self.n2730:
      self.n2733 = self.n2710
    else:
      self.n2733 = self.n6667
    if self.n2720:
      self.n2721 = self.n2702
    else:
      self.n2721 = self.n2701
    self.n2700r = self.n6580
    self.n2700e = self.n6547
    self.n2700d = self.n2695
    self.n2603r = self.n6548
    self.n2603e = self.n6547
    self.n2603d = self.n2596
    self.n2593r = self.n6548
    self.n2593e = self.n6547
    self.n2593d = self.n2586
    self.n2568 = ((self.n2567 & 0x4000L) >> 7) | ((self.n2567 & 0x2000L) >> 7) | ((self.n2567 & 0x1000L) >> 7) | ((self.n2567 & 0x800L) >> 7) | ((self.n2567 & 0x400L) >> 7) | ((self.n2567 & 0x200L) >> 7) | ((self.n2567 & 0x100L) >> 7) | ((self.n2567 & 0x80L) >> 7)
    self.n2559 = ((self.n2558 & 0x4000L) >> 7) | ((self.n2558 & 0x2000L) >> 7) | ((self.n2558 & 0x1000L) >> 7) | ((self.n2558 & 0x800L) >> 7) | ((self.n2558 & 0x400L) >> 7) | ((self.n2558 & 0x200L) >> 7) | ((self.n2558 & 0x100L) >> 7) | ((self.n2558 & 0x80L) >> 7)
    self.n2542 = ((self.n2541 & 0x4000L) >> 7) | ((self.n2541 & 0x2000L) >> 7) | ((self.n2541 & 0x1000L) >> 7) | ((self.n2541 & 0x800L) >> 7) | ((self.n2541 & 0x400L) >> 7) | ((self.n2541 & 0x200L) >> 7) | ((self.n2541 & 0x100L) >> 7) | ((self.n2541 & 0x80L) >> 7)
    self.n2533 = ((self.n2532 & 0x4000L) >> 7) | ((self.n2532 & 0x2000L) >> 7) | ((self.n2532 & 0x1000L) >> 7) | ((self.n2532 & 0x800L) >> 7) | ((self.n2532 & 0x400L) >> 7) | ((self.n2532 & 0x200L) >> 7) | ((self.n2532 & 0x100L) >> 7) | ((self.n2532 & 0x80L) >> 7)
    self.n2477 = self.n2476 & self.n2402
    self.n2403 = self.n2223 << 1 | self.n2402
    self.n2319 = self.n2225 << 1 | self.n2223
    if self.n2284:
      self.n2287 = self.n2264
    else:
      self.n2287 = self.n6657
    if self.n2274:
      self.n2275 = self.n2256
    else:
      self.n2275 = self.n2255
    self.n2254r = self.n6583
    self.n2254e = self.n6547
    self.n2254d = self.n2249
    if self.n2211:
      self.n2214 = self.n2191
    else:
      self.n2214 = self.n6655
    if self.n2201:
      self.n2202 = self.n2183
    else:
      self.n2202 = self.n2182
    self.n2181r = self.n6584
    self.n2181e = self.n6547
    self.n2181d = self.n2176
    self.n2084r = self.n6548
    self.n2084e = self.n6547
    self.n2084d = self.n2077
    self.n2074r = self.n6548
    self.n2074e = self.n6547
    self.n2074d = self.n2067
    self.n2049 = ((self.n2048 & 0x4000L) >> 7) | ((self.n2048 & 0x2000L) >> 7) | ((self.n2048 & 0x1000L) >> 7) | ((self.n2048 & 0x800L) >> 7) | ((self.n2048 & 0x400L) >> 7) | ((self.n2048 & 0x200L) >> 7) | ((self.n2048 & 0x100L) >> 7) | ((self.n2048 & 0x80L) >> 7)
    self.n2040 = ((self.n2039 & 0x4000L) >> 7) | ((self.n2039 & 0x2000L) >> 7) | ((self.n2039 & 0x1000L) >> 7) | ((self.n2039 & 0x800L) >> 7) | ((self.n2039 & 0x400L) >> 7) | ((self.n2039 & 0x200L) >> 7) | ((self.n2039 & 0x100L) >> 7) | ((self.n2039 & 0x80L) >> 7)
    self.n2023 = ((self.n2022 & 0x4000L) >> 7) | ((self.n2022 & 0x2000L) >> 7) | ((self.n2022 & 0x1000L) >> 7) | ((self.n2022 & 0x800L) >> 7) | ((self.n2022 & 0x400L) >> 7) | ((self.n2022 & 0x200L) >> 7) | ((self.n2022 & 0x100L) >> 7) | ((self.n2022 & 0x80L) >> 7)
    self.n2014 = ((self.n2013 & 0x4000L) >> 7) | ((self.n2013 & 0x2000L) >> 7) | ((self.n2013 & 0x1000L) >> 7) | ((self.n2013 & 0x800L) >> 7) | ((self.n2013 & 0x400L) >> 7) | ((self.n2013 & 0x200L) >> 7) | ((self.n2013 & 0x100L) >> 7) | ((self.n2013 & 0x80L) >> 7)
    self.n1958 = self.n1957 & self.n1883
    self.n1884 = self.n1704 << 1 | self.n1883
    self.n1800 = self.n1706 << 1 | self.n1704
    if self.n1765:
      self.n1768 = self.n1745
    else:
      self.n1768 = self.n6645
    if self.n1755:
      self.n1756 = self.n1737
    else:
      self.n1756 = self.n1736
    self.n1735r = self.n6587
    self.n1735e = self.n6547
    self.n1735d = self.n1730
    if self.n1692:
      self.n1695 = self.n1672
    else:
      self.n1695 = self.n6643
    if self.n1682:
      self.n1683 = self.n1664
    else:
      self.n1683 = self.n1663
    self.n1662r = self.n6588
    self.n1662e = self.n6547
    self.n1662d = self.n1657
    self.n1565r = self.n6548
    self.n1565e = self.n6547
    self.n1565d = self.n1558
    self.n1555r = self.n6548
    self.n1555e = self.n6547
    self.n1555d = self.n1548
    self.n1530 = ((self.n1529 & 0x4000L) >> 7) | ((self.n1529 & 0x2000L) >> 7) | ((self.n1529 & 0x1000L) >> 7) | ((self.n1529 & 0x800L) >> 7) | ((self.n1529 & 0x400L) >> 7) | ((self.n1529 & 0x200L) >> 7) | ((self.n1529 & 0x100L) >> 7) | ((self.n1529 & 0x80L) >> 7)
    self.n1521 = ((self.n1520 & 0x4000L) >> 7) | ((self.n1520 & 0x2000L) >> 7) | ((self.n1520 & 0x1000L) >> 7) | ((self.n1520 & 0x800L) >> 7) | ((self.n1520 & 0x400L) >> 7) | ((self.n1520 & 0x200L) >> 7) | ((self.n1520 & 0x100L) >> 7) | ((self.n1520 & 0x80L) >> 7)
    self.n1504 = ((self.n1503 & 0x4000L) >> 7) | ((self.n1503 & 0x2000L) >> 7) | ((self.n1503 & 0x1000L) >> 7) | ((self.n1503 & 0x800L) >> 7) | ((self.n1503 & 0x400L) >> 7) | ((self.n1503 & 0x200L) >> 7) | ((self.n1503 & 0x100L) >> 7) | ((self.n1503 & 0x80L) >> 7)
    self.n1495 = ((self.n1494 & 0x4000L) >> 7) | ((self.n1494 & 0x2000L) >> 7) | ((self.n1494 & 0x1000L) >> 7) | ((self.n1494 & 0x800L) >> 7) | ((self.n1494 & 0x400L) >> 7) | ((self.n1494 & 0x200L) >> 7) | ((self.n1494 & 0x100L) >> 7) | ((self.n1494 & 0x80L) >> 7)
    self.n1439 = self.n1438 & self.n1364
    self.n1365 = self.n1185 << 1 | self.n1364
    self.n1281 = self.n1187 << 1 | self.n1185
    if self.n1246:
      self.n1249 = self.n1226
    else:
      self.n1249 = self.n6633
    if self.n1236:
      self.n1237 = self.n1218
    else:
      self.n1237 = self.n1217
    self.n1216r = self.n6591
    self.n1216e = self.n6547
    self.n1216d = self.n1211
    if self.n1173:
      self.n1176 = self.n1153
    else:
      self.n1176 = self.n6631
    if self.n1163:
      self.n1164 = self.n1145
    else:
      self.n1164 = self.n1144
    self.n1143r = self.n6592
    self.n1143e = self.n6547
    self.n1143d = self.n1138
    self.n1046r = self.n6548
    self.n1046e = self.n6547
    self.n1046d = self.n1039
    self.n1036r = self.n6548
    self.n1036e = self.n6547
    self.n1036d = self.n1029
    self.n1011 = ((self.n1010 & 0x4000L) >> 7) | ((self.n1010 & 0x2000L) >> 7) | ((self.n1010 & 0x1000L) >> 7) | ((self.n1010 & 0x800L) >> 7) | ((self.n1010 & 0x400L) >> 7) | ((self.n1010 & 0x200L) >> 7) | ((self.n1010 & 0x100L) >> 7) | ((self.n1010 & 0x80L) >> 7)
    self.n1002 = ((self.n1001 & 0x4000L) >> 7) | ((self.n1001 & 0x2000L) >> 7) | ((self.n1001 & 0x1000L) >> 7) | ((self.n1001 & 0x800L) >> 7) | ((self.n1001 & 0x400L) >> 7) | ((self.n1001 & 0x200L) >> 7) | ((self.n1001 & 0x100L) >> 7) | ((self.n1001 & 0x80L) >> 7)
    self.n985 = ((self.n984 & 0x4000L) >> 7) | ((self.n984 & 0x2000L) >> 7) | ((self.n984 & 0x1000L) >> 7) | ((self.n984 & 0x800L) >> 7) | ((self.n984 & 0x400L) >> 7) | ((self.n984 & 0x200L) >> 7) | ((self.n984 & 0x100L) >> 7) | ((self.n984 & 0x80L) >> 7)
    self.n976 = ((self.n975 & 0x4000L) >> 7) | ((self.n975 & 0x2000L) >> 7) | ((self.n975 & 0x1000L) >> 7) | ((self.n975 & 0x800L) >> 7) | ((self.n975 & 0x400L) >> 7) | ((self.n975 & 0x200L) >> 7) | ((self.n975 & 0x100L) >> 7) | ((self.n975 & 0x80L) >> 7)
    self.n920 = self.n919 & self.n845
    self.n846 = self.n666 << 1 | self.n845
    self.n762 = self.n668 << 1 | self.n666
    if self.n727:
      self.n730 = self.n707
    else:
      self.n730 = self.n6621
    if self.n717:
      self.n718 = self.n699
    else:
      self.n718 = self.n698
    self.n697r = self.n6595
    self.n697e = self.n6547
    self.n697d = self.n692
    if self.n654:
      self.n657 = self.n634
    else:
      self.n657 = self.n6619
    if self.n644:
      self.n645 = self.n626
    else:
      self.n645 = self.n625
    self.n624r = self.n6596
    self.n624e = self.n6547
    self.n624d = self.n619
    self.n527r = self.n6548
    self.n527e = self.n6547
    self.n527d = self.n520
    self.n517r = self.n6548
    self.n517e = self.n6547
    self.n517d = self.n510
    self.n492 = ((self.n491 & 0x4000L) >> 7) | ((self.n491 & 0x2000L) >> 7) | ((self.n491 & 0x1000L) >> 7) | ((self.n491 & 0x800L) >> 7) | ((self.n491 & 0x400L) >> 7) | ((self.n491 & 0x200L) >> 7) | ((self.n491 & 0x100L) >> 7) | ((self.n491 & 0x80L) >> 7)
    self.n483 = ((self.n482 & 0x4000L) >> 7) | ((self.n482 & 0x2000L) >> 7) | ((self.n482 & 0x1000L) >> 7) | ((self.n482 & 0x800L) >> 7) | ((self.n482 & 0x400L) >> 7) | ((self.n482 & 0x200L) >> 7) | ((self.n482 & 0x100L) >> 7) | ((self.n482 & 0x80L) >> 7)
    self.n466 = ((self.n465 & 0x4000L) >> 7) | ((self.n465 & 0x2000L) >> 7) | ((self.n465 & 0x1000L) >> 7) | ((self.n465 & 0x800L) >> 7) | ((self.n465 & 0x400L) >> 7) | ((self.n465 & 0x200L) >> 7) | ((self.n465 & 0x100L) >> 7) | ((self.n465 & 0x80L) >> 7)
    self.n457 = ((self.n456 & 0x4000L) >> 7) | ((self.n456 & 0x2000L) >> 7) | ((self.n456 & 0x1000L) >> 7) | ((self.n456 & 0x800L) >> 7) | ((self.n456 & 0x400L) >> 7) | ((self.n456 & 0x200L) >> 7) | ((self.n456 & 0x100L) >> 7) | ((self.n456 & 0x80L) >> 7)
    self.n401 = self.n400 & self.n326
    self.n327 = self.n147 << 1 | self.n326
    self.n243 = self.n149 << 1 | self.n147
    self.n91 = self.n90 & self.n16
    self.n17 = self.n3 << 1 | self.n16
    self.n6600 = self.n91 | self.n6548
    self.n6599 = self.n91 | self.n6548
    self.n6504 = self.n6471 << 1 | self.n6523
    if self.n6435:
      self.n6440 = self.n6417
    else:
      self.n6440 = self.n6439
    if self.n6425:
      self.n6428 = self.n6409
    else:
      self.n6428 = self.n6427
    if self.n6362:
      self.n6367 = self.n6344
    else:
      self.n6367 = self.n6366
    if self.n6352:
      self.n6355 = self.n6336
    else:
      self.n6355 = self.n6354
    self.n6244r = self.n6548
    self.n6244e = self.n6547
    self.n6244d = self.n6110
    self.n6208r = self.n6548
    self.n6208e = self.n6547
    self.n6208d = self.n6201
    self.n6199r = self.n6548
    self.n6199e = self.n6547
    self.n6199d = self.n6192
    self.n6182r = self.n6548
    self.n6182e = self.n6547
    self.n6182d = self.n6175
    self.n6173r = self.n6548
    self.n6173e = self.n6547
    self.n6173d = self.n6166
    self.n6069 = self.n6036 << 1 | self.n6088
    self.n5985 = self.n5952 << 1 | self.n6004
    if self.n5916:
      self.n5921 = self.n5898
    else:
      self.n5921 = self.n5920
    if self.n5906:
      self.n5909 = self.n5890
    else:
      self.n5909 = self.n5908
    if self.n5843:
      self.n5848 = self.n5825
    else:
      self.n5848 = self.n5847
    if self.n5833:
      self.n5836 = self.n5817
    else:
      self.n5836 = self.n5835
    self.n5725r = self.n6548
    self.n5725e = self.n6547
    self.n5725d = self.n5591
    self.n5689r = self.n6548
    self.n5689e = self.n6547
    self.n5689d = self.n5682
    self.n5680r = self.n6548
    self.n5680e = self.n6547
    self.n5680d = self.n5673
    self.n5663r = self.n6548
    self.n5663e = self.n6547
    self.n5663d = self.n5656
    self.n5654r = self.n6548
    self.n5654e = self.n6547
    self.n5654d = self.n5647
    self.n5550 = self.n5517 << 1 | self.n5569
    self.n5466 = self.n5433 << 1 | self.n5485
    if self.n5397:
      self.n5402 = self.n5379
    else:
      self.n5402 = self.n5401
    if self.n5387:
      self.n5390 = self.n5371
    else:
      self.n5390 = self.n5389
    if self.n5324:
      self.n5329 = self.n5306
    else:
      self.n5329 = self.n5328
    if self.n5314:
      self.n5317 = self.n5298
    else:
      self.n5317 = self.n5316
    self.n5206r = self.n6548
    self.n5206e = self.n6547
    self.n5206d = self.n5072
    self.n5170r = self.n6548
    self.n5170e = self.n6547
    self.n5170d = self.n5163
    self.n5161r = self.n6548
    self.n5161e = self.n6547
    self.n5161d = self.n5154
    self.n5144r = self.n6548
    self.n5144e = self.n6547
    self.n5144d = self.n5137
    self.n5135r = self.n6548
    self.n5135e = self.n6547
    self.n5135d = self.n5128
    self.n5031 = self.n4998 << 1 | self.n5050
    self.n4947 = self.n4914 << 1 | self.n4966
    if self.n4878:
      self.n4883 = self.n4860
    else:
      self.n4883 = self.n4882
    if self.n4868:
      self.n4871 = self.n4852
    else:
      self.n4871 = self.n4870
    if self.n4805:
      self.n4810 = self.n4787
    else:
      self.n4810 = self.n4809
    if self.n4795:
      self.n4798 = self.n4779
    else:
      self.n4798 = self.n4797
    self.n4687r = self.n6548
    self.n4687e = self.n6547
    self.n4687d = self.n4553
    self.n4651r = self.n6548
    self.n4651e = self.n6547
    self.n4651d = self.n4644
    self.n4642r = self.n6548
    self.n4642e = self.n6547
    self.n4642d = self.n4635
    self.n4625r = self.n6548
    self.n4625e = self.n6547
    self.n4625d = self.n4618
    self.n4616r = self.n6548
    self.n4616e = self.n6547
    self.n4616d = self.n4609
    self.n4512 = self.n4479 << 1 | self.n4531
    self.n4428 = self.n4395 << 1 | self.n4447
    if self.n4359:
      self.n4364 = self.n4341
    else:
      self.n4364 = self.n4363
    if self.n4349:
      self.n4352 = self.n4333
    else:
      self.n4352 = self.n4351
    if self.n4286:
      self.n4291 = self.n4268
    else:
      self.n4291 = self.n4290
    if self.n4276:
      self.n4279 = self.n4260
    else:
      self.n4279 = self.n4278
    self.n4168r = self.n6548
    self.n4168e = self.n6547
    self.n4168d = self.n4034
    self.n4132r = self.n6548
    self.n4132e = self.n6547
    self.n4132d = self.n4125
    self.n4123r = self.n6548
    self.n4123e = self.n6547
    self.n4123d = self.n4116
    self.n4106r = self.n6548
    self.n4106e = self.n6547
    self.n4106d = self.n4099
    self.n4097r = self.n6548
    self.n4097e = self.n6547
    self.n4097d = self.n4090
    self.n3993 = self.n3960 << 1 | self.n4012
    self.n3909 = self.n3876 << 1 | self.n3928
    if self.n3840:
      self.n3845 = self.n3822
    else:
      self.n3845 = self.n3844
    if self.n3830:
      self.n3833 = self.n3814
    else:
      self.n3833 = self.n3832
    if self.n3767:
      self.n3772 = self.n3749
    else:
      self.n3772 = self.n3771
    if self.n3757:
      self.n3760 = self.n3741
    else:
      self.n3760 = self.n3759
    self.n3649r = self.n6548
    self.n3649e = self.n6547
    self.n3649d = self.n3515
    self.n3613r = self.n6548
    self.n3613e = self.n6547
    self.n3613d = self.n3606
    self.n3604r = self.n6548
    self.n3604e = self.n6547
    self.n3604d = self.n3597
    self.n3587r = self.n6548
    self.n3587e = self.n6547
    self.n3587d = self.n3580
    self.n3578r = self.n6548
    self.n3578e = self.n6547
    self.n3578d = self.n3571
    self.n3474 = self.n3441 << 1 | self.n3493
    self.n3390 = self.n3357 << 1 | self.n3409
    if self.n3321:
      self.n3326 = self.n3303
    else:
      self.n3326 = self.n3325
    if self.n3311:
      self.n3314 = self.n3295
    else:
      self.n3314 = self.n3313
    if self.n3248:
      self.n3253 = self.n3230
    else:
      self.n3253 = self.n3252
    if self.n3238:
      self.n3241 = self.n3222
    else:
      self.n3241 = self.n3240
    self.n3130r = self.n6548
    self.n3130e = self.n6547
    self.n3130d = self.n2996
    self.n3094r = self.n6548
    self.n3094e = self.n6547
    self.n3094d = self.n3087
    self.n3085r = self.n6548
    self.n3085e = self.n6547
    self.n3085d = self.n3078
    self.n3068r = self.n6548
    self.n3068e = self.n6547
    self.n3068d = self.n3061
    self.n3059r = self.n6548
    self.n3059e = self.n6547
    self.n3059d = self.n3052
    self.n2955 = self.n2922 << 1 | self.n2974
    self.n2871 = self.n2838 << 1 | self.n2890
    if self.n2802:
      self.n2807 = self.n2784
    else:
      self.n2807 = self.n2806
    if self.n2792:
      self.n2795 = self.n2776
    else:
      self.n2795 = self.n2794
    if self.n2729:
      self.n2734 = self.n2711
    else:
      self.n2734 = self.n2733
    if self.n2719:
      self.n2722 = self.n2703
    else:
      self.n2722 = self.n2721
    self.n2611r = self.n6548
    self.n2611e = self.n6547
    self.n2611d = self.n2477
    self.n2575r = self.n6548
    self.n2575e = self.n6547
    self.n2575d = self.n2568
    self.n2566r = self.n6548
    self.n2566e = self.n6547
    self.n2566d = self.n2559
    self.n2549r = self.n6548
    self.n2549e = self.n6547
    self.n2549d = self.n2542
    self.n2540r = self.n6548
    self.n2540e = self.n6547
    self.n2540d = self.n2533
    self.n2436 = self.n2403 << 1 | self.n2455
    self.n2352 = self.n2319 << 1 | self.n2371
    if self.n2283:
      self.n2288 = self.n2265
    else:
      self.n2288 = self.n2287
    if self.n2273:
      self.n2276 = self.n2257
    else:
      self.n2276 = self.n2275
    if self.n2210:
      self.n2215 = self.n2192
    else:
      self.n2215 = self.n2214
    if self.n2200:
      self.n2203 = self.n2184
    else:
      self.n2203 = self.n2202
    self.n2092r = self.n6548
    self.n2092e = self.n6547
    self.n2092d = self.n1958
    self.n2056r = self.n6548
    self.n2056e = self.n6547
    self.n2056d = self.n2049
    self.n2047r = self.n6548
    self.n2047e = self.n6547
    self.n2047d = self.n2040
    self.n2030r = self.n6548
    self.n2030e = self.n6547
    self.n2030d = self.n2023
    self.n2021r = self.n6548
    self.n2021e = self.n6547
    self.n2021d = self.n2014
    self.n1917 = self.n1884 << 1 | self.n1936
    self.n1833 = self.n1800 << 1 | self.n1852
    if self.n1764:
      self.n1769 = self.n1746
    else:
      self.n1769 = self.n1768
    if self.n1754:
      self.n1757 = self.n1738
    else:
      self.n1757 = self.n1756
    if self.n1691:
      self.n1696 = self.n1673
    else:
      self.n1696 = self.n1695
    if self.n1681:
      self.n1684 = self.n1665
    else:
      self.n1684 = self.n1683
    self.n1573r = self.n6548
    self.n1573e = self.n6547
    self.n1573d = self.n1439
    self.n1537r = self.n6548
    self.n1537e = self.n6547
    self.n1537d = self.n1530
    self.n1528r = self.n6548
    self.n1528e = self.n6547
    self.n1528d = self.n1521
    self.n1511r = self.n6548
    self.n1511e = self.n6547
    self.n1511d = self.n1504
    self.n1502r = self.n6548
    self.n1502e = self.n6547
    self.n1502d = self.n1495
    self.n1398 = self.n1365 << 1 | self.n1417
    self.n1314 = self.n1281 << 1 | self.n1333
    if self.n1245:
      self.n1250 = self.n1227
    else:
      self.n1250 = self.n1249
    if self.n1235:
      self.n1238 = self.n1219
    else:
      self.n1238 = self.n1237
    if self.n1172:
      self.n1177 = self.n1154
    else:
      self.n1177 = self.n1176
    if self.n1162:
      self.n1165 = self.n1146
    else:
      self.n1165 = self.n1164
    self.n1054r = self.n6548
    self.n1054e = self.n6547
    self.n1054d = self.n920
    self.n1018r = self.n6548
    self.n1018e = self.n6547
    self.n1018d = self.n1011
    self.n1009r = self.n6548
    self.n1009e = self.n6547
    self.n1009d = self.n1002
    self.n992r = self.n6548
    self.n992e = self.n6547
    self.n992d = self.n985
    self.n983r = self.n6548
    self.n983e = self.n6547
    self.n983d = self.n976
    self.n879 = self.n846 << 1 | self.n898
    self.n795 = self.n762 << 1 | self.n814
    if self.n726:
      self.n731 = self.n708
    else:
      self.n731 = self.n730
    if self.n716:
      self.n719 = self.n700
    else:
      self.n719 = self.n718
    if self.n653:
      self.n658 = self.n635
    else:
      self.n658 = self.n657
    if self.n643:
      self.n646 = self.n627
    else:
      self.n646 = self.n645
    self.n535r = self.n6548
    self.n535e = self.n6547
    self.n535d = self.n401
    self.n499r = self.n6548
    self.n499e = self.n6547
    self.n499d = self.n492
    self.n490r = self.n6548
    self.n490e = self.n6547
    self.n490d = self.n483
    self.n473r = self.n6548
    self.n473e = self.n6547
    self.n473d = self.n466
    self.n464r = self.n6548
    self.n464e = self.n6547
    self.n464d = self.n457
    self.n360 = self.n327 << 1 | self.n379
    self.n276 = self.n243 << 1 | self.n295
    self.n195 = self.n91 << 1 | self.n206
    self.n147r = self.n6548
    self.n147e = self.n6547
    self.n147d = self.n91
    self.n122 = self.n91 << 1 | self.n133
    self.n50 = self.n17 << 1 | self.n69
    if self.n6504 == self.n6498:
      self.n6527 = 1L
    else:
      self.n6527 = 0L
    if self.n6504 == self.n6497:
      self.n6526 = 1L
    else:
      self.n6526 = 0L
    if self.n6504 == self.n6496:
      self.n6525 = 1L
    else:
      self.n6525 = 0L
    if self.n6504 == self.n6495:
      self.n6524 = 1L
    else:
      self.n6524 = 0L
    if self.n6504 == self.n6486:
      self.n6511 = 1L
    else:
      self.n6511 = 0L
    if self.n6504 == self.n6485:
      self.n6510 = 1L
    else:
      self.n6510 = 0L
    if self.n6504 == self.n6484:
      self.n6509 = 1L
    else:
      self.n6509 = 0L
    if self.n6504 == self.n6483:
      self.n6508 = 1L
    else:
      self.n6508 = 0L
    if self.n6504 == self.n6482:
      self.n6507 = 1L
    else:
      self.n6507 = 0L
    if self.n6504 == self.n6481:
      self.n6506 = 1L
    else:
      self.n6506 = 0L
    if self.n6504 == self.n6480:
      self.n6505 = 1L
    else:
      self.n6505 = 0L
    self.n6457 = self.n6323 & self.n6440
    self.n6441 = ~self.n6440 & 0x1L
    if self.n6424:
      self.n6429 = self.n6410
    else:
      self.n6429 = self.n6428
    self.n6384 = self.n6324 & self.n6367
    self.n6368 = ~self.n6367 & 0x1L
    if self.n6351:
      self.n6356 = self.n6337
    else:
      self.n6356 = self.n6355
    if self.n6069 == self.n6065:
      self.n6094 = 1L
    else:
      self.n6094 = 0L
    if self.n6069 == self.n6064:
      self.n6093 = 1L
    else:
      self.n6093 = 0L
    if self.n6069 == self.n6063:
      self.n6092 = 1L
    else:
      self.n6092 = 0L
    if self.n6069 == self.n6062:
      self.n6091 = 1L
    else:
      self.n6091 = 0L
    if self.n6069 == self.n6061:
      self.n6090 = 1L
    else:
      self.n6090 = 0L
    if self.n6069 == self.n6060:
      self.n6089 = 1L
    else:
      self.n6089 = 0L
    if self.n6069 == self.n6050:
      self.n6075 = 1L
    else:
      self.n6075 = 0L
    if self.n6069 == self.n6049:
      self.n6074 = 1L
    else:
      self.n6074 = 0L
    if self.n6069 == self.n6048:
      self.n6073 = 1L
    else:
      self.n6073 = 0L
    if self.n6069 == self.n6047:
      self.n6072 = 1L
    else:
      self.n6072 = 0L
    if self.n6069 == self.n6046:
      self.n6071 = 1L
    else:
      self.n6071 = 0L
    if self.n6069 == self.n6045:
      self.n6070 = 1L
    else:
      self.n6070 = 0L
    if self.n5985 == self.n5979:
      self.n6008 = 1L
    else:
      self.n6008 = 0L
    if self.n5985 == self.n5978:
      self.n6007 = 1L
    else:
      self.n6007 = 0L
    if self.n5985 == self.n5977:
      self.n6006 = 1L
    else:
      self.n6006 = 0L
    if self.n5985 == self.n5976:
      self.n6005 = 1L
    else:
      self.n6005 = 0L
    if self.n5985 == self.n5967:
      self.n5992 = 1L
    else:
      self.n5992 = 0L
    if self.n5985 == self.n5966:
      self.n5991 = 1L
    else:
      self.n5991 = 0L
    if self.n5985 == self.n5965:
      self.n5990 = 1L
    else:
      self.n5990 = 0L
    if self.n5985 == self.n5964:
      self.n5989 = 1L
    else:
      self.n5989 = 0L
    if self.n5985 == self.n5963:
      self.n5988 = 1L
    else:
      self.n5988 = 0L
    if self.n5985 == self.n5962:
      self.n5987 = 1L
    else:
      self.n5987 = 0L
    if self.n5985 == self.n5961:
      self.n5986 = 1L
    else:
      self.n5986 = 0L
    self.n5938 = self.n5804 & self.n5921
    self.n5922 = ~self.n5921 & 0x1L
    if self.n5905:
      self.n5910 = self.n5891
    else:
      self.n5910 = self.n5909
    self.n5865 = self.n5805 & self.n5848
    self.n5849 = ~self.n5848 & 0x1L
    if self.n5832:
      self.n5837 = self.n5818
    else:
      self.n5837 = self.n5836
    if self.n5550 == self.n5546:
      self.n5575 = 1L
    else:
      self.n5575 = 0L
    if self.n5550 == self.n5545:
      self.n5574 = 1L
    else:
      self.n5574 = 0L
    if self.n5550 == self.n5544:
      self.n5573 = 1L
    else:
      self.n5573 = 0L
    if self.n5550 == self.n5543:
      self.n5572 = 1L
    else:
      self.n5572 = 0L
    if self.n5550 == self.n5542:
      self.n5571 = 1L
    else:
      self.n5571 = 0L
    if self.n5550 == self.n5541:
      self.n5570 = 1L
    else:
      self.n5570 = 0L
    if self.n5550 == self.n5531:
      self.n5556 = 1L
    else:
      self.n5556 = 0L
    if self.n5550 == self.n5530:
      self.n5555 = 1L
    else:
      self.n5555 = 0L
    if self.n5550 == self.n5529:
      self.n5554 = 1L
    else:
      self.n5554 = 0L
    if self.n5550 == self.n5528:
      self.n5553 = 1L
    else:
      self.n5553 = 0L
    if self.n5550 == self.n5527:
      self.n5552 = 1L
    else:
      self.n5552 = 0L
    if self.n5550 == self.n5526:
      self.n5551 = 1L
    else:
      self.n5551 = 0L
    if self.n5466 == self.n5460:
      self.n5489 = 1L
    else:
      self.n5489 = 0L
    if self.n5466 == self.n5459:
      self.n5488 = 1L
    else:
      self.n5488 = 0L
    if self.n5466 == self.n5458:
      self.n5487 = 1L
    else:
      self.n5487 = 0L
    if self.n5466 == self.n5457:
      self.n5486 = 1L
    else:
      self.n5486 = 0L
    if self.n5466 == self.n5448:
      self.n5473 = 1L
    else:
      self.n5473 = 0L
    if self.n5466 == self.n5447:
      self.n5472 = 1L
    else:
      self.n5472 = 0L
    if self.n5466 == self.n5446:
      self.n5471 = 1L
    else:
      self.n5471 = 0L
    if self.n5466 == self.n5445:
      self.n5470 = 1L
    else:
      self.n5470 = 0L
    if self.n5466 == self.n5444:
      self.n5469 = 1L
    else:
      self.n5469 = 0L
    if self.n5466 == self.n5443:
      self.n5468 = 1L
    else:
      self.n5468 = 0L
    if self.n5466 == self.n5442:
      self.n5467 = 1L
    else:
      self.n5467 = 0L
    self.n5419 = self.n5285 & self.n5402
    self.n5403 = ~self.n5402 & 0x1L
    if self.n5386:
      self.n5391 = self.n5372
    else:
      self.n5391 = self.n5390
    self.n5346 = self.n5286 & self.n5329
    self.n5330 = ~self.n5329 & 0x1L
    if self.n5313:
      self.n5318 = self.n5299
    else:
      self.n5318 = self.n5317
    if self.n5031 == self.n5027:
      self.n5056 = 1L
    else:
      self.n5056 = 0L
    if self.n5031 == self.n5026:
      self.n5055 = 1L
    else:
      self.n5055 = 0L
    if self.n5031 == self.n5025:
      self.n5054 = 1L
    else:
      self.n5054 = 0L
    if self.n5031 == self.n5024:
      self.n5053 = 1L
    else:
      self.n5053 = 0L
    if self.n5031 == self.n5023:
      self.n5052 = 1L
    else:
      self.n5052 = 0L
    if self.n5031 == self.n5022:
      self.n5051 = 1L
    else:
      self.n5051 = 0L
    if self.n5031 == self.n5012:
      self.n5037 = 1L
    else:
      self.n5037 = 0L
    if self.n5031 == self.n5011:
      self.n5036 = 1L
    else:
      self.n5036 = 0L
    if self.n5031 == self.n5010:
      self.n5035 = 1L
    else:
      self.n5035 = 0L
    if self.n5031 == self.n5009:
      self.n5034 = 1L
    else:
      self.n5034 = 0L
    if self.n5031 == self.n5008:
      self.n5033 = 1L
    else:
      self.n5033 = 0L
    if self.n5031 == self.n5007:
      self.n5032 = 1L
    else:
      self.n5032 = 0L
    if self.n4947 == self.n4941:
      self.n4970 = 1L
    else:
      self.n4970 = 0L
    if self.n4947 == self.n4940:
      self.n4969 = 1L
    else:
      self.n4969 = 0L
    if self.n4947 == self.n4939:
      self.n4968 = 1L
    else:
      self.n4968 = 0L
    if self.n4947 == self.n4938:
      self.n4967 = 1L
    else:
      self.n4967 = 0L
    if self.n4947 == self.n4929:
      self.n4954 = 1L
    else:
      self.n4954 = 0L
    if self.n4947 == self.n4928:
      self.n4953 = 1L
    else:
      self.n4953 = 0L
    if self.n4947 == self.n4927:
      self.n4952 = 1L
    else:
      self.n4952 = 0L
    if self.n4947 == self.n4926:
      self.n4951 = 1L
    else:
      self.n4951 = 0L
    if self.n4947 == self.n4925:
      self.n4950 = 1L
    else:
      self.n4950 = 0L
    if self.n4947 == self.n4924:
      self.n4949 = 1L
    else:
      self.n4949 = 0L
    if self.n4947 == self.n4923:
      self.n4948 = 1L
    else:
      self.n4948 = 0L
    self.n4900 = self.n4766 & self.n4883
    self.n4884 = ~self.n4883 & 0x1L
    if self.n4867:
      self.n4872 = self.n4853
    else:
      self.n4872 = self.n4871
    self.n4827 = self.n4767 & self.n4810
    self.n4811 = ~self.n4810 & 0x1L
    if self.n4794:
      self.n4799 = self.n4780
    else:
      self.n4799 = self.n4798
    if self.n4512 == self.n4508:
      self.n4537 = 1L
    else:
      self.n4537 = 0L
    if self.n4512 == self.n4507:
      self.n4536 = 1L
    else:
      self.n4536 = 0L
    if self.n4512 == self.n4506:
      self.n4535 = 1L
    else:
      self.n4535 = 0L
    if self.n4512 == self.n4505:
      self.n4534 = 1L
    else:
      self.n4534 = 0L
    if self.n4512 == self.n4504:
      self.n4533 = 1L
    else:
      self.n4533 = 0L
    if self.n4512 == self.n4503:
      self.n4532 = 1L
    else:
      self.n4532 = 0L
    if self.n4512 == self.n4493:
      self.n4518 = 1L
    else:
      self.n4518 = 0L
    if self.n4512 == self.n4492:
      self.n4517 = 1L
    else:
      self.n4517 = 0L
    if self.n4512 == self.n4491:
      self.n4516 = 1L
    else:
      self.n4516 = 0L
    if self.n4512 == self.n4490:
      self.n4515 = 1L
    else:
      self.n4515 = 0L
    if self.n4512 == self.n4489:
      self.n4514 = 1L
    else:
      self.n4514 = 0L
    if self.n4512 == self.n4488:
      self.n4513 = 1L
    else:
      self.n4513 = 0L
    if self.n4428 == self.n4422:
      self.n4451 = 1L
    else:
      self.n4451 = 0L
    if self.n4428 == self.n4421:
      self.n4450 = 1L
    else:
      self.n4450 = 0L
    if self.n4428 == self.n4420:
      self.n4449 = 1L
    else:
      self.n4449 = 0L
    if self.n4428 == self.n4419:
      self.n4448 = 1L
    else:
      self.n4448 = 0L
    if self.n4428 == self.n4410:
      self.n4435 = 1L
    else:
      self.n4435 = 0L
    if self.n4428 == self.n4409:
      self.n4434 = 1L
    else:
      self.n4434 = 0L
    if self.n4428 == self.n4408:
      self.n4433 = 1L
    else:
      self.n4433 = 0L
    if self.n4428 == self.n4407:
      self.n4432 = 1L
    else:
      self.n4432 = 0L
    if self.n4428 == self.n4406:
      self.n4431 = 1L
    else:
      self.n4431 = 0L
    if self.n4428 == self.n4405:
      self.n4430 = 1L
    else:
      self.n4430 = 0L
    if self.n4428 == self.n4404:
      self.n4429 = 1L
    else:
      self.n4429 = 0L
    self.n4381 = self.n4247 & self.n4364
    self.n4365 = ~self.n4364 & 0x1L
    if self.n4348:
      self.n4353 = self.n4334
    else:
      self.n4353 = self.n4352
    self.n4308 = self.n4248 & self.n4291
    self.n4292 = ~self.n4291 & 0x1L
    if self.n4275:
      self.n4280 = self.n4261
    else:
      self.n4280 = self.n4279
    if self.n3993 == self.n3989:
      self.n4018 = 1L
    else:
      self.n4018 = 0L
    if self.n3993 == self.n3988:
      self.n4017 = 1L
    else:
      self.n4017 = 0L
    if self.n3993 == self.n3987:
      self.n4016 = 1L
    else:
      self.n4016 = 0L
    if self.n3993 == self.n3986:
      self.n4015 = 1L
    else:
      self.n4015 = 0L
    if self.n3993 == self.n3985:
      self.n4014 = 1L
    else:
      self.n4014 = 0L
    if self.n3993 == self.n3984:
      self.n4013 = 1L
    else:
      self.n4013 = 0L
    if self.n3993 == self.n3974:
      self.n3999 = 1L
    else:
      self.n3999 = 0L
    if self.n3993 == self.n3973:
      self.n3998 = 1L
    else:
      self.n3998 = 0L
    if self.n3993 == self.n3972:
      self.n3997 = 1L
    else:
      self.n3997 = 0L
    if self.n3993 == self.n3971:
      self.n3996 = 1L
    else:
      self.n3996 = 0L
    if self.n3993 == self.n3970:
      self.n3995 = 1L
    else:
      self.n3995 = 0L
    if self.n3993 == self.n3969:
      self.n3994 = 1L
    else:
      self.n3994 = 0L
    if self.n3909 == self.n3903:
      self.n3932 = 1L
    else:
      self.n3932 = 0L
    if self.n3909 == self.n3902:
      self.n3931 = 1L
    else:
      self.n3931 = 0L
    if self.n3909 == self.n3901:
      self.n3930 = 1L
    else:
      self.n3930 = 0L
    if self.n3909 == self.n3900:
      self.n3929 = 1L
    else:
      self.n3929 = 0L
    if self.n3909 == self.n3891:
      self.n3916 = 1L
    else:
      self.n3916 = 0L
    if self.n3909 == self.n3890:
      self.n3915 = 1L
    else:
      self.n3915 = 0L
    if self.n3909 == self.n3889:
      self.n3914 = 1L
    else:
      self.n3914 = 0L
    if self.n3909 == self.n3888:
      self.n3913 = 1L
    else:
      self.n3913 = 0L
    if self.n3909 == self.n3887:
      self.n3912 = 1L
    else:
      self.n3912 = 0L
    if self.n3909 == self.n3886:
      self.n3911 = 1L
    else:
      self.n3911 = 0L
    if self.n3909 == self.n3885:
      self.n3910 = 1L
    else:
      self.n3910 = 0L
    self.n3862 = self.n3728 & self.n3845
    self.n3846 = ~self.n3845 & 0x1L
    if self.n3829:
      self.n3834 = self.n3815
    else:
      self.n3834 = self.n3833
    self.n3789 = self.n3729 & self.n3772
    self.n3773 = ~self.n3772 & 0x1L
    if self.n3756:
      self.n3761 = self.n3742
    else:
      self.n3761 = self.n3760
    if self.n3474 == self.n3470:
      self.n3499 = 1L
    else:
      self.n3499 = 0L
    if self.n3474 == self.n3469:
      self.n3498 = 1L
    else:
      self.n3498 = 0L
    if self.n3474 == self.n3468:
      self.n3497 = 1L
    else:
      self.n3497 = 0L
    if self.n3474 == self.n3467:
      self.n3496 = 1L
    else:
      self.n3496 = 0L
    if self.n3474 == self.n3466:
      self.n3495 = 1L
    else:
      self.n3495 = 0L
    if self.n3474 == self.n3465:
      self.n3494 = 1L
    else:
      self.n3494 = 0L
    if self.n3474 == self.n3455:
      self.n3480 = 1L
    else:
      self.n3480 = 0L
    if self.n3474 == self.n3454:
      self.n3479 = 1L
    else:
      self.n3479 = 0L
    if self.n3474 == self.n3453:
      self.n3478 = 1L
    else:
      self.n3478 = 0L
    if self.n3474 == self.n3452:
      self.n3477 = 1L
    else:
      self.n3477 = 0L
    if self.n3474 == self.n3451:
      self.n3476 = 1L
    else:
      self.n3476 = 0L
    if self.n3474 == self.n3450:
      self.n3475 = 1L
    else:
      self.n3475 = 0L
    if self.n3390 == self.n3384:
      self.n3413 = 1L
    else:
      self.n3413 = 0L
    if self.n3390 == self.n3383:
      self.n3412 = 1L
    else:
      self.n3412 = 0L
    if self.n3390 == self.n3382:
      self.n3411 = 1L
    else:
      self.n3411 = 0L
    if self.n3390 == self.n3381:
      self.n3410 = 1L
    else:
      self.n3410 = 0L
    if self.n3390 == self.n3372:
      self.n3397 = 1L
    else:
      self.n3397 = 0L
    if self.n3390 == self.n3371:
      self.n3396 = 1L
    else:
      self.n3396 = 0L
    if self.n3390 == self.n3370:
      self.n3395 = 1L
    else:
      self.n3395 = 0L
    if self.n3390 == self.n3369:
      self.n3394 = 1L
    else:
      self.n3394 = 0L
    if self.n3390 == self.n3368:
      self.n3393 = 1L
    else:
      self.n3393 = 0L
    if self.n3390 == self.n3367:
      self.n3392 = 1L
    else:
      self.n3392 = 0L
    if self.n3390 == self.n3366:
      self.n3391 = 1L
    else:
      self.n3391 = 0L
    self.n3343 = self.n3209 & self.n3326
    self.n3327 = ~self.n3326 & 0x1L
    if self.n3310:
      self.n3315 = self.n3296
    else:
      self.n3315 = self.n3314
    self.n3270 = self.n3210 & self.n3253
    self.n3254 = ~self.n3253 & 0x1L
    if self.n3237:
      self.n3242 = self.n3223
    else:
      self.n3242 = self.n3241
    if self.n2955 == self.n2951:
      self.n2980 = 1L
    else:
      self.n2980 = 0L
    if self.n2955 == self.n2950:
      self.n2979 = 1L
    else:
      self.n2979 = 0L
    if self.n2955 == self.n2949:
      self.n2978 = 1L
    else:
      self.n2978 = 0L
    if self.n2955 == self.n2948:
      self.n2977 = 1L
    else:
      self.n2977 = 0L
    if self.n2955 == self.n2947:
      self.n2976 = 1L
    else:
      self.n2976 = 0L
    if self.n2955 == self.n2946:
      self.n2975 = 1L
    else:
      self.n2975 = 0L
    if self.n2955 == self.n2936:
      self.n2961 = 1L
    else:
      self.n2961 = 0L
    if self.n2955 == self.n2935:
      self.n2960 = 1L
    else:
      self.n2960 = 0L
    if self.n2955 == self.n2934:
      self.n2959 = 1L
    else:
      self.n2959 = 0L
    if self.n2955 == self.n2933:
      self.n2958 = 1L
    else:
      self.n2958 = 0L
    if self.n2955 == self.n2932:
      self.n2957 = 1L
    else:
      self.n2957 = 0L
    if self.n2955 == self.n2931:
      self.n2956 = 1L
    else:
      self.n2956 = 0L
    if self.n2871 == self.n2865:
      self.n2894 = 1L
    else:
      self.n2894 = 0L
    if self.n2871 == self.n2864:
      self.n2893 = 1L
    else:
      self.n2893 = 0L
    if self.n2871 == self.n2863:
      self.n2892 = 1L
    else:
      self.n2892 = 0L
    if self.n2871 == self.n2862:
      self.n2891 = 1L
    else:
      self.n2891 = 0L
    if self.n2871 == self.n2853:
      self.n2878 = 1L
    else:
      self.n2878 = 0L
    if self.n2871 == self.n2852:
      self.n2877 = 1L
    else:
      self.n2877 = 0L
    if self.n2871 == self.n2851:
      self.n2876 = 1L
    else:
      self.n2876 = 0L
    if self.n2871 == self.n2850:
      self.n2875 = 1L
    else:
      self.n2875 = 0L
    if self.n2871 == self.n2849:
      self.n2874 = 1L
    else:
      self.n2874 = 0L
    if self.n2871 == self.n2848:
      self.n2873 = 1L
    else:
      self.n2873 = 0L
    if self.n2871 == self.n2847:
      self.n2872 = 1L
    else:
      self.n2872 = 0L
    self.n2824 = self.n2690 & self.n2807
    self.n2808 = ~self.n2807 & 0x1L
    if self.n2791:
      self.n2796 = self.n2777
    else:
      self.n2796 = self.n2795
    self.n2751 = self.n2691 & self.n2734
    self.n2735 = ~self.n2734 & 0x1L
    if self.n2718:
      self.n2723 = self.n2704
    else:
      self.n2723 = self.n2722
    if self.n2436 == self.n2432:
      self.n2461 = 1L
    else:
      self.n2461 = 0L
    if self.n2436 == self.n2431:
      self.n2460 = 1L
    else:
      self.n2460 = 0L
    if self.n2436 == self.n2430:
      self.n2459 = 1L
    else:
      self.n2459 = 0L
    if self.n2436 == self.n2429:
      self.n2458 = 1L
    else:
      self.n2458 = 0L
    if self.n2436 == self.n2428:
      self.n2457 = 1L
    else:
      self.n2457 = 0L
    if self.n2436 == self.n2427:
      self.n2456 = 1L
    else:
      self.n2456 = 0L
    if self.n2436 == self.n2417:
      self.n2442 = 1L
    else:
      self.n2442 = 0L
    if self.n2436 == self.n2416:
      self.n2441 = 1L
    else:
      self.n2441 = 0L
    if self.n2436 == self.n2415:
      self.n2440 = 1L
    else:
      self.n2440 = 0L
    if self.n2436 == self.n2414:
      self.n2439 = 1L
    else:
      self.n2439 = 0L
    if self.n2436 == self.n2413:
      self.n2438 = 1L
    else:
      self.n2438 = 0L
    if self.n2436 == self.n2412:
      self.n2437 = 1L
    else:
      self.n2437 = 0L
    if self.n2352 == self.n2346:
      self.n2375 = 1L
    else:
      self.n2375 = 0L
    if self.n2352 == self.n2345:
      self.n2374 = 1L
    else:
      self.n2374 = 0L
    if self.n2352 == self.n2344:
      self.n2373 = 1L
    else:
      self.n2373 = 0L
    if self.n2352 == self.n2343:
      self.n2372 = 1L
    else:
      self.n2372 = 0L
    if self.n2352 == self.n2334:
      self.n2359 = 1L
    else:
      self.n2359 = 0L
    if self.n2352 == self.n2333:
      self.n2358 = 1L
    else:
      self.n2358 = 0L
    if self.n2352 == self.n2332:
      self.n2357 = 1L
    else:
      self.n2357 = 0L
    if self.n2352 == self.n2331:
      self.n2356 = 1L
    else:
      self.n2356 = 0L
    if self.n2352 == self.n2330:
      self.n2355 = 1L
    else:
      self.n2355 = 0L
    if self.n2352 == self.n2329:
      self.n2354 = 1L
    else:
      self.n2354 = 0L
    if self.n2352 == self.n2328:
      self.n2353 = 1L
    else:
      self.n2353 = 0L
    self.n2305 = self.n2171 & self.n2288
    self.n2289 = ~self.n2288 & 0x1L
    if self.n2272:
      self.n2277 = self.n2258
    else:
      self.n2277 = self.n2276
    self.n2232 = self.n2172 & self.n2215
    self.n2216 = ~self.n2215 & 0x1L
    if self.n2199:
      self.n2204 = self.n2185
    else:
      self.n2204 = self.n2203
    if self.n1917 == self.n1913:
      self.n1942 = 1L
    else:
      self.n1942 = 0L
    if self.n1917 == self.n1912:
      self.n1941 = 1L
    else:
      self.n1941 = 0L
    if self.n1917 == self.n1911:
      self.n1940 = 1L
    else:
      self.n1940 = 0L
    if self.n1917 == self.n1910:
      self.n1939 = 1L
    else:
      self.n1939 = 0L
    if self.n1917 == self.n1909:
      self.n1938 = 1L
    else:
      self.n1938 = 0L
    if self.n1917 == self.n1908:
      self.n1937 = 1L
    else:
      self.n1937 = 0L
    if self.n1917 == self.n1898:
      self.n1923 = 1L
    else:
      self.n1923 = 0L
    if self.n1917 == self.n1897:
      self.n1922 = 1L
    else:
      self.n1922 = 0L
    if self.n1917 == self.n1896:
      self.n1921 = 1L
    else:
      self.n1921 = 0L
    if self.n1917 == self.n1895:
      self.n1920 = 1L
    else:
      self.n1920 = 0L
    if self.n1917 == self.n1894:
      self.n1919 = 1L
    else:
      self.n1919 = 0L
    if self.n1917 == self.n1893:
      self.n1918 = 1L
    else:
      self.n1918 = 0L
    if self.n1833 == self.n1827:
      self.n1856 = 1L
    else:
      self.n1856 = 0L
    if self.n1833 == self.n1826:
      self.n1855 = 1L
    else:
      self.n1855 = 0L
    if self.n1833 == self.n1825:
      self.n1854 = 1L
    else:
      self.n1854 = 0L
    if self.n1833 == self.n1824:
      self.n1853 = 1L
    else:
      self.n1853 = 0L
    if self.n1833 == self.n1815:
      self.n1840 = 1L
    else:
      self.n1840 = 0L
    if self.n1833 == self.n1814:
      self.n1839 = 1L
    else:
      self.n1839 = 0L
    if self.n1833 == self.n1813:
      self.n1838 = 1L
    else:
      self.n1838 = 0L
    if self.n1833 == self.n1812:
      self.n1837 = 1L
    else:
      self.n1837 = 0L
    if self.n1833 == self.n1811:
      self.n1836 = 1L
    else:
      self.n1836 = 0L
    if self.n1833 == self.n1810:
      self.n1835 = 1L
    else:
      self.n1835 = 0L
    if self.n1833 == self.n1809:
      self.n1834 = 1L
    else:
      self.n1834 = 0L
    self.n1786 = self.n1652 & self.n1769
    self.n1770 = ~self.n1769 & 0x1L
    if self.n1753:
      self.n1758 = self.n1739
    else:
      self.n1758 = self.n1757
    self.n1713 = self.n1653 & self.n1696
    self.n1697 = ~self.n1696 & 0x1L
    if self.n1680:
      self.n1685 = self.n1666
    else:
      self.n1685 = self.n1684
    if self.n1398 == self.n1394:
      self.n1423 = 1L
    else:
      self.n1423 = 0L
    if self.n1398 == self.n1393:
      self.n1422 = 1L
    else:
      self.n1422 = 0L
    if self.n1398 == self.n1392:
      self.n1421 = 1L
    else:
      self.n1421 = 0L
    if self.n1398 == self.n1391:
      self.n1420 = 1L
    else:
      self.n1420 = 0L
    if self.n1398 == self.n1390:
      self.n1419 = 1L
    else:
      self.n1419 = 0L
    if self.n1398 == self.n1389:
      self.n1418 = 1L
    else:
      self.n1418 = 0L
    if self.n1398 == self.n1379:
      self.n1404 = 1L
    else:
      self.n1404 = 0L
    if self.n1398 == self.n1378:
      self.n1403 = 1L
    else:
      self.n1403 = 0L
    if self.n1398 == self.n1377:
      self.n1402 = 1L
    else:
      self.n1402 = 0L
    if self.n1398 == self.n1376:
      self.n1401 = 1L
    else:
      self.n1401 = 0L
    if self.n1398 == self.n1375:
      self.n1400 = 1L
    else:
      self.n1400 = 0L
    if self.n1398 == self.n1374:
      self.n1399 = 1L
    else:
      self.n1399 = 0L
    if self.n1314 == self.n1308:
      self.n1337 = 1L
    else:
      self.n1337 = 0L
    if self.n1314 == self.n1307:
      self.n1336 = 1L
    else:
      self.n1336 = 0L
    if self.n1314 == self.n1306:
      self.n1335 = 1L
    else:
      self.n1335 = 0L
    if self.n1314 == self.n1305:
      self.n1334 = 1L
    else:
      self.n1334 = 0L
    if self.n1314 == self.n1296:
      self.n1321 = 1L
    else:
      self.n1321 = 0L
    if self.n1314 == self.n1295:
      self.n1320 = 1L
    else:
      self.n1320 = 0L
    if self.n1314 == self.n1294:
      self.n1319 = 1L
    else:
      self.n1319 = 0L
    if self.n1314 == self.n1293:
      self.n1318 = 1L
    else:
      self.n1318 = 0L
    if self.n1314 == self.n1292:
      self.n1317 = 1L
    else:
      self.n1317 = 0L
    if self.n1314 == self.n1291:
      self.n1316 = 1L
    else:
      self.n1316 = 0L
    if self.n1314 == self.n1290:
      self.n1315 = 1L
    else:
      self.n1315 = 0L
    self.n1267 = self.n1133 & self.n1250
    self.n1251 = ~self.n1250 & 0x1L
    if self.n1234:
      self.n1239 = self.n1220
    else:
      self.n1239 = self.n1238
    self.n1194 = self.n1134 & self.n1177
    self.n1178 = ~self.n1177 & 0x1L
    if self.n1161:
      self.n1166 = self.n1147
    else:
      self.n1166 = self.n1165
    if self.n879 == self.n875:
      self.n904 = 1L
    else:
      self.n904 = 0L
    if self.n879 == self.n874:
      self.n903 = 1L
    else:
      self.n903 = 0L
    if self.n879 == self.n873:
      self.n902 = 1L
    else:
      self.n902 = 0L
    if self.n879 == self.n872:
      self.n901 = 1L
    else:
      self.n901 = 0L
    if self.n879 == self.n871:
      self.n900 = 1L
    else:
      self.n900 = 0L
    if self.n879 == self.n870:
      self.n899 = 1L
    else:
      self.n899 = 0L
    if self.n879 == self.n860:
      self.n885 = 1L
    else:
      self.n885 = 0L
    if self.n879 == self.n859:
      self.n884 = 1L
    else:
      self.n884 = 0L
    if self.n879 == self.n858:
      self.n883 = 1L
    else:
      self.n883 = 0L
    if self.n879 == self.n857:
      self.n882 = 1L
    else:
      self.n882 = 0L
    if self.n879 == self.n856:
      self.n881 = 1L
    else:
      self.n881 = 0L
    if self.n879 == self.n855:
      self.n880 = 1L
    else:
      self.n880 = 0L
    if self.n795 == self.n789:
      self.n818 = 1L
    else:
      self.n818 = 0L
    if self.n795 == self.n788:
      self.n817 = 1L
    else:
      self.n817 = 0L
    if self.n795 == self.n787:
      self.n816 = 1L
    else:
      self.n816 = 0L
    if self.n795 == self.n786:
      self.n815 = 1L
    else:
      self.n815 = 0L
    if self.n795 == self.n777:
      self.n802 = 1L
    else:
      self.n802 = 0L
    if self.n795 == self.n776:
      self.n801 = 1L
    else:
      self.n801 = 0L
    if self.n795 == self.n775:
      self.n800 = 1L
    else:
      self.n800 = 0L
    if self.n795 == self.n774:
      self.n799 = 1L
    else:
      self.n799 = 0L
    if self.n795 == self.n773:
      self.n798 = 1L
    else:
      self.n798 = 0L
    if self.n795 == self.n772:
      self.n797 = 1L
    else:
      self.n797 = 0L
    if self.n795 == self.n771:
      self.n796 = 1L
    else:
      self.n796 = 0L
    self.n748 = self.n614 & self.n731
    self.n732 = ~self.n731 & 0x1L
    if self.n715:
      self.n720 = self.n701
    else:
      self.n720 = self.n719
    self.n675 = self.n615 & self.n658
    self.n659 = ~self.n658 & 0x1L
    if self.n642:
      self.n647 = self.n628
    else:
      self.n647 = self.n646
    if self.n360 == self.n356:
      self.n385 = 1L
    else:
      self.n385 = 0L
    if self.n360 == self.n355:
      self.n384 = 1L
    else:
      self.n384 = 0L
    if self.n360 == self.n354:
      self.n383 = 1L
    else:
      self.n383 = 0L
    if self.n360 == self.n353:
      self.n382 = 1L
    else:
      self.n382 = 0L
    if self.n360 == self.n352:
      self.n381 = 1L
    else:
      self.n381 = 0L
    if self.n360 == self.n351:
      self.n380 = 1L
    else:
      self.n380 = 0L
    if self.n360 == self.n341:
      self.n366 = 1L
    else:
      self.n366 = 0L
    if self.n360 == self.n340:
      self.n365 = 1L
    else:
      self.n365 = 0L
    if self.n360 == self.n339:
      self.n364 = 1L
    else:
      self.n364 = 0L
    if self.n360 == self.n338:
      self.n363 = 1L
    else:
      self.n363 = 0L
    if self.n360 == self.n337:
      self.n362 = 1L
    else:
      self.n362 = 0L
    if self.n360 == self.n336:
      self.n361 = 1L
    else:
      self.n361 = 0L
    if self.n276 == self.n270:
      self.n299 = 1L
    else:
      self.n299 = 0L
    if self.n276 == self.n269:
      self.n298 = 1L
    else:
      self.n298 = 0L
    if self.n276 == self.n268:
      self.n297 = 1L
    else:
      self.n297 = 0L
    if self.n276 == self.n267:
      self.n296 = 1L
    else:
      self.n296 = 0L
    if self.n276 == self.n258:
      self.n283 = 1L
    else:
      self.n283 = 0L
    if self.n276 == self.n257:
      self.n282 = 1L
    else:
      self.n282 = 0L
    if self.n276 == self.n256:
      self.n281 = 1L
    else:
      self.n281 = 0L
    if self.n276 == self.n255:
      self.n280 = 1L
    else:
      self.n280 = 0L
    if self.n276 == self.n254:
      self.n279 = 1L
    else:
      self.n279 = 0L
    if self.n276 == self.n253:
      self.n278 = 1L
    else:
      self.n278 = 0L
    if self.n276 == self.n252:
      self.n277 = 1L
    else:
      self.n277 = 0L
    if self.n195 == self.n191:
      self.n208 = 1L
    else:
      self.n208 = 0L
    if self.n195 == self.n190:
      self.n207 = 1L
    else:
      self.n207 = 0L
    if self.n195 == self.n185:
      self.n198 = 1L
    else:
      self.n198 = 0L
    if self.n195 == self.n184:
      self.n197 = 1L
    else:
      self.n197 = 0L
    if self.n195 == self.n183:
      self.n196 = 1L
    else:
      self.n196 = 0L
    self.n178r = self.n6599
    self.n178e = self.n6547
    self.n178d = self.n173
    if self.n122 == self.n118:
      self.n135 = 1L
    else:
      self.n135 = 0L
    if self.n122 == self.n117:
      self.n134 = 1L
    else:
      self.n134 = 0L
    if self.n122 == self.n112:
      self.n125 = 1L
    else:
      self.n125 = 0L
    if self.n122 == self.n111:
      self.n124 = 1L
    else:
      self.n124 = 0L
    if self.n122 == self.n110:
      self.n123 = 1L
    else:
      self.n123 = 0L
    self.n105r = self.n6600
    self.n105e = self.n6547
    self.n105d = self.n100
    if self.n50 == self.n46:
      self.n75 = 1L
    else:
      self.n75 = 0L
    if self.n50 == self.n45:
      self.n74 = 1L
    else:
      self.n74 = 0L
    if self.n50 == self.n44:
      self.n73 = 1L
    else:
      self.n73 = 0L
    if self.n50 == self.n43:
      self.n72 = 1L
    else:
      self.n72 = 0L
    if self.n50 == self.n42:
      self.n71 = 1L
    else:
      self.n71 = 0L
    if self.n50 == self.n41:
      self.n70 = 1L
    else:
      self.n70 = 0L
    if self.n50 == self.n31:
      self.n56 = 1L
    else:
      self.n56 = 0L
    if self.n50 == self.n30:
      self.n55 = 1L
    else:
      self.n55 = 0L
    if self.n50 == self.n29:
      self.n54 = 1L
    else:
      self.n54 = 0L
    if self.n50 == self.n28:
      self.n53 = 1L
    else:
      self.n53 = 0L
    if self.n50 == self.n27:
      self.n52 = 1L
    else:
      self.n52 = 0L
    if self.n50 == self.n26:
      self.n51 = 1L
    else:
      self.n51 = 0L
    if self.n6527:
      self.n6534 = self.n6491
    else:
      self.n6534 = self.n6758
    if self.n6511:
      self.n6512 = self.n6473
    else:
      self.n6512 = self.n6472
    self.n6469r = self.n6548
    self.n6469e = self.n6547
    self.n6469d = self.n6441
    self.n6462e = self.n6547
    self.n6462w = self.n6457
    self.n6462aw = self.n6294
    self.n6462ar = self.n6406
    self.n6462dw = self.n6237
    self.n6451 = self.n6323 & self.n6441
    self.n6434r = self.n6548
    self.n6434e = self.n6547
    self.n6434d = self.n6429
    self.n6396r = self.n6548
    self.n6396e = self.n6547
    self.n6396d = self.n6368
    self.n6389e = self.n6547
    self.n6389w = self.n6384
    self.n6389aw = self.n6294
    self.n6389ar = self.n6333
    self.n6389dw = self.n6237
    self.n6378 = self.n6324 & self.n6368
    self.n6361r = self.n6548
    self.n6361e = self.n6547
    self.n6361d = self.n6356
    if self.n6094:
      self.n6097 = self.n6054
    else:
      self.n6097 = self.n6749
    if self.n6075:
      self.n6078 = self.n6039
    else:
      self.n6078 = self.n6747
    if self.n6008:
      self.n6015 = self.n5972
    else:
      self.n6015 = self.n6746
    if self.n5992:
      self.n5993 = self.n5954
    else:
      self.n5993 = self.n5953
    self.n5950r = self.n6548
    self.n5950e = self.n6547
    self.n5950d = self.n5922
    self.n5943e = self.n6547
    self.n5943w = self.n5938
    self.n5943aw = self.n5775
    self.n5943ar = self.n5887
    self.n5943dw = self.n5718
    self.n5932 = self.n5804 & self.n5922
    self.n5915r = self.n6548
    self.n5915e = self.n6547
    self.n5915d = self.n5910
    self.n5877r = self.n6548
    self.n5877e = self.n6547
    self.n5877d = self.n5849
    self.n5870e = self.n6547
    self.n5870w = self.n5865
    self.n5870aw = self.n5775
    self.n5870ar = self.n5814
    self.n5870dw = self.n5718
    self.n5859 = self.n5805 & self.n5849
    self.n5842r = self.n6548
    self.n5842e = self.n6547
    self.n5842d = self.n5837
    if self.n5575:
      self.n5578 = self.n5535
    else:
      self.n5578 = self.n6737
    if self.n5556:
      self.n5559 = self.n5520
    else:
      self.n5559 = self.n6735
    if self.n5489:
      self.n5496 = self.n5453
    else:
      self.n5496 = self.n6734
    if self.n5473:
      self.n5474 = self.n5435
    else:
      self.n5474 = self.n5434
    self.n5431r = self.n6548
    self.n5431e = self.n6547
    self.n5431d = self.n5403
    self.n5424e = self.n6547
    self.n5424w = self.n5419
    self.n5424aw = self.n5256
    self.n5424ar = self.n5368
    self.n5424dw = self.n5199
    self.n5413 = self.n5285 & self.n5403
    self.n5396r = self.n6548
    self.n5396e = self.n6547
    self.n5396d = self.n5391
    self.n5358r = self.n6548
    self.n5358e = self.n6547
    self.n5358d = self.n5330
    self.n5351e = self.n6547
    self.n5351w = self.n5346
    self.n5351aw = self.n5256
    self.n5351ar = self.n5295
    self.n5351dw = self.n5199
    self.n5340 = self.n5286 & self.n5330
    self.n5323r = self.n6548
    self.n5323e = self.n6547
    self.n5323d = self.n5318
    if self.n5056:
      self.n5059 = self.n5016
    else:
      self.n5059 = self.n6725
    if self.n5037:
      self.n5040 = self.n5001
    else:
      self.n5040 = self.n6723
    if self.n4970:
      self.n4977 = self.n4934
    else:
      self.n4977 = self.n6722
    if self.n4954:
      self.n4955 = self.n4916
    else:
      self.n4955 = self.n4915
    self.n4912r = self.n6548
    self.n4912e = self.n6547
    self.n4912d = self.n4884
    self.n4905e = self.n6547
    self.n4905w = self.n4900
    self.n4905aw = self.n4737
    self.n4905ar = self.n4849
    self.n4905dw = self.n4680
    self.n4894 = self.n4766 & self.n4884
    self.n4877r = self.n6548
    self.n4877e = self.n6547
    self.n4877d = self.n4872
    self.n4839r = self.n6548
    self.n4839e = self.n6547
    self.n4839d = self.n4811
    self.n4832e = self.n6547
    self.n4832w = self.n4827
    self.n4832aw = self.n4737
    self.n4832ar = self.n4776
    self.n4832dw = self.n4680
    self.n4821 = self.n4767 & self.n4811
    self.n4804r = self.n6548
    self.n4804e = self.n6547
    self.n4804d = self.n4799
    if self.n4537:
      self.n4540 = self.n4497
    else:
      self.n4540 = self.n6713
    if self.n4518:
      self.n4521 = self.n4482
    else:
      self.n4521 = self.n6711
    if self.n4451:
      self.n4458 = self.n4415
    else:
      self.n4458 = self.n6710
    if self.n4435:
      self.n4436 = self.n4397
    else:
      self.n4436 = self.n4396
    self.n4393r = self.n6548
    self.n4393e = self.n6547
    self.n4393d = self.n4365
    self.n4386e = self.n6547
    self.n4386w = self.n4381
    self.n4386aw = self.n4218
    self.n4386ar = self.n4330
    self.n4386dw = self.n4161
    self.n4375 = self.n4247 & self.n4365
    self.n4358r = self.n6548
    self.n4358e = self.n6547
    self.n4358d = self.n4353
    self.n4320r = self.n6548
    self.n4320e = self.n6547
    self.n4320d = self.n4292
    self.n4313e = self.n6547
    self.n4313w = self.n4308
    self.n4313aw = self.n4218
    self.n4313ar = self.n4257
    self.n4313dw = self.n4161
    self.n4302 = self.n4248 & self.n4292
    self.n4285r = self.n6548
    self.n4285e = self.n6547
    self.n4285d = self.n4280
    if self.n4018:
      self.n4021 = self.n3978
    else:
      self.n4021 = self.n6701
    if self.n3999:
      self.n4002 = self.n3963
    else:
      self.n4002 = self.n6699
    if self.n3932:
      self.n3939 = self.n3896
    else:
      self.n3939 = self.n6698
    if self.n3916:
      self.n3917 = self.n3878
    else:
      self.n3917 = self.n3877
    self.n3874r = self.n6548
    self.n3874e = self.n6547
    self.n3874d = self.n3846
    self.n3867e = self.n6547
    self.n3867w = self.n3862
    self.n3867aw = self.n3699
    self.n3867ar = self.n3811
    self.n3867dw = self.n3642
    self.n3856 = self.n3728 & self.n3846
    self.n3839r = self.n6548
    self.n3839e = self.n6547
    self.n3839d = self.n3834
    self.n3801r = self.n6548
    self.n3801e = self.n6547
    self.n3801d = self.n3773
    self.n3794e = self.n6547
    self.n3794w = self.n3789
    self.n3794aw = self.n3699
    self.n3794ar = self.n3738
    self.n3794dw = self.n3642
    self.n3783 = self.n3729 & self.n3773
    self.n3766r = self.n6548
    self.n3766e = self.n6547
    self.n3766d = self.n3761
    if self.n3499:
      self.n3502 = self.n3459
    else:
      self.n3502 = self.n6689
    if self.n3480:
      self.n3483 = self.n3444
    else:
      self.n3483 = self.n6687
    if self.n3413:
      self.n3420 = self.n3377
    else:
      self.n3420 = self.n6686
    if self.n3397:
      self.n3398 = self.n3359
    else:
      self.n3398 = self.n3358
    self.n3355r = self.n6548
    self.n3355e = self.n6547
    self.n3355d = self.n3327
    self.n3348e = self.n6547
    self.n3348w = self.n3343
    self.n3348aw = self.n3180
    self.n3348ar = self.n3292
    self.n3348dw = self.n3123
    self.n3337 = self.n3209 & self.n3327
    self.n3320r = self.n6548
    self.n3320e = self.n6547
    self.n3320d = self.n3315
    self.n3282r = self.n6548
    self.n3282e = self.n6547
    self.n3282d = self.n3254
    self.n3275e = self.n6547
    self.n3275w = self.n3270
    self.n3275aw = self.n3180
    self.n3275ar = self.n3219
    self.n3275dw = self.n3123
    self.n3264 = self.n3210 & self.n3254
    self.n3247r = self.n6548
    self.n3247e = self.n6547
    self.n3247d = self.n3242
    if self.n2980:
      self.n2983 = self.n2940
    else:
      self.n2983 = self.n6677
    if self.n2961:
      self.n2964 = self.n2925
    else:
      self.n2964 = self.n6675
    if self.n2894:
      self.n2901 = self.n2858
    else:
      self.n2901 = self.n6674
    if self.n2878:
      self.n2879 = self.n2840
    else:
      self.n2879 = self.n2839
    self.n2836r = self.n6548
    self.n2836e = self.n6547
    self.n2836d = self.n2808
    self.n2829e = self.n6547
    self.n2829w = self.n2824
    self.n2829aw = self.n2661
    self.n2829ar = self.n2773
    self.n2829dw = self.n2604
    self.n2818 = self.n2690 & self.n2808
    self.n2801r = self.n6548
    self.n2801e = self.n6547
    self.n2801d = self.n2796
    self.n2763r = self.n6548
    self.n2763e = self.n6547
    self.n2763d = self.n2735
    self.n2756e = self.n6547
    self.n2756w = self.n2751
    self.n2756aw = self.n2661
    self.n2756ar = self.n2700
    self.n2756dw = self.n2604
    self.n2745 = self.n2691 & self.n2735
    self.n2728r = self.n6548
    self.n2728e = self.n6547
    self.n2728d = self.n2723
    if self.n2461:
      self.n2464 = self.n2421
    else:
      self.n2464 = self.n6665
    if self.n2442:
      self.n2445 = self.n2406
    else:
      self.n2445 = self.n6663
    if self.n2375:
      self.n2382 = self.n2339
    else:
      self.n2382 = self.n6662
    if self.n2359:
      self.n2360 = self.n2321
    else:
      self.n2360 = self.n2320
    self.n2317r = self.n6548
    self.n2317e = self.n6547
    self.n2317d = self.n2289
    self.n2310e = self.n6547
    self.n2310w = self.n2305
    self.n2310aw = self.n2142
    self.n2310ar = self.n2254
    self.n2310dw = self.n2085
    self.n2299 = self.n2171 & self.n2289
    self.n2282r = self.n6548
    self.n2282e = self.n6547
    self.n2282d = self.n2277
    self.n2244r = self.n6548
    self.n2244e = self.n6547
    self.n2244d = self.n2216
    self.n2237e = self.n6547
    self.n2237w = self.n2232
    self.n2237aw = self.n2142
    self.n2237ar = self.n2181
    self.n2237dw = self.n2085
    self.n2226 = self.n2172 & self.n2216
    self.n2209r = self.n6548
    self.n2209e = self.n6547
    self.n2209d = self.n2204
    if self.n1942:
      self.n1945 = self.n1902
    else:
      self.n1945 = self.n6653
    if self.n1923:
      self.n1926 = self.n1887
    else:
      self.n1926 = self.n6651
    if self.n1856:
      self.n1863 = self.n1820
    else:
      self.n1863 = self.n6650
    if self.n1840:
      self.n1841 = self.n1802
    else:
      self.n1841 = self.n1801
    self.n1798r = self.n6548
    self.n1798e = self.n6547
    self.n1798d = self.n1770
    self.n1791e = self.n6547
    self.n1791w = self.n1786
    self.n1791aw = self.n1623
    self.n1791ar = self.n1735
    self.n1791dw = self.n1566
    self.n1780 = self.n1652 & self.n1770
    self.n1763r = self.n6548
    self.n1763e = self.n6547
    self.n1763d = self.n1758
    self.n1725r = self.n6548
    self.n1725e = self.n6547
    self.n1725d = self.n1697
    self.n1718e = self.n6547
    self.n1718w = self.n1713
    self.n1718aw = self.n1623
    self.n1718ar = self.n1662
    self.n1718dw = self.n1566
    self.n1707 = self.n1653 & self.n1697
    self.n1690r = self.n6548
    self.n1690e = self.n6547
    self.n1690d = self.n1685
    if self.n1423:
      self.n1426 = self.n1383
    else:
      self.n1426 = self.n6641
    if self.n1404:
      self.n1407 = self.n1368
    else:
      self.n1407 = self.n6639
    if self.n1337:
      self.n1344 = self.n1301
    else:
      self.n1344 = self.n6638
    if self.n1321:
      self.n1322 = self.n1283
    else:
      self.n1322 = self.n1282
    self.n1279r = self.n6548
    self.n1279e = self.n6547
    self.n1279d = self.n1251
    self.n1272e = self.n6547
    self.n1272w = self.n1267
    self.n1272aw = self.n1104
    self.n1272ar = self.n1216
    self.n1272dw = self.n1047
    self.n1261 = self.n1133 & self.n1251
    self.n1244r = self.n6548
    self.n1244e = self.n6547
    self.n1244d = self.n1239
    self.n1206r = self.n6548
    self.n1206e = self.n6547
    self.n1206d = self.n1178
    self.n1199e = self.n6547
    self.n1199w = self.n1194
    self.n1199aw = self.n1104
    self.n1199ar = self.n1143
    self.n1199dw = self.n1047
    self.n1188 = self.n1134 & self.n1178
    self.n1171r = self.n6548
    self.n1171e = self.n6547
    self.n1171d = self.n1166
    if self.n904:
      self.n907 = self.n864
    else:
      self.n907 = self.n6629
    if self.n885:
      self.n888 = self.n849
    else:
      self.n888 = self.n6627
    if self.n818:
      self.n825 = self.n782
    else:
      self.n825 = self.n6626
    if self.n802:
      self.n803 = self.n764
    else:
      self.n803 = self.n763
    self.n760r = self.n6548
    self.n760e = self.n6547
    self.n760d = self.n732
    self.n753e = self.n6547
    self.n753w = self.n748
    self.n753aw = self.n585
    self.n753ar = self.n697
    self.n753dw = self.n528
    self.n742 = self.n614 & self.n732
    self.n725r = self.n6548
    self.n725e = self.n6547
    self.n725d = self.n720
    self.n687r = self.n6548
    self.n687e = self.n6547
    self.n687d = self.n659
    self.n680e = self.n6547
    self.n680w = self.n675
    self.n680aw = self.n585
    self.n680ar = self.n624
    self.n680dw = self.n528
    self.n669 = self.n615 & self.n659
    self.n652r = self.n6548
    self.n652e = self.n6547
    self.n652d = self.n647
    if self.n385:
      self.n388 = self.n345
    else:
      self.n388 = self.n6617
    if self.n366:
      self.n369 = self.n330
    else:
      self.n369 = self.n6615
    if self.n299:
      self.n306 = self.n263
    else:
      self.n306 = self.n6614
    if self.n283:
      self.n284 = self.n245
    else:
      self.n284 = self.n244
    if self.n208:
      self.n211 = self.n188
    else:
      self.n211 = self.n6609
    if self.n198:
      self.n199 = self.n180
    else:
      self.n199 = self.n179
    if self.n135:
      self.n138 = self.n115
    else:
      self.n138 = self.n6607
    if self.n125:
      self.n126 = self.n107
    else:
      self.n126 = self.n106
    if self.n75:
      self.n78 = self.n35
    else:
      self.n78 = self.n6605
    if self.n56:
      self.n59 = self.n20
    else:
      self.n59 = self.n6603
    if self.n6526:
      self.n6535 = self.n6492
    else:
      self.n6535 = self.n6534
    if self.n6510:
      self.n6513 = self.n6474
    else:
      self.n6513 = self.n6512
    self.n6456e = self.n6547
    self.n6456w = self.n6451
    self.n6456aw = self.n6294
    self.n6456ar = self.n6406
    self.n6456dw = self.n6237
    self.n6383e = self.n6547
    self.n6383w = self.n6378
    self.n6383aw = self.n6294
    self.n6383ar = self.n6333
    self.n6383dw = self.n6237
    if self.n6093:
      self.n6098 = self.n6055
    else:
      self.n6098 = self.n6097
    if self.n6074:
      self.n6079 = self.n6040
    else:
      self.n6079 = self.n6078
    if self.n6007:
      self.n6016 = self.n5973
    else:
      self.n6016 = self.n6015
    if self.n5991:
      self.n5994 = self.n5955
    else:
      self.n5994 = self.n5993
    self.n5937e = self.n6547
    self.n5937w = self.n5932
    self.n5937aw = self.n5775
    self.n5937ar = self.n5887
    self.n5937dw = self.n5718
    self.n5864e = self.n6547
    self.n5864w = self.n5859
    self.n5864aw = self.n5775
    self.n5864ar = self.n5814
    self.n5864dw = self.n5718
    if self.n5574:
      self.n5579 = self.n5536
    else:
      self.n5579 = self.n5578
    if self.n5555:
      self.n5560 = self.n5521
    else:
      self.n5560 = self.n5559
    if self.n5488:
      self.n5497 = self.n5454
    else:
      self.n5497 = self.n5496
    if self.n5472:
      self.n5475 = self.n5436
    else:
      self.n5475 = self.n5474
    self.n5418e = self.n6547
    self.n5418w = self.n5413
    self.n5418aw = self.n5256
    self.n5418ar = self.n5368
    self.n5418dw = self.n5199
    self.n5345e = self.n6547
    self.n5345w = self.n5340
    self.n5345aw = self.n5256
    self.n5345ar = self.n5295
    self.n5345dw = self.n5199
    if self.n5055:
      self.n5060 = self.n5017
    else:
      self.n5060 = self.n5059
    if self.n5036:
      self.n5041 = self.n5002
    else:
      self.n5041 = self.n5040
    if self.n4969:
      self.n4978 = self.n4935
    else:
      self.n4978 = self.n4977
    if self.n4953:
      self.n4956 = self.n4917
    else:
      self.n4956 = self.n4955
    self.n4899e = self.n6547
    self.n4899w = self.n4894
    self.n4899aw = self.n4737
    self.n4899ar = self.n4849
    self.n4899dw = self.n4680
    self.n4826e = self.n6547
    self.n4826w = self.n4821
    self.n4826aw = self.n4737
    self.n4826ar = self.n4776
    self.n4826dw = self.n4680
    if self.n4536:
      self.n4541 = self.n4498
    else:
      self.n4541 = self.n4540
    if self.n4517:
      self.n4522 = self.n4483
    else:
      self.n4522 = self.n4521
    if self.n4450:
      self.n4459 = self.n4416
    else:
      self.n4459 = self.n4458
    if self.n4434:
      self.n4437 = self.n4398
    else:
      self.n4437 = self.n4436
    self.n4380e = self.n6547
    self.n4380w = self.n4375
    self.n4380aw = self.n4218
    self.n4380ar = self.n4330
    self.n4380dw = self.n4161
    self.n4307e = self.n6547
    self.n4307w = self.n4302
    self.n4307aw = self.n4218
    self.n4307ar = self.n4257
    self.n4307dw = self.n4161
    if self.n4017:
      self.n4022 = self.n3979
    else:
      self.n4022 = self.n4021
    if self.n3998:
      self.n4003 = self.n3964
    else:
      self.n4003 = self.n4002
    if self.n3931:
      self.n3940 = self.n3897
    else:
      self.n3940 = self.n3939
    if self.n3915:
      self.n3918 = self.n3879
    else:
      self.n3918 = self.n3917
    self.n3861e = self.n6547
    self.n3861w = self.n3856
    self.n3861aw = self.n3699
    self.n3861ar = self.n3811
    self.n3861dw = self.n3642
    self.n3788e = self.n6547
    self.n3788w = self.n3783
    self.n3788aw = self.n3699
    self.n3788ar = self.n3738
    self.n3788dw = self.n3642
    if self.n3498:
      self.n3503 = self.n3460
    else:
      self.n3503 = self.n3502
    if self.n3479:
      self.n3484 = self.n3445
    else:
      self.n3484 = self.n3483
    if self.n3412:
      self.n3421 = self.n3378
    else:
      self.n3421 = self.n3420
    if self.n3396:
      self.n3399 = self.n3360
    else:
      self.n3399 = self.n3398
    self.n3342e = self.n6547
    self.n3342w = self.n3337
    self.n3342aw = self.n3180
    self.n3342ar = self.n3292
    self.n3342dw = self.n3123
    self.n3269e = self.n6547
    self.n3269w = self.n3264
    self.n3269aw = self.n3180
    self.n3269ar = self.n3219
    self.n3269dw = self.n3123
    if self.n2979:
      self.n2984 = self.n2941
    else:
      self.n2984 = self.n2983
    if self.n2960:
      self.n2965 = self.n2926
    else:
      self.n2965 = self.n2964
    if self.n2893:
      self.n2902 = self.n2859
    else:
      self.n2902 = self.n2901
    if self.n2877:
      self.n2880 = self.n2841
    else:
      self.n2880 = self.n2879
    self.n2823e = self.n6547
    self.n2823w = self.n2818
    self.n2823aw = self.n2661
    self.n2823ar = self.n2773
    self.n2823dw = self.n2604
    self.n2750e = self.n6547
    self.n2750w = self.n2745
    self.n2750aw = self.n2661
    self.n2750ar = self.n2700
    self.n2750dw = self.n2604
    if self.n2460:
      self.n2465 = self.n2422
    else:
      self.n2465 = self.n2464
    if self.n2441:
      self.n2446 = self.n2407
    else:
      self.n2446 = self.n2445
    if self.n2374:
      self.n2383 = self.n2340
    else:
      self.n2383 = self.n2382
    if self.n2358:
      self.n2361 = self.n2322
    else:
      self.n2361 = self.n2360
    self.n2304e = self.n6547
    self.n2304w = self.n2299
    self.n2304aw = self.n2142
    self.n2304ar = self.n2254
    self.n2304dw = self.n2085
    self.n2231e = self.n6547
    self.n2231w = self.n2226
    self.n2231aw = self.n2142
    self.n2231ar = self.n2181
    self.n2231dw = self.n2085
    if self.n1941:
      self.n1946 = self.n1903
    else:
      self.n1946 = self.n1945
    if self.n1922:
      self.n1927 = self.n1888
    else:
      self.n1927 = self.n1926
    if self.n1855:
      self.n1864 = self.n1821
    else:
      self.n1864 = self.n1863
    if self.n1839:
      self.n1842 = self.n1803
    else:
      self.n1842 = self.n1841
    self.n1785e = self.n6547
    self.n1785w = self.n1780
    self.n1785aw = self.n1623
    self.n1785ar = self.n1735
    self.n1785dw = self.n1566
    self.n1712e = self.n6547
    self.n1712w = self.n1707
    self.n1712aw = self.n1623
    self.n1712ar = self.n1662
    self.n1712dw = self.n1566
    if self.n1422:
      self.n1427 = self.n1384
    else:
      self.n1427 = self.n1426
    if self.n1403:
      self.n1408 = self.n1369
    else:
      self.n1408 = self.n1407
    if self.n1336:
      self.n1345 = self.n1302
    else:
      self.n1345 = self.n1344
    if self.n1320:
      self.n1323 = self.n1284
    else:
      self.n1323 = self.n1322
    self.n1266e = self.n6547
    self.n1266w = self.n1261
    self.n1266aw = self.n1104
    self.n1266ar = self.n1216
    self.n1266dw = self.n1047
    self.n1193e = self.n6547
    self.n1193w = self.n1188
    self.n1193aw = self.n1104
    self.n1193ar = self.n1143
    self.n1193dw = self.n1047
    if self.n903:
      self.n908 = self.n865
    else:
      self.n908 = self.n907
    if self.n884:
      self.n889 = self.n850
    else:
      self.n889 = self.n888
    if self.n817:
      self.n826 = self.n783
    else:
      self.n826 = self.n825
    if self.n801:
      self.n804 = self.n765
    else:
      self.n804 = self.n803
    self.n747e = self.n6547
    self.n747w = self.n742
    self.n747aw = self.n585
    self.n747ar = self.n697
    self.n747dw = self.n528
    self.n674e = self.n6547
    self.n674w = self.n669
    self.n674aw = self.n585
    self.n674ar = self.n624
    self.n674dw = self.n528
    if self.n384:
      self.n389 = self.n346
    else:
      self.n389 = self.n388
    if self.n365:
      self.n370 = self.n331
    else:
      self.n370 = self.n369
    if self.n298:
      self.n307 = self.n264
    else:
      self.n307 = self.n306
    if self.n282:
      self.n285 = self.n246
    else:
      self.n285 = self.n284
    if self.n207:
      self.n212 = self.n189
    else:
      self.n212 = self.n211
    if self.n197:
      self.n200 = self.n181
    else:
      self.n200 = self.n199
    if self.n134:
      self.n139 = self.n116
    else:
      self.n139 = self.n138
    if self.n124:
      self.n127 = self.n108
    else:
      self.n127 = self.n126
    if self.n74:
      self.n79 = self.n36
    else:
      self.n79 = self.n78
    if self.n55:
      self.n60 = self.n21
    else:
      self.n60 = self.n59
    if self.n6525:
      self.n6536 = self.n6493
    else:
      self.n6536 = self.n6535
    if self.n6509:
      self.n6514 = self.n6475
    else:
      self.n6514 = self.n6513
    if self.n6092:
      self.n6099 = self.n6056
    else:
      self.n6099 = self.n6098
    if self.n6073:
      self.n6080 = self.n6041
    else:
      self.n6080 = self.n6079
    if self.n6006:
      self.n6017 = self.n5974
    else:
      self.n6017 = self.n6016
    if self.n5990:
      self.n5995 = self.n5956
    else:
      self.n5995 = self.n5994
    if self.n5573:
      self.n5580 = self.n5537
    else:
      self.n5580 = self.n5579
    if self.n5554:
      self.n5561 = self.n5522
    else:
      self.n5561 = self.n5560
    if self.n5487:
      self.n5498 = self.n5455
    else:
      self.n5498 = self.n5497
    if self.n5471:
      self.n5476 = self.n5437
    else:
      self.n5476 = self.n5475
    if self.n5054:
      self.n5061 = self.n5018
    else:
      self.n5061 = self.n5060
    if self.n5035:
      self.n5042 = self.n5003
    else:
      self.n5042 = self.n5041
    if self.n4968:
      self.n4979 = self.n4936
    else:
      self.n4979 = self.n4978
    if self.n4952:
      self.n4957 = self.n4918
    else:
      self.n4957 = self.n4956
    if self.n4535:
      self.n4542 = self.n4499
    else:
      self.n4542 = self.n4541
    if self.n4516:
      self.n4523 = self.n4484
    else:
      self.n4523 = self.n4522
    if self.n4449:
      self.n4460 = self.n4417
    else:
      self.n4460 = self.n4459
    if self.n4433:
      self.n4438 = self.n4399
    else:
      self.n4438 = self.n4437
    if self.n4016:
      self.n4023 = self.n3980
    else:
      self.n4023 = self.n4022
    if self.n3997:
      self.n4004 = self.n3965
    else:
      self.n4004 = self.n4003
    if self.n3930:
      self.n3941 = self.n3898
    else:
      self.n3941 = self.n3940
    if self.n3914:
      self.n3919 = self.n3880
    else:
      self.n3919 = self.n3918
    if self.n3497:
      self.n3504 = self.n3461
    else:
      self.n3504 = self.n3503
    if self.n3478:
      self.n3485 = self.n3446
    else:
      self.n3485 = self.n3484
    if self.n3411:
      self.n3422 = self.n3379
    else:
      self.n3422 = self.n3421
    if self.n3395:
      self.n3400 = self.n3361
    else:
      self.n3400 = self.n3399
    if self.n2978:
      self.n2985 = self.n2942
    else:
      self.n2985 = self.n2984
    if self.n2959:
      self.n2966 = self.n2927
    else:
      self.n2966 = self.n2965
    if self.n2892:
      self.n2903 = self.n2860
    else:
      self.n2903 = self.n2902
    if self.n2876:
      self.n2881 = self.n2842
    else:
      self.n2881 = self.n2880
    if self.n2459:
      self.n2466 = self.n2423
    else:
      self.n2466 = self.n2465
    if self.n2440:
      self.n2447 = self.n2408
    else:
      self.n2447 = self.n2446
    if self.n2373:
      self.n2384 = self.n2341
    else:
      self.n2384 = self.n2383
    if self.n2357:
      self.n2362 = self.n2323
    else:
      self.n2362 = self.n2361
    if self.n1940:
      self.n1947 = self.n1904
    else:
      self.n1947 = self.n1946
    if self.n1921:
      self.n1928 = self.n1889
    else:
      self.n1928 = self.n1927
    if self.n1854:
      self.n1865 = self.n1822
    else:
      self.n1865 = self.n1864
    if self.n1838:
      self.n1843 = self.n1804
    else:
      self.n1843 = self.n1842
    if self.n1421:
      self.n1428 = self.n1385
    else:
      self.n1428 = self.n1427
    if self.n1402:
      self.n1409 = self.n1370
    else:
      self.n1409 = self.n1408
    if self.n1335:
      self.n1346 = self.n1303
    else:
      self.n1346 = self.n1345
    if self.n1319:
      self.n1324 = self.n1285
    else:
      self.n1324 = self.n1323
    if self.n902:
      self.n909 = self.n866
    else:
      self.n909 = self.n908
    if self.n883:
      self.n890 = self.n851
    else:
      self.n890 = self.n889
    if self.n816:
      self.n827 = self.n784
    else:
      self.n827 = self.n826
    if self.n800:
      self.n805 = self.n766
    else:
      self.n805 = self.n804
    if self.n383:
      self.n390 = self.n347
    else:
      self.n390 = self.n389
    if self.n364:
      self.n371 = self.n332
    else:
      self.n371 = self.n370
    if self.n297:
      self.n308 = self.n265
    else:
      self.n308 = self.n307
    if self.n281:
      self.n286 = self.n247
    else:
      self.n286 = self.n285
    self.n229 = self.n93 & self.n212
    self.n213 = ~self.n212 & 0x1L
    if self.n196:
      self.n201 = self.n182
    else:
      self.n201 = self.n200
    self.n156 = self.n94 & self.n139
    self.n140 = ~self.n139 & 0x1L
    if self.n123:
      self.n128 = self.n109
    else:
      self.n128 = self.n127
    if self.n73:
      self.n80 = self.n37
    else:
      self.n80 = self.n79
    if self.n54:
      self.n61 = self.n22
    else:
      self.n61 = self.n60
    if self.n6524:
      self.n6537 = self.n6494
    else:
      self.n6537 = self.n6536
    if self.n6508:
      self.n6515 = self.n6476
    else:
      self.n6515 = self.n6514
    if self.n6091:
      self.n6100 = self.n6057
    else:
      self.n6100 = self.n6099
    if self.n6072:
      self.n6081 = self.n6042
    else:
      self.n6081 = self.n6080
    if self.n6005:
      self.n6018 = self.n5975
    else:
      self.n6018 = self.n6017
    if self.n5989:
      self.n5996 = self.n5957
    else:
      self.n5996 = self.n5995
    if self.n5572:
      self.n5581 = self.n5538
    else:
      self.n5581 = self.n5580
    if self.n5553:
      self.n5562 = self.n5523
    else:
      self.n5562 = self.n5561
    if self.n5486:
      self.n5499 = self.n5456
    else:
      self.n5499 = self.n5498
    if self.n5470:
      self.n5477 = self.n5438
    else:
      self.n5477 = self.n5476
    if self.n5053:
      self.n5062 = self.n5019
    else:
      self.n5062 = self.n5061
    if self.n5034:
      self.n5043 = self.n5004
    else:
      self.n5043 = self.n5042
    if self.n4967:
      self.n4980 = self.n4937
    else:
      self.n4980 = self.n4979
    if self.n4951:
      self.n4958 = self.n4919
    else:
      self.n4958 = self.n4957
    if self.n4534:
      self.n4543 = self.n4500
    else:
      self.n4543 = self.n4542
    if self.n4515:
      self.n4524 = self.n4485
    else:
      self.n4524 = self.n4523
    if self.n4448:
      self.n4461 = self.n4418
    else:
      self.n4461 = self.n4460
    if self.n4432:
      self.n4439 = self.n4400
    else:
      self.n4439 = self.n4438
    if self.n4015:
      self.n4024 = self.n3981
    else:
      self.n4024 = self.n4023
    if self.n3996:
      self.n4005 = self.n3966
    else:
      self.n4005 = self.n4004
    if self.n3929:
      self.n3942 = self.n3899
    else:
      self.n3942 = self.n3941
    if self.n3913:
      self.n3920 = self.n3881
    else:
      self.n3920 = self.n3919
    if self.n3496:
      self.n3505 = self.n3462
    else:
      self.n3505 = self.n3504
    if self.n3477:
      self.n3486 = self.n3447
    else:
      self.n3486 = self.n3485
    if self.n3410:
      self.n3423 = self.n3380
    else:
      self.n3423 = self.n3422
    if self.n3394:
      self.n3401 = self.n3362
    else:
      self.n3401 = self.n3400
    if self.n2977:
      self.n2986 = self.n2943
    else:
      self.n2986 = self.n2985
    if self.n2958:
      self.n2967 = self.n2928
    else:
      self.n2967 = self.n2966
    if self.n2891:
      self.n2904 = self.n2861
    else:
      self.n2904 = self.n2903
    if self.n2875:
      self.n2882 = self.n2843
    else:
      self.n2882 = self.n2881
    if self.n2458:
      self.n2467 = self.n2424
    else:
      self.n2467 = self.n2466
    if self.n2439:
      self.n2448 = self.n2409
    else:
      self.n2448 = self.n2447
    if self.n2372:
      self.n2385 = self.n2342
    else:
      self.n2385 = self.n2384
    if self.n2356:
      self.n2363 = self.n2324
    else:
      self.n2363 = self.n2362
    if self.n1939:
      self.n1948 = self.n1905
    else:
      self.n1948 = self.n1947
    if self.n1920:
      self.n1929 = self.n1890
    else:
      self.n1929 = self.n1928
    if self.n1853:
      self.n1866 = self.n1823
    else:
      self.n1866 = self.n1865
    if self.n1837:
      self.n1844 = self.n1805
    else:
      self.n1844 = self.n1843
    if self.n1420:
      self.n1429 = self.n1386
    else:
      self.n1429 = self.n1428
    if self.n1401:
      self.n1410 = self.n1371
    else:
      self.n1410 = self.n1409
    if self.n1334:
      self.n1347 = self.n1304
    else:
      self.n1347 = self.n1346
    if self.n1318:
      self.n1325 = self.n1286
    else:
      self.n1325 = self.n1324
    if self.n901:
      self.n910 = self.n867
    else:
      self.n910 = self.n909
    if self.n882:
      self.n891 = self.n852
    else:
      self.n891 = self.n890
    if self.n815:
      self.n828 = self.n785
    else:
      self.n828 = self.n827
    if self.n799:
      self.n806 = self.n767
    else:
      self.n806 = self.n805
    if self.n382:
      self.n391 = self.n348
    else:
      self.n391 = self.n390
    if self.n363:
      self.n372 = self.n333
    else:
      self.n372 = self.n371
    if self.n296:
      self.n309 = self.n266
    else:
      self.n309 = self.n308
    if self.n280:
      self.n287 = self.n248
    else:
      self.n287 = self.n286
    self.n241r = self.n6548
    self.n241e = self.n6547
    self.n241d = self.n213
    self.n234e = self.n6547
    self.n234w = self.n229
    self.n234aw = self.n96
    self.n234ar = self.n178
    self.n234dw = self.n92
    self.n223 = self.n93 & self.n213
    self.n206r = self.n6548
    self.n206e = self.n6547
    self.n206d = self.n201
    self.n168r = self.n6548
    self.n168e = self.n6547
    self.n168d = self.n140
    self.n161e = self.n6547
    self.n161w = self.n156
    self.n161aw = self.n96
    self.n161ar = self.n105
    self.n161dw = self.n92
    self.n150 = self.n94 & self.n140
    self.n133r = self.n6548
    self.n133e = self.n6547
    self.n133d = self.n128
    if self.n72:
      self.n81 = self.n38
    else:
      self.n81 = self.n80
    if self.n53:
      self.n62 = self.n23
    else:
      self.n62 = self.n61
    if self.n6537:
      self.n6543 = self.n6541
    else:
      self.n6543 = self.n6540
    if self.n6537:
      self.n6542 = self.n6539
    else:
      self.n6542 = self.n6538
    if self.n6507:
      self.n6516 = self.n6477
    else:
      self.n6516 = self.n6515
    if self.n6090:
      self.n6101 = self.n6058
    else:
      self.n6101 = self.n6100
    if self.n6071:
      self.n6082 = self.n6043
    else:
      self.n6082 = self.n6081
    if self.n6018:
      self.n6024 = self.n6022
    else:
      self.n6024 = self.n6021
    if self.n6018:
      self.n6023 = self.n6020
    else:
      self.n6023 = self.n6019
    if self.n5988:
      self.n5997 = self.n5958
    else:
      self.n5997 = self.n5996
    if self.n5571:
      self.n5582 = self.n5539
    else:
      self.n5582 = self.n5581
    if self.n5552:
      self.n5563 = self.n5524
    else:
      self.n5563 = self.n5562
    if self.n5499:
      self.n5505 = self.n5503
    else:
      self.n5505 = self.n5502
    if self.n5499:
      self.n5504 = self.n5501
    else:
      self.n5504 = self.n5500
    if self.n5469:
      self.n5478 = self.n5439
    else:
      self.n5478 = self.n5477
    if self.n5052:
      self.n5063 = self.n5020
    else:
      self.n5063 = self.n5062
    if self.n5033:
      self.n5044 = self.n5005
    else:
      self.n5044 = self.n5043
    if self.n4980:
      self.n4986 = self.n4984
    else:
      self.n4986 = self.n4983
    if self.n4980:
      self.n4985 = self.n4982
    else:
      self.n4985 = self.n4981
    if self.n4950:
      self.n4959 = self.n4920
    else:
      self.n4959 = self.n4958
    if self.n4533:
      self.n4544 = self.n4501
    else:
      self.n4544 = self.n4543
    if self.n4514:
      self.n4525 = self.n4486
    else:
      self.n4525 = self.n4524
    if self.n4461:
      self.n4467 = self.n4465
    else:
      self.n4467 = self.n4464
    if self.n4461:
      self.n4466 = self.n4463
    else:
      self.n4466 = self.n4462
    if self.n4431:
      self.n4440 = self.n4401
    else:
      self.n4440 = self.n4439
    if self.n4014:
      self.n4025 = self.n3982
    else:
      self.n4025 = self.n4024
    if self.n3995:
      self.n4006 = self.n3967
    else:
      self.n4006 = self.n4005
    if self.n3942:
      self.n3948 = self.n3946
    else:
      self.n3948 = self.n3945
    if self.n3942:
      self.n3947 = self.n3944
    else:
      self.n3947 = self.n3943
    if self.n3912:
      self.n3921 = self.n3882
    else:
      self.n3921 = self.n3920
    if self.n3495:
      self.n3506 = self.n3463
    else:
      self.n3506 = self.n3505
    if self.n3476:
      self.n3487 = self.n3448
    else:
      self.n3487 = self.n3486
    if self.n3423:
      self.n3429 = self.n3427
    else:
      self.n3429 = self.n3426
    if self.n3423:
      self.n3428 = self.n3425
    else:
      self.n3428 = self.n3424
    if self.n3393:
      self.n3402 = self.n3363
    else:
      self.n3402 = self.n3401
    if self.n2976:
      self.n2987 = self.n2944
    else:
      self.n2987 = self.n2986
    if self.n2957:
      self.n2968 = self.n2929
    else:
      self.n2968 = self.n2967
    if self.n2904:
      self.n2910 = self.n2908
    else:
      self.n2910 = self.n2907
    if self.n2904:
      self.n2909 = self.n2906
    else:
      self.n2909 = self.n2905
    if self.n2874:
      self.n2883 = self.n2844
    else:
      self.n2883 = self.n2882
    if self.n2457:
      self.n2468 = self.n2425
    else:
      self.n2468 = self.n2467
    if self.n2438:
      self.n2449 = self.n2410
    else:
      self.n2449 = self.n2448
    if self.n2385:
      self.n2391 = self.n2389
    else:
      self.n2391 = self.n2388
    if self.n2385:
      self.n2390 = self.n2387
    else:
      self.n2390 = self.n2386
    if self.n2355:
      self.n2364 = self.n2325
    else:
      self.n2364 = self.n2363
    if self.n1938:
      self.n1949 = self.n1906
    else:
      self.n1949 = self.n1948
    if self.n1919:
      self.n1930 = self.n1891
    else:
      self.n1930 = self.n1929
    if self.n1866:
      self.n1872 = self.n1870
    else:
      self.n1872 = self.n1869
    if self.n1866:
      self.n1871 = self.n1868
    else:
      self.n1871 = self.n1867
    if self.n1836:
      self.n1845 = self.n1806
    else:
      self.n1845 = self.n1844
    if self.n1419:
      self.n1430 = self.n1387
    else:
      self.n1430 = self.n1429
    if self.n1400:
      self.n1411 = self.n1372
    else:
      self.n1411 = self.n1410
    if self.n1347:
      self.n1353 = self.n1351
    else:
      self.n1353 = self.n1350
    if self.n1347:
      self.n1352 = self.n1349
    else:
      self.n1352 = self.n1348
    if self.n1317:
      self.n1326 = self.n1287
    else:
      self.n1326 = self.n1325
    if self.n900:
      self.n911 = self.n868
    else:
      self.n911 = self.n910
    if self.n881:
      self.n892 = self.n853
    else:
      self.n892 = self.n891
    if self.n828:
      self.n834 = self.n832
    else:
      self.n834 = self.n831
    if self.n828:
      self.n833 = self.n830
    else:
      self.n833 = self.n829
    if self.n798:
      self.n807 = self.n768
    else:
      self.n807 = self.n806
    if self.n381:
      self.n392 = self.n349
    else:
      self.n392 = self.n391
    if self.n362:
      self.n373 = self.n334
    else:
      self.n373 = self.n372
    if self.n309:
      self.n315 = self.n313
    else:
      self.n315 = self.n312
    if self.n309:
      self.n314 = self.n311
    else:
      self.n314 = self.n310
    if self.n279:
      self.n288 = self.n249
    else:
      self.n288 = self.n287
    self.n228e = self.n6547
    self.n228w = self.n223
    self.n228aw = self.n96
    self.n228ar = self.n178
    self.n228dw = self.n92
    self.n155e = self.n6547
    self.n155w = self.n150
    self.n155aw = self.n96
    self.n155ar = self.n105
    self.n155dw = self.n92
    if self.n71:
      self.n82 = self.n39
    else:
      self.n82 = self.n81
    if self.n52:
      self.n63 = self.n24
    else:
      self.n63 = self.n62
    data_1_o = self.n6543
    self.n6546 = self.n6543
    data_0_o = self.n6542
    self.n6545 = self.n6542
    if self.n6506:
      self.n6517 = self.n6478
    else:
      self.n6517 = self.n6516
    self.n6127r = self.n6548
    self.n6127e = self.n6547
    self.n6127d = self.n6024
    self.n6118r = self.n6548
    self.n6118e = self.n6547
    self.n6118d = self.n6023
    if self.n6089:
      self.n6102 = self.n6059
    else:
      self.n6102 = self.n6101
    if self.n6070:
      self.n6083 = self.n6044
    else:
      self.n6083 = self.n6082
    if self.n5987:
      self.n5998 = self.n5959
    else:
      self.n5998 = self.n5997
    self.n5608r = self.n6548
    self.n5608e = self.n6547
    self.n5608d = self.n5505
    self.n5599r = self.n6548
    self.n5599e = self.n6547
    self.n5599d = self.n5504
    if self.n5570:
      self.n5583 = self.n5540
    else:
      self.n5583 = self.n5582
    if self.n5551:
      self.n5564 = self.n5525
    else:
      self.n5564 = self.n5563
    if self.n5468:
      self.n5479 = self.n5440
    else:
      self.n5479 = self.n5478
    self.n5089r = self.n6548
    self.n5089e = self.n6547
    self.n5089d = self.n4986
    self.n5080r = self.n6548
    self.n5080e = self.n6547
    self.n5080d = self.n4985
    if self.n5051:
      self.n5064 = self.n5021
    else:
      self.n5064 = self.n5063
    if self.n5032:
      self.n5045 = self.n5006
    else:
      self.n5045 = self.n5044
    if self.n4949:
      self.n4960 = self.n4921
    else:
      self.n4960 = self.n4959
    self.n4570r = self.n6548
    self.n4570e = self.n6547
    self.n4570d = self.n4467
    self.n4561r = self.n6548
    self.n4561e = self.n6547
    self.n4561d = self.n4466
    if self.n4532:
      self.n4545 = self.n4502
    else:
      self.n4545 = self.n4544
    if self.n4513:
      self.n4526 = self.n4487
    else:
      self.n4526 = self.n4525
    if self.n4430:
      self.n4441 = self.n4402
    else:
      self.n4441 = self.n4440
    self.n4051r = self.n6548
    self.n4051e = self.n6547
    self.n4051d = self.n3948
    self.n4042r = self.n6548
    self.n4042e = self.n6547
    self.n4042d = self.n3947
    if self.n4013:
      self.n4026 = self.n3983
    else:
      self.n4026 = self.n4025
    if self.n3994:
      self.n4007 = self.n3968
    else:
      self.n4007 = self.n4006
    if self.n3911:
      self.n3922 = self.n3883
    else:
      self.n3922 = self.n3921
    self.n3532r = self.n6548
    self.n3532e = self.n6547
    self.n3532d = self.n3429
    self.n3523r = self.n6548
    self.n3523e = self.n6547
    self.n3523d = self.n3428
    if self.n3494:
      self.n3507 = self.n3464
    else:
      self.n3507 = self.n3506
    if self.n3475:
      self.n3488 = self.n3449
    else:
      self.n3488 = self.n3487
    if self.n3392:
      self.n3403 = self.n3364
    else:
      self.n3403 = self.n3402
    self.n3013r = self.n6548
    self.n3013e = self.n6547
    self.n3013d = self.n2910
    self.n3004r = self.n6548
    self.n3004e = self.n6547
    self.n3004d = self.n2909
    if self.n2975:
      self.n2988 = self.n2945
    else:
      self.n2988 = self.n2987
    if self.n2956:
      self.n2969 = self.n2930
    else:
      self.n2969 = self.n2968
    if self.n2873:
      self.n2884 = self.n2845
    else:
      self.n2884 = self.n2883
    self.n2494r = self.n6548
    self.n2494e = self.n6547
    self.n2494d = self.n2391
    self.n2485r = self.n6548
    self.n2485e = self.n6547
    self.n2485d = self.n2390
    if self.n2456:
      self.n2469 = self.n2426
    else:
      self.n2469 = self.n2468
    if self.n2437:
      self.n2450 = self.n2411
    else:
      self.n2450 = self.n2449
    if self.n2354:
      self.n2365 = self.n2326
    else:
      self.n2365 = self.n2364
    self.n1975r = self.n6548
    self.n1975e = self.n6547
    self.n1975d = self.n1872
    self.n1966r = self.n6548
    self.n1966e = self.n6547
    self.n1966d = self.n1871
    if self.n1937:
      self.n1950 = self.n1907
    else:
      self.n1950 = self.n1949
    if self.n1918:
      self.n1931 = self.n1892
    else:
      self.n1931 = self.n1930
    if self.n1835:
      self.n1846 = self.n1807
    else:
      self.n1846 = self.n1845
    self.n1456r = self.n6548
    self.n1456e = self.n6547
    self.n1456d = self.n1353
    self.n1447r = self.n6548
    self.n1447e = self.n6547
    self.n1447d = self.n1352
    if self.n1418:
      self.n1431 = self.n1388
    else:
      self.n1431 = self.n1430
    if self.n1399:
      self.n1412 = self.n1373
    else:
      self.n1412 = self.n1411
    if self.n1316:
      self.n1327 = self.n1288
    else:
      self.n1327 = self.n1326
    self.n937r = self.n6548
    self.n937e = self.n6547
    self.n937d = self.n834
    self.n928r = self.n6548
    self.n928e = self.n6547
    self.n928d = self.n833
    if self.n899:
      self.n912 = self.n869
    else:
      self.n912 = self.n911
    if self.n880:
      self.n893 = self.n854
    else:
      self.n893 = self.n892
    if self.n797:
      self.n808 = self.n769
    else:
      self.n808 = self.n807
    self.n418r = self.n6548
    self.n418e = self.n6547
    self.n418d = self.n315
    self.n409r = self.n6548
    self.n409e = self.n6547
    self.n409d = self.n314
    if self.n380:
      self.n393 = self.n350
    else:
      self.n393 = self.n392
    if self.n361:
      self.n374 = self.n335
    else:
      self.n374 = self.n373
    if self.n278:
      self.n289 = self.n250
    else:
      self.n289 = self.n288
    if self.n70:
      self.n83 = self.n40
    else:
      self.n83 = self.n82
    if self.n51:
      self.n64 = self.n25
    else:
      self.n64 = self.n63
    self.n6602 = self.n83 & self.n6547
    self.n6598 = self.n393 & self.n6547
    self.n6594 = self.n912 & self.n6547
    self.n6590 = self.n1431 & self.n6547
    self.n6586 = self.n1950 & self.n6547
    self.n6582 = self.n2469 & self.n6547
    self.n6578 = self.n2988 & self.n6547
    self.n6574 = self.n3507 & self.n6547
    self.n6570 = self.n4026 & self.n6547
    self.n6566 = self.n4545 & self.n6547
    self.n6562 = self.n5064 & self.n6547
    self.n6558 = self.n5583 & self.n6547
    self.n6554 = self.n6102 & self.n6547
    if self.n6505:
      self.n6518 = self.n6479
    else:
      self.n6518 = self.n6517
    self.n6109r = self.n6548
    self.n6109e = self.n6547
    self.n6109d = self.n6102
    self.n6088r = self.n6548
    self.n6088e = self.n6547
    self.n6088d = self.n6083
    if self.n5986:
      self.n5999 = self.n5960
    else:
      self.n5999 = self.n5998
    self.n5590r = self.n6548
    self.n5590e = self.n6547
    self.n5590d = self.n5583
    self.n5569r = self.n6548
    self.n5569e = self.n6547
    self.n5569d = self.n5564
    if self.n5467:
      self.n5480 = self.n5441
    else:
      self.n5480 = self.n5479
    self.n5071r = self.n6548
    self.n5071e = self.n6547
    self.n5071d = self.n5064
    self.n5050r = self.n6548
    self.n5050e = self.n6547
    self.n5050d = self.n5045
    if self.n4948:
      self.n4961 = self.n4922
    else:
      self.n4961 = self.n4960
    self.n4552r = self.n6548
    self.n4552e = self.n6547
    self.n4552d = self.n4545
    self.n4531r = self.n6548
    self.n4531e = self.n6547
    self.n4531d = self.n4526
    if self.n4429:
      self.n4442 = self.n4403
    else:
      self.n4442 = self.n4441
    self.n4033r = self.n6548
    self.n4033e = self.n6547
    self.n4033d = self.n4026
    self.n4012r = self.n6548
    self.n4012e = self.n6547
    self.n4012d = self.n4007
    if self.n3910:
      self.n3923 = self.n3884
    else:
      self.n3923 = self.n3922
    self.n3514r = self.n6548
    self.n3514e = self.n6547
    self.n3514d = self.n3507
    self.n3493r = self.n6548
    self.n3493e = self.n6547
    self.n3493d = self.n3488
    if self.n3391:
      self.n3404 = self.n3365
    else:
      self.n3404 = self.n3403
    self.n2995r = self.n6548
    self.n2995e = self.n6547
    self.n2995d = self.n2988
    self.n2974r = self.n6548
    self.n2974e = self.n6547
    self.n2974d = self.n2969
    if self.n2872:
      self.n2885 = self.n2846
    else:
      self.n2885 = self.n2884
    self.n2476r = self.n6548
    self.n2476e = self.n6547
    self.n2476d = self.n2469
    self.n2455r = self.n6548
    self.n2455e = self.n6547
    self.n2455d = self.n2450
    if self.n2353:
      self.n2366 = self.n2327
    else:
      self.n2366 = self.n2365
    self.n1957r = self.n6548
    self.n1957e = self.n6547
    self.n1957d = self.n1950
    self.n1936r = self.n6548
    self.n1936e = self.n6547
    self.n1936d = self.n1931
    if self.n1834:
      self.n1847 = self.n1808
    else:
      self.n1847 = self.n1846
    self.n1438r = self.n6548
    self.n1438e = self.n6547
    self.n1438d = self.n1431
    self.n1417r = self.n6548
    self.n1417e = self.n6547
    self.n1417d = self.n1412
    if self.n1315:
      self.n1328 = self.n1289
    else:
      self.n1328 = self.n1327
    self.n919r = self.n6548
    self.n919e = self.n6547
    self.n919d = self.n912
    self.n898r = self.n6548
    self.n898e = self.n6547
    self.n898d = self.n893
    if self.n796:
      self.n809 = self.n770
    else:
      self.n809 = self.n808
    self.n400r = self.n6548
    self.n400e = self.n6547
    self.n400d = self.n393
    self.n379r = self.n6548
    self.n379e = self.n6547
    self.n379d = self.n374
    if self.n277:
      self.n290 = self.n251
    else:
      self.n290 = self.n289
    self.n90r = self.n6548
    self.n90e = self.n6547
    self.n90d = self.n83
    self.n69r = self.n6548
    self.n69e = self.n6547
    self.n69d = self.n64
    self.n6523r = self.n6548
    self.n6523e = self.n6547
    self.n6523d = self.n6518
    self.n6033r = self.n6553
    self.n6033e = self.n6554
    self.n6033d = self.n6028
    self.n6004r = self.n6548
    self.n6004e = self.n6547
    self.n6004d = self.n5999
    self.n5514r = self.n6557
    self.n5514e = self.n6558
    self.n5514d = self.n5509
    self.n5485r = self.n6548
    self.n5485e = self.n6547
    self.n5485d = self.n5480
    self.n4995r = self.n6561
    self.n4995e = self.n6562
    self.n4995d = self.n4990
    self.n4966r = self.n6548
    self.n4966e = self.n6547
    self.n4966d = self.n4961
    self.n4476r = self.n6565
    self.n4476e = self.n6566
    self.n4476d = self.n4471
    self.n4447r = self.n6548
    self.n4447e = self.n6547
    self.n4447d = self.n4442
    self.n3957r = self.n6569
    self.n3957e = self.n6570
    self.n3957d = self.n3952
    self.n3928r = self.n6548
    self.n3928e = self.n6547
    self.n3928d = self.n3923
    self.n3438r = self.n6573
    self.n3438e = self.n6574
    self.n3438d = self.n3433
    self.n3409r = self.n6548
    self.n3409e = self.n6547
    self.n3409d = self.n3404
    self.n2919r = self.n6577
    self.n2919e = self.n6578
    self.n2919d = self.n2914
    self.n2890r = self.n6548
    self.n2890e = self.n6547
    self.n2890d = self.n2885
    self.n2400r = self.n6581
    self.n2400e = self.n6582
    self.n2400d = self.n2395
    self.n2371r = self.n6548
    self.n2371e = self.n6547
    self.n2371d = self.n2366
    self.n1881r = self.n6585
    self.n1881e = self.n6586
    self.n1881d = self.n1876
    self.n1852r = self.n6548
    self.n1852e = self.n6547
    self.n1852d = self.n1847
    self.n1362r = self.n6589
    self.n1362e = self.n6590
    self.n1362d = self.n1357
    self.n1333r = self.n6548
    self.n1333e = self.n6547
    self.n1333d = self.n1328
    self.n843r = self.n6593
    self.n843e = self.n6594
    self.n843d = self.n838
    self.n814r = self.n6548
    self.n814e = self.n6547
    self.n814d = self.n809
    self.n324r = self.n6597
    self.n324e = self.n6598
    self.n324d = self.n319
    self.n295r = self.n6548
    self.n295e = self.n6547
    self.n295d = self.n290
    self.n14r = self.n6601
    self.n14e = self.n6602
    self.n14d = self.n9
    return (sync_o, data_0_o, data_1_o, )

  def cycle_clock(self):
    if self.n14r:
      self.n14 = 0L
    elif self.n14e:
        self.n14 = self.n14d
    if self.n69r:
      self.n69 = 0L
    elif self.n69e:
        self.n69 = self.n69d
    if self.n90r:
      self.n90 = 0L
    elif self.n90e:
        self.n90 = self.n90d
    if self.n105r:
      self.n105 = 0L
    elif self.n105e:
        self.n105 = self.n105d
    if self.n133r:
      self.n133 = 0L
    elif self.n133e:
        self.n133 = self.n133d
    if self.n147r:
      self.n147 = 0L
    elif self.n147e:
        self.n147 = self.n147d
    if self.n155e:
      if self.n155w:
        self.n155m[self.n155aw] = self.n155dw
      self.n155 = self.n155m[self.n155ar]
    if self.n161e:
      if self.n161w:
        self.n161m[self.n161aw] = self.n161dw
      self.n161 = self.n161m[self.n161ar]
    if self.n168r:
      self.n168 = 0L
    elif self.n168e:
        self.n168 = self.n168d
    if self.n178r:
      self.n178 = 0L
    elif self.n178e:
        self.n178 = self.n178d
    if self.n206r:
      self.n206 = 0L
    elif self.n206e:
        self.n206 = self.n206d
    if self.n228e:
      if self.n228w:
        self.n228m[self.n228aw] = self.n228dw
      self.n228 = self.n228m[self.n228ar]
    if self.n234e:
      if self.n234w:
        self.n234m[self.n234aw] = self.n234dw
      self.n234 = self.n234m[self.n234ar]
    if self.n241r:
      self.n241 = 0L
    elif self.n241e:
        self.n241 = self.n241d
    if self.n295r:
      self.n295 = 0L
    elif self.n295e:
        self.n295 = self.n295d
    if self.n324r:
      self.n324 = 0L
    elif self.n324e:
        self.n324 = self.n324d
    if self.n379r:
      self.n379 = 0L
    elif self.n379e:
        self.n379 = self.n379d
    if self.n400r:
      self.n400 = 0L
    elif self.n400e:
        self.n400 = self.n400d
    if self.n409r:
      self.n409 = 0L
    elif self.n409e:
        self.n409 = self.n409d
    if self.n418r:
      self.n418 = 0L
    elif self.n418e:
        self.n418 = self.n418d
    if self.n427r:
      self.n427 = 0L
    elif self.n427e:
        self.n427 = self.n427d
    if self.n434r:
      self.n434 = 0L
    elif self.n434e:
        self.n434 = self.n434d
    if self.n441r:
      self.n441 = 0L
    elif self.n441e:
        self.n441 = self.n441d
    if self.n448r:
      self.n448 = 0L
    elif self.n448e:
        self.n448 = self.n448d
    if self.n453e:
      self.n453 = self.n453m[self.n453a]
    if self.n464r:
      self.n464 = 0L
    elif self.n464e:
        self.n464 = self.n464d
    if self.n473r:
      self.n473 = 0L
    elif self.n473e:
        self.n473 = self.n473d
    if self.n481r:
      self.n481 = 0L
    elif self.n481e:
        self.n481 = self.n481d
    if self.n490r:
      self.n490 = 0L
    elif self.n490e:
        self.n490 = self.n490d
    if self.n499r:
      self.n499 = 0L
    elif self.n499e:
        self.n499 = self.n499d
    if self.n507r:
      self.n507 = 0L
    elif self.n507e:
        self.n507 = self.n507d
    if self.n517r:
      self.n517 = 0L
    elif self.n517e:
        self.n517 = self.n517d
    if self.n527r:
      self.n527 = 0L
    elif self.n527e:
        self.n527 = self.n527d
    if self.n535r:
      self.n535 = 0L
    elif self.n535e:
        self.n535 = self.n535d
    if self.n542r:
      self.n542 = 0L
    elif self.n542e:
        self.n542 = self.n542d
    if self.n549r:
      self.n549 = 0L
    elif self.n549e:
        self.n549 = self.n549d
    if self.n556r:
      self.n556 = 0L
    elif self.n556e:
        self.n556 = self.n556d
    if self.n564r:
      self.n564 = 0L
    elif self.n564e:
        self.n564 = self.n564d
    if self.n571r:
      self.n571 = 0L
    elif self.n571e:
        self.n571 = self.n571d
    if self.n578r:
      self.n578 = 0L
    elif self.n578e:
        self.n578 = self.n578d
    if self.n585r:
      self.n585 = 0L
    elif self.n585e:
        self.n585 = self.n585d
    if self.n593r:
      self.n593 = 0L
    elif self.n593e:
        self.n593 = self.n593d
    if self.n600r:
      self.n600 = 0L
    elif self.n600e:
        self.n600 = self.n600d
    if self.n607r:
      self.n607 = 0L
    elif self.n607e:
        self.n607 = self.n607d
    if self.n614r:
      self.n614 = 0L
    elif self.n614e:
        self.n614 = self.n614d
    if self.n624r:
      self.n624 = 0L
    elif self.n624e:
        self.n624 = self.n624d
    if self.n652r:
      self.n652 = 0L
    elif self.n652e:
        self.n652 = self.n652d
    if self.n666r:
      self.n666 = 0L
    elif self.n666e:
        self.n666 = self.n666d
    if self.n674e:
      if self.n674w:
        self.n674m[self.n674aw] = self.n674dw
      self.n674 = self.n674m[self.n674ar]
    if self.n680e:
      if self.n680w:
        self.n680m[self.n680aw] = self.n680dw
      self.n680 = self.n680m[self.n680ar]
    if self.n687r:
      self.n687 = 0L
    elif self.n687e:
        self.n687 = self.n687d
    if self.n697r:
      self.n697 = 0L
    elif self.n697e:
        self.n697 = self.n697d
    if self.n725r:
      self.n725 = 0L
    elif self.n725e:
        self.n725 = self.n725d
    if self.n747e:
      if self.n747w:
        self.n747m[self.n747aw] = self.n747dw
      self.n747 = self.n747m[self.n747ar]
    if self.n753e:
      if self.n753w:
        self.n753m[self.n753aw] = self.n753dw
      self.n753 = self.n753m[self.n753ar]
    if self.n760r:
      self.n760 = 0L
    elif self.n760e:
        self.n760 = self.n760d
    if self.n814r:
      self.n814 = 0L
    elif self.n814e:
        self.n814 = self.n814d
    if self.n843r:
      self.n843 = 0L
    elif self.n843e:
        self.n843 = self.n843d
    if self.n898r:
      self.n898 = 0L
    elif self.n898e:
        self.n898 = self.n898d
    if self.n919r:
      self.n919 = 0L
    elif self.n919e:
        self.n919 = self.n919d
    if self.n928r:
      self.n928 = 0L
    elif self.n928e:
        self.n928 = self.n928d
    if self.n937r:
      self.n937 = 0L
    elif self.n937e:
        self.n937 = self.n937d
    if self.n946r:
      self.n946 = 0L
    elif self.n946e:
        self.n946 = self.n946d
    if self.n953r:
      self.n953 = 0L
    elif self.n953e:
        self.n953 = self.n953d
    if self.n960r:
      self.n960 = 0L
    elif self.n960e:
        self.n960 = self.n960d
    if self.n967r:
      self.n967 = 0L
    elif self.n967e:
        self.n967 = self.n967d
    if self.n972e:
      self.n972 = self.n972m[self.n972a]
    if self.n983r:
      self.n983 = 0L
    elif self.n983e:
        self.n983 = self.n983d
    if self.n992r:
      self.n992 = 0L
    elif self.n992e:
        self.n992 = self.n992d
    if self.n1000r:
      self.n1000 = 0L
    elif self.n1000e:
        self.n1000 = self.n1000d
    if self.n1009r:
      self.n1009 = 0L
    elif self.n1009e:
        self.n1009 = self.n1009d
    if self.n1018r:
      self.n1018 = 0L
    elif self.n1018e:
        self.n1018 = self.n1018d
    if self.n1026r:
      self.n1026 = 0L
    elif self.n1026e:
        self.n1026 = self.n1026d
    if self.n1036r:
      self.n1036 = 0L
    elif self.n1036e:
        self.n1036 = self.n1036d
    if self.n1046r:
      self.n1046 = 0L
    elif self.n1046e:
        self.n1046 = self.n1046d
    if self.n1054r:
      self.n1054 = 0L
    elif self.n1054e:
        self.n1054 = self.n1054d
    if self.n1061r:
      self.n1061 = 0L
    elif self.n1061e:
        self.n1061 = self.n1061d
    if self.n1068r:
      self.n1068 = 0L
    elif self.n1068e:
        self.n1068 = self.n1068d
    if self.n1075r:
      self.n1075 = 0L
    elif self.n1075e:
        self.n1075 = self.n1075d
    if self.n1083r:
      self.n1083 = 0L
    elif self.n1083e:
        self.n1083 = self.n1083d
    if self.n1090r:
      self.n1090 = 0L
    elif self.n1090e:
        self.n1090 = self.n1090d
    if self.n1097r:
      self.n1097 = 0L
    elif self.n1097e:
        self.n1097 = self.n1097d
    if self.n1104r:
      self.n1104 = 0L
    elif self.n1104e:
        self.n1104 = self.n1104d
    if self.n1112r:
      self.n1112 = 0L
    elif self.n1112e:
        self.n1112 = self.n1112d
    if self.n1119r:
      self.n1119 = 0L
    elif self.n1119e:
        self.n1119 = self.n1119d
    if self.n1126r:
      self.n1126 = 0L
    elif self.n1126e:
        self.n1126 = self.n1126d
    if self.n1133r:
      self.n1133 = 0L
    elif self.n1133e:
        self.n1133 = self.n1133d
    if self.n1143r:
      self.n1143 = 0L
    elif self.n1143e:
        self.n1143 = self.n1143d
    if self.n1171r:
      self.n1171 = 0L
    elif self.n1171e:
        self.n1171 = self.n1171d
    if self.n1185r:
      self.n1185 = 0L
    elif self.n1185e:
        self.n1185 = self.n1185d
    if self.n1193e:
      if self.n1193w:
        self.n1193m[self.n1193aw] = self.n1193dw
      self.n1193 = self.n1193m[self.n1193ar]
    if self.n1199e:
      if self.n1199w:
        self.n1199m[self.n1199aw] = self.n1199dw
      self.n1199 = self.n1199m[self.n1199ar]
    if self.n1206r:
      self.n1206 = 0L
    elif self.n1206e:
        self.n1206 = self.n1206d
    if self.n1216r:
      self.n1216 = 0L
    elif self.n1216e:
        self.n1216 = self.n1216d
    if self.n1244r:
      self.n1244 = 0L
    elif self.n1244e:
        self.n1244 = self.n1244d
    if self.n1266e:
      if self.n1266w:
        self.n1266m[self.n1266aw] = self.n1266dw
      self.n1266 = self.n1266m[self.n1266ar]
    if self.n1272e:
      if self.n1272w:
        self.n1272m[self.n1272aw] = self.n1272dw
      self.n1272 = self.n1272m[self.n1272ar]
    if self.n1279r:
      self.n1279 = 0L
    elif self.n1279e:
        self.n1279 = self.n1279d
    if self.n1333r:
      self.n1333 = 0L
    elif self.n1333e:
        self.n1333 = self.n1333d
    if self.n1362r:
      self.n1362 = 0L
    elif self.n1362e:
        self.n1362 = self.n1362d
    if self.n1417r:
      self.n1417 = 0L
    elif self.n1417e:
        self.n1417 = self.n1417d
    if self.n1438r:
      self.n1438 = 0L
    elif self.n1438e:
        self.n1438 = self.n1438d
    if self.n1447r:
      self.n1447 = 0L
    elif self.n1447e:
        self.n1447 = self.n1447d
    if self.n1456r:
      self.n1456 = 0L
    elif self.n1456e:
        self.n1456 = self.n1456d
    if self.n1465r:
      self.n1465 = 0L
    elif self.n1465e:
        self.n1465 = self.n1465d
    if self.n1472r:
      self.n1472 = 0L
    elif self.n1472e:
        self.n1472 = self.n1472d
    if self.n1479r:
      self.n1479 = 0L
    elif self.n1479e:
        self.n1479 = self.n1479d
    if self.n1486r:
      self.n1486 = 0L
    elif self.n1486e:
        self.n1486 = self.n1486d
    if self.n1491e:
      self.n1491 = self.n1491m[self.n1491a]
    if self.n1502r:
      self.n1502 = 0L
    elif self.n1502e:
        self.n1502 = self.n1502d
    if self.n1511r:
      self.n1511 = 0L
    elif self.n1511e:
        self.n1511 = self.n1511d
    if self.n1519r:
      self.n1519 = 0L
    elif self.n1519e:
        self.n1519 = self.n1519d
    if self.n1528r:
      self.n1528 = 0L
    elif self.n1528e:
        self.n1528 = self.n1528d
    if self.n1537r:
      self.n1537 = 0L
    elif self.n1537e:
        self.n1537 = self.n1537d
    if self.n1545r:
      self.n1545 = 0L
    elif self.n1545e:
        self.n1545 = self.n1545d
    if self.n1555r:
      self.n1555 = 0L
    elif self.n1555e:
        self.n1555 = self.n1555d
    if self.n1565r:
      self.n1565 = 0L
    elif self.n1565e:
        self.n1565 = self.n1565d
    if self.n1573r:
      self.n1573 = 0L
    elif self.n1573e:
        self.n1573 = self.n1573d
    if self.n1580r:
      self.n1580 = 0L
    elif self.n1580e:
        self.n1580 = self.n1580d
    if self.n1587r:
      self.n1587 = 0L
    elif self.n1587e:
        self.n1587 = self.n1587d
    if self.n1594r:
      self.n1594 = 0L
    elif self.n1594e:
        self.n1594 = self.n1594d
    if self.n1602r:
      self.n1602 = 0L
    elif self.n1602e:
        self.n1602 = self.n1602d
    if self.n1609r:
      self.n1609 = 0L
    elif self.n1609e:
        self.n1609 = self.n1609d
    if self.n1616r:
      self.n1616 = 0L
    elif self.n1616e:
        self.n1616 = self.n1616d
    if self.n1623r:
      self.n1623 = 0L
    elif self.n1623e:
        self.n1623 = self.n1623d
    if self.n1631r:
      self.n1631 = 0L
    elif self.n1631e:
        self.n1631 = self.n1631d
    if self.n1638r:
      self.n1638 = 0L
    elif self.n1638e:
        self.n1638 = self.n1638d
    if self.n1645r:
      self.n1645 = 0L
    elif self.n1645e:
        self.n1645 = self.n1645d
    if self.n1652r:
      self.n1652 = 0L
    elif self.n1652e:
        self.n1652 = self.n1652d
    if self.n1662r:
      self.n1662 = 0L
    elif self.n1662e:
        self.n1662 = self.n1662d
    if self.n1690r:
      self.n1690 = 0L
    elif self.n1690e:
        self.n1690 = self.n1690d
    if self.n1704r:
      self.n1704 = 0L
    elif self.n1704e:
        self.n1704 = self.n1704d
    if self.n1712e:
      if self.n1712w:
        self.n1712m[self.n1712aw] = self.n1712dw
      self.n1712 = self.n1712m[self.n1712ar]
    if self.n1718e:
      if self.n1718w:
        self.n1718m[self.n1718aw] = self.n1718dw
      self.n1718 = self.n1718m[self.n1718ar]
    if self.n1725r:
      self.n1725 = 0L
    elif self.n1725e:
        self.n1725 = self.n1725d
    if self.n1735r:
      self.n1735 = 0L
    elif self.n1735e:
        self.n1735 = self.n1735d
    if self.n1763r:
      self.n1763 = 0L
    elif self.n1763e:
        self.n1763 = self.n1763d
    if self.n1785e:
      if self.n1785w:
        self.n1785m[self.n1785aw] = self.n1785dw
      self.n1785 = self.n1785m[self.n1785ar]
    if self.n1791e:
      if self.n1791w:
        self.n1791m[self.n1791aw] = self.n1791dw
      self.n1791 = self.n1791m[self.n1791ar]
    if self.n1798r:
      self.n1798 = 0L
    elif self.n1798e:
        self.n1798 = self.n1798d
    if self.n1852r:
      self.n1852 = 0L
    elif self.n1852e:
        self.n1852 = self.n1852d
    if self.n1881r:
      self.n1881 = 0L
    elif self.n1881e:
        self.n1881 = self.n1881d
    if self.n1936r:
      self.n1936 = 0L
    elif self.n1936e:
        self.n1936 = self.n1936d
    if self.n1957r:
      self.n1957 = 0L
    elif self.n1957e:
        self.n1957 = self.n1957d
    if self.n1966r:
      self.n1966 = 0L
    elif self.n1966e:
        self.n1966 = self.n1966d
    if self.n1975r:
      self.n1975 = 0L
    elif self.n1975e:
        self.n1975 = self.n1975d
    if self.n1984r:
      self.n1984 = 0L
    elif self.n1984e:
        self.n1984 = self.n1984d
    if self.n1991r:
      self.n1991 = 0L
    elif self.n1991e:
        self.n1991 = self.n1991d
    if self.n1998r:
      self.n1998 = 0L
    elif self.n1998e:
        self.n1998 = self.n1998d
    if self.n2005r:
      self.n2005 = 0L
    elif self.n2005e:
        self.n2005 = self.n2005d
    if self.n2010e:
      self.n2010 = self.n2010m[self.n2010a]
    if self.n2021r:
      self.n2021 = 0L
    elif self.n2021e:
        self.n2021 = self.n2021d
    if self.n2030r:
      self.n2030 = 0L
    elif self.n2030e:
        self.n2030 = self.n2030d
    if self.n2038r:
      self.n2038 = 0L
    elif self.n2038e:
        self.n2038 = self.n2038d
    if self.n2047r:
      self.n2047 = 0L
    elif self.n2047e:
        self.n2047 = self.n2047d
    if self.n2056r:
      self.n2056 = 0L
    elif self.n2056e:
        self.n2056 = self.n2056d
    if self.n2064r:
      self.n2064 = 0L
    elif self.n2064e:
        self.n2064 = self.n2064d
    if self.n2074r:
      self.n2074 = 0L
    elif self.n2074e:
        self.n2074 = self.n2074d
    if self.n2084r:
      self.n2084 = 0L
    elif self.n2084e:
        self.n2084 = self.n2084d
    if self.n2092r:
      self.n2092 = 0L
    elif self.n2092e:
        self.n2092 = self.n2092d
    if self.n2099r:
      self.n2099 = 0L
    elif self.n2099e:
        self.n2099 = self.n2099d
    if self.n2106r:
      self.n2106 = 0L
    elif self.n2106e:
        self.n2106 = self.n2106d
    if self.n2113r:
      self.n2113 = 0L
    elif self.n2113e:
        self.n2113 = self.n2113d
    if self.n2121r:
      self.n2121 = 0L
    elif self.n2121e:
        self.n2121 = self.n2121d
    if self.n2128r:
      self.n2128 = 0L
    elif self.n2128e:
        self.n2128 = self.n2128d
    if self.n2135r:
      self.n2135 = 0L
    elif self.n2135e:
        self.n2135 = self.n2135d
    if self.n2142r:
      self.n2142 = 0L
    elif self.n2142e:
        self.n2142 = self.n2142d
    if self.n2150r:
      self.n2150 = 0L
    elif self.n2150e:
        self.n2150 = self.n2150d
    if self.n2157r:
      self.n2157 = 0L
    elif self.n2157e:
        self.n2157 = self.n2157d
    if self.n2164r:
      self.n2164 = 0L
    elif self.n2164e:
        self.n2164 = self.n2164d
    if self.n2171r:
      self.n2171 = 0L
    elif self.n2171e:
        self.n2171 = self.n2171d
    if self.n2181r:
      self.n2181 = 0L
    elif self.n2181e:
        self.n2181 = self.n2181d
    if self.n2209r:
      self.n2209 = 0L
    elif self.n2209e:
        self.n2209 = self.n2209d
    if self.n2223r:
      self.n2223 = 0L
    elif self.n2223e:
        self.n2223 = self.n2223d
    if self.n2231e:
      if self.n2231w:
        self.n2231m[self.n2231aw] = self.n2231dw
      self.n2231 = self.n2231m[self.n2231ar]
    if self.n2237e:
      if self.n2237w:
        self.n2237m[self.n2237aw] = self.n2237dw
      self.n2237 = self.n2237m[self.n2237ar]
    if self.n2244r:
      self.n2244 = 0L
    elif self.n2244e:
        self.n2244 = self.n2244d
    if self.n2254r:
      self.n2254 = 0L
    elif self.n2254e:
        self.n2254 = self.n2254d
    if self.n2282r:
      self.n2282 = 0L
    elif self.n2282e:
        self.n2282 = self.n2282d
    if self.n2304e:
      if self.n2304w:
        self.n2304m[self.n2304aw] = self.n2304dw
      self.n2304 = self.n2304m[self.n2304ar]
    if self.n2310e:
      if self.n2310w:
        self.n2310m[self.n2310aw] = self.n2310dw
      self.n2310 = self.n2310m[self.n2310ar]
    if self.n2317r:
      self.n2317 = 0L
    elif self.n2317e:
        self.n2317 = self.n2317d
    if self.n2371r:
      self.n2371 = 0L
    elif self.n2371e:
        self.n2371 = self.n2371d
    if self.n2400r:
      self.n2400 = 0L
    elif self.n2400e:
        self.n2400 = self.n2400d
    if self.n2455r:
      self.n2455 = 0L
    elif self.n2455e:
        self.n2455 = self.n2455d
    if self.n2476r:
      self.n2476 = 0L
    elif self.n2476e:
        self.n2476 = self.n2476d
    if self.n2485r:
      self.n2485 = 0L
    elif self.n2485e:
        self.n2485 = self.n2485d
    if self.n2494r:
      self.n2494 = 0L
    elif self.n2494e:
        self.n2494 = self.n2494d
    if self.n2503r:
      self.n2503 = 0L
    elif self.n2503e:
        self.n2503 = self.n2503d
    if self.n2510r:
      self.n2510 = 0L
    elif self.n2510e:
        self.n2510 = self.n2510d
    if self.n2517r:
      self.n2517 = 0L
    elif self.n2517e:
        self.n2517 = self.n2517d
    if self.n2524r:
      self.n2524 = 0L
    elif self.n2524e:
        self.n2524 = self.n2524d
    if self.n2529e:
      self.n2529 = self.n2529m[self.n2529a]
    if self.n2540r:
      self.n2540 = 0L
    elif self.n2540e:
        self.n2540 = self.n2540d
    if self.n2549r:
      self.n2549 = 0L
    elif self.n2549e:
        self.n2549 = self.n2549d
    if self.n2557r:
      self.n2557 = 0L
    elif self.n2557e:
        self.n2557 = self.n2557d
    if self.n2566r:
      self.n2566 = 0L
    elif self.n2566e:
        self.n2566 = self.n2566d
    if self.n2575r:
      self.n2575 = 0L
    elif self.n2575e:
        self.n2575 = self.n2575d
    if self.n2583r:
      self.n2583 = 0L
    elif self.n2583e:
        self.n2583 = self.n2583d
    if self.n2593r:
      self.n2593 = 0L
    elif self.n2593e:
        self.n2593 = self.n2593d
    if self.n2603r:
      self.n2603 = 0L
    elif self.n2603e:
        self.n2603 = self.n2603d
    if self.n2611r:
      self.n2611 = 0L
    elif self.n2611e:
        self.n2611 = self.n2611d
    if self.n2618r:
      self.n2618 = 0L
    elif self.n2618e:
        self.n2618 = self.n2618d
    if self.n2625r:
      self.n2625 = 0L
    elif self.n2625e:
        self.n2625 = self.n2625d
    if self.n2632r:
      self.n2632 = 0L
    elif self.n2632e:
        self.n2632 = self.n2632d
    if self.n2640r:
      self.n2640 = 0L
    elif self.n2640e:
        self.n2640 = self.n2640d
    if self.n2647r:
      self.n2647 = 0L
    elif self.n2647e:
        self.n2647 = self.n2647d
    if self.n2654r:
      self.n2654 = 0L
    elif self.n2654e:
        self.n2654 = self.n2654d
    if self.n2661r:
      self.n2661 = 0L
    elif self.n2661e:
        self.n2661 = self.n2661d
    if self.n2669r:
      self.n2669 = 0L
    elif self.n2669e:
        self.n2669 = self.n2669d
    if self.n2676r:
      self.n2676 = 0L
    elif self.n2676e:
        self.n2676 = self.n2676d
    if self.n2683r:
      self.n2683 = 0L
    elif self.n2683e:
        self.n2683 = self.n2683d
    if self.n2690r:
      self.n2690 = 0L
    elif self.n2690e:
        self.n2690 = self.n2690d
    if self.n2700r:
      self.n2700 = 0L
    elif self.n2700e:
        self.n2700 = self.n2700d
    if self.n2728r:
      self.n2728 = 0L
    elif self.n2728e:
        self.n2728 = self.n2728d
    if self.n2742r:
      self.n2742 = 0L
    elif self.n2742e:
        self.n2742 = self.n2742d
    if self.n2750e:
      if self.n2750w:
        self.n2750m[self.n2750aw] = self.n2750dw
      self.n2750 = self.n2750m[self.n2750ar]
    if self.n2756e:
      if self.n2756w:
        self.n2756m[self.n2756aw] = self.n2756dw
      self.n2756 = self.n2756m[self.n2756ar]
    if self.n2763r:
      self.n2763 = 0L
    elif self.n2763e:
        self.n2763 = self.n2763d
    if self.n2773r:
      self.n2773 = 0L
    elif self.n2773e:
        self.n2773 = self.n2773d
    if self.n2801r:
      self.n2801 = 0L
    elif self.n2801e:
        self.n2801 = self.n2801d
    if self.n2823e:
      if self.n2823w:
        self.n2823m[self.n2823aw] = self.n2823dw
      self.n2823 = self.n2823m[self.n2823ar]
    if self.n2829e:
      if self.n2829w:
        self.n2829m[self.n2829aw] = self.n2829dw
      self.n2829 = self.n2829m[self.n2829ar]
    if self.n2836r:
      self.n2836 = 0L
    elif self.n2836e:
        self.n2836 = self.n2836d
    if self.n2890r:
      self.n2890 = 0L
    elif self.n2890e:
        self.n2890 = self.n2890d
    if self.n2919r:
      self.n2919 = 0L
    elif self.n2919e:
        self.n2919 = self.n2919d
    if self.n2974r:
      self.n2974 = 0L
    elif self.n2974e:
        self.n2974 = self.n2974d
    if self.n2995r:
      self.n2995 = 0L
    elif self.n2995e:
        self.n2995 = self.n2995d
    if self.n3004r:
      self.n3004 = 0L
    elif self.n3004e:
        self.n3004 = self.n3004d
    if self.n3013r:
      self.n3013 = 0L
    elif self.n3013e:
        self.n3013 = self.n3013d
    if self.n3022r:
      self.n3022 = 0L
    elif self.n3022e:
        self.n3022 = self.n3022d
    if self.n3029r:
      self.n3029 = 0L
    elif self.n3029e:
        self.n3029 = self.n3029d
    if self.n3036r:
      self.n3036 = 0L
    elif self.n3036e:
        self.n3036 = self.n3036d
    if self.n3043r:
      self.n3043 = 0L
    elif self.n3043e:
        self.n3043 = self.n3043d
    if self.n3048e:
      self.n3048 = self.n3048m[self.n3048a]
    if self.n3059r:
      self.n3059 = 0L
    elif self.n3059e:
        self.n3059 = self.n3059d
    if self.n3068r:
      self.n3068 = 0L
    elif self.n3068e:
        self.n3068 = self.n3068d
    if self.n3076r:
      self.n3076 = 0L
    elif self.n3076e:
        self.n3076 = self.n3076d
    if self.n3085r:
      self.n3085 = 0L
    elif self.n3085e:
        self.n3085 = self.n3085d
    if self.n3094r:
      self.n3094 = 0L
    elif self.n3094e:
        self.n3094 = self.n3094d
    if self.n3102r:
      self.n3102 = 0L
    elif self.n3102e:
        self.n3102 = self.n3102d
    if self.n3112r:
      self.n3112 = 0L
    elif self.n3112e:
        self.n3112 = self.n3112d
    if self.n3122r:
      self.n3122 = 0L
    elif self.n3122e:
        self.n3122 = self.n3122d
    if self.n3130r:
      self.n3130 = 0L
    elif self.n3130e:
        self.n3130 = self.n3130d
    if self.n3137r:
      self.n3137 = 0L
    elif self.n3137e:
        self.n3137 = self.n3137d
    if self.n3144r:
      self.n3144 = 0L
    elif self.n3144e:
        self.n3144 = self.n3144d
    if self.n3151r:
      self.n3151 = 0L
    elif self.n3151e:
        self.n3151 = self.n3151d
    if self.n3159r:
      self.n3159 = 0L
    elif self.n3159e:
        self.n3159 = self.n3159d
    if self.n3166r:
      self.n3166 = 0L
    elif self.n3166e:
        self.n3166 = self.n3166d
    if self.n3173r:
      self.n3173 = 0L
    elif self.n3173e:
        self.n3173 = self.n3173d
    if self.n3180r:
      self.n3180 = 0L
    elif self.n3180e:
        self.n3180 = self.n3180d
    if self.n3188r:
      self.n3188 = 0L
    elif self.n3188e:
        self.n3188 = self.n3188d
    if self.n3195r:
      self.n3195 = 0L
    elif self.n3195e:
        self.n3195 = self.n3195d
    if self.n3202r:
      self.n3202 = 0L
    elif self.n3202e:
        self.n3202 = self.n3202d
    if self.n3209r:
      self.n3209 = 0L
    elif self.n3209e:
        self.n3209 = self.n3209d
    if self.n3219r:
      self.n3219 = 0L
    elif self.n3219e:
        self.n3219 = self.n3219d
    if self.n3247r:
      self.n3247 = 0L
    elif self.n3247e:
        self.n3247 = self.n3247d
    if self.n3261r:
      self.n3261 = 0L
    elif self.n3261e:
        self.n3261 = self.n3261d
    if self.n3269e:
      if self.n3269w:
        self.n3269m[self.n3269aw] = self.n3269dw
      self.n3269 = self.n3269m[self.n3269ar]
    if self.n3275e:
      if self.n3275w:
        self.n3275m[self.n3275aw] = self.n3275dw
      self.n3275 = self.n3275m[self.n3275ar]
    if self.n3282r:
      self.n3282 = 0L
    elif self.n3282e:
        self.n3282 = self.n3282d
    if self.n3292r:
      self.n3292 = 0L
    elif self.n3292e:
        self.n3292 = self.n3292d
    if self.n3320r:
      self.n3320 = 0L
    elif self.n3320e:
        self.n3320 = self.n3320d
    if self.n3342e:
      if self.n3342w:
        self.n3342m[self.n3342aw] = self.n3342dw
      self.n3342 = self.n3342m[self.n3342ar]
    if self.n3348e:
      if self.n3348w:
        self.n3348m[self.n3348aw] = self.n3348dw
      self.n3348 = self.n3348m[self.n3348ar]
    if self.n3355r:
      self.n3355 = 0L
    elif self.n3355e:
        self.n3355 = self.n3355d
    if self.n3409r:
      self.n3409 = 0L
    elif self.n3409e:
        self.n3409 = self.n3409d
    if self.n3438r:
      self.n3438 = 0L
    elif self.n3438e:
        self.n3438 = self.n3438d
    if self.n3493r:
      self.n3493 = 0L
    elif self.n3493e:
        self.n3493 = self.n3493d
    if self.n3514r:
      self.n3514 = 0L
    elif self.n3514e:
        self.n3514 = self.n3514d
    if self.n3523r:
      self.n3523 = 0L
    elif self.n3523e:
        self.n3523 = self.n3523d
    if self.n3532r:
      self.n3532 = 0L
    elif self.n3532e:
        self.n3532 = self.n3532d
    if self.n3541r:
      self.n3541 = 0L
    elif self.n3541e:
        self.n3541 = self.n3541d
    if self.n3548r:
      self.n3548 = 0L
    elif self.n3548e:
        self.n3548 = self.n3548d
    if self.n3555r:
      self.n3555 = 0L
    elif self.n3555e:
        self.n3555 = self.n3555d
    if self.n3562r:
      self.n3562 = 0L
    elif self.n3562e:
        self.n3562 = self.n3562d
    if self.n3567e:
      self.n3567 = self.n3567m[self.n3567a]
    if self.n3578r:
      self.n3578 = 0L
    elif self.n3578e:
        self.n3578 = self.n3578d
    if self.n3587r:
      self.n3587 = 0L
    elif self.n3587e:
        self.n3587 = self.n3587d
    if self.n3595r:
      self.n3595 = 0L
    elif self.n3595e:
        self.n3595 = self.n3595d
    if self.n3604r:
      self.n3604 = 0L
    elif self.n3604e:
        self.n3604 = self.n3604d
    if self.n3613r:
      self.n3613 = 0L
    elif self.n3613e:
        self.n3613 = self.n3613d
    if self.n3621r:
      self.n3621 = 0L
    elif self.n3621e:
        self.n3621 = self.n3621d
    if self.n3631r:
      self.n3631 = 0L
    elif self.n3631e:
        self.n3631 = self.n3631d
    if self.n3641r:
      self.n3641 = 0L
    elif self.n3641e:
        self.n3641 = self.n3641d
    if self.n3649r:
      self.n3649 = 0L
    elif self.n3649e:
        self.n3649 = self.n3649d
    if self.n3656r:
      self.n3656 = 0L
    elif self.n3656e:
        self.n3656 = self.n3656d
    if self.n3663r:
      self.n3663 = 0L
    elif self.n3663e:
        self.n3663 = self.n3663d
    if self.n3670r:
      self.n3670 = 0L
    elif self.n3670e:
        self.n3670 = self.n3670d
    if self.n3678r:
      self.n3678 = 0L
    elif self.n3678e:
        self.n3678 = self.n3678d
    if self.n3685r:
      self.n3685 = 0L
    elif self.n3685e:
        self.n3685 = self.n3685d
    if self.n3692r:
      self.n3692 = 0L
    elif self.n3692e:
        self.n3692 = self.n3692d
    if self.n3699r:
      self.n3699 = 0L
    elif self.n3699e:
        self.n3699 = self.n3699d
    if self.n3707r:
      self.n3707 = 0L
    elif self.n3707e:
        self.n3707 = self.n3707d
    if self.n3714r:
      self.n3714 = 0L
    elif self.n3714e:
        self.n3714 = self.n3714d
    if self.n3721r:
      self.n3721 = 0L
    elif self.n3721e:
        self.n3721 = self.n3721d
    if self.n3728r:
      self.n3728 = 0L
    elif self.n3728e:
        self.n3728 = self.n3728d
    if self.n3738r:
      self.n3738 = 0L
    elif self.n3738e:
        self.n3738 = self.n3738d
    if self.n3766r:
      self.n3766 = 0L
    elif self.n3766e:
        self.n3766 = self.n3766d
    if self.n3780r:
      self.n3780 = 0L
    elif self.n3780e:
        self.n3780 = self.n3780d
    if self.n3788e:
      if self.n3788w:
        self.n3788m[self.n3788aw] = self.n3788dw
      self.n3788 = self.n3788m[self.n3788ar]
    if self.n3794e:
      if self.n3794w:
        self.n3794m[self.n3794aw] = self.n3794dw
      self.n3794 = self.n3794m[self.n3794ar]
    if self.n3801r:
      self.n3801 = 0L
    elif self.n3801e:
        self.n3801 = self.n3801d
    if self.n3811r:
      self.n3811 = 0L
    elif self.n3811e:
        self.n3811 = self.n3811d
    if self.n3839r:
      self.n3839 = 0L
    elif self.n3839e:
        self.n3839 = self.n3839d
    if self.n3861e:
      if self.n3861w:
        self.n3861m[self.n3861aw] = self.n3861dw
      self.n3861 = self.n3861m[self.n3861ar]
    if self.n3867e:
      if self.n3867w:
        self.n3867m[self.n3867aw] = self.n3867dw
      self.n3867 = self.n3867m[self.n3867ar]
    if self.n3874r:
      self.n3874 = 0L
    elif self.n3874e:
        self.n3874 = self.n3874d
    if self.n3928r:
      self.n3928 = 0L
    elif self.n3928e:
        self.n3928 = self.n3928d
    if self.n3957r:
      self.n3957 = 0L
    elif self.n3957e:
        self.n3957 = self.n3957d
    if self.n4012r:
      self.n4012 = 0L
    elif self.n4012e:
        self.n4012 = self.n4012d
    if self.n4033r:
      self.n4033 = 0L
    elif self.n4033e:
        self.n4033 = self.n4033d
    if self.n4042r:
      self.n4042 = 0L
    elif self.n4042e:
        self.n4042 = self.n4042d
    if self.n4051r:
      self.n4051 = 0L
    elif self.n4051e:
        self.n4051 = self.n4051d
    if self.n4060r:
      self.n4060 = 0L
    elif self.n4060e:
        self.n4060 = self.n4060d
    if self.n4067r:
      self.n4067 = 0L
    elif self.n4067e:
        self.n4067 = self.n4067d
    if self.n4074r:
      self.n4074 = 0L
    elif self.n4074e:
        self.n4074 = self.n4074d
    if self.n4081r:
      self.n4081 = 0L
    elif self.n4081e:
        self.n4081 = self.n4081d
    if self.n4086e:
      self.n4086 = self.n4086m[self.n4086a]
    if self.n4097r:
      self.n4097 = 0L
    elif self.n4097e:
        self.n4097 = self.n4097d
    if self.n4106r:
      self.n4106 = 0L
    elif self.n4106e:
        self.n4106 = self.n4106d
    if self.n4114r:
      self.n4114 = 0L
    elif self.n4114e:
        self.n4114 = self.n4114d
    if self.n4123r:
      self.n4123 = 0L
    elif self.n4123e:
        self.n4123 = self.n4123d
    if self.n4132r:
      self.n4132 = 0L
    elif self.n4132e:
        self.n4132 = self.n4132d
    if self.n4140r:
      self.n4140 = 0L
    elif self.n4140e:
        self.n4140 = self.n4140d
    if self.n4150r:
      self.n4150 = 0L
    elif self.n4150e:
        self.n4150 = self.n4150d
    if self.n4160r:
      self.n4160 = 0L
    elif self.n4160e:
        self.n4160 = self.n4160d
    if self.n4168r:
      self.n4168 = 0L
    elif self.n4168e:
        self.n4168 = self.n4168d
    if self.n4175r:
      self.n4175 = 0L
    elif self.n4175e:
        self.n4175 = self.n4175d
    if self.n4182r:
      self.n4182 = 0L
    elif self.n4182e:
        self.n4182 = self.n4182d
    if self.n4189r:
      self.n4189 = 0L
    elif self.n4189e:
        self.n4189 = self.n4189d
    if self.n4197r:
      self.n4197 = 0L
    elif self.n4197e:
        self.n4197 = self.n4197d
    if self.n4204r:
      self.n4204 = 0L
    elif self.n4204e:
        self.n4204 = self.n4204d
    if self.n4211r:
      self.n4211 = 0L
    elif self.n4211e:
        self.n4211 = self.n4211d
    if self.n4218r:
      self.n4218 = 0L
    elif self.n4218e:
        self.n4218 = self.n4218d
    if self.n4226r:
      self.n4226 = 0L
    elif self.n4226e:
        self.n4226 = self.n4226d
    if self.n4233r:
      self.n4233 = 0L
    elif self.n4233e:
        self.n4233 = self.n4233d
    if self.n4240r:
      self.n4240 = 0L
    elif self.n4240e:
        self.n4240 = self.n4240d
    if self.n4247r:
      self.n4247 = 0L
    elif self.n4247e:
        self.n4247 = self.n4247d
    if self.n4257r:
      self.n4257 = 0L
    elif self.n4257e:
        self.n4257 = self.n4257d
    if self.n4285r:
      self.n4285 = 0L
    elif self.n4285e:
        self.n4285 = self.n4285d
    if self.n4299r:
      self.n4299 = 0L
    elif self.n4299e:
        self.n4299 = self.n4299d
    if self.n4307e:
      if self.n4307w:
        self.n4307m[self.n4307aw] = self.n4307dw
      self.n4307 = self.n4307m[self.n4307ar]
    if self.n4313e:
      if self.n4313w:
        self.n4313m[self.n4313aw] = self.n4313dw
      self.n4313 = self.n4313m[self.n4313ar]
    if self.n4320r:
      self.n4320 = 0L
    elif self.n4320e:
        self.n4320 = self.n4320d
    if self.n4330r:
      self.n4330 = 0L
    elif self.n4330e:
        self.n4330 = self.n4330d
    if self.n4358r:
      self.n4358 = 0L
    elif self.n4358e:
        self.n4358 = self.n4358d
    if self.n4380e:
      if self.n4380w:
        self.n4380m[self.n4380aw] = self.n4380dw
      self.n4380 = self.n4380m[self.n4380ar]
    if self.n4386e:
      if self.n4386w:
        self.n4386m[self.n4386aw] = self.n4386dw
      self.n4386 = self.n4386m[self.n4386ar]
    if self.n4393r:
      self.n4393 = 0L
    elif self.n4393e:
        self.n4393 = self.n4393d
    if self.n4447r:
      self.n4447 = 0L
    elif self.n4447e:
        self.n4447 = self.n4447d
    if self.n4476r:
      self.n4476 = 0L
    elif self.n4476e:
        self.n4476 = self.n4476d
    if self.n4531r:
      self.n4531 = 0L
    elif self.n4531e:
        self.n4531 = self.n4531d
    if self.n4552r:
      self.n4552 = 0L
    elif self.n4552e:
        self.n4552 = self.n4552d
    if self.n4561r:
      self.n4561 = 0L
    elif self.n4561e:
        self.n4561 = self.n4561d
    if self.n4570r:
      self.n4570 = 0L
    elif self.n4570e:
        self.n4570 = self.n4570d
    if self.n4579r:
      self.n4579 = 0L
    elif self.n4579e:
        self.n4579 = self.n4579d
    if self.n4586r:
      self.n4586 = 0L
    elif self.n4586e:
        self.n4586 = self.n4586d
    if self.n4593r:
      self.n4593 = 0L
    elif self.n4593e:
        self.n4593 = self.n4593d
    if self.n4600r:
      self.n4600 = 0L
    elif self.n4600e:
        self.n4600 = self.n4600d
    if self.n4605e:
      self.n4605 = self.n4605m[self.n4605a]
    if self.n4616r:
      self.n4616 = 0L
    elif self.n4616e:
        self.n4616 = self.n4616d
    if self.n4625r:
      self.n4625 = 0L
    elif self.n4625e:
        self.n4625 = self.n4625d
    if self.n4633r:
      self.n4633 = 0L
    elif self.n4633e:
        self.n4633 = self.n4633d
    if self.n4642r:
      self.n4642 = 0L
    elif self.n4642e:
        self.n4642 = self.n4642d
    if self.n4651r:
      self.n4651 = 0L
    elif self.n4651e:
        self.n4651 = self.n4651d
    if self.n4659r:
      self.n4659 = 0L
    elif self.n4659e:
        self.n4659 = self.n4659d
    if self.n4669r:
      self.n4669 = 0L
    elif self.n4669e:
        self.n4669 = self.n4669d
    if self.n4679r:
      self.n4679 = 0L
    elif self.n4679e:
        self.n4679 = self.n4679d
    if self.n4687r:
      self.n4687 = 0L
    elif self.n4687e:
        self.n4687 = self.n4687d
    if self.n4694r:
      self.n4694 = 0L
    elif self.n4694e:
        self.n4694 = self.n4694d
    if self.n4701r:
      self.n4701 = 0L
    elif self.n4701e:
        self.n4701 = self.n4701d
    if self.n4708r:
      self.n4708 = 0L
    elif self.n4708e:
        self.n4708 = self.n4708d
    if self.n4716r:
      self.n4716 = 0L
    elif self.n4716e:
        self.n4716 = self.n4716d
    if self.n4723r:
      self.n4723 = 0L
    elif self.n4723e:
        self.n4723 = self.n4723d
    if self.n4730r:
      self.n4730 = 0L
    elif self.n4730e:
        self.n4730 = self.n4730d
    if self.n4737r:
      self.n4737 = 0L
    elif self.n4737e:
        self.n4737 = self.n4737d
    if self.n4745r:
      self.n4745 = 0L
    elif self.n4745e:
        self.n4745 = self.n4745d
    if self.n4752r:
      self.n4752 = 0L
    elif self.n4752e:
        self.n4752 = self.n4752d
    if self.n4759r:
      self.n4759 = 0L
    elif self.n4759e:
        self.n4759 = self.n4759d
    if self.n4766r:
      self.n4766 = 0L
    elif self.n4766e:
        self.n4766 = self.n4766d
    if self.n4776r:
      self.n4776 = 0L
    elif self.n4776e:
        self.n4776 = self.n4776d
    if self.n4804r:
      self.n4804 = 0L
    elif self.n4804e:
        self.n4804 = self.n4804d
    if self.n4818r:
      self.n4818 = 0L
    elif self.n4818e:
        self.n4818 = self.n4818d
    if self.n4826e:
      if self.n4826w:
        self.n4826m[self.n4826aw] = self.n4826dw
      self.n4826 = self.n4826m[self.n4826ar]
    if self.n4832e:
      if self.n4832w:
        self.n4832m[self.n4832aw] = self.n4832dw
      self.n4832 = self.n4832m[self.n4832ar]
    if self.n4839r:
      self.n4839 = 0L
    elif self.n4839e:
        self.n4839 = self.n4839d
    if self.n4849r:
      self.n4849 = 0L
    elif self.n4849e:
        self.n4849 = self.n4849d
    if self.n4877r:
      self.n4877 = 0L
    elif self.n4877e:
        self.n4877 = self.n4877d
    if self.n4899e:
      if self.n4899w:
        self.n4899m[self.n4899aw] = self.n4899dw
      self.n4899 = self.n4899m[self.n4899ar]
    if self.n4905e:
      if self.n4905w:
        self.n4905m[self.n4905aw] = self.n4905dw
      self.n4905 = self.n4905m[self.n4905ar]
    if self.n4912r:
      self.n4912 = 0L
    elif self.n4912e:
        self.n4912 = self.n4912d
    if self.n4966r:
      self.n4966 = 0L
    elif self.n4966e:
        self.n4966 = self.n4966d
    if self.n4995r:
      self.n4995 = 0L
    elif self.n4995e:
        self.n4995 = self.n4995d
    if self.n5050r:
      self.n5050 = 0L
    elif self.n5050e:
        self.n5050 = self.n5050d
    if self.n5071r:
      self.n5071 = 0L
    elif self.n5071e:
        self.n5071 = self.n5071d
    if self.n5080r:
      self.n5080 = 0L
    elif self.n5080e:
        self.n5080 = self.n5080d
    if self.n5089r:
      self.n5089 = 0L
    elif self.n5089e:
        self.n5089 = self.n5089d
    if self.n5098r:
      self.n5098 = 0L
    elif self.n5098e:
        self.n5098 = self.n5098d
    if self.n5105r:
      self.n5105 = 0L
    elif self.n5105e:
        self.n5105 = self.n5105d
    if self.n5112r:
      self.n5112 = 0L
    elif self.n5112e:
        self.n5112 = self.n5112d
    if self.n5119r:
      self.n5119 = 0L
    elif self.n5119e:
        self.n5119 = self.n5119d
    if self.n5124e:
      self.n5124 = self.n5124m[self.n5124a]
    if self.n5135r:
      self.n5135 = 0L
    elif self.n5135e:
        self.n5135 = self.n5135d
    if self.n5144r:
      self.n5144 = 0L
    elif self.n5144e:
        self.n5144 = self.n5144d
    if self.n5152r:
      self.n5152 = 0L
    elif self.n5152e:
        self.n5152 = self.n5152d
    if self.n5161r:
      self.n5161 = 0L
    elif self.n5161e:
        self.n5161 = self.n5161d
    if self.n5170r:
      self.n5170 = 0L
    elif self.n5170e:
        self.n5170 = self.n5170d
    if self.n5178r:
      self.n5178 = 0L
    elif self.n5178e:
        self.n5178 = self.n5178d
    if self.n5188r:
      self.n5188 = 0L
    elif self.n5188e:
        self.n5188 = self.n5188d
    if self.n5198r:
      self.n5198 = 0L
    elif self.n5198e:
        self.n5198 = self.n5198d
    if self.n5206r:
      self.n5206 = 0L
    elif self.n5206e:
        self.n5206 = self.n5206d
    if self.n5213r:
      self.n5213 = 0L
    elif self.n5213e:
        self.n5213 = self.n5213d
    if self.n5220r:
      self.n5220 = 0L
    elif self.n5220e:
        self.n5220 = self.n5220d
    if self.n5227r:
      self.n5227 = 0L
    elif self.n5227e:
        self.n5227 = self.n5227d
    if self.n5235r:
      self.n5235 = 0L
    elif self.n5235e:
        self.n5235 = self.n5235d
    if self.n5242r:
      self.n5242 = 0L
    elif self.n5242e:
        self.n5242 = self.n5242d
    if self.n5249r:
      self.n5249 = 0L
    elif self.n5249e:
        self.n5249 = self.n5249d
    if self.n5256r:
      self.n5256 = 0L
    elif self.n5256e:
        self.n5256 = self.n5256d
    if self.n5264r:
      self.n5264 = 0L
    elif self.n5264e:
        self.n5264 = self.n5264d
    if self.n5271r:
      self.n5271 = 0L
    elif self.n5271e:
        self.n5271 = self.n5271d
    if self.n5278r:
      self.n5278 = 0L
    elif self.n5278e:
        self.n5278 = self.n5278d
    if self.n5285r:
      self.n5285 = 0L
    elif self.n5285e:
        self.n5285 = self.n5285d
    if self.n5295r:
      self.n5295 = 0L
    elif self.n5295e:
        self.n5295 = self.n5295d
    if self.n5323r:
      self.n5323 = 0L
    elif self.n5323e:
        self.n5323 = self.n5323d
    if self.n5337r:
      self.n5337 = 0L
    elif self.n5337e:
        self.n5337 = self.n5337d
    if self.n5345e:
      if self.n5345w:
        self.n5345m[self.n5345aw] = self.n5345dw
      self.n5345 = self.n5345m[self.n5345ar]
    if self.n5351e:
      if self.n5351w:
        self.n5351m[self.n5351aw] = self.n5351dw
      self.n5351 = self.n5351m[self.n5351ar]
    if self.n5358r:
      self.n5358 = 0L
    elif self.n5358e:
        self.n5358 = self.n5358d
    if self.n5368r:
      self.n5368 = 0L
    elif self.n5368e:
        self.n5368 = self.n5368d
    if self.n5396r:
      self.n5396 = 0L
    elif self.n5396e:
        self.n5396 = self.n5396d
    if self.n5418e:
      if self.n5418w:
        self.n5418m[self.n5418aw] = self.n5418dw
      self.n5418 = self.n5418m[self.n5418ar]
    if self.n5424e:
      if self.n5424w:
        self.n5424m[self.n5424aw] = self.n5424dw
      self.n5424 = self.n5424m[self.n5424ar]
    if self.n5431r:
      self.n5431 = 0L
    elif self.n5431e:
        self.n5431 = self.n5431d
    if self.n5485r:
      self.n5485 = 0L
    elif self.n5485e:
        self.n5485 = self.n5485d
    if self.n5514r:
      self.n5514 = 0L
    elif self.n5514e:
        self.n5514 = self.n5514d
    if self.n5569r:
      self.n5569 = 0L
    elif self.n5569e:
        self.n5569 = self.n5569d
    if self.n5590r:
      self.n5590 = 0L
    elif self.n5590e:
        self.n5590 = self.n5590d
    if self.n5599r:
      self.n5599 = 0L
    elif self.n5599e:
        self.n5599 = self.n5599d
    if self.n5608r:
      self.n5608 = 0L
    elif self.n5608e:
        self.n5608 = self.n5608d
    if self.n5617r:
      self.n5617 = 0L
    elif self.n5617e:
        self.n5617 = self.n5617d
    if self.n5624r:
      self.n5624 = 0L
    elif self.n5624e:
        self.n5624 = self.n5624d
    if self.n5631r:
      self.n5631 = 0L
    elif self.n5631e:
        self.n5631 = self.n5631d
    if self.n5638r:
      self.n5638 = 0L
    elif self.n5638e:
        self.n5638 = self.n5638d
    if self.n5643e:
      self.n5643 = self.n5643m[self.n5643a]
    if self.n5654r:
      self.n5654 = 0L
    elif self.n5654e:
        self.n5654 = self.n5654d
    if self.n5663r:
      self.n5663 = 0L
    elif self.n5663e:
        self.n5663 = self.n5663d
    if self.n5671r:
      self.n5671 = 0L
    elif self.n5671e:
        self.n5671 = self.n5671d
    if self.n5680r:
      self.n5680 = 0L
    elif self.n5680e:
        self.n5680 = self.n5680d
    if self.n5689r:
      self.n5689 = 0L
    elif self.n5689e:
        self.n5689 = self.n5689d
    if self.n5697r:
      self.n5697 = 0L
    elif self.n5697e:
        self.n5697 = self.n5697d
    if self.n5707r:
      self.n5707 = 0L
    elif self.n5707e:
        self.n5707 = self.n5707d
    if self.n5717r:
      self.n5717 = 0L
    elif self.n5717e:
        self.n5717 = self.n5717d
    if self.n5725r:
      self.n5725 = 0L
    elif self.n5725e:
        self.n5725 = self.n5725d
    if self.n5732r:
      self.n5732 = 0L
    elif self.n5732e:
        self.n5732 = self.n5732d
    if self.n5739r:
      self.n5739 = 0L
    elif self.n5739e:
        self.n5739 = self.n5739d
    if self.n5746r:
      self.n5746 = 0L
    elif self.n5746e:
        self.n5746 = self.n5746d
    if self.n5754r:
      self.n5754 = 0L
    elif self.n5754e:
        self.n5754 = self.n5754d
    if self.n5761r:
      self.n5761 = 0L
    elif self.n5761e:
        self.n5761 = self.n5761d
    if self.n5768r:
      self.n5768 = 0L
    elif self.n5768e:
        self.n5768 = self.n5768d
    if self.n5775r:
      self.n5775 = 0L
    elif self.n5775e:
        self.n5775 = self.n5775d
    if self.n5783r:
      self.n5783 = 0L
    elif self.n5783e:
        self.n5783 = self.n5783d
    if self.n5790r:
      self.n5790 = 0L
    elif self.n5790e:
        self.n5790 = self.n5790d
    if self.n5797r:
      self.n5797 = 0L
    elif self.n5797e:
        self.n5797 = self.n5797d
    if self.n5804r:
      self.n5804 = 0L
    elif self.n5804e:
        self.n5804 = self.n5804d
    if self.n5814r:
      self.n5814 = 0L
    elif self.n5814e:
        self.n5814 = self.n5814d
    if self.n5842r:
      self.n5842 = 0L
    elif self.n5842e:
        self.n5842 = self.n5842d
    if self.n5856r:
      self.n5856 = 0L
    elif self.n5856e:
        self.n5856 = self.n5856d
    if self.n5864e:
      if self.n5864w:
        self.n5864m[self.n5864aw] = self.n5864dw
      self.n5864 = self.n5864m[self.n5864ar]
    if self.n5870e:
      if self.n5870w:
        self.n5870m[self.n5870aw] = self.n5870dw
      self.n5870 = self.n5870m[self.n5870ar]
    if self.n5877r:
      self.n5877 = 0L
    elif self.n5877e:
        self.n5877 = self.n5877d
    if self.n5887r:
      self.n5887 = 0L
    elif self.n5887e:
        self.n5887 = self.n5887d
    if self.n5915r:
      self.n5915 = 0L
    elif self.n5915e:
        self.n5915 = self.n5915d
    if self.n5937e:
      if self.n5937w:
        self.n5937m[self.n5937aw] = self.n5937dw
      self.n5937 = self.n5937m[self.n5937ar]
    if self.n5943e:
      if self.n5943w:
        self.n5943m[self.n5943aw] = self.n5943dw
      self.n5943 = self.n5943m[self.n5943ar]
    if self.n5950r:
      self.n5950 = 0L
    elif self.n5950e:
        self.n5950 = self.n5950d
    if self.n6004r:
      self.n6004 = 0L
    elif self.n6004e:
        self.n6004 = self.n6004d
    if self.n6033r:
      self.n6033 = 0L
    elif self.n6033e:
        self.n6033 = self.n6033d
    if self.n6088r:
      self.n6088 = 0L
    elif self.n6088e:
        self.n6088 = self.n6088d
    if self.n6109r:
      self.n6109 = 0L
    elif self.n6109e:
        self.n6109 = self.n6109d
    if self.n6118r:
      self.n6118 = 0L
    elif self.n6118e:
        self.n6118 = self.n6118d
    if self.n6127r:
      self.n6127 = 0L
    elif self.n6127e:
        self.n6127 = self.n6127d
    if self.n6136r:
      self.n6136 = 0L
    elif self.n6136e:
        self.n6136 = self.n6136d
    if self.n6143r:
      self.n6143 = 0L
    elif self.n6143e:
        self.n6143 = self.n6143d
    if self.n6150r:
      self.n6150 = 0L
    elif self.n6150e:
        self.n6150 = self.n6150d
    if self.n6157r:
      self.n6157 = 0L
    elif self.n6157e:
        self.n6157 = self.n6157d
    if self.n6162e:
      self.n6162 = self.n6162m[self.n6162a]
    if self.n6173r:
      self.n6173 = 0L
    elif self.n6173e:
        self.n6173 = self.n6173d
    if self.n6182r:
      self.n6182 = 0L
    elif self.n6182e:
        self.n6182 = self.n6182d
    if self.n6190r:
      self.n6190 = 0L
    elif self.n6190e:
        self.n6190 = self.n6190d
    if self.n6199r:
      self.n6199 = 0L
    elif self.n6199e:
        self.n6199 = self.n6199d
    if self.n6208r:
      self.n6208 = 0L
    elif self.n6208e:
        self.n6208 = self.n6208d
    if self.n6216r:
      self.n6216 = 0L
    elif self.n6216e:
        self.n6216 = self.n6216d
    if self.n6226r:
      self.n6226 = 0L
    elif self.n6226e:
        self.n6226 = self.n6226d
    if self.n6236r:
      self.n6236 = 0L
    elif self.n6236e:
        self.n6236 = self.n6236d
    if self.n6244r:
      self.n6244 = 0L
    elif self.n6244e:
        self.n6244 = self.n6244d
    if self.n6251r:
      self.n6251 = 0L
    elif self.n6251e:
        self.n6251 = self.n6251d
    if self.n6258r:
      self.n6258 = 0L
    elif self.n6258e:
        self.n6258 = self.n6258d
    if self.n6265r:
      self.n6265 = 0L
    elif self.n6265e:
        self.n6265 = self.n6265d
    if self.n6273r:
      self.n6273 = 0L
    elif self.n6273e:
        self.n6273 = self.n6273d
    if self.n6280r:
      self.n6280 = 0L
    elif self.n6280e:
        self.n6280 = self.n6280d
    if self.n6287r:
      self.n6287 = 0L
    elif self.n6287e:
        self.n6287 = self.n6287d
    if self.n6294r:
      self.n6294 = 0L
    elif self.n6294e:
        self.n6294 = self.n6294d
    if self.n6302r:
      self.n6302 = 0L
    elif self.n6302e:
        self.n6302 = self.n6302d
    if self.n6309r:
      self.n6309 = 0L
    elif self.n6309e:
        self.n6309 = self.n6309d
    if self.n6316r:
      self.n6316 = 0L
    elif self.n6316e:
        self.n6316 = self.n6316d
    if self.n6323r:
      self.n6323 = 0L
    elif self.n6323e:
        self.n6323 = self.n6323d
    if self.n6333r:
      self.n6333 = 0L
    elif self.n6333e:
        self.n6333 = self.n6333d
    if self.n6361r:
      self.n6361 = 0L
    elif self.n6361e:
        self.n6361 = self.n6361d
    if self.n6375r:
      self.n6375 = 0L
    elif self.n6375e:
        self.n6375 = self.n6375d
    if self.n6383e:
      if self.n6383w:
        self.n6383m[self.n6383aw] = self.n6383dw
      self.n6383 = self.n6383m[self.n6383ar]
    if self.n6389e:
      if self.n6389w:
        self.n6389m[self.n6389aw] = self.n6389dw
      self.n6389 = self.n6389m[self.n6389ar]
    if self.n6396r:
      self.n6396 = 0L
    elif self.n6396e:
        self.n6396 = self.n6396d
    if self.n6406r:
      self.n6406 = 0L
    elif self.n6406e:
        self.n6406 = self.n6406d
    if self.n6434r:
      self.n6434 = 0L
    elif self.n6434e:
        self.n6434 = self.n6434d
    if self.n6456e:
      if self.n6456w:
        self.n6456m[self.n6456aw] = self.n6456dw
      self.n6456 = self.n6456m[self.n6456ar]
    if self.n6462e:
      if self.n6462w:
        self.n6462m[self.n6462aw] = self.n6462dw
      self.n6462 = self.n6462m[self.n6462ar]
    if self.n6469r:
      self.n6469 = 0L
    elif self.n6469e:
        self.n6469 = self.n6469d
    if self.n6523r:
      self.n6523 = 0L
    elif self.n6523e:
        self.n6523 = self.n6523d

  def sim_init(self, vcdFile):
    self.sim_file = open(vcdFile, 'w')
    self.sim_count = 1
    self.init()
    self.sim_n6547 = self.n6547
    self.sim_n6548 = self.n6548
    self.sim_n3 = self.n3
    self.sim_n4 = self.n4
    self.sim_n5 = self.n5
    self.sim_n6544 = self.n6544
    self.sim_n6545 = self.n6545
    self.sim_n6546 = self.n6546
    self.sim_file.write("$date\n")
    self.sim_file.write("  " + time.strftime("%a %b %d %H:%M:%S %Y", time.localtime()) + "\n")
    self.sim_file.write("$end\n")
    self.sim_file.write("$version\n  Confluence 0.6.3 -- Launchbird Design Systems, Inc.\n$end\n")
    self.sim_file.write("$timescale\n  1 ns\n$end\n")
    self.sim_file.write("$scope module cf_fft_4096_8 $end\n")
    self.sim_file.write("$var wire 1 ! enable_i $end\n")
    self.sim_file.write("$var wire 1 \" reset_i $end\n")
    self.sim_file.write("$var wire 1 # sync_i $end\n")
    self.sim_file.write("$var wire 16 $ data_0_i $end\n")
    self.sim_file.write("$var wire 16 % data_1_i $end\n")
    self.sim_file.write("$var wire 1 & sync_o $end\n")
    self.sim_file.write("$var wire 16 ' data_0_o $end\n")
    self.sim_file.write("$var wire 16 ( data_1_o $end\n")
    self.sim_file.write("$upscope $end\n")
    self.sim_file.write("$enddefinitions $end\n")
    self.sim_file.write("#0\n")
    self.sim_file.write("$dumpvars\n")
    if self.n6547:
      self.sim_file.write("1!\n")
    else:
      self.sim_file.write("0!\n")
    if self.n6548:
      self.sim_file.write("1\"\n")
    else:
      self.sim_file.write("0\"\n")
    if self.n3:
      self.sim_file.write("1#\n")
    else:
      self.sim_file.write("0#\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n4 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n4 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" $\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n5 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n5 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" %\n")
    if self.n6544:
      self.sim_file.write("1&\n")
    else:
      self.sim_file.write("0&\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n6545 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n6545 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" '\n")
    found = 0
    for bit in range(15, -1, -1):
      if found:
        if self.n6546 & (2L ** bit):
          self.sim_file.write("1")
        else:
          self.sim_file.write("0")
      else:
        if self.n6546 & (2L ** bit):
          self.sim_file.write("b1")
          found = 1
    if not found:
      self.sim_file.write("b0")
    self.sim_file.write(" (\n")
    self.sim_file.write("$end\n")

  def sim_end(self):
    self.sim_file.write("#%d\n" % self.sim_count)
    self.sim_file.close()

  def sim_sample(self):
    changed = 0
    if self.sim_n6547 != self.n6547:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      if self.n6547:
        self.sim_file.write("1!\n")
      else:
        self.sim_file.write("0!\n")
      self.sim_n6547 = self.n6547
    if self.sim_n6548 != self.n6548:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      if self.n6548:
        self.sim_file.write("1\"\n")
      else:
        self.sim_file.write("0\"\n")
      self.sim_n6548 = self.n6548
    if self.sim_n3 != self.n3:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      if self.n3:
        self.sim_file.write("1#\n")
      else:
        self.sim_file.write("0#\n")
      self.sim_n3 = self.n3
    if self.sim_n4 != self.n4:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n4 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n4 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" $\n")
      self.sim_n4 = self.n4
    if self.sim_n5 != self.n5:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n5 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n5 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" %\n")
      self.sim_n5 = self.n5
    if self.sim_n6544 != self.n6544:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      if self.n6544:
        self.sim_file.write("1&\n")
      else:
        self.sim_file.write("0&\n")
      self.sim_n6544 = self.n6544
    if self.sim_n6545 != self.n6545:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n6545 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n6545 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" '\n")
      self.sim_n6545 = self.n6545
    if self.sim_n6546 != self.n6546:
      if not changed:
        changed = 1
        self.sim_file.write("#%d\n" % self.sim_count)
      found = 0
      for bit in range(15, -1, -1):
        if found:
          if self.n6546 & (2L ** bit):
            self.sim_file.write("1")
          else:
            self.sim_file.write("0")
        else:
          if self.n6546 & (2L ** bit):
            self.sim_file.write("b1")
            found = 1
      if not found:
        self.sim_file.write("b0")
      self.sim_file.write(" (\n")
      self.sim_n6546 = self.n6546
    self.sim_count = self.sim_count + 1

